agentregistry library

agentregistry registries.

Classes

AgentregistryRegistryApprovalConfiguration
Typed helper for the approval_configuration block of aws_agentregistry_registry (derived from provider schema).
AgentregistryRegistryAuthorizerConfiguration
Typed helper for the discovery_configuration.authorizer_configuration block of aws_agentregistry_registry (derived from provider schema).
AgentregistryRegistryAuthorizingClaimMatchValue
Typed helper for the discovery_configuration.authorizer_configuration.custom_jwt_authorizer.custom_claim.authorizing_claim_match_value block of aws_agentregistry_registry (derived from provider schema).
AgentregistryRegistryAutoDetectionConfiguration
Typed helper for the auto_detection_configuration block of aws_agentregistry_registry (derived from provider schema).
AgentregistryRegistryClaimMatchValue
Typed helper for the discovery_configuration.authorizer_configuration.custom_jwt_authorizer.custom_claim.authorizing_claim_match_value.claim_match_value block of aws_agentregistry_registry (derived from provider schema).
AgentregistryRegistryCustomClaim
Typed helper for the discovery_configuration.authorizer_configuration.custom_jwt_authorizer.custom_claim block of aws_agentregistry_registry (derived from provider schema).
AgentregistryRegistryCustomJwtAuthorizer
Typed helper for the discovery_configuration.authorizer_configuration.custom_jwt_authorizer block of aws_agentregistry_registry (derived from provider schema).
AgentregistryRegistryDiscoveryConfiguration
Typed helper for the discovery_configuration block of aws_agentregistry_registry (derived from provider schema).
AgentregistryRegistryEncryptionConfiguration
Typed helper for the encryption_configuration block of aws_agentregistry_registry (derived from provider schema).
AgentregistryRegistryManagedVpcResource
Typed helper for the discovery_configuration.authorizer_configuration.custom_jwt_authorizer.private_endpoint.managed_vpc_resource block of aws_agentregistry_registry (derived from provider schema). Shared by every block of this shape in the resource.
AgentregistryRegistryPrivateEndpoint
Typed helper for the discovery_configuration.authorizer_configuration.custom_jwt_authorizer.private_endpoint block of aws_agentregistry_registry (derived from provider schema). Shared by every block of this shape in the resource.
AgentregistryRegistryPrivateEndpointOverride
Typed helper for the discovery_configuration.authorizer_configuration.custom_jwt_authorizer.private_endpoint_override block of aws_agentregistry_registry (derived from provider schema).
AgentregistryRegistrySelfManagedLatticeResource
Typed helper for the discovery_configuration.authorizer_configuration.custom_jwt_authorizer.private_endpoint.self_managed_lattice_resource block of aws_agentregistry_registry (derived from provider schema). Shared by every block of this shape in the resource.
AwsAgentregistryRegistry
Factory wrapper for aws_agentregistry_registry.

Enums

AgentregistryRegistryAuthorizerType
authorizer_type — derived from the provider schema description.
AgentregistryRegistryAutoApprovalRules
auto_approval_rules — derived from the provider schema description.
AgentregistryRegistryClaimMatchOperator
claim_match_operator — derived from the provider schema description.
AgentregistryRegistryEndpointIpAddressType
endpoint_ip_address_type — derived from the provider schema description.
AgentregistryRegistryInboundTokenClaimValueType
inbound_token_claim_value_type — derived from the provider schema description.
AgentregistryRegistryScope
scope — derived from the provider schema description.