appflow library

AWS AppFlow.

Classes

AppflowConnectorProfileApiKey
Typed helper for the connector_profile_config.connector_profile_credentials.custom_connector.api_key block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileBasic
Typed helper for the connector_profile_config.connector_profile_credentials.custom_connector.basic block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileBasicAuthCredentials
Typed helper for the connector_profile_config.connector_profile_credentials.sapo_data.basic_auth_credentials block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileConfig
Typed helper for the connector_profile_config block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentials
Typed helper for the connector_profile_config.connector_profile_credentials block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsAmplitude
Typed helper for the connector_profile_config.connector_profile_credentials.amplitude block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsCustomConnector
Typed helper for the connector_profile_config.connector_profile_credentials.custom_connector block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsDatadog
Typed helper for the connector_profile_config.connector_profile_credentials.datadog block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsDynatrace
Typed helper for the connector_profile_config.connector_profile_credentials.dynatrace block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsGoogleAnalytics
Typed helper for the connector_profile_config.connector_profile_credentials.google_analytics block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsHoneycode
Typed helper for the connector_profile_config.connector_profile_credentials.honeycode block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsInforNexus
Typed helper for the connector_profile_config.connector_profile_credentials.infor_nexus block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsMarketo
Typed helper for the connector_profile_config.connector_profile_credentials.marketo block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsRedshift
Typed helper for the connector_profile_config.connector_profile_credentials.redshift block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsSalesforce
Typed helper for the connector_profile_config.connector_profile_credentials.salesforce block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsSapoData
Typed helper for the connector_profile_config.connector_profile_credentials.sapo_data block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsServiceNow
Typed helper for the connector_profile_config.connector_profile_credentials.service_now block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsSingular
Typed helper for the connector_profile_config.connector_profile_credentials.singular block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsSlack
Typed helper for the connector_profile_config.connector_profile_credentials.slack block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsSnowflake
Typed helper for the connector_profile_config.connector_profile_credentials.snowflake block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsTrendmicro
Typed helper for the connector_profile_config.connector_profile_credentials.trendmicro block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsVeeva
Typed helper for the connector_profile_config.connector_profile_credentials.veeva block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCredentialsZendesk
Typed helper for the connector_profile_config.connector_profile_credentials.zendesk block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileCustom
Typed helper for the connector_profile_config.connector_profile_credentials.custom_connector.custom block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileOauth2
Typed helper for the connector_profile_config.connector_profile_credentials.custom_connector.oauth2 block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileOauth2Properties
Typed helper for the connector_profile_config.connector_profile_properties.custom_connector.oauth2_properties block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileOauthCredentials
Typed helper for the connector_profile_config.connector_profile_credentials.sapo_data.oauth_credentials block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileOauthProperties
Typed helper for the connector_profile_config.connector_profile_properties.sapo_data.oauth_properties block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfileOauthRequest
Typed helper for the connector_profile_config.connector_profile_credentials.google_analytics.oauth_request block of aws_appflow_connector_profile (derived from provider schema). Shared by every block of this shape in the resource.
AppflowConnectorProfileProperties
Typed helper for the connector_profile_config.connector_profile_properties block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesAmplitude
Typed helper for the connector_profile_config.connector_profile_properties.amplitude block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesCustomConnector
Typed helper for the connector_profile_config.connector_profile_properties.custom_connector block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesDatadog
Typed helper for the connector_profile_config.connector_profile_properties.datadog block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesDynatrace
Typed helper for the connector_profile_config.connector_profile_properties.dynatrace block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesGoogleAnalytics
Typed helper for the connector_profile_config.connector_profile_properties.google_analytics block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesHoneycode
Typed helper for the connector_profile_config.connector_profile_properties.honeycode block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesInforNexus
Typed helper for the connector_profile_config.connector_profile_properties.infor_nexus block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesMarketo
Typed helper for the connector_profile_config.connector_profile_properties.marketo block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesRedshift
Typed helper for the connector_profile_config.connector_profile_properties.redshift block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesSalesforce
Typed helper for the connector_profile_config.connector_profile_properties.salesforce block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesSapoData
Typed helper for the connector_profile_config.connector_profile_properties.sapo_data block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesServiceNow
Typed helper for the connector_profile_config.connector_profile_properties.service_now block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesSingular
Typed helper for the connector_profile_config.connector_profile_properties.singular block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesSlack
Typed helper for the connector_profile_config.connector_profile_properties.slack block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesSnowflake
Typed helper for the connector_profile_config.connector_profile_properties.snowflake block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesTrendmicro
Typed helper for the connector_profile_config.connector_profile_properties.trendmicro block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesVeeva
Typed helper for the connector_profile_config.connector_profile_properties.veeva block of aws_appflow_connector_profile (derived from provider schema).
AppflowConnectorProfilePropertiesZendesk
Typed helper for the connector_profile_config.connector_profile_properties.zendesk block of aws_appflow_connector_profile (derived from provider schema).
AppflowFlowConnectorOperator
Typed helper for the task.connector_operator block of aws_appflow_flow (derived from provider schema).
AppflowFlowCustomerProfiles
Typed helper for the destination_flow_config.destination_connector_properties.customer_profiles block of aws_appflow_flow (derived from provider schema).
AppflowFlowDestinationConnectorProperties
Typed helper for the destination_flow_config.destination_connector_properties block of aws_appflow_flow (derived from provider schema).
AppflowFlowDestinationConnectorPropertiesCustomConnector
Typed helper for the destination_flow_config.destination_connector_properties.custom_connector block of aws_appflow_flow (derived from provider schema).
AppflowFlowDestinationConnectorPropertiesMarketo
Typed helper for the destination_flow_config.destination_connector_properties.marketo block of aws_appflow_flow (derived from provider schema).
AppflowFlowDestinationConnectorPropertiesS3
Typed helper for the destination_flow_config.destination_connector_properties.s3 block of aws_appflow_flow (derived from provider schema).
AppflowFlowDestinationConnectorPropertiesS3OutputFormatConfig
Typed helper for the destination_flow_config.destination_connector_properties.s3.s3_output_format_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowDestinationConnectorPropertiesSalesforce
Typed helper for the destination_flow_config.destination_connector_properties.salesforce block of aws_appflow_flow (derived from provider schema).
AppflowFlowDestinationConnectorPropertiesSapoData
Typed helper for the destination_flow_config.destination_connector_properties.sapo_data block of aws_appflow_flow (derived from provider schema).
AppflowFlowDestinationConnectorPropertiesZendesk
Typed helper for the destination_flow_config.destination_connector_properties.zendesk block of aws_appflow_flow (derived from provider schema).
AppflowFlowDestinationFlowConfig
Typed helper for the destination_flow_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowErrorHandlingConfig
Typed helper for the destination_flow_config.destination_connector_properties.custom_connector.error_handling_config block of aws_appflow_flow (derived from provider schema). Shared by every block of this shape in the resource.
AppflowFlowEventBridge
Typed helper for the destination_flow_config.destination_connector_properties.event_bridge block of aws_appflow_flow (derived from provider schema).
AppflowFlowGlueDataCatalog
Typed helper for the metadata_catalog_config.glue_data_catalog block of aws_appflow_flow (derived from provider schema).
AppflowFlowHoneycode
Typed helper for the destination_flow_config.destination_connector_properties.honeycode block of aws_appflow_flow (derived from provider schema).
AppflowFlowIncrementalPullConfig
Typed helper for the source_flow_config.incremental_pull_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowLookoutMetrics
Typed helper for the destination_flow_config.destination_connector_properties.lookout_metrics block of aws_appflow_flow (derived from provider schema).
AppflowFlowMetadataCatalogConfig
Typed helper for the metadata_catalog_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowPaginationConfig
Typed helper for the source_flow_config.source_connector_properties.sapo_data.pagination_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowParallelismConfig
Typed helper for the source_flow_config.source_connector_properties.sapo_data.parallelism_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowRedshift
Typed helper for the destination_flow_config.destination_connector_properties.redshift block of aws_appflow_flow (derived from provider schema).
AppflowFlowS3AggregationConfig
Typed helper for the destination_flow_config.destination_connector_properties.s3.s3_output_format_config.aggregation_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowS3InputFormatConfig
Typed helper for the source_flow_config.source_connector_properties.s3.s3_input_format_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowS3PrefixConfig
Typed helper for the destination_flow_config.destination_connector_properties.s3.s3_output_format_config.prefix_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowScheduled
Typed helper for the trigger_config.trigger_properties.scheduled block of aws_appflow_flow (derived from provider schema).
AppflowFlowSnowflake
Typed helper for the destination_flow_config.destination_connector_properties.snowflake block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorProperties
Typed helper for the source_flow_config.source_connector_properties block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesAmplitude
Typed helper for the source_flow_config.source_connector_properties.amplitude block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesCustomConnector
Typed helper for the source_flow_config.source_connector_properties.custom_connector block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesDatadog
Typed helper for the source_flow_config.source_connector_properties.datadog block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesDynatrace
Typed helper for the source_flow_config.source_connector_properties.dynatrace block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesGoogleAnalytics
Typed helper for the source_flow_config.source_connector_properties.google_analytics block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesInforNexus
Typed helper for the source_flow_config.source_connector_properties.infor_nexus block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesMarketo
Typed helper for the source_flow_config.source_connector_properties.marketo block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesS3
Typed helper for the source_flow_config.source_connector_properties.s3 block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesSalesforce
Typed helper for the source_flow_config.source_connector_properties.salesforce block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesSapoData
Typed helper for the source_flow_config.source_connector_properties.sapo_data block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesServiceNow
Typed helper for the source_flow_config.source_connector_properties.service_now block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesSingular
Typed helper for the source_flow_config.source_connector_properties.singular block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesSlack
Typed helper for the source_flow_config.source_connector_properties.slack block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesTrendmicro
Typed helper for the source_flow_config.source_connector_properties.trendmicro block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesVeeva
Typed helper for the source_flow_config.source_connector_properties.veeva block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceConnectorPropertiesZendesk
Typed helper for the source_flow_config.source_connector_properties.zendesk block of aws_appflow_flow (derived from provider schema).
AppflowFlowSourceFlowConfig
Typed helper for the source_flow_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowSuccessResponseHandlingConfig
Typed helper for the destination_flow_config.destination_connector_properties.sapo_data.success_response_handling_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowTask
Typed helper for the task block of aws_appflow_flow (derived from provider schema).
AppflowFlowTriggerConfig
Typed helper for the trigger_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowTriggerProperties
Typed helper for the trigger_config.trigger_properties block of aws_appflow_flow (derived from provider schema).
AppflowFlowUpsolver
Typed helper for the destination_flow_config.destination_connector_properties.upsolver block of aws_appflow_flow (derived from provider schema).
AppflowFlowUpsolverAggregationConfig
Typed helper for the destination_flow_config.destination_connector_properties.upsolver.s3_output_format_config.aggregation_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowUpsolverPrefixConfig
Typed helper for the destination_flow_config.destination_connector_properties.upsolver.s3_output_format_config.prefix_config block of aws_appflow_flow (derived from provider schema).
AppflowFlowUpsolverS3OutputFormatConfig
Typed helper for the destination_flow_config.destination_connector_properties.upsolver.s3_output_format_config block of aws_appflow_flow (derived from provider schema).
AwsAppflowConnectorProfile
Factory wrapper for aws_appflow_connector_profile.
AwsAppflowFlow
Factory wrapper for aws_appflow_flow.

Enums

AppflowConnectorProfileAuthenticationType
authentication_type — derived from the provider schema description.
AppflowConnectorProfileConnectionMode
Appflow Connector Profile Connection enum for connection_mode.
AppflowConnectorProfileConnectorType
Appflow Connector Profile Connector enum for connector_type.
AppflowConnectorProfileOauth2GrantType
oauth2_grant_type — derived from the provider schema description.
AppflowFlowAggregationType
aggregation_type — derived from the provider schema description.
AppflowFlowConnectorOperatorAmplitude
amplitude — derived from the provider schema description.
AppflowFlowConnectorOperatorCustomConnector
custom_connector — derived from the provider schema description.
AppflowFlowConnectorOperatorDatadog
datadog — derived from the provider schema description.
AppflowFlowConnectorOperatorDynatrace
dynatrace — derived from the provider schema description.
AppflowFlowConnectorOperatorGoogleAnalytics
google_analytics — derived from the provider schema description.
AppflowFlowConnectorOperatorInforNexus
infor_nexus — derived from the provider schema description.
AppflowFlowConnectorOperatorMarketo
marketo — derived from the provider schema description.
AppflowFlowConnectorOperatorS3
s3 — derived from the provider schema description.
AppflowFlowConnectorOperatorSalesforce
salesforce — derived from the provider schema description.
AppflowFlowConnectorOperatorSapoData
sapo_data — derived from the provider schema description.
AppflowFlowConnectorOperatorServiceNow
service_now — derived from the provider schema description.
AppflowFlowConnectorOperatorSingular
singular — derived from the provider schema description.
AppflowFlowConnectorOperatorSlack
slack — derived from the provider schema description.
AppflowFlowConnectorOperatorTrendmicro
trendmicro — derived from the provider schema description.
AppflowFlowConnectorOperatorVeeva
veeva — derived from the provider schema description.
AppflowFlowConnectorOperatorZendesk
zendesk — derived from the provider schema description.
AppflowFlowConnectorType
connector_type — derived from the provider schema description.
AppflowFlowDataPullMode
data_pull_mode — derived from the provider schema description.
AppflowFlowDataTransferApi
data_transfer_api — derived from the provider schema description.
AppflowFlowFileType
file_type — derived from the provider schema description.
AppflowFlowPrefixFormat
prefix_format — derived from the provider schema description.
AppflowFlowPrefixHierarchy
prefix_hierarchy — derived from the provider schema description.
AppflowFlowPrefixType
prefix_type — derived from the provider schema description.
AppflowFlowS3InputFileType
s3_input_file_type — derived from the provider schema description.
AppflowFlowTaskType
task_type — derived from the provider schema description.
AppflowFlowTriggerType
trigger_type — derived from the provider schema description.
AppflowFlowWriteOperationType
write_operation_type — derived from the provider schema description.