codepipeline library

AWS CodePipeline.

Classes

AwsCodepipeline
Factory wrapper for aws_codepipeline.
AwsCodepipelineCustomActionType
Factory wrapper for aws_codepipeline_custom_action_type.
AwsCodepipelineWebhook
Factory wrapper for aws_codepipeline_webhook.
CodepipelineAction
Typed helper for the stage.action block of aws_codepipeline (derived from provider schema).
CodepipelineArtifactStore
Typed helper for the artifact_store block of aws_codepipeline (derived from provider schema).
CodepipelineBeforeEntry
Typed helper for the stage.before_entry block of aws_codepipeline (derived from provider schema).
CodepipelineBranches
Typed helper for the trigger.git_configuration.pull_request.branches block of aws_codepipeline (derived from provider schema). Shared by every block of this shape in the resource.
CodepipelineCondition
Typed helper for the stage.before_entry.condition block of aws_codepipeline (derived from provider schema). Shared by every block of this shape in the resource.
CodepipelineCustomActionTypeConfigurationProperty
Typed helper for the configuration_property block of aws_codepipeline_custom_action_type (derived from provider schema).
CodepipelineCustomActionTypeInputArtifactDetails
Typed helper for the input_artifact_details block of aws_codepipeline_custom_action_type (derived from provider schema).
CodepipelineCustomActionTypeOutputArtifactDetails
Typed helper for the output_artifact_details block of aws_codepipeline_custom_action_type (derived from provider schema).
CodepipelineCustomActionTypeSettings
Typed helper for the settings block of aws_codepipeline_custom_action_type (derived from provider schema).
CodepipelineEncryptionKey
Typed helper for the artifact_store.encryption_key block of aws_codepipeline (derived from provider schema).
CodepipelineFilePaths
Typed helper for the trigger.git_configuration.pull_request.file_paths block of aws_codepipeline (derived from provider schema). Shared by every block of this shape in the resource.
CodepipelineGitConfiguration
Typed helper for the trigger.git_configuration block of aws_codepipeline (derived from provider schema).
CodepipelineOnFailure
Typed helper for the stage.on_failure block of aws_codepipeline (derived from provider schema).
CodepipelineOnSuccess
Typed helper for the stage.on_success block of aws_codepipeline (derived from provider schema).
CodepipelineOutputArtifactsForComputeAction
Typed helper for the stage.action.output_artifacts_for_compute_action block of aws_codepipeline (derived from provider schema).
CodepipelinePullRequest
Typed helper for the trigger.git_configuration.pull_request block of aws_codepipeline (derived from provider schema).
CodepipelinePush
Typed helper for the trigger.git_configuration.push block of aws_codepipeline (derived from provider schema).
CodepipelinePushTags
Typed helper for the trigger.git_configuration.push.tags block of aws_codepipeline (derived from provider schema).
CodepipelineRetryConfiguration
Typed helper for the stage.on_failure.retry_configuration block of aws_codepipeline (derived from provider schema).
CodepipelineRule
Typed helper for the stage.before_entry.condition.rule block of aws_codepipeline (derived from provider schema). Shared by every block of this shape in the resource.
CodepipelineRuleTypeId
Typed helper for the stage.before_entry.condition.rule.rule_type_id block of aws_codepipeline (derived from provider schema). Shared by every block of this shape in the resource.
CodepipelineStage
Typed helper for the stage block of aws_codepipeline (derived from provider schema).
CodepipelineTrigger
Typed helper for the trigger block of aws_codepipeline (derived from provider schema).
CodepipelineVariable
Typed helper for the variable block of aws_codepipeline (derived from provider schema).
CodepipelineWebhookAuthenticationConfiguration
Typed helper for the authentication_configuration block of aws_codepipeline_webhook (derived from provider schema).
CodepipelineWebhookFilter
Typed helper for the filter block of aws_codepipeline_webhook (derived from provider schema).

Enums

CodepipelineCategory
category — derived from the provider schema description.
CodepipelineCustomActionType
type — derived from the provider schema description.
CodepipelineCustomActionTypeCategory
Codepipeline Custom Action Type enum for category.
CodepipelineEncryptionKeyType
type — derived from the provider schema description.
CodepipelineExecutionMode
Codepipeline Execution enum for execution_mode.
CodepipelineOwner
owner — derived from the provider schema description.
CodepipelinePipelineType
Codepipeline Pipeline enum for pipeline_type.
CodepipelineResult
result — derived from the provider schema description.
CodepipelineRetryMode
retry_mode — derived from the provider schema description.
CodepipelineType
type — derived from the provider schema description.
CodepipelineWebhookAuthentication
Codepipeline Webhook enum for authentication.