customerprofiles library

AWS Customer Profiles.

Classes

AwsCustomerprofilesDomain
Factory wrapper for aws_customerprofiles_domain.
AwsCustomerprofilesProfile
Factory wrapper for aws_customerprofiles_profile.
CustomerprofilesDomainAttributeTypesSelector
Typed helper for the rule_based_matching.attribute_types_selector block of aws_customerprofiles_domain (derived from provider schema).
CustomerprofilesDomainAutoMerging
Typed helper for the matching.auto_merging block of aws_customerprofiles_domain (derived from provider schema).
CustomerprofilesDomainConflictResolution
Typed helper for the rule_based_matching.conflict_resolution block of aws_customerprofiles_domain (derived from provider schema). Shared by every block of this shape in the resource.
CustomerprofilesDomainConsolidation
Typed helper for the matching.auto_merging.consolidation block of aws_customerprofiles_domain (derived from provider schema).
CustomerprofilesDomainExportingConfig
Typed helper for the matching.exporting_config block of aws_customerprofiles_domain (derived from provider schema). Shared by every block of this shape in the resource.
CustomerprofilesDomainJobSchedule
Typed helper for the matching.job_schedule block of aws_customerprofiles_domain (derived from provider schema).
CustomerprofilesDomainMatching
Typed helper for the matching block of aws_customerprofiles_domain (derived from provider schema).
CustomerprofilesDomainMatchingRules
Typed helper for the rule_based_matching.matching_rules block of aws_customerprofiles_domain (derived from provider schema).
CustomerprofilesDomainRuleBasedMatching
Typed helper for the rule_based_matching block of aws_customerprofiles_domain (derived from provider schema).
CustomerprofilesDomainS3Exporting
Typed helper for the matching.exporting_config.s3_exporting block of aws_customerprofiles_domain (derived from provider schema). Shared by every block of this shape in the resource.
CustomerprofilesProfileAddress
Typed helper for the address block of aws_customerprofiles_profile (derived from provider schema).
CustomerprofilesProfileBillingAddress
Typed helper for the billing_address block of aws_customerprofiles_profile (derived from provider schema).
CustomerprofilesProfileMailingAddress
Typed helper for the mailing_address block of aws_customerprofiles_profile (derived from provider schema).
CustomerprofilesProfileShippingAddress
Typed helper for the shipping_address block of aws_customerprofiles_profile (derived from provider schema).

Enums

CustomerprofilesDomainAttributeMatchingModel
attribute_matching_model — derived from the provider schema description.
CustomerprofilesDomainConflictResolvingModel
conflict_resolving_model — derived from the provider schema description.
CustomerprofilesDomainDayOfTheWeek
day_of_the_week — derived from the provider schema description.
CustomerprofilesDomainStatus
status — derived from the provider schema description.