dms library

AWS Database Migration Service.

Classes

AwsDmsCertificate
Factory wrapper for aws_dms_certificate.
AwsDmsDataProvider
Factory wrapper for aws_dms_data_provider.
AwsDmsEndpoint
Factory wrapper for aws_dms_endpoint.
AwsDmsEventSubscription
Factory wrapper for aws_dms_event_subscription.
AwsDmsInstanceProfile
Factory wrapper for aws_dms_instance_profile.
AwsDmsMigrationProject
Factory wrapper for aws_dms_migration_project.
AwsDmsReplicationConfig
Factory wrapper for aws_dms_replication_config.
AwsDmsReplicationInstance
Factory wrapper for aws_dms_replication_instance.
AwsDmsReplicationSubnetGroup
Factory wrapper for aws_dms_replication_subnet_group.
AwsDmsReplicationTask
Factory wrapper for aws_dms_replication_task.
AwsDmsS3Endpoint
Factory wrapper for aws_dms_s3_endpoint.
DmsCertificateContent
Exactly one of certificate_pem, certificate_wallet on aws_dms_certificate: the provider rejects none and more than one, so each variant sets one of them.
DmsCertificateContentCertificatePem
The DmsCertificateContent.certificatePem choice: sets certificate_pem.
DmsCertificateContentCertificateWallet
The DmsCertificateContent.certificateWallet choice: sets certificate_wallet.
DmsDataProviderDocDbSettings
Typed helper for the settings.doc_db_settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderIbmDb2LuwSettings
Typed helper for the settings.ibm_db2_luw_settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderIbmDb2ZosSettings
Typed helper for the settings.ibm_db2_zos_settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderMariaDbSettings
Typed helper for the settings.maria_db_settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderMicrosoftSqlServerSettings
Typed helper for the settings.microsoft_sql_server_settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderMongoDbSettings
Typed helper for the settings.mongo_db_settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderMysqlSettings
Typed helper for the settings.mysql_settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderOracleSettings
Typed helper for the settings.oracle_settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderPostgresqlSettings
Typed helper for the settings.postgresql_settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderRedshiftSettings
Typed helper for the settings.redshift_settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderSettings
Typed helper for the settings block of aws_dms_data_provider (derived from provider schema).
DmsDataProviderSybaseAseSettings
Typed helper for the settings.sybase_ase_settings block of aws_dms_data_provider (derived from provider schema).
DmsEndpointElasticsearchSettings
Typed helper for the elasticsearch_settings block of aws_dms_endpoint (derived from provider schema).
DmsEndpointKafkaSettings
Typed helper for the kafka_settings block of aws_dms_endpoint (derived from provider schema).
DmsEndpointKinesisSettings
Typed helper for the kinesis_settings block of aws_dms_endpoint (derived from provider schema).
DmsEndpointMongodbSettings
Typed helper for the mongodb_settings block of aws_dms_endpoint (derived from provider schema).
DmsEndpointMysqlSettings
Typed helper for the mysql_settings block of aws_dms_endpoint (derived from provider schema).
DmsEndpointOracleSettings
Typed helper for the oracle_settings block of aws_dms_endpoint (derived from provider schema).
DmsEndpointPostgresSettings
Typed helper for the postgres_settings block of aws_dms_endpoint (derived from provider schema).
DmsEndpointRedisSettings
Typed helper for the redis_settings block of aws_dms_endpoint (derived from provider schema).
DmsEndpointRedshiftSettings
Typed helper for the redshift_settings block of aws_dms_endpoint (derived from provider schema).
DmsMigrationProjectSchemaConversionApplicationAttributes
Typed helper for the schema_conversion_application_attributes block of aws_dms_migration_project (derived from provider schema).
DmsMigrationProjectSourceDataProviderDescriptor
Typed helper for the source_data_provider_descriptor block of aws_dms_migration_project (derived from provider schema).
DmsMigrationProjectTargetDataProviderDescriptor
Typed helper for the target_data_provider_descriptor block of aws_dms_migration_project (derived from provider schema).
DmsReplicationConfigComputeConfig
Typed helper for the compute_config block of aws_dms_replication_config (derived from provider schema).
DmsReplicationInstanceKerberosAuthenticationSettings
Typed helper for the kerberos_authentication_settings block of aws_dms_replication_instance (derived from provider schema).
DmsReplicationTaskCdcStart
At most one of cdc_start_position, cdc_start_time on aws_dms_replication_task: the provider rejects more than one, so each variant sets one of them and a null choice sets none.
DmsReplicationTaskCdcStartPosition
The DmsReplicationTaskCdcStart.cdcStartPosition choice: sets cdc_start_position.
DmsReplicationTaskCdcStartTime
The DmsReplicationTaskCdcStart.cdcStartTime choice: sets cdc_start_time.

Enums

DmsDataProviderAuthMechanism
auth_mechanism — derived from the provider schema description.
DmsDataProviderAuthType
auth_type — derived from the provider schema description.
DmsDataProviderEngine
Dms Data Provider enum for engine.
DmsEndpointAuthMechanism
auth_mechanism — derived from the provider schema description.
DmsEndpointCharLengthSemantics
char_length_semantics — derived from the provider schema description.
DmsEndpointDatabaseMode
database_mode — derived from the provider schema description.
DmsEndpointEncryptionMode
encryption_mode — derived from the provider schema description.
DmsEndpointEngineName
Dms Endpoint Engine enum for engine_name.
DmsEndpointMapLongVarcharAs
map_long_varchar_as — derived from the provider schema description.
DmsEndpointMessageFormat
message_format — derived from the provider schema description.
DmsEndpointMongodbSettingsAuthType
auth_type — derived from the provider schema description.
DmsEndpointMysqlSettingsAuthenticationMethod
authentication_method — derived from the provider schema description.
DmsEndpointNestingLevel
nesting_level — derived from the provider schema description.
DmsEndpointOracleSettingsAuthenticationMethod
authentication_method — derived from the provider schema description.
DmsEndpointPluginName
plugin_name — derived from the provider schema description.
DmsEndpointRedisSettingsAuthType
auth_type — derived from the provider schema description.
DmsEndpointSaslMechanism
sasl_mechanism — derived from the provider schema description.
DmsEndpointSecurityProtocol
security_protocol — derived from the provider schema description.
DmsEndpointSslMode
Dms Endpoint Ssl enum for ssl_mode.
DmsEndpointSslSecurityProtocol
ssl_security_protocol — derived from the provider schema description.
DmsEndpointTargetDbType
target_db_type — derived from the provider schema description.
DmsEndpointType
Dms Endpoint enum for endpoint_type.
DmsEventSubscriptionSourceType
Dms Event Subscription Source enum for source_type.
DmsInstanceProfileNetworkType
Dms Instance Profile Network enum for network_type.
DmsReplicationConfigReplicationType
Dms Replication Config Replication enum for replication_type.
DmsReplicationInstanceNetworkType
Dms Replication Instance Network enum for network_type.
DmsReplicationTaskMigrationType
Dms Replication Task Migration enum for migration_type.
DmsS3EndpointCannedAclForObjects
Dms S3 Endpoint Canned Acl For enum for canned_acl_for_objects.
DmsS3EndpointCompressionType
Dms S3 Endpoint Compression enum for compression_type.
DmsS3EndpointDataFormat
Dms S3 Endpoint Data enum for data_format.
DmsS3EndpointDatePartitionDelimiter
Dms S3 Endpoint Date Partition enum for date_partition_delimiter.
DmsS3EndpointDatePartitionSequence
Dms S3 Endpoint Date Partition enum for date_partition_sequence.
DmsS3EndpointEncodingType
Dms S3 Endpoint Encoding enum for encoding_type.
DmsS3EndpointEncryptionMode
Dms S3 Endpoint Encryption enum for encryption_mode.
DmsS3EndpointParquetVersion
Dms S3 Endpoint Parquet enum for parquet_version.
DmsS3EndpointSslMode
Dms S3 Endpoint Ssl enum for ssl_mode.
DmsS3EndpointType
Dms S3 Endpoint enum for endpoint_type.