dx library

AWS Direct Connect.

Classes

AwsDxBgpPeer
Factory wrapper for aws_dx_bgp_peer.
AwsDxConnection
Factory wrapper for aws_dx_connection.
AwsDxConnectionAssociation
Factory wrapper for aws_dx_connection_association.
AwsDxConnectionConfirmation
Factory wrapper for aws_dx_connection_confirmation.
AwsDxGateway
Factory wrapper for aws_dx_gateway.
AwsDxGatewayAssociation
Factory wrapper for aws_dx_gateway_association.
AwsDxGatewayAssociationProposal
Factory wrapper for aws_dx_gateway_association_proposal.
AwsDxHostedConnection
Factory wrapper for aws_dx_hosted_connection.
AwsDxHostedPrivateVirtualInterface
Factory wrapper for aws_dx_hosted_private_virtual_interface.
AwsDxHostedPrivateVirtualInterfaceAccepter
Factory wrapper for aws_dx_hosted_private_virtual_interface_accepter.
AwsDxHostedPublicVirtualInterface
Factory wrapper for aws_dx_hosted_public_virtual_interface.
AwsDxHostedPublicVirtualInterfaceAccepter
Factory wrapper for aws_dx_hosted_public_virtual_interface_accepter.
AwsDxHostedTransitVirtualInterface
Factory wrapper for aws_dx_hosted_transit_virtual_interface.
AwsDxHostedTransitVirtualInterfaceAccepter
Factory wrapper for aws_dx_hosted_transit_virtual_interface_accepter.
AwsDxLag
Factory wrapper for aws_dx_lag.
AwsDxMacsecKeyAssociation
Factory wrapper for aws_dx_macsec_key_association.
AwsDxPrivateVirtualInterface
Factory wrapper for aws_dx_private_virtual_interface.
AwsDxPublicVirtualInterface
Factory wrapper for aws_dx_public_virtual_interface.
AwsDxTransitVirtualInterface
Factory wrapper for aws_dx_transit_virtual_interface.
DxHostedPrivateVirtualInterfaceAccepterDxGatewayId
The DxHostedPrivateVirtualInterfaceAccepterGatewayId.dxGatewayId choice: sets dx_gateway_id.
DxHostedPrivateVirtualInterfaceAccepterGatewayId
Exactly one of dx_gateway_id, vpn_gateway_id on aws_dx_hosted_private_virtual_interface_accepter: the provider rejects none and more than one, so each variant sets one of them.
DxHostedPrivateVirtualInterfaceAccepterVpnGatewayId
The DxHostedPrivateVirtualInterfaceAccepterGatewayId.vpnGatewayId choice: sets vpn_gateway_id.
DxPrivateVirtualInterfaceDxGatewayId
The DxPrivateVirtualInterfaceGatewayId.dxGatewayId choice: sets dx_gateway_id.
DxPrivateVirtualInterfaceGatewayId
Exactly one of dx_gateway_id, vpn_gateway_id on aws_dx_private_virtual_interface: the provider rejects none and more than one, so each variant sets one of them.
DxPrivateVirtualInterfaceVpnGatewayId
The DxPrivateVirtualInterfaceGatewayId.vpnGatewayId choice: sets vpn_gateway_id.

Enums

DxBgpPeerAddressFamily
Dx Bgp Peer Address enum for address_family.
DxConnectionEncryptionMode
Dx Connection Encryption enum for encryption_mode.
DxHostedPrivateVirtualInterfaceAddressFamily
Dx Hosted Private Virtual Interface Address enum for address_family.
DxHostedPublicVirtualInterfaceAddressFamily
Dx Hosted Public Virtual Interface Address enum for address_family.
DxHostedTransitVirtualInterfaceAddressFamily
Dx Hosted Transit Virtual Interface Address enum for address_family.
DxPrivateVirtualInterfaceAddressFamily
Dx Private Virtual Interface Address enum for address_family.
DxPublicVirtualInterfaceAddressFamily
Dx Public Virtual Interface Address enum for address_family.
DxTransitVirtualInterfaceAddressFamily
Dx Transit Virtual Interface Address enum for address_family.