ecs library
AWS Elastic Container Service (ECS).
Classes
- AwsEcsAccountSettingDefault
-
Factory wrapper for
aws_ecs_account_setting_default. - AwsEcsCapacityProvider
-
Factory wrapper for
aws_ecs_capacity_provider. - AwsEcsCluster
-
Factory wrapper for
aws_ecs_cluster. - AwsEcsClusterCapacityProviders
-
Factory wrapper for
aws_ecs_cluster_capacity_providers. - AwsEcsDaemon
-
Factory wrapper for
aws_ecs_daemon. - AwsEcsDaemonTaskDefinition
-
Factory wrapper for
aws_ecs_daemon_task_definition. - AwsEcsExpressGatewayService
-
Factory wrapper for
aws_ecs_express_gateway_service. - AwsEcsService
-
Factory wrapper for
aws_ecs_service. - AwsEcsTag
-
Factory wrapper for
aws_ecs_tag. - AwsEcsTaskDefinition
-
Factory wrapper for
aws_ecs_task_definition. - AwsEcsTaskSet
-
Factory wrapper for
aws_ecs_task_set. - EcsCapacityProviderAcceleratorCount
-
Typed helper for the
managed_instances_provider.instance_launch_template.instance_requirements.accelerator_countblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderAcceleratorTotalMemoryMib
-
Typed helper for the
managed_instances_provider.instance_launch_template.instance_requirements.accelerator_total_memory_mibblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderAutoRepairConfiguration
-
Typed helper for the
managed_instances_provider.auto_repair_configurationblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderAutoScalingGroupProvider
-
Typed helper for the
auto_scaling_group_providerblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderBaselineEbsBandwidthMbps
-
Typed helper for the
managed_instances_provider.instance_launch_template.instance_requirements.baseline_ebs_bandwidth_mbpsblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderCapacityReservations
-
Typed helper for the
managed_instances_provider.instance_launch_template.capacity_reservationsblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderInfrastructureOptimization
-
Typed helper for the
managed_instances_provider.infrastructure_optimizationblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderInstanceLaunchTemplate
-
Typed helper for the
managed_instances_provider.instance_launch_templateblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderInstanceRequirements
-
Typed helper for the
managed_instances_provider.instance_launch_template.instance_requirementsblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderLocalStorageConfiguration
-
Typed helper for the
managed_instances_provider.instance_launch_template.local_storage_configurationblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderManagedInstancesProvider
-
Typed helper for the
managed_instances_providerblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderManagedScaling
-
Typed helper for the
auto_scaling_group_provider.managed_scalingblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderMemoryGibPerVcpu
-
Typed helper for the
managed_instances_provider.instance_launch_template.instance_requirements.memory_gib_per_vcpublock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderMemoryMib
-
Typed helper for the
managed_instances_provider.instance_launch_template.instance_requirements.memory_mibblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderNetworkBandwidthGbps
-
Typed helper for the
managed_instances_provider.instance_launch_template.instance_requirements.network_bandwidth_gbpsblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderNetworkConfiguration
-
Typed helper for the
managed_instances_provider.instance_launch_template.network_configurationblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderNetworkInterfaceCount
-
Typed helper for the
managed_instances_provider.instance_launch_template.instance_requirements.network_interface_countblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderStorageConfiguration
-
Typed helper for the
managed_instances_provider.instance_launch_template.storage_configurationblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderTotalLocalStorageGb
-
Typed helper for the
managed_instances_provider.instance_launch_template.instance_requirements.total_local_storage_gbblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsCapacityProviderVcpuCount
-
Typed helper for the
managed_instances_provider.instance_launch_template.instance_requirements.vcpu_countblock ofaws_ecs_capacity_provider(derived from provider schema). - EcsClusterCapacityProvidersDefaultCapacityProviderStrategy
-
Typed helper for the
default_capacity_provider_strategyblock ofaws_ecs_cluster_capacity_providers(derived from provider schema). - EcsClusterConfiguration
-
Typed helper for the
configurationblock ofaws_ecs_cluster(derived from provider schema). - EcsClusterExecuteCommandConfiguration
-
Typed helper for the
configuration.execute_command_configurationblock ofaws_ecs_cluster(derived from provider schema). - EcsClusterLogConfiguration
-
Typed helper for the
configuration.execute_command_configuration.log_configurationblock ofaws_ecs_cluster(derived from provider schema). - EcsClusterManagedStorageConfiguration
-
Typed helper for the
configuration.managed_storage_configurationblock ofaws_ecs_cluster(derived from provider schema). - EcsClusterServiceConnectDefaults
-
Typed helper for the
service_connect_defaultsblock ofaws_ecs_cluster(derived from provider schema). - EcsClusterSetting
-
Typed helper for the
settingblock ofaws_ecs_cluster(derived from provider schema). - EcsDaemonAlarms
-
Typed helper for the
deployment_configuration.alarmsblock ofaws_ecs_daemon(derived from provider schema). - EcsDaemonDeploymentConfiguration
-
Typed helper for the
deployment_configurationblock ofaws_ecs_daemon(derived from provider schema). - EcsDaemonTaskDefinitionCapabilities
-
Typed helper for the
container_definition.linux_parameters.capabilitiesblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionContainerDefinition
-
Typed helper for the
container_definitionblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionDependsOn
-
Typed helper for the
container_definition.depends_onblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionDevice
-
Typed helper for the
container_definition.linux_parameters.deviceblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionEnvironment
-
Typed helper for the
container_definition.environmentblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionEnvironmentFile
-
Typed helper for the
container_definition.environment_fileblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionFirelensConfiguration
-
Typed helper for the
container_definition.firelens_configurationblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionHealthCheck
-
Typed helper for the
container_definition.health_checkblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionHost
-
Typed helper for the
volume.hostblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionLinuxParameters
-
Typed helper for the
container_definition.linux_parametersblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionLogConfiguration
-
Typed helper for the
container_definition.log_configurationblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionMountPoint
-
Typed helper for the
container_definition.mount_pointblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionRepositoryCredentials
-
Typed helper for the
container_definition.repository_credentialsblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionRestartPolicy
-
Typed helper for the
container_definition.restart_policyblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionSecret
-
Typed helper for the
container_definition.secretblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionSecretOption
-
Typed helper for the
container_definition.log_configuration.secret_optionblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionSystemControl
-
Typed helper for the
container_definition.system_controlblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionTmpfs
-
Typed helper for the
container_definition.linux_parameters.tmpfsblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionUlimit
-
Typed helper for the
container_definition.ulimitblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsDaemonTaskDefinitionVolume
-
Typed helper for the
volumeblock ofaws_ecs_daemon_task_definition(derived from provider schema). - EcsExpressGatewayServiceEnvironment
-
Typed helper for the
primary_container.environmentblock ofaws_ecs_express_gateway_service(derived from provider schema). - EcsExpressGatewayServicePrimaryContainer
-
Typed helper for the
primary_containerblock ofaws_ecs_express_gateway_service(derived from provider schema). - EcsExpressGatewayServiceRepositoryCredentials
-
Typed helper for the
primary_container.repository_credentialsblock ofaws_ecs_express_gateway_service(derived from provider schema). - EcsExpressGatewayServiceSecret
-
Typed helper for the
primary_container.secretblock ofaws_ecs_express_gateway_service(derived from provider schema). - EcsService
-
Typed helper for the
service_connect_configuration.serviceblock ofaws_ecs_service(derived from provider schema). - EcsServiceAccessLogConfiguration
-
Typed helper for the
service_connect_configuration.access_log_configurationblock ofaws_ecs_service(derived from provider schema). - EcsServiceAdvancedConfiguration
-
Typed helper for the
load_balancer.advanced_configurationblock ofaws_ecs_service(derived from provider schema). - EcsServiceAlarms
-
Typed helper for the
alarmsblock ofaws_ecs_service(derived from provider schema). - EcsServiceCanaryConfiguration
-
Typed helper for the
deployment_configuration.canary_configurationblock ofaws_ecs_service(derived from provider schema). - EcsServiceCapacityProviderStrategy
-
Typed helper for the
capacity_provider_strategyblock ofaws_ecs_service(derived from provider schema). - EcsServiceClientAlias
-
Typed helper for the
service_connect_configuration.service.client_aliasblock ofaws_ecs_service(derived from provider schema). - EcsServiceConnectConfiguration
-
Typed helper for the
service_connect_configurationblock ofaws_ecs_service(derived from provider schema). - EcsServiceDeploymentCircuitBreaker
-
Typed helper for the
deployment_circuit_breakerblock ofaws_ecs_service(derived from provider schema). - EcsServiceDeploymentConfiguration
-
Typed helper for the
deployment_configurationblock ofaws_ecs_service(derived from provider schema). - EcsServiceDeploymentController
-
Typed helper for the
deployment_controllerblock ofaws_ecs_service(derived from provider schema). - EcsServiceHeader
-
Typed helper for the
service_connect_configuration.service.client_alias.test_traffic_rules.headerblock ofaws_ecs_service(derived from provider schema). - EcsServiceIssuerCertAuthority
-
Typed helper for the
service_connect_configuration.service.tls.issuer_cert_authorityblock ofaws_ecs_service(derived from provider schema). - EcsServiceLifecycleHook
-
Typed helper for the
deployment_configuration.lifecycle_hookblock ofaws_ecs_service(derived from provider schema). - EcsServiceLinearConfiguration
-
Typed helper for the
deployment_configuration.linear_configurationblock ofaws_ecs_service(derived from provider schema). - EcsServiceLoadBalancer
-
Typed helper for the
load_balancerblock ofaws_ecs_service(derived from provider schema). - EcsServiceLogConfiguration
-
Typed helper for the
service_connect_configuration.log_configurationblock ofaws_ecs_service(derived from provider schema). - EcsServiceManagedEbsVolume
-
Typed helper for the
volume_configuration.managed_ebs_volumeblock ofaws_ecs_service(derived from provider schema). - EcsServiceNetworkConfiguration
-
Typed helper for the
network_configurationblock ofaws_ecs_service(derived from provider schema). - EcsServiceOrderedPlacementStrategy
-
Typed helper for the
ordered_placement_strategyblock ofaws_ecs_service(derived from provider schema). - EcsServicePlacementConstraints
-
Typed helper for the
placement_constraintsblock ofaws_ecs_service(derived from provider schema). - EcsServiceRegistries
-
Typed helper for the
service_registriesblock ofaws_ecs_service(derived from provider schema). - EcsServiceSecretOption
-
Typed helper for the
service_connect_configuration.log_configuration.secret_optionblock ofaws_ecs_service(derived from provider schema). - EcsServiceTagSpecifications
-
Typed helper for the
volume_configuration.managed_ebs_volume.tag_specificationsblock ofaws_ecs_service(derived from provider schema). - EcsServiceTestTrafficRules
-
Typed helper for the
service_connect_configuration.service.client_alias.test_traffic_rulesblock ofaws_ecs_service(derived from provider schema). - EcsServiceTimeout
-
Typed helper for the
service_connect_configuration.service.timeoutblock ofaws_ecs_service(derived from provider schema). - EcsServiceTimeoutConfiguration
-
Typed helper for the
deployment_configuration.lifecycle_hook.timeout_configurationblock ofaws_ecs_service(derived from provider schema). - EcsServiceTls
-
Typed helper for the
service_connect_configuration.service.tlsblock ofaws_ecs_service(derived from provider schema). - EcsServiceValue
-
Typed helper for the
service_connect_configuration.service.client_alias.test_traffic_rules.header.valueblock ofaws_ecs_service(derived from provider schema). - EcsServiceVolumeConfiguration
-
Typed helper for the
volume_configurationblock ofaws_ecs_service(derived from provider schema). - EcsServiceVpcLatticeConfigurations
-
Typed helper for the
vpc_lattice_configurationsblock ofaws_ecs_service(derived from provider schema). - EcsTaskDefinitionDockerVolumeConfiguration
-
Typed helper for the
volume.docker_volume_configurationblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskDefinitionEfsVolumeConfiguration
-
Typed helper for the
volume.efs_volume_configurationblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskDefinitionEfsVolumeConfigurationAuthorizationConfig
-
Typed helper for the
volume.efs_volume_configuration.authorization_configblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskDefinitionEphemeralStorage
-
Typed helper for the
ephemeral_storageblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskDefinitionFsxWindowsFileServerVolumeConfiguration
-
Typed helper for the
volume.fsx_windows_file_server_volume_configurationblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskDefinitionFsxWindowsFileServerVolumeConfigurationAuthorizationConfig
-
Typed helper for the
volume.fsx_windows_file_server_volume_configuration.authorization_configblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskDefinitionPlacementConstraints
-
Typed helper for the
placement_constraintsblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskDefinitionProxyConfiguration
-
Typed helper for the
proxy_configurationblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskDefinitionRuntimePlatform
-
Typed helper for the
runtime_platformblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskDefinitionS3filesVolumeConfiguration
-
Typed helper for the
volume.s3files_volume_configurationblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskDefinitionVolume
-
Typed helper for the
volumeblock ofaws_ecs_task_definition(derived from provider schema). - EcsTaskSetCapacityProviderStrategy
-
Typed helper for the
capacity_provider_strategyblock ofaws_ecs_task_set(derived from provider schema). - EcsTaskSetCompute
-
At most one of
capacity_provider_strategy,launch_typeonaws_ecs_task_set: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - EcsTaskSetComputeCapacityProviderStrategy
-
The EcsTaskSetCompute.capacityProviderStrategy choice: sets
capacity_provider_strategy. - EcsTaskSetComputeLaunchType
-
The EcsTaskSetCompute.launchType choice: sets
launch_type. - EcsTaskSetLoadBalancer
-
Typed helper for the
load_balancerblock ofaws_ecs_task_set(derived from provider schema). - EcsTaskSetNetworkConfiguration
-
Typed helper for the
network_configurationblock ofaws_ecs_task_set(derived from provider schema). - EcsTaskSetScale
-
Typed helper for the
scaleblock ofaws_ecs_task_set(derived from provider schema). - EcsTaskSetServiceRegistries
-
Typed helper for the
service_registriesblock ofaws_ecs_task_set(derived from provider schema).
Enums
- EcsCapacityProviderAcceleratorManufacturers
-
accelerator_manufacturers— derived from the provider schema description. - EcsCapacityProviderAcceleratorNames
-
accelerator_names— derived from the provider schema description. - EcsCapacityProviderAcceleratorTypes
-
accelerator_types— derived from the provider schema description. - EcsCapacityProviderActionsStatus
-
actions_status— derived from the provider schema description. - EcsCapacityProviderBareMetal
-
bare_metal— derived from the provider schema description. - EcsCapacityProviderBurstablePerformance
-
burstable_performance— derived from the provider schema description. - EcsCapacityProviderCapacityOptionType
-
capacity_option_type— derived from the provider schema description. - EcsCapacityProviderCpuManufacturers
-
cpu_manufacturers— derived from the provider schema description. - EcsCapacityProviderInstanceGenerations
-
instance_generations— derived from the provider schema description. - EcsCapacityProviderLocalStorage
-
local_storage— derived from the provider schema description. - EcsCapacityProviderLocalStorageTypes
-
local_storage_types— derived from the provider schema description. - EcsCapacityProviderManagedDraining
-
managed_draining— derived from the provider schema description. - EcsCapacityProviderManagedTerminationProtection
-
managed_termination_protection— derived from the provider schema description. - EcsCapacityProviderMonitoring
-
monitoring— derived from the provider schema description. - EcsCapacityProviderPropagateTags
-
propagate_tags— derived from the provider schema description. - EcsCapacityProviderReservationPreference
-
reservation_preference— derived from the provider schema description. - EcsCapacityProviderStatus
-
status— derived from the provider schema description. - EcsClusterLogging
-
logging— derived from the provider schema description. - EcsClusterSettingName
-
name— derived from the provider schema description. - EcsDaemonPropagateTags
-
Ecs Daemon Propagate enum for
propagate_tags. - EcsDaemonTaskDefinitionCondition
-
condition— derived from the provider schema description. - EcsDaemonTaskDefinitionEnvironmentFileType
-
type— derived from the provider schema description. - EcsDaemonTaskDefinitionFirelensConfigurationType
-
type— derived from the provider schema description. - EcsDaemonTaskDefinitionLogDriver
-
log_driver— derived from the provider schema description. - EcsDaemonTaskDefinitionName
-
name— derived from the provider schema description. - EcsDaemonTaskDefinitionPermissions
-
permissions— derived from the provider schema description. - EcsServiceAction
-
action— derived from the provider schema description. - EcsServiceAvailabilityZoneRebalancing
-
Ecs Service Availability Zone enum for
availability_zone_rebalancing. - EcsServiceDeploymentControllerType
-
type— derived from the provider schema description. - EcsServiceFileSystemType
-
file_system_type— derived from the provider schema description. - EcsServiceFormat
-
format— derived from the provider schema description. - EcsServiceIncludeQueryParameters
-
include_query_parameters— derived from the provider schema description. - EcsServiceLaunchType
-
Ecs Service Launch enum for
launch_type. - EcsServiceLifecycleStages
-
lifecycle_stages— derived from the provider schema description. - EcsServiceLogDriver
-
log_driver— derived from the provider schema description. - EcsServiceOrderedPlacementStrategyType
-
type— derived from the provider schema description. - EcsServicePlacementConstraintsType
-
type— derived from the provider schema description. - EcsServicePropagateTags
-
Ecs Service Propagate enum for
propagate_tags. - EcsServiceResourceType
-
resource_type— derived from the provider schema description. - EcsServiceSchedulingStrategy
-
Ecs Service Scheduling enum for
scheduling_strategy. - EcsServiceStrategy
-
strategy— derived from the provider schema description. - EcsServiceTagSpecificationsPropagateTags
-
propagate_tags— derived from the provider schema description. - EcsServiceTargetType
-
target_type— derived from the provider schema description. - EcsTaskDefinitionCpuArchitecture
-
cpu_architecture— derived from the provider schema description. - EcsTaskDefinitionIam
-
iam— derived from the provider schema description. - EcsTaskDefinitionIpcMode
-
Ecs Task Definition Ipc enum for
ipc_mode. - EcsTaskDefinitionNetworkMode
-
Ecs Task Definition Network enum for
network_mode. - EcsTaskDefinitionOperatingSystemFamily
-
operating_system_family— derived from the provider schema description. - EcsTaskDefinitionPidMode
-
Ecs Task Definition Pid enum for
pid_mode. - EcsTaskDefinitionPlacementConstraintsType
-
type— derived from the provider schema description. - EcsTaskDefinitionProxyConfigurationType
-
type— derived from the provider schema description. - EcsTaskDefinitionRequiresCompatibilities
-
Ecs Task Definition Requires enum for
requires_compatibilities. - EcsTaskDefinitionScope
-
scope— derived from the provider schema description. - EcsTaskDefinitionTransitEncryption
-
transit_encryption— derived from the provider schema description. - EcsTaskSetLaunchType
-
Ecs Task Set Launch enum for
launch_type. - EcsTaskSetUnit
-
unit— derived from the provider schema description.