glue library

AWS Glue.

Classes

AwsGlueCatalog
Factory wrapper for aws_glue_catalog.
AwsGlueCatalogDatabase
Factory wrapper for aws_glue_catalog_database.
AwsGlueCatalogTable
Factory wrapper for aws_glue_catalog_table.
AwsGlueCatalogTableOptimizer
Factory wrapper for aws_glue_catalog_table_optimizer.
AwsGlueClassifier
Factory wrapper for aws_glue_classifier.
AwsGlueConnection
Factory wrapper for aws_glue_connection.
AwsGlueCrawler
Factory wrapper for aws_glue_crawler.
AwsGlueDataCatalogEncryptionSettings
Factory wrapper for aws_glue_data_catalog_encryption_settings.
AwsGlueDataQualityRuleset
Factory wrapper for aws_glue_data_quality_ruleset.
AwsGlueDevEndpoint
Factory wrapper for aws_glue_dev_endpoint.
AwsGlueJob
Factory wrapper for aws_glue_job.
AwsGlueMlTransform
Factory wrapper for aws_glue_ml_transform.
AwsGluePartition
Factory wrapper for aws_glue_partition.
AwsGluePartitionIndex
Factory wrapper for aws_glue_partition_index.
AwsGlueRegistry
Factory wrapper for aws_glue_registry.
AwsGlueResourcePolicy
Factory wrapper for aws_glue_resource_policy.
AwsGlueSchema
Factory wrapper for aws_glue_schema.
AwsGlueSecurityConfiguration
Factory wrapper for aws_glue_security_configuration.
AwsGlueTrigger
Factory wrapper for aws_glue_trigger.
AwsGlueUserDefinedFunction
Factory wrapper for aws_glue_user_defined_function.
AwsGlueWorkflow
Factory wrapper for aws_glue_workflow.
GlueCatalogCreateDatabaseDefaultPermissions
Typed helper for the create_database_default_permissions block of aws_glue_catalog (derived from provider schema).
GlueCatalogCreateTableDefaultPermissions
Typed helper for the create_table_default_permissions block of aws_glue_catalog (derived from provider schema).
GlueCatalogDatabaseCreateTableDefaultPermission
Typed helper for the create_table_default_permission block of aws_glue_catalog_database (derived from provider schema).
GlueCatalogDatabaseFederatedDatabase
Typed helper for the federated_database block of aws_glue_catalog_database (derived from provider schema).
GlueCatalogDatabasePrincipal
Typed helper for the create_table_default_permission.principal block of aws_glue_catalog_database (derived from provider schema).
GlueCatalogDatabaseTargetDatabase
Typed helper for the target_database block of aws_glue_catalog_database (derived from provider schema).
GlueCatalogDataLakeAccessProperties
Typed helper for the catalog_properties.data_lake_access_properties block of aws_glue_catalog (derived from provider schema).
GlueCatalogFederatedCatalog
Typed helper for the federated_catalog block of aws_glue_catalog (derived from provider schema).
GlueCatalogIcebergOptimizationProperties
Typed helper for the catalog_properties.iceberg_optimization_properties block of aws_glue_catalog (derived from provider schema).
GlueCatalogPrincipal
Typed helper for the create_database_default_permissions.principal block of aws_glue_catalog (derived from provider schema). Shared by every block of this shape in the resource.
GlueCatalogProperties
Typed helper for the catalog_properties block of aws_glue_catalog (derived from provider schema).
GlueCatalogTableColumns
Typed helper for the storage_descriptor.columns block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableIcebergInput
Typed helper for the open_table_format_input.iceberg_input block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableIcebergTableInput
Typed helper for the open_table_format_input.iceberg_input.iceberg_table_input block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableIcebergTableInputSchema
Typed helper for the open_table_format_input.iceberg_input.iceberg_table_input.schema block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableOpenTableFormatInput
Typed helper for the open_table_format_input block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableOptimizerCompactionConfiguration
Typed helper for the configuration.compaction_configuration block of aws_glue_catalog_table_optimizer (derived from provider schema).
GlueCatalogTableOptimizerCompactionConfigurationIcebergConfiguration
Typed helper for the configuration.compaction_configuration.iceberg_configuration block of aws_glue_catalog_table_optimizer (derived from provider schema).
GlueCatalogTableOptimizerConfiguration
Typed helper for the configuration block of aws_glue_catalog_table_optimizer (derived from provider schema).
GlueCatalogTableOptimizerOrphanFileDeletionConfiguration
Typed helper for the configuration.orphan_file_deletion_configuration block of aws_glue_catalog_table_optimizer (derived from provider schema).
GlueCatalogTableOptimizerOrphanFileDeletionConfigurationIcebergConfiguration
Typed helper for the configuration.orphan_file_deletion_configuration.iceberg_configuration block of aws_glue_catalog_table_optimizer (derived from provider schema).
GlueCatalogTableOptimizerRetentionConfiguration
Typed helper for the configuration.retention_configuration block of aws_glue_catalog_table_optimizer (derived from provider schema).
GlueCatalogTableOptimizerRetentionConfigurationIcebergConfiguration
Typed helper for the configuration.retention_configuration.iceberg_configuration block of aws_glue_catalog_table_optimizer (derived from provider schema).
GlueCatalogTablePartitionIndex
Typed helper for the partition_index block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTablePartitionKeys
Typed helper for the partition_keys block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTablePartitionSpec
Typed helper for the open_table_format_input.iceberg_input.iceberg_table_input.partition_spec block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTablePartitionSpecFields
Typed helper for the open_table_format_input.iceberg_input.iceberg_table_input.partition_spec.fields block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableRepresentations
Typed helper for the view_definition.representations block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableSchema
Exactly one of schema_id, schema_version_id on the storage_descriptor.schema_reference block of aws_glue_catalog_table: the provider rejects none and more than one, so each variant sets one of them.
GlueCatalogTableSchemaFields
Typed helper for the open_table_format_input.iceberg_input.iceberg_table_input.schema.fields block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableSchemaId
Typed helper for the storage_descriptor.schema_reference.schema_id block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableSchemaIdChoice
The GlueCatalogTableSchema.schemaId choice: sets schema_id.
GlueCatalogTableSchemaIdSchema
Exactly one of schema_arn, schema_name on the storage_descriptor.schema_reference.schema_id block of aws_glue_catalog_table: the provider rejects none and more than one, so each variant sets one of them.
GlueCatalogTableSchemaIdSchemaArn
The GlueCatalogTableSchemaIdSchema.schemaArn choice: sets schema_arn.
GlueCatalogTableSchemaIdSchemaName
The GlueCatalogTableSchemaIdSchema.schemaName choice: sets schema_name.
GlueCatalogTableSchemaReference
Typed helper for the storage_descriptor.schema_reference block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableSchemaVersionId
The GlueCatalogTableSchema.schemaVersionId choice: sets schema_version_id.
GlueCatalogTableSerDeInfo
Typed helper for the storage_descriptor.ser_de_info block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableSkewedInfo
Typed helper for the storage_descriptor.skewed_info block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableSortColumns
Typed helper for the storage_descriptor.sort_columns block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableSortOrder
Typed helper for the open_table_format_input.iceberg_input.iceberg_table_input.sort_order block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableSortOrderFields
Typed helper for the open_table_format_input.iceberg_input.iceberg_table_input.sort_order.fields block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableStorageDescriptor
Typed helper for the storage_descriptor block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableTargetTable
Typed helper for the target_table block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTableViewDefinition
Typed helper for the view_definition block of aws_glue_catalog_table (derived from provider schema).
GlueCatalogTargetRedshiftCatalog
Typed helper for the target_redshift_catalog block of aws_glue_catalog (derived from provider schema).
GlueClassifierCsvClassifier
Typed helper for the csv_classifier block of aws_glue_classifier (derived from provider schema).
GlueClassifierFormat
At most one of csv_classifier, grok_classifier, json_classifier, xml_classifier on aws_glue_classifier: the provider rejects more than one, so each variant sets one of them and a null choice sets none.
GlueClassifierFormatCsvClassifier
The GlueClassifierFormat.csvClassifier choice: sets csv_classifier.
GlueClassifierFormatGrokClassifier
The GlueClassifierFormat.grokClassifier choice: sets grok_classifier.
GlueClassifierFormatJsonClassifier
The GlueClassifierFormat.jsonClassifier choice: sets json_classifier.
GlueClassifierFormatXmlClassifier
The GlueClassifierFormat.xmlClassifier choice: sets xml_classifier.
GlueClassifierGrokClassifier
Typed helper for the grok_classifier block of aws_glue_classifier (derived from provider schema).
GlueClassifierJsonClassifier
Typed helper for the json_classifier block of aws_glue_classifier (derived from provider schema).
GlueClassifierXmlClassifier
Typed helper for the xml_classifier block of aws_glue_classifier (derived from provider schema).
GlueConnectionAuthenticationConfiguration
Typed helper for the authentication_configuration block of aws_glue_connection (derived from provider schema).
GlueConnectionAuthorizationCodeProperties
Typed helper for the authentication_configuration.oauth2_properties.authorization_code_properties block of aws_glue_connection (derived from provider schema).
GlueConnectionBasicAuthenticationCredentials
Typed helper for the authentication_configuration.basic_authentication_credentials block of aws_glue_connection (derived from provider schema).
GlueConnectionOauth2ClientApplication
Typed helper for the authentication_configuration.oauth2_properties.oauth2_client_application block of aws_glue_connection (derived from provider schema).
GlueConnectionOauth2Credentials
Typed helper for the authentication_configuration.oauth2_properties.oauth2_credentials block of aws_glue_connection (derived from provider schema).
GlueConnectionOauth2Properties
Typed helper for the authentication_configuration.oauth2_properties block of aws_glue_connection (derived from provider schema).
GlueConnectionPhysicalConnectionRequirements
Typed helper for the physical_connection_requirements block of aws_glue_connection (derived from provider schema).
GlueCrawlerCatalogTarget
Typed helper for the catalog_target block of aws_glue_crawler (derived from provider schema).
GlueCrawlerDeltaTarget
Typed helper for the delta_target block of aws_glue_crawler (derived from provider schema).
GlueCrawlerDynamodbTarget
Typed helper for the dynamodb_target block of aws_glue_crawler (derived from provider schema).
GlueCrawlerHudiTarget
Typed helper for the hudi_target block of aws_glue_crawler (derived from provider schema).
GlueCrawlerIcebergTarget
Typed helper for the iceberg_target block of aws_glue_crawler (derived from provider schema).
GlueCrawlerJdbcTarget
Typed helper for the jdbc_target block of aws_glue_crawler (derived from provider schema).
GlueCrawlerLakeFormationConfiguration
Typed helper for the lake_formation_configuration block of aws_glue_crawler (derived from provider schema).
GlueCrawlerLineageConfiguration
Typed helper for the lineage_configuration block of aws_glue_crawler (derived from provider schema).
GlueCrawlerMongodbTarget
Typed helper for the mongodb_target block of aws_glue_crawler (derived from provider schema).
GlueCrawlerRecrawlPolicy
Typed helper for the recrawl_policy block of aws_glue_crawler (derived from provider schema).
GlueCrawlerS3Target
Typed helper for the s3_target block of aws_glue_crawler (derived from provider schema).
GlueCrawlerSchemaChangePolicy
Typed helper for the schema_change_policy block of aws_glue_crawler (derived from provider schema).
GlueDataCatalogEncryptionSettings
Typed helper for the data_catalog_encryption_settings block of aws_glue_data_catalog_encryption_settings (derived from provider schema).
GlueDataCatalogEncryptionSettingsConnectionPasswordEncryption
Typed helper for the data_catalog_encryption_settings.connection_password_encryption block of aws_glue_data_catalog_encryption_settings (derived from provider schema).
GlueDataCatalogEncryptionSettingsEncryptionAtRest
Typed helper for the data_catalog_encryption_settings.encryption_at_rest block of aws_glue_data_catalog_encryption_settings (derived from provider schema).
GlueDataQualityRulesetTargetTable
Typed helper for the target_table block of aws_glue_data_quality_ruleset (derived from provider schema).
GlueDevEndpointPublicKey
At most one of public_key, public_keys on aws_glue_dev_endpoint: the provider rejects more than one, so each variant sets one of them and a null choice sets none.
GlueDevEndpointPublicKeyChoice
The GlueDevEndpointPublicKey.publicKey choice: sets public_key.
GlueDevEndpointPublicKeyPublicKeys
The GlueDevEndpointPublicKey.publicKeys choice: sets public_keys.
GlueJobCommand
Typed helper for the command block of aws_glue_job (derived from provider schema).
GlueJobExecutionProperty
Typed helper for the execution_property block of aws_glue_job (derived from provider schema).
GlueJobNotificationProperty
Typed helper for the notification_property block of aws_glue_job (derived from provider schema).
GlueJobSourceControlDetails
Typed helper for the source_control_details block of aws_glue_job (derived from provider schema).
GlueMlTransformFindMatchesParameters
Typed helper for the parameters.find_matches_parameters block of aws_glue_ml_transform (derived from provider schema).
GlueMlTransformInputRecordTables
Typed helper for the input_record_tables block of aws_glue_ml_transform (derived from provider schema).
GlueMlTransformParameters
Typed helper for the parameters block of aws_glue_ml_transform (derived from provider schema).
GluePartitionColumns
Typed helper for the storage_descriptor.columns block of aws_glue_partition (derived from provider schema).
GluePartitionIndex
Typed helper for the partition_index block of aws_glue_partition_index (derived from provider schema).
GluePartitionSerDeInfo
Typed helper for the storage_descriptor.ser_de_info block of aws_glue_partition (derived from provider schema).
GluePartitionSkewedInfo
Typed helper for the storage_descriptor.skewed_info block of aws_glue_partition (derived from provider schema).
GluePartitionSortColumns
Typed helper for the storage_descriptor.sort_columns block of aws_glue_partition (derived from provider schema).
GluePartitionStorageDescriptor
Typed helper for the storage_descriptor block of aws_glue_partition (derived from provider schema).
GlueSecurityConfigurationCloudwatchEncryption
Typed helper for the encryption_configuration.cloudwatch_encryption block of aws_glue_security_configuration (derived from provider schema).
GlueSecurityConfigurationEncryptionConfiguration
Typed helper for the encryption_configuration block of aws_glue_security_configuration (derived from provider schema).
GlueSecurityConfigurationJobBookmarksEncryption
Typed helper for the encryption_configuration.job_bookmarks_encryption block of aws_glue_security_configuration (derived from provider schema).
GlueSecurityConfigurationS3Encryption
Typed helper for the encryption_configuration.s3_encryption block of aws_glue_security_configuration (derived from provider schema).
GlueTriggerActions
Typed helper for the actions block of aws_glue_trigger (derived from provider schema).
GlueTriggerConditions
Typed helper for the predicate.conditions block of aws_glue_trigger (derived from provider schema).
GlueTriggerEventBatchingCondition
Typed helper for the event_batching_condition block of aws_glue_trigger (derived from provider schema).
GlueTriggerNotificationProperty
Typed helper for the actions.notification_property block of aws_glue_trigger (derived from provider schema).
GlueTriggerPredicate
Typed helper for the predicate block of aws_glue_trigger (derived from provider schema).
GlueUserDefinedFunctionResourceUris
Typed helper for the resource_uris block of aws_glue_user_defined_function (derived from provider schema).

Enums

GlueCatalogAllowFullTableExternalDataAccess
Glue Catalog Allow Full Table External Data enum for allow_full_table_external_data_access.
GlueCatalogDatabasePermissions
permissions — derived from the provider schema description.
GlueCatalogOverwriteChildResourcePermissionsWithDefault
Glue Catalog Overwrite Child Resource Permissions With enum for overwrite_child_resource_permissions_with_default.
GlueCatalogTableDialect
dialect — derived from the provider schema description.
GlueCatalogTableDirection
direction — derived from the provider schema description.
GlueCatalogTableLastRefreshType
last_refresh_type — derived from the provider schema description.
GlueCatalogTableMetadataOperation
metadata_operation — derived from the provider schema description.
GlueCatalogTableNullOrder
null_order — derived from the provider schema description.
GlueCatalogTableOptimizerStrategy
strategy — derived from the provider schema description.
GlueCatalogTableOptimizerType
Glue Catalog Table Optimizer enum for type.
GlueCatalogTableSchemaType
type — derived from the provider schema description.
GlueClassifierContainsHeader
contains_header — derived from the provider schema description.
GlueClassifierCustomDatatypes
custom_datatypes — derived from the provider schema description.
GlueClassifierSerde
serde — derived from the provider schema description.
GlueCrawlerDeleteBehavior
delete_behavior — derived from the provider schema description.
GlueCrawlerEnableAdditionalMetadata
enable_additional_metadata — derived from the provider schema description.
GlueCrawlerLineageSettings
crawler_lineage_settings — derived from the provider schema description.
GlueCrawlerRecrawlBehavior
recrawl_behavior — derived from the provider schema description.
GlueCrawlerUpdateBehavior
update_behavior — derived from the provider schema description.
GlueDataCatalogEncryptionSettingsCatalogEncryptionMode
catalog_encryption_mode — derived from the provider schema description.
GlueDevEndpointWorkerType
Glue Dev Endpoint Worker enum for worker_type.
GlueJobAuthStrategy
auth_strategy — derived from the provider schema description.
GlueJobExecutionClass
Glue Job Execution enum for execution_class.
GlueJobMode
Glue Job enum for job_mode.
GlueJobProvider
provider — derived from the provider schema description.
GlueJobPythonVersion
python_version — derived from the provider schema description.
GlueJobRuntime
runtime — derived from the provider schema description.
GlueMlTransformType
transform_type — derived from the provider schema description.
GlueMlTransformWorkerType
Glue Ml Transform Worker enum for worker_type.
GlueResourcePolicyEnableHybrid
Glue Resource Policy Enable enum for enable_hybrid.
GlueSchemaCompatibility
Glue Schema enum for compatibility.
GlueSchemaDataFormat
Glue Schema Data enum for data_format.
GlueSecurityConfigurationCloudwatchEncryptionMode
cloudwatch_encryption_mode — derived from the provider schema description.
GlueSecurityConfigurationJobBookmarksEncryptionMode
job_bookmarks_encryption_mode — derived from the provider schema description.
GlueSecurityConfigurationS3EncryptionMode
s3_encryption_mode — derived from the provider schema description.
GlueTriggerConditionsState
state — derived from the provider schema description.
GlueTriggerCrawlState
crawl_state — derived from the provider schema description.
GlueTriggerLogical
logical — derived from the provider schema description.
GlueTriggerLogicalOperator
logical_operator — derived from the provider schema description.
GlueTriggerType
Glue Trigger enum for type.
GlueUserDefinedFunctionOwnerType
Glue User Defined Function Owner enum for owner_type.
GlueUserDefinedFunctionResourceType
resource_type — derived from the provider schema description.