iot library

AWS IoT Core.

Classes

AwsIotAuthorizer
Factory wrapper for aws_iot_authorizer.
AwsIotBillingGroup
Factory wrapper for aws_iot_billing_group.
AwsIotCaCertificate
Factory wrapper for aws_iot_ca_certificate.
AwsIotCertificate
Factory wrapper for aws_iot_certificate.
AwsIotDomainConfiguration
Factory wrapper for aws_iot_domain_configuration.
AwsIotEventConfigurations
Factory wrapper for aws_iot_event_configurations.
AwsIotIndexingConfiguration
Factory wrapper for aws_iot_indexing_configuration.
AwsIotLoggingOptions
Factory wrapper for aws_iot_logging_options.
AwsIotPolicy
Factory wrapper for aws_iot_policy.
AwsIotPolicyAttachment
Factory wrapper for aws_iot_policy_attachment.
AwsIotProvisioningTemplate
Factory wrapper for aws_iot_provisioning_template.
AwsIotRoleAlias
Factory wrapper for aws_iot_role_alias.
AwsIotThing
Factory wrapper for aws_iot_thing.
AwsIotThingGroup
Factory wrapper for aws_iot_thing_group.
AwsIotThingGroupMembership
Factory wrapper for aws_iot_thing_group_membership.
AwsIotThingPrincipalAttachment
Factory wrapper for aws_iot_thing_principal_attachment.
AwsIotThingType
Factory wrapper for aws_iot_thing_type.
AwsIotTopicRule
Factory wrapper for aws_iot_topic_rule.
AwsIotTopicRuleDestination
Factory wrapper for aws_iot_topic_rule_destination.
IotBillingGroupProperties
Typed helper for the properties block of aws_iot_billing_group (derived from provider schema).
IotCaCertificateRegistrationConfig
Typed helper for the registration_config block of aws_iot_ca_certificate (derived from provider schema).
IotDomainConfigurationAuthorizerConfig
Typed helper for the authorizer_config block of aws_iot_domain_configuration (derived from provider schema).
IotDomainConfigurationTlsConfig
Typed helper for the tls_config block of aws_iot_domain_configuration (derived from provider schema).
IotIndexingConfigurationCustomField
Typed helper for the thing_group_indexing_configuration.custom_field block of aws_iot_indexing_configuration (derived from provider schema). Shared by every block of this shape in the resource.
IotIndexingConfigurationFilter
Typed helper for the thing_indexing_configuration.filter block of aws_iot_indexing_configuration (derived from provider schema).
IotIndexingConfigurationManagedField
Typed helper for the thing_group_indexing_configuration.managed_field block of aws_iot_indexing_configuration (derived from provider schema). Shared by every block of this shape in the resource.
IotIndexingConfigurationThingGroupIndexingConfiguration
Typed helper for the thing_group_indexing_configuration block of aws_iot_indexing_configuration (derived from provider schema).
IotIndexingConfigurationThingIndexingConfiguration
Typed helper for the thing_indexing_configuration block of aws_iot_indexing_configuration (derived from provider schema).
IotProvisioningTemplatePreProvisioningHook
Typed helper for the pre_provisioning_hook block of aws_iot_provisioning_template (derived from provider schema).
IotThingGroupAttributePayload
Typed helper for the properties.attribute_payload block of aws_iot_thing_group (derived from provider schema).
IotThingGroupProperties
Typed helper for the properties block of aws_iot_thing_group (derived from provider schema).
IotThingTypeProperties
Typed helper for the properties block of aws_iot_thing_type (derived from provider schema).
IotTopicRuleCloudwatchAlarm
Typed helper for the cloudwatch_alarm block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleCloudwatchLogs
Typed helper for the cloudwatch_logs block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleCloudwatchMetric
Typed helper for the cloudwatch_metric block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleDestinationVpcConfiguration
Typed helper for the vpc_configuration block of aws_iot_topic_rule_destination (derived from provider schema).
IotTopicRuleDimension
Typed helper for the timestream.dimension block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleDynamodb
Typed helper for the dynamodb block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleDynamodbv2
Typed helper for the dynamodbv2 block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleElasticsearch
Typed helper for the elasticsearch block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleErrorAction
Typed helper for the error_action block of aws_iot_topic_rule (derived from provider schema).
IotTopicRuleFirehose
Typed helper for the firehose block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleHeader
Typed helper for the kafka.header block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleHttp
Typed helper for the http block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleHttpHeader
Typed helper for the http.http_header block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleIotAnalytics
Typed helper for the iot_analytics block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleIotEvents
Typed helper for the iot_events block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleKafka
Typed helper for the kafka block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleKinesis
Typed helper for the kinesis block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleLambda
Typed helper for the lambda block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRulePutItem
Typed helper for the dynamodbv2.put_item block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleRepublish
Typed helper for the republish block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleS3
Typed helper for the s3 block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleSns
Typed helper for the sns block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleSqs
Typed helper for the sqs block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleStepFunctions
Typed helper for the step_functions block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleTimestamp
Typed helper for the timestream.timestamp block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.
IotTopicRuleTimestream
Typed helper for the timestream block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.

Enums

IotAuthorizerStatus
Iot Authorizer enum for status.
IotCaCertificateMode
Iot Ca Certificate enum for certificate_mode.
IotDomainConfigurationApplicationProtocol
Iot Domain Configuration Application enum for application_protocol.
IotDomainConfigurationAuthenticationType
Iot Domain Configuration Authentication enum for authentication_type.
IotDomainConfigurationServiceType
Iot Domain Configuration Service enum for service_type.
IotDomainConfigurationStatus
Iot Domain Configuration enum for status.
IotIndexingConfigurationDeviceDefenderIndexingMode
device_defender_indexing_mode — derived from the provider schema description.
IotIndexingConfigurationNamedShadowIndexingMode
named_shadow_indexing_mode — derived from the provider schema description.
IotIndexingConfigurationThingConnectivityIndexingMode
thing_connectivity_indexing_mode — derived from the provider schema description.
IotIndexingConfigurationThingGroupIndexingMode
thing_group_indexing_mode — derived from the provider schema description.
IotIndexingConfigurationThingIndexingMode
thing_indexing_mode — derived from the provider schema description.
IotIndexingConfigurationType
type — derived from the provider schema description.
IotLoggingOptionsDefaultLogLevel
Iot Logging Options Default Log enum for default_log_level.
IotProvisioningTemplatePayloadVersion
payload_version — derived from the provider schema description.
IotProvisioningTemplateType
Iot Provisioning Template enum for type.
IotThingPrincipalAttachmentThingPrincipalType
Iot Thing Principal Attachment Thing Principal enum for thing_principal_type.
IotTopicRuleCannedAcl
canned_acl — derived from the provider schema description.
IotTopicRuleOperation
operation — derived from the provider schema description.
IotTopicRuleUnit
unit — derived from the provider schema description.