lexv2models library

AWS Lex V2.

Classes

AwsLexv2modelsBot
Factory wrapper for aws_lexv2models_bot.
AwsLexv2modelsBotLocale
Factory wrapper for aws_lexv2models_bot_locale.
AwsLexv2modelsBotVersion
Factory wrapper for aws_lexv2models_bot_version.
AwsLexv2modelsIntent
Factory wrapper for aws_lexv2models_intent.
AwsLexv2modelsSlot
Factory wrapper for aws_lexv2models_slot.
AwsLexv2modelsSlotType
Factory wrapper for aws_lexv2models_slot_type.
Lexv2modelsBotDataPrivacy
Typed helper for the data_privacy block of aws_lexv2models_bot (derived from provider schema).
Lexv2modelsBotLocaleVoiceSettings
Typed helper for the voice_settings block of aws_lexv2models_bot_locale (derived from provider schema).
Lexv2modelsBotMembers
Typed helper for the members block of aws_lexv2models_bot (derived from provider schema).
Lexv2modelsIntent
Typed helper for the closing_setting.next_step.intent block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentAllowedInputTypes
Typed helper for the confirmation_setting.prompt_specification.prompt_attempts_specification.allowed_input_types block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentAudioAndDtmfInputSpecification
Typed helper for the confirmation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specification block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentAudioSpecification
Typed helper for the confirmation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specification.audio_specification block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentBedrockKnowledgeStoreConfiguration
Typed helper for the qna_intent_configuration.data_source_configuration.bedrock_knowledge_store_configuration block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentBedrockKnowledgeStoreConfigurationExactResponseFields
Typed helper for the qna_intent_configuration.data_source_configuration.bedrock_knowledge_store_configuration.exact_response_fields block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentBedrockModelConfiguration
Typed helper for the qna_intent_configuration.bedrock_model_configuration block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentButton
Typed helper for the closing_setting.closing_response.message_group.message.image_response_card.button block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentClosingResponse
Typed helper for the closing_setting.closing_response block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentClosingSetting
Typed helper for the closing_setting block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentCodeHook
Typed helper for the confirmation_setting.code_hook block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentCondition
Typed helper for the closing_setting.conditional.conditional_branch.condition block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentConditional
Typed helper for the closing_setting.conditional block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentConditionalBranch
Typed helper for the closing_setting.conditional.conditional_branch block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentConfirmationConditional
Typed helper for the confirmation_setting.confirmation_conditional block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentConfirmationNextStep
Typed helper for the confirmation_setting.confirmation_next_step block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentConfirmationResponse
Typed helper for the confirmation_setting.confirmation_response block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentConfirmationSetting
Typed helper for the confirmation_setting block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentCustomPayload
Typed helper for the closing_setting.closing_response.message_group.message.custom_payload block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentDataSourceConfiguration
Typed helper for the qna_intent_configuration.data_source_configuration block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentDataSourceConfigurationKendraConfiguration
Typed helper for the qna_intent_configuration.data_source_configuration.kendra_configuration block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentDeclinationConditional
Typed helper for the confirmation_setting.declination_conditional block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentDeclinationNextStep
Typed helper for the confirmation_setting.declination_next_step block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentDeclinationResponse
Typed helper for the confirmation_setting.declination_response block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentDefaultBranch
Typed helper for the closing_setting.conditional.default_branch block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentDialogAction
Typed helper for the closing_setting.next_step.dialog_action block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentDialogCodeHook
Typed helper for the dialog_code_hook block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentDtmfSpecification
Typed helper for the confirmation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specification.dtmf_specification block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentElicitationCodeHook
Typed helper for the confirmation_setting.elicitation_code_hook block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentFailureConditional
Typed helper for the confirmation_setting.failure_conditional block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentFailureNextStep
Typed helper for the confirmation_setting.failure_next_step block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentFailureResponse
Typed helper for the confirmation_setting.failure_response block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentFulfillmentCodeHook
Typed helper for the fulfillment_code_hook block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentFulfillmentUpdatesSpecification
Typed helper for the fulfillment_code_hook.fulfillment_updates_specification block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentGuardrail
Typed helper for the qna_intent_configuration.bedrock_model_configuration.guardrail block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentImageResponseCard
Typed helper for the closing_setting.closing_response.message_group.message.image_response_card block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentInitialResponse
Typed helper for the initial_response_setting.initial_response block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentInitialResponseSetting
Typed helper for the initial_response_setting block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentInputContext
Typed helper for the input_context block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentKendraConfiguration
Typed helper for the kendra_configuration block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentMessage
Typed helper for the closing_setting.closing_response.message_group.message block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentMessageGroup
Typed helper for the closing_setting.closing_response.message_group block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentNextStep
Typed helper for the closing_setting.next_step block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentOpensearchConfiguration
Typed helper for the qna_intent_configuration.data_source_configuration.opensearch_configuration block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentOpensearchConfigurationExactResponseFields
Typed helper for the qna_intent_configuration.data_source_configuration.opensearch_configuration.exact_response_fields block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentOutputContext
Typed helper for the output_context block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentPlainTextMessage
Typed helper for the closing_setting.closing_response.message_group.message.plain_text_message block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentPostCodeHookSpecification
Typed helper for the confirmation_setting.code_hook.post_code_hook_specification block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentPostFulfillmentStatusSpecification
Typed helper for the fulfillment_code_hook.post_fulfillment_status_specification block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentPromptAttemptsSpecification
Typed helper for the confirmation_setting.prompt_specification.prompt_attempts_specification block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentPromptSpecification
Typed helper for the confirmation_setting.prompt_specification block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentQnaIntentConfiguration
Typed helper for the qna_intent_configuration block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentResponse
Typed helper for the closing_setting.conditional.conditional_branch.response block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentSampleUtterance
Typed helper for the sample_utterance block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentSlot
Typed helper for the closing_setting.next_step.intent.slot block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentSlotPriority
Typed helper for the slot_priority block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentSsmlMessage
Typed helper for the closing_setting.closing_response.message_group.message.ssml_message block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentStartResponse
Typed helper for the fulfillment_code_hook.fulfillment_updates_specification.start_response block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentSuccessConditional
Typed helper for the fulfillment_code_hook.post_fulfillment_status_specification.success_conditional block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentSuccessNextStep
Typed helper for the fulfillment_code_hook.post_fulfillment_status_specification.success_next_step block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentSuccessResponse
Typed helper for the fulfillment_code_hook.post_fulfillment_status_specification.success_response block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentTextInputSpecification
Typed helper for the confirmation_setting.prompt_specification.prompt_attempts_specification.text_input_specification block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentTimeoutConditional
Typed helper for the fulfillment_code_hook.post_fulfillment_status_specification.timeout_conditional block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentTimeoutNextStep
Typed helper for the fulfillment_code_hook.post_fulfillment_status_specification.timeout_next_step block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentTimeoutResponse
Typed helper for the fulfillment_code_hook.post_fulfillment_status_specification.timeout_response block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentUpdateResponse
Typed helper for the fulfillment_code_hook.fulfillment_updates_specification.update_response block of aws_lexv2models_intent (derived from provider schema).
Lexv2modelsIntentValue
Typed helper for the closing_setting.next_step.intent.slot.value block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsIntentVariation
Typed helper for the closing_setting.closing_response.message_group.variation block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotAllowedInputTypes
Typed helper for the value_elicitation_setting.prompt_specification.prompt_attempts_specification.allowed_input_types block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotAudioAndDtmfInputSpecification
Typed helper for the value_elicitation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specification block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotAudioSpecification
Typed helper for the value_elicitation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specification.audio_specification block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotButton
Typed helper for the value_elicitation_setting.prompt_specification.message_group.message.image_response_card.button block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotContinueResponse
Typed helper for the value_elicitation_setting.wait_and_continue_specification.continue_response block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotCustomPayload
Typed helper for the value_elicitation_setting.prompt_specification.message_group.message.custom_payload block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotDefaultValueList
Typed helper for the value_elicitation_setting.default_value_specification.default_value_list block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotDefaultValueSpecification
Typed helper for the value_elicitation_setting.default_value_specification block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotDtmfSpecification
Typed helper for the value_elicitation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specification.dtmf_specification block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotImageResponseCard
Typed helper for the value_elicitation_setting.prompt_specification.message_group.message.image_response_card block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotMessage
Typed helper for the value_elicitation_setting.prompt_specification.message_group.message block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotMessageGroup
Typed helper for the value_elicitation_setting.prompt_specification.message_group block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotMultipleValuesSetting
Typed helper for the multiple_values_setting block of aws_lexv2models_slot (derived from provider schema).
Lexv2modelsSlotObfuscationSetting
Typed helper for the obfuscation_setting block of aws_lexv2models_slot (derived from provider schema).
Lexv2modelsSlotPlainTextMessage
Typed helper for the value_elicitation_setting.prompt_specification.message_group.message.plain_text_message block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotPromptAttemptsSpecification
Typed helper for the value_elicitation_setting.prompt_specification.prompt_attempts_specification block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotPromptSpecification
Typed helper for the value_elicitation_setting.prompt_specification block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotResolutionSetting
Typed helper for the value_elicitation_setting.slot_resolution_setting block of aws_lexv2models_slot (derived from provider schema).
Lexv2modelsSlotSampleUtterance
Typed helper for the value_elicitation_setting.sample_utterance block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotSpecification
Typed helper for the sub_slot_setting.slot_specification block of aws_lexv2models_slot (derived from provider schema).
Lexv2modelsSlotSpecificationValueElicitationSetting
Typed helper for the sub_slot_setting.slot_specification.value_elicitation_setting block of aws_lexv2models_slot (derived from provider schema).
Lexv2modelsSlotSsmlMessage
Typed helper for the value_elicitation_setting.prompt_specification.message_group.message.ssml_message block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotStillWaitingResponse
Typed helper for the value_elicitation_setting.wait_and_continue_specification.still_waiting_response block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotSubSlotSetting
Typed helper for the sub_slot_setting block of aws_lexv2models_slot (derived from provider schema).
Lexv2modelsSlotTextInputSpecification
Typed helper for the value_elicitation_setting.prompt_specification.prompt_attempts_specification.text_input_specification block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotTypeAdvancedRecognitionSetting
Typed helper for the value_selection_setting.advanced_recognition_setting block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotTypeCompositeSlotTypeSetting
Typed helper for the composite_slot_type_setting block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotTypeExternalSourceSetting
Typed helper for the external_source_setting block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotTypeGrammarSlotTypeSetting
Typed helper for the external_source_setting.grammar_slot_type_setting block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotTypeRegexFilter
Typed helper for the value_selection_setting.regex_filter block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotTypeSampleValue
Typed helper for the slot_type_values.sample_value block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotTypeSource
Typed helper for the external_source_setting.grammar_slot_type_setting.source block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotTypeSubSlots
Typed helper for the composite_slot_type_setting.sub_slots block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotTypeSynonyms
Typed helper for the slot_type_values.synonyms block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotTypeValues
Typed helper for the slot_type_values block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotTypeValueSelectionSetting
Typed helper for the value_selection_setting block of aws_lexv2models_slot_type (derived from provider schema).
Lexv2modelsSlotValueElicitationSetting
Typed helper for the value_elicitation_setting block of aws_lexv2models_slot (derived from provider schema).
Lexv2modelsSlotVariation
Typed helper for the value_elicitation_setting.prompt_specification.message_group.variation block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotWaitAndContinueSpecification
Typed helper for the value_elicitation_setting.wait_and_continue_specification block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.
Lexv2modelsSlotWaitingResponse
Typed helper for the value_elicitation_setting.wait_and_continue_specification.waiting_response block of aws_lexv2models_slot (derived from provider schema). Shared by every block of this shape in the resource.

Enums

Lexv2modelsBotLocaleEngine
engine — derived from the provider schema description.
Lexv2modelsBotType
Lexv2models Bot enum for type.
Lexv2modelsSlotTypeAudioRecognitionStrategy
audio_recognition_strategy — derived from the provider schema description.
Lexv2modelsSlotTypeResolutionStrategy
resolution_strategy — derived from the provider schema description.