prometheus library

AWS Managed Service for Prometheus.

Classes

AwsPrometheusAlertManagerDefinition
Factory wrapper for aws_prometheus_alert_manager_definition.
AwsPrometheusAnomalyDetector
Factory wrapper for aws_prometheus_anomaly_detector.
AwsPrometheusQueryLoggingConfiguration
Factory wrapper for aws_prometheus_query_logging_configuration.
AwsPrometheusResourcePolicy
Factory wrapper for aws_prometheus_resource_policy.
AwsPrometheusRuleGroupNamespace
Factory wrapper for aws_prometheus_rule_group_namespace.
AwsPrometheusScraper
Factory wrapper for aws_prometheus_scraper.
AwsPrometheusScraperLoggingConfiguration
Factory wrapper for aws_prometheus_scraper_logging_configuration.
AwsPrometheusWorkspace
Factory wrapper for aws_prometheus_workspace.
AwsPrometheusWorkspaceConfiguration
Factory wrapper for aws_prometheus_workspace_configuration.
PrometheusAnomalyDetectorConfiguration
Typed helper for the configuration block of aws_prometheus_anomaly_detector (derived from provider schema).
PrometheusAnomalyDetectorIgnoreNearExpectedFromAbove
Exactly one of amount, ratio on the configuration.random_cut_forest.ignore_near_expected_from_above block of aws_prometheus_anomaly_detector: the provider rejects none and more than one, so each variant sets one of them.
PrometheusAnomalyDetectorIgnoreNearExpectedFromAboveAmount
The PrometheusAnomalyDetectorIgnoreNearExpectedFromAbove.amount choice: sets amount.
PrometheusAnomalyDetectorIgnoreNearExpectedFromAboveRatio
The PrometheusAnomalyDetectorIgnoreNearExpectedFromAbove.ratio choice: sets ratio.
PrometheusAnomalyDetectorIgnoreNearExpectedFromBelow
Exactly one of amount, ratio on the configuration.random_cut_forest.ignore_near_expected_from_below block of aws_prometheus_anomaly_detector: the provider rejects none and more than one, so each variant sets one of them.
PrometheusAnomalyDetectorIgnoreNearExpectedFromBelowAmount
The PrometheusAnomalyDetectorIgnoreNearExpectedFromBelow.amount choice: sets amount.
PrometheusAnomalyDetectorIgnoreNearExpectedFromBelowRatio
The PrometheusAnomalyDetectorIgnoreNearExpectedFromBelow.ratio choice: sets ratio.
PrometheusAnomalyDetectorMissingDataAction
Exactly one of mark_as_anomaly, skip on the missing_data_action block of aws_prometheus_anomaly_detector: the provider rejects none and more than one, so each variant sets one of them.
PrometheusAnomalyDetectorMissingDataActionMarkAsAnomaly
The PrometheusAnomalyDetectorMissingDataAction.markAsAnomaly choice: sets mark_as_anomaly.
PrometheusAnomalyDetectorMissingDataActionSkip
The PrometheusAnomalyDetectorMissingDataAction.skip choice: sets skip.
PrometheusAnomalyDetectorRandomCutForest
Typed helper for the configuration.random_cut_forest block of aws_prometheus_anomaly_detector (derived from provider schema).
PrometheusQueryLoggingConfigurationCloudwatchLogs
Typed helper for the destination.cloudwatch_logs block of aws_prometheus_query_logging_configuration (derived from provider schema).
PrometheusQueryLoggingConfigurationDestination
Typed helper for the destination block of aws_prometheus_query_logging_configuration (derived from provider schema).
PrometheusQueryLoggingConfigurationFilters
Typed helper for the destination.filters block of aws_prometheus_query_logging_configuration (derived from provider schema).
PrometheusScraperAmp
Typed helper for the destination.amp block of aws_prometheus_scraper (derived from provider schema).
PrometheusScraperCloudwatch
Typed helper for the destination.cloudwatch block of aws_prometheus_scraper (derived from provider schema).
PrometheusScraperDestination
Typed helper for the destination block of aws_prometheus_scraper (derived from provider schema).
PrometheusScraperEks
Typed helper for the source.eks block of aws_prometheus_scraper (derived from provider schema).
PrometheusScraperExporter
Typed helper for the exporter block of aws_prometheus_scraper (derived from provider schema).
PrometheusScraperLoggingConfigurationCloudwatchLogs
Typed helper for the logging_destination.cloudwatch_logs block of aws_prometheus_scraper_logging_configuration (derived from provider schema).
PrometheusScraperLoggingConfigurationLoggingDestination
Typed helper for the logging_destination block of aws_prometheus_scraper_logging_configuration (derived from provider schema).
PrometheusScraperOpensearch
Typed helper for the exporter.opensearch block of aws_prometheus_scraper (derived from provider schema).
PrometheusScraperRoleConfiguration
Typed helper for the role_configuration block of aws_prometheus_scraper (derived from provider schema).
PrometheusScraperSource
Typed helper for the source block of aws_prometheus_scraper (derived from provider schema).
PrometheusScraperVpc
Typed helper for the source.vpc block of aws_prometheus_scraper (derived from provider schema).
PrometheusWorkspaceConfigurationLimits
Typed helper for the limits_per_label_set.limits block of aws_prometheus_workspace_configuration (derived from provider schema).
PrometheusWorkspaceConfigurationLimitsPerLabelSet
Typed helper for the limits_per_label_set block of aws_prometheus_workspace_configuration (derived from provider schema).
PrometheusWorkspaceLoggingConfiguration
Typed helper for the logging_configuration block of aws_prometheus_workspace (derived from provider schema).

Enums

PrometheusScraperLoggingConfigurationScraperComponents
Prometheus Scraper Logging Configuration Scraper enum for scraper_components.