AppflowConnectorProfileBasicAuthCredentials class final

Typed helper for the connector_profile_config.connector_profile_credentials.sapo_data.basic_auth_credentials block of aws_appflow_connector_profile (derived from provider schema).

Annotations
  • @immutable

Constructors

AppflowConnectorProfileBasicAuthCredentials({required TfArg<String> password, required TfArg<String> username})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
password → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited