AppflowConnectorProfileCredentialsDatadog class final

Typed helper for the connector_profile_config.connector_profile_credentials.datadog block of aws_appflow_connector_profile (derived from provider schema).

Annotations
  • @immutable

Constructors

AppflowConnectorProfileCredentialsDatadog({required TfArg<String> apiKey, required TfArg<String> applicationKey})
const

Properties

apiKey → TfArg<String>
final
applicationKey → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited