AppflowConnectorProfileCredentialsHoneycode class final

Typed helper for the connector_profile_config.connector_profile_credentials.honeycode block of aws_appflow_connector_profile (derived from provider schema).

Annotations
  • @immutable

Constructors

AppflowConnectorProfileCredentialsHoneycode({Sensitive<String>? accessToken, TfArg<String>? refreshToken, AppflowConnectorProfileOauthRequest? oauthRequest})
const

Properties

accessToken → Sensitive<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
oauthRequest → AppflowConnectorProfileOauthRequest?
final
refreshToken → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited