AppflowFlowDestinationConnectorPropertiesS3OutputFormatConfig class final

Typed helper for the destination_flow_config.destination_connector_properties.s3.s3_output_format_config block of aws_appflow_flow (derived from provider schema).

Annotations
  • @immutable

Constructors

AppflowFlowDestinationConnectorPropertiesS3OutputFormatConfig({AppflowFlowFileType? fileType, TfArg<bool>? preserveSourceDataTyping, AppflowFlowS3AggregationConfig? aggregationConfig, AppflowFlowS3PrefixConfig? prefixConfig})
const

Properties

aggregationConfig → AppflowFlowS3AggregationConfig?
final
fileType → AppflowFlowFileType?
final
hashCode → int
The hash code for this object.
no setterinherited
prefixConfig → AppflowFlowS3PrefixConfig?
final
preserveSourceDataTyping → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited