AppflowFlowErrorHandlingConfig class final

Typed helper for the destination_flow_config.destination_connector_properties.custom_connector.error_handling_config block of aws_appflow_flow (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

AppflowFlowErrorHandlingConfig({RefTo<AwsS3Bucket>? bucketName, TfArg<String>? bucketPrefix, TfArg<bool>? failOnFirstDestinationError})
const

Properties

bucketName → RefTo<AwsS3Bucket>?
final
bucketPrefix → TfArg<String>?
final
failOnFirstDestinationError → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited