AppflowFlowS3PrefixConfig class final

Typed helper for the destination_flow_config.destination_connector_properties.s3.s3_output_format_config.prefix_config block of aws_appflow_flow (derived from provider schema).

Annotations
  • @immutable

Constructors

AppflowFlowS3PrefixConfig({TfArg<AppflowFlowPrefixFormat>? prefixFormat, List<TfArg<AppflowFlowPrefixHierarchy>>? prefixHierarchy, TfArg<AppflowFlowPrefixType>? prefixType})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
prefixFormat → TfArg<AppflowFlowPrefixFormat>?
final
prefixHierarchy → List<TfArg<AppflowFlowPrefixHierarchy>>?
final
prefixType → TfArg<AppflowFlowPrefixType>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited