AppflowFlowSourceConnectorPropertiesSlack class final

Typed helper for the source_flow_config.source_connector_properties.slack block of aws_appflow_flow (derived from provider schema).

Annotations
  • @immutable

Constructors

AppflowFlowSourceConnectorPropertiesSlack({required TfArg<String> object})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
object → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited