AppflowFlowTriggerConfig class final

Typed helper for the trigger_config block of aws_appflow_flow (derived from provider schema).

Annotations
  • @immutable

Constructors

AppflowFlowTriggerConfig({required TfArg<AppflowFlowTriggerType> triggerType, AppflowFlowTriggerProperties? triggerProperties})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerProperties → AppflowFlowTriggerProperties?
final
triggerType → TfArg<AppflowFlowTriggerType>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited