AppflowFlowUpsolverAggregationConfig class final
Typed helper for the destination_flow_config.destination_connector_properties.upsolver.s3_output_format_config.aggregation_config block of
aws_appflow_flow (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AppflowFlowUpsolverAggregationConfig({TfArg<
AppflowFlowAggregationType> ? aggregationType}) -
const
Properties
-
aggregationType
→ TfArg<
AppflowFlowAggregationType> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited