AppmeshRouteQueryParameter class final

Typed helper for the spec.http2_route.match.query_parameter block of aws_appmesh_route (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

AppmeshRouteQueryParameter({required TfArg<String> name, AppmeshRouteQueryParameterMatch? match})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
match → AppmeshRouteQueryParameterMatch?
final
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited