AppmeshVirtualGatewayHealthCheck class final

Typed helper for the spec.listener.health_check block of aws_appmesh_virtual_gateway (derived from provider schema).

Annotations
  • @immutable

Constructors

AppmeshVirtualGatewayHealthCheck({required TfArg<num> healthyThreshold, required TfArg<num> intervalMillis, TfArg<String>? path, TfArg<num>? port, required AppmeshVirtualGatewayProtocol protocol, required TfArg<num> timeoutMillis, required TfArg<num> unhealthyThreshold})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
healthyThreshold → TfArg<num>
final
intervalMillis → TfArg<num>
final
path → TfArg<String>?
final
port → TfArg<num>?
final
protocol → AppmeshVirtualGatewayProtocol
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutMillis → TfArg<num>
final
unhealthyThreshold → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited