AppmeshVirtualNodeCertificateFile class final

Typed helper for the spec.listener.tls.certificate.file block of aws_appmesh_virtual_node (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

AppmeshVirtualNodeCertificateFile({required TfArg<String> certificateChain, required TfArg<String> privateKey})
const

Properties

certificateChain → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
privateKey → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited