AppmeshVirtualNodeClientPolicyTls class final

Typed helper for the spec.backend_defaults.client_policy.tls block of aws_appmesh_virtual_node (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

AppmeshVirtualNodeClientPolicyTls({TfArg<bool>? enforce, TfArg<List<num>>? ports, AppmeshVirtualNodeTlsCertificate? certificate, required AppmeshVirtualNodeTlsValidation validation})
const

Properties

certificate → AppmeshVirtualNodeTlsCertificate?
final
enforce → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
ports → TfArg<List<num>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validation → AppmeshVirtualNodeTlsValidation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited