AppmeshVirtualNodeFile class final

Typed helper for the spec.logging.access_log.file block of aws_appmesh_virtual_node (derived from provider schema).

Annotations
  • @immutable

Constructors

AppmeshVirtualNodeFile({required TfArg<String> path, AppmeshVirtualNodeFormat? format})
const

Properties

format → AppmeshVirtualNodeFormat?
final
hashCode → int
The hash code for this object.
no setterinherited
path → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited