AppmeshVirtualNodeFormat class final

Typed helper for the spec.logging.access_log.file.format block of aws_appmesh_virtual_node (derived from provider schema).

Annotations
  • @immutable

Constructors

AppmeshVirtualNodeFormat({TfArg<String>? text, List<AppmeshVirtualNodeJson>? json})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
json → List<AppmeshVirtualNodeJson>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited