AppmeshVirtualNodeVirtualService class final

Typed helper for the spec.backend.virtual_service block of aws_appmesh_virtual_node (derived from provider schema).

Annotations
  • @immutable

Constructors

AppmeshVirtualNodeVirtualService({required TfArg<String> virtualServiceName, AppmeshVirtualNodeClientPolicy? clientPolicy})
const

Properties

clientPolicy → AppmeshVirtualNodeClientPolicy?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
virtualServiceName → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited