ApprunnerServiceCodeConfigurationValues class final

Typed helper for the source_configuration.code_repository.code_configuration.code_configuration_values block of aws_apprunner_service (derived from provider schema).

Annotations
  • @immutable

Constructors

ApprunnerServiceCodeConfigurationValues({TfArg<String>? buildCommand, TfArg<String>? port, required TfArg<ApprunnerServiceRuntime> runtime, TfArg<Map<String, String>>? runtimeEnvironmentSecrets, TfArg<Map<String, String>>? runtimeEnvironmentVariables, TfArg<String>? startCommand})
const

Properties

buildCommand → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
port → TfArg<String>?
final
runtime → TfArg<ApprunnerServiceRuntime>
final
runtimeEnvironmentSecrets → TfArg<Map<String, String>>?
final
runtimeEnvironmentVariables → TfArg<Map<String, String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startCommand → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited