ApprunnerServiceImageRepository class final

Typed helper for the source_configuration.image_repository block of aws_apprunner_service (derived from provider schema).

Annotations
  • @immutable

Constructors

ApprunnerServiceImageRepository({required TfArg<String> imageIdentifier, required TfArg<ApprunnerServiceImageRepositoryType> imageRepositoryType, ApprunnerServiceImageConfiguration? imageConfiguration})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageConfiguration → ApprunnerServiceImageConfiguration?
final
imageIdentifier → TfArg<String>
final
imageRepositoryType → TfArg<ApprunnerServiceImageRepositoryType>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited