ApprunnerServiceImageRepositoryChoice class final
The ApprunnerServiceRepository.imageRepository choice: sets image_repository.
- Inheritance
-
- Object
- ApprunnerServiceRepository
- ApprunnerServiceImageRepositoryChoice
Constructors
- ApprunnerServiceImageRepositoryChoice(ApprunnerServiceImageRepository imageRepository)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageRepository → ApprunnerServiceImageRepository
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited