AppstreamDirectoryConfigServiceAccountCredentials class final

Typed helper for the service_account_credentials block of aws_appstream_directory_config (derived from provider schema).

Annotations
  • @immutable

Constructors

AppstreamDirectoryConfigServiceAccountCredentials({required TfArg<String> accountName, required Sensitive<String> accountPassword})
const

Properties

accountName → TfArg<String>
final
accountPassword → Sensitive<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited