AppstreamStackAccessEndpoints class final

Typed helper for the access_endpoints block of aws_appstream_stack (derived from provider schema).

Annotations
  • @immutable

Constructors

AppstreamStackAccessEndpoints({required TfArg<AppstreamStackEndpointType> endpointType, TfArg<String>? vpceId})
const

Properties

endpointType → TfArg<AppstreamStackEndpointType>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpceId → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited