AppstreamStackStorageConnectors class final

Typed helper for the storage_connectors block of aws_appstream_stack (derived from provider schema).

Annotations
  • @immutable

Constructors

AppstreamStackStorageConnectors({required AppstreamStackConnectorType connectorType, TfArg<List<String>>? domains, TfArg<String>? resourceIdentifier})
const

Properties

connectorType → AppstreamStackConnectorType
final
domains → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
resourceIdentifier → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited