AppstreamStackUserSettings class final

Typed helper for the user_settings block of aws_appstream_stack (derived from provider schema).

Annotations
  • @immutable

Constructors

AppstreamStackUserSettings({required AppstreamStackAction action, required AppstreamStackPermission permission})
const

Properties

action → AppstreamStackAction
final
hashCode → int
The hash code for this object.
no setterinherited
permission → AppstreamStackPermission
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited