AppsyncApiConnectionAuthMode class final

Typed helper for the event_config.connection_auth_mode block of aws_appsync_api (derived from provider schema).

Annotations
  • @immutable

Constructors

AppsyncApiConnectionAuthMode({required AppsyncApiAuthType authType})
const

Properties

authType → AppsyncApiAuthType
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited