AppsyncDatasourceAwsIamConfig class final
Typed helper for the http_config.authorization_config.aws_iam_config block of
aws_appsync_datasource (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AppsyncDatasourceAwsIamConfig({TfArg<
String> ? signingRegion, TfArg<String> ? signingServiceName}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signingRegion
→ TfArg<
String> ? -
final
-
signingServiceName
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited