AppsyncDatasourceOpensearchserviceConfig class final

Typed helper for the opensearchservice_config block of aws_appsync_datasource (derived from provider schema).

Annotations
  • @immutable

Constructors

AppsyncDatasourceOpensearchserviceConfig({required TfArg<String> endpoint, TfArg<String>? region})
const

Properties

endpoint → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
region → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited