AppsyncFunctionLambdaConflictHandlerConfig class final

Typed helper for the sync_config.lambda_conflict_handler_config block of aws_appsync_function (derived from provider schema).

Annotations
  • @immutable

Constructors

AppsyncFunctionLambdaConflictHandlerConfig({TfArg<String>? lambdaConflictHandlerArn})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lambdaConflictHandlerArn → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited