AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig class final

Typed helper for the additional_authentication_provider.user_pool_config block of aws_appsync_graphql_api (derived from provider schema).

Annotations
  • @immutable

Constructors

AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig({TfArg<String>? appIdClientRegex, TfArg<String>? awsRegion, required TfArg<String> userPoolId})
const

Properties

appIdClientRegex → TfArg<String>?
final
awsRegion → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userPoolId → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited