AuditmanagerControlMappingSources class final

Typed helper for the control_mapping_sources block of aws_auditmanager_control (derived from provider schema).

Annotations
  • @immutable

Constructors

AuditmanagerControlMappingSources({TfArg<String>? sourceDescription, AuditmanagerControlSourceFrequency? sourceFrequency, TfArg<List<Object?>>? sourceKeyword, required TfArg<String> sourceName, required AuditmanagerControlSourceSetUpOption sourceSetUpOption, required AuditmanagerControlSourceType sourceType, TfArg<String>? troubleshootingText})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDescription → TfArg<String>?
final
sourceFrequency → AuditmanagerControlSourceFrequency?
final
sourceKeyword → TfArg<List<Object?>>?
final
sourceName → TfArg<String>
final
sourceSetUpOption → AuditmanagerControlSourceSetUpOption
final
sourceType → AuditmanagerControlSourceType
final
troubleshootingText → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited