AutoscalingGroupInstanceRefresh class final

Typed helper for the instance_refresh block of aws_autoscaling_group (derived from provider schema).

Annotations
  • @immutable

Constructors

AutoscalingGroupInstanceRefresh({required AutoscalingGroupStrategy strategy, TfArg<List<String>>? triggers, AutoscalingGroupPreferences? preferences})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
preferences → AutoscalingGroupPreferences?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strategy → AutoscalingGroupStrategy
final
triggers → TfArg<List<String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited