BackupFrameworkControl class final

Typed helper for the control block of aws_backup_framework (derived from provider schema).

Annotations
  • @immutable

Constructors

BackupFrameworkControl({required TfArg<String> name, List<BackupFrameworkInputParameter>? inputParameter, BackupFrameworkScope? scope})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputParameter → List<BackupFrameworkInputParameter>?
final
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → BackupFrameworkScope?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited