BackupRestoreTestingSelectionProtectedResourceConditions class final

Typed helper for the protected_resource_conditions block of aws_backup_restore_testing_selection (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringEquals → List<BackupRestoreTestingSelectionStringEquals>?
final
stringNotEquals → List<BackupRestoreTestingSelectionStringNotEquals>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited