BatchJobDefinitionContainers class final

Typed helper for the eks_properties.pod_properties.containers block of aws_batch_job_definition (derived from provider schema).

Annotations
  • @immutable

Constructors

BatchJobDefinitionContainers({TfArg<List<String>>? args, TfArg<List<String>>? command, required TfArg<String> image, BatchJobDefinitionImagePullPolicy? imagePullPolicy, TfArg<String>? name, List<BatchJobDefinitionEnv>? env, BatchJobDefinitionResources? resources, BatchJobDefinitionSecurityContext? securityContext, List<BatchJobDefinitionVolumeMounts>? volumeMounts})
const

Properties

args → TfArg<List<String>>?
final
command → TfArg<List<String>>?
final
env → List<BatchJobDefinitionEnv>?
final
hashCode → int
The hash code for this object.
no setterinherited
image → TfArg<String>
final
imagePullPolicy → BatchJobDefinitionImagePullPolicy?
final
name → TfArg<String>?
final
resources → BatchJobDefinitionResources?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityContext → BatchJobDefinitionSecurityContext?
final
volumeMounts → List<BatchJobDefinitionVolumeMounts>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited