BatchJobDefinitionImagePullSecret class final

Typed helper for the eks_properties.pod_properties.image_pull_secret block of aws_batch_job_definition (derived from provider schema).

Annotations
  • @immutable

Constructors

BatchJobDefinitionImagePullSecret({required TfArg<String> name})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited