BedrockEvaluationJobPrecomputedRagSourceConfigRetrieveSourceConfig class final
The BedrockEvaluationJobPrecomputedRagSourceConfig.retrieveSourceConfig choice: sets retrieve_source_config.
- Inheritance
-
- Object
- BedrockEvaluationJobPrecomputedRagSourceConfig
- BedrockEvaluationJobPrecomputedRagSourceConfigRetrieveSourceConfig
Constructors
-
BedrockEvaluationJobPrecomputedRagSourceConfigRetrieveSourceConfig(List<
BedrockEvaluationJobRetrieveSourceConfig> retrieveSourceConfig) -
const
Properties
- blockKey → String
-
The Terraform argument this choice sets.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
retrieveSourceConfig
→ List<
BedrockEvaluationJobRetrieveSourceConfig> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited