BedrockModelInvocationJobInputDataConfig class final
Typed helper for the input_data_config block of
aws_bedrock_model_invocation_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BedrockModelInvocationJobInputDataConfig({List<
BedrockModelInvocationJobS3InputDataConfig> ? s3InputDataConfig}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
s3InputDataConfig
→ List<
BedrockModelInvocationJobS3InputDataConfig> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited