BedrockagentDataSourceConfluenceConfigurationSourceConfiguration class final
Typed helper for the data_source_configuration.confluence_configuration.source_configuration block of
aws_bedrockagent_data_source (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BedrockagentDataSourceConfluenceConfigurationSourceConfiguration({required TfArg<
BedrockagentDataSourceConfluenceConfigurationAuthType> authType, required TfArg<String> credentialsSecretArn, required TfArg<BedrockagentDataSourceConfluenceConfigurationHostType> hostType, required TfArg<String> hostUrl}) -
const
Properties
-
authType
→ TfArg<
BedrockagentDataSourceConfluenceConfigurationAuthType> -
final
-
credentialsSecretArn
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hostType
→ TfArg<
BedrockagentDataSourceConfluenceConfigurationHostType> -
final
-
hostUrl
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited