BedrockagentDataSourceDeletionProtectionConfiguration class final
Typed helper for the data_source_configuration.managed_knowledge_base_connector_configuration.deletion_protection_configuration block of
aws_bedrockagent_data_source (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BedrockagentDataSourceDeletionProtectionConfiguration({required TfArg<
BedrockagentDataSourceDeletionProtectionStatus> deletionProtectionStatus, TfArg<num> ? deletionProtectionThreshold}) -
const
Properties
-
deletionProtectionStatus
→ TfArg<
BedrockagentDataSourceDeletionProtectionStatus> -
final
-
deletionProtectionThreshold
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited