BedrockagentDataSourceFilterConfiguration class final

Typed helper for the data_source_configuration.confluence_configuration.crawler_configuration.filter_configuration block of aws_bedrockagent_data_source (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

BedrockagentDataSourceFilterConfiguration({required TfArg<String> type, List<BedrockagentDataSourcePatternObjectFilter>? patternObjectFilter})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
patternObjectFilter → List<BedrockagentDataSourcePatternObjectFilter>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited