BedrockagentDataSourceSemanticChunkingConfiguration class final

Typed helper for the vector_ingestion_configuration.chunking_configuration.semantic_chunking_configuration block of aws_bedrockagent_data_source (derived from provider schema).

Annotations
  • @immutable

Constructors

BedrockagentDataSourceSemanticChunkingConfiguration({required TfArg<num> breakpointPercentileThreshold, required TfArg<num> bufferSize, required TfArg<num> maxToken})
const

Properties

breakpointPercentileThreshold → TfArg<num>
final
bufferSize → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
maxToken → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited