BedrockagentDataSourceServerSideEncryptionConfiguration class final

Typed helper for the server_side_encryption_configuration block of aws_bedrockagent_data_source (derived from provider schema).

Annotations
  • @immutable

Constructors

BedrockagentDataSourceServerSideEncryptionConfiguration({RefTo<AwsKmsKey>? kmsKeyArn})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyArn → RefTo<AwsKmsKey>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited