BedrockagentFlowNodeConfigurationKnowledgeBase class final
The BedrockagentFlowNodeConfiguration.knowledgeBase choice: sets knowledge_base.
- Inheritance
-
- Object
- BedrockagentFlowNodeConfiguration
- BedrockagentFlowNodeConfigurationKnowledgeBase
Constructors
-
BedrockagentFlowNodeConfigurationKnowledgeBase(List<
BedrockagentFlowKnowledgeBase> knowledgeBase) -
const
Properties
- blockKey → String
-
The Terraform argument this choice sets.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
knowledgeBase
→ List<
BedrockagentFlowKnowledgeBase> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited