BedrockagentKnowledgeBaseManagedKnowledgeBaseConfiguration class final

Typed helper for the knowledge_base_configuration.managed_knowledge_base_configuration block of aws_bedrockagent_knowledge_base (derived from provider schema).

Annotations
  • @immutable

Constructors

BedrockagentKnowledgeBaseManagedKnowledgeBaseConfiguration({TfArg<String>? embeddingModelArn, TfArg<BedrockagentKnowledgeBaseEmbeddingModelType>? embeddingModelType, List<BedrockagentKnowledgeBaseEmbeddingModelConfiguration>? embeddingModelConfiguration, List<BedrockagentKnowledgeBaseServerSideEncryptionConfiguration>? serverSideEncryptionConfiguration})
const

Properties

embeddingModelArn → TfArg<String>?
final
embeddingModelConfiguration → List<BedrockagentKnowledgeBaseEmbeddingModelConfiguration>?
final
embeddingModelType → TfArg<BedrockagentKnowledgeBaseEmbeddingModelType>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverSideEncryptionConfiguration → List<BedrockagentKnowledgeBaseServerSideEncryptionConfiguration>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited