BedrockagentKnowledgeBaseRedisEnterpriseCloudConfigurationFieldMapping class final

Typed helper for the storage_configuration.redis_enterprise_cloud_configuration.field_mapping block of aws_bedrockagent_knowledge_base (derived from provider schema).

Annotations
  • @immutable

Constructors

BedrockagentKnowledgeBaseRedisEnterpriseCloudConfigurationFieldMapping({TfArg<String>? metadataField, TfArg<String>? textField, TfArg<String>? vectorField})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadataField → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textField → TfArg<String>?
final
vectorField → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited