BedrockagentKnowledgeBaseStorageConfiguration class final
Typed helper for the storage_configuration block of
aws_bedrockagent_knowledge_base (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BedrockagentKnowledgeBaseStorageConfiguration({required BedrockagentKnowledgeBaseStorageConfigurationType type, List<
BedrockagentKnowledgeBaseMongoDbAtlasConfiguration> ? mongoDbAtlasConfiguration, List<BedrockagentKnowledgeBaseNeptuneAnalyticsConfiguration> ? neptuneAnalyticsConfiguration, List<BedrockagentKnowledgeBaseOpensearchManagedClusterConfiguration> ? opensearchManagedClusterConfiguration, List<BedrockagentKnowledgeBaseOpensearchServerlessConfiguration> ? opensearchServerlessConfiguration, List<BedrockagentKnowledgeBasePineconeConfiguration> ? pineconeConfiguration, List<BedrockagentKnowledgeBaseRdsConfiguration> ? rdsConfiguration, List<BedrockagentKnowledgeBaseRedisEnterpriseCloudConfiguration> ? redisEnterpriseCloudConfiguration, List<BedrockagentKnowledgeBaseS3VectorsConfiguration> ? s3VectorsConfiguration}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mongoDbAtlasConfiguration
→ List<
BedrockagentKnowledgeBaseMongoDbAtlasConfiguration> ? -
final
-
neptuneAnalyticsConfiguration
→ List<
BedrockagentKnowledgeBaseNeptuneAnalyticsConfiguration> ? -
final
-
opensearchManagedClusterConfiguration
→ List<
BedrockagentKnowledgeBaseOpensearchManagedClusterConfiguration> ? -
final
-
opensearchServerlessConfiguration
→ List<
BedrockagentKnowledgeBaseOpensearchServerlessConfiguration> ? -
final
-
pineconeConfiguration
→ List<
BedrockagentKnowledgeBasePineconeConfiguration> ? -
final
-
rdsConfiguration
→ List<
BedrockagentKnowledgeBaseRdsConfiguration> ? -
final
-
redisEnterpriseCloudConfiguration
→ List<
BedrockagentKnowledgeBaseRedisEnterpriseCloudConfiguration> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
s3VectorsConfiguration
→ List<
BedrockagentKnowledgeBaseS3VectorsConfiguration> ? -
final
- type → BedrockagentKnowledgeBaseStorageConfigurationType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited