BedrockagentPromptContentCachePoint class final
The BedrockagentPromptContent.cachePoint choice: sets cache_point.
- Inheritance
-
- Object
- BedrockagentPromptContent
- BedrockagentPromptContentCachePoint
Constructors
-
BedrockagentPromptContentCachePoint(List<
BedrockagentPromptCachePoint> cachePoint) -
const
Properties
-
cachePoint
→ List<
BedrockagentPromptCachePoint> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited