BedrockagentcoreMemoryStrategyExtraction class final

Typed helper for the configuration.extraction block of aws_bedrockagentcore_memory_strategy (derived from provider schema).

Annotations
  • @immutable

Constructors

BedrockagentcoreMemoryStrategyExtraction({required TfArg<String> appendToPrompt, required TfArg<String> modelId})
const

Properties

appendToPrompt → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
modelId → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited