BedrockagentcoreMemoryStrategyInvocationConfiguration class final

Typed helper for the configuration.self_managed_configuration.invocation_configuration block of aws_bedrockagentcore_memory_strategy (derived from provider schema).

Annotations
  • @immutable

Constructors

BedrockagentcoreMemoryStrategyInvocationConfiguration({required TfArg<String> payloadDeliveryBucketName, required RefTo<AwsSnsTopic> topicArn})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
payloadDeliveryBucketName → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topicArn → RefTo<AwsSnsTopic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited