BedrockagentcoreMemoryStrategyStringValidation class final
Typed helper for the memory_record_schema.metadata_schema.extraction_config.llm_extraction_config.validation.string_validation block of
aws_bedrockagentcore_memory_strategy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BedrockagentcoreMemoryStrategyStringValidation({required TfArg<
List< allowedValues})String> > -
const
Properties
-
allowedValues
→ TfArg<
List< String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited