BillingViewDimensions class final

Typed helper for the data_filter_expression.dimensions block of aws_billing_view (derived from provider schema).

Annotations
  • @immutable

Constructors

BillingViewDimensions({required BillingViewKey key, required TfArg<List<String>> values})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → BillingViewKey
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → TfArg<List<String>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited