BudgetsBudgetFilterExpression class final
Typed helper for the filter_expression block of
aws_budgets_budget (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BudgetsBudgetFilterExpression({List<
BudgetsBudgetAnd> ? and, BudgetsBudgetCostCategories? costCategories, BudgetsBudgetDimensions? dimensions, BudgetsBudgetNot? not, List<BudgetsBudgetOr> ? or, BudgetsBudgetFilterExpressionTags? tags}) -
const
Properties
-
and
→ List<
BudgetsBudgetAnd> ? -
final
- costCategories → BudgetsBudgetCostCategories?
-
final
- dimensions → BudgetsBudgetDimensions?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- not → BudgetsBudgetNot?
-
final
-
or
→ List<
BudgetsBudgetOr> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited