CleanroomsMembershipQueryCompute class final

Typed helper for the payment_configuration.query_compute block of aws_cleanrooms_membership (derived from provider schema).

Annotations
  • @immutable

Constructors

CleanroomsMembershipQueryCompute({required TfArg<bool> isResponsible})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isResponsible → TfArg<bool>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited