CloudformationStackSetMaxConcurrentPercentage class final
The CloudformationStackSetMaxConcurrent.maxConcurrentPercentage choice: sets max_concurrent_percentage.
- Inheritance
-
- Object
- CloudformationStackSetMaxConcurrent
- CloudformationStackSetMaxConcurrentPercentage
Constructors
-
CloudformationStackSetMaxConcurrentPercentage(TfArg<
num> maxConcurrentPercentage) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxConcurrentPercentage
→ TfArg<
num> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited