CloudfrontCachePolicyQueryStringsConfig class final

Typed helper for the parameters_in_cache_key_and_forwarded_to_origin.query_strings_config block of aws_cloudfront_cache_policy (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
queryStringBehavior → CloudfrontCachePolicyQueryStringBehavior
final
queryStrings → CloudfrontCachePolicyQueryStrings?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited