CloudfrontDistributionCustomErrorResponse class final

Typed helper for the custom_error_response block of aws_cloudfront_distribution (derived from provider schema).

Annotations
  • @immutable

Constructors

CloudfrontDistributionCustomErrorResponse({TfArg<num>? errorCachingMinTtl, required TfArg<num> errorCode, TfArg<num>? responseCode, TfArg<String>? responsePagePath})
const

Properties

errorCachingMinTtl → TfArg<num>?
final
errorCode → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
responseCode → TfArg<num>?
final
responsePagePath → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited