CloudfrontDistributionDefaultCacheBehavior class final
Typed helper for the default_cache_behavior block of
aws_cloudfront_distribution (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudfrontDistributionDefaultCacheBehavior({required TfArg<
List< allowedMethods, RefTo<String> >AwsCloudfrontCachePolicy> ? cachePolicyId, required TfArg<List< cachedMethods, TfArg<String> >bool> ? compress, TfArg<num> ? defaultTtl, TfArg<String> ? fieldLevelEncryptionId, TfArg<num> ? maxTtl, TfArg<num> ? minTtl, TfArg<String> ? originRequestPolicyId, TfArg<String> ? realtimeLogConfigArn, TfArg<String> ? responseHeadersPolicyId, TfArg<bool> ? smoothStreaming, required TfArg<String> targetOriginId, TfArg<List< ? trustedKeyGroups, TfArg<String> >List< ? trustedSigners, required CloudfrontDistributionViewerProtocolPolicy viewerProtocolPolicy, CloudfrontDistributionForwardedValues? forwardedValues, List<String> >CloudfrontDistributionFunctionAssociation> ? functionAssociation, CloudfrontDistributionGrpcConfig? grpcConfig, List<CloudfrontDistributionLambdaFunctionAssociation> ? lambdaFunctionAssociation}) -
const
Properties
-
allowedMethods
→ TfArg<
List< String> > -
final
-
cachedMethods
→ TfArg<
List< String> > -
final
-
cachePolicyId
→ RefTo<
AwsCloudfrontCachePolicy> ? -
final
-
compress
→ TfArg<
bool> ? -
final
-
defaultTtl
→ TfArg<
num> ? -
final
-
fieldLevelEncryptionId
→ TfArg<
String> ? -
final
- forwardedValues → CloudfrontDistributionForwardedValues?
-
final
-
functionAssociation
→ List<
CloudfrontDistributionFunctionAssociation> ? -
final
- grpcConfig → CloudfrontDistributionGrpcConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lambdaFunctionAssociation
→ List<
CloudfrontDistributionLambdaFunctionAssociation> ? -
final
-
maxTtl
→ TfArg<
num> ? -
final
-
minTtl
→ TfArg<
num> ? -
final
-
originRequestPolicyId
→ TfArg<
String> ? -
final
-
realtimeLogConfigArn
→ TfArg<
String> ? -
final
-
responseHeadersPolicyId
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
smoothStreaming
→ TfArg<
bool> ? -
final
-
targetOriginId
→ TfArg<
String> -
final
-
trustedKeyGroups
→ TfArg<
List< ?String> > -
final
-
trustedSigners
→ TfArg<
List< ?String> > -
final
- viewerProtocolPolicy → CloudfrontDistributionViewerProtocolPolicy
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited