CloudfrontDistributionTrustStoreConfig class final

Typed helper for the viewer_mtls_config.trust_store_config block of aws_cloudfront_distribution (derived from provider schema).

Annotations
  • @immutable

Constructors

CloudfrontDistributionTrustStoreConfig({TfArg<bool>? advertiseTrustStoreCaNames, TfArg<bool>? ignoreCertificateExpiry, required TfArg<String> trustStoreId})
const

Properties

advertiseTrustStoreCaNames → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
ignoreCertificateExpiry → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trustStoreId → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited