CloudfrontFieldLevelEncryptionConfigContentTypeProfileConfig class final

Typed helper for the content_type_profile_config block of aws_cloudfront_field_level_encryption_config (derived from provider schema).

Annotations
  • @immutable

Constructors

CloudfrontFieldLevelEncryptionConfigContentTypeProfileConfig({required TfArg<bool> forwardWhenContentTypeIsUnknown, required CloudfrontFieldLevelEncryptionConfigContentTypeProfiles contentTypeProfiles})
const

Properties

contentTypeProfiles → CloudfrontFieldLevelEncryptionConfigContentTypeProfiles
final
forwardWhenContentTypeIsUnknown → TfArg<bool>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited