CloudfrontFieldLevelEncryptionConfigContentTypeProfilesItems class final

Typed helper for the content_type_profile_config.content_type_profiles.items block of aws_cloudfront_field_level_encryption_config (derived from provider schema).

Annotations
  • @immutable

Constructors

CloudfrontFieldLevelEncryptionConfigContentTypeProfilesItems({required TfArg<String> contentType, required TfArg<String> format, TfArg<String>? profileId})
const

Properties

contentType → TfArg<String>
final
format → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
profileId → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited