CloudfrontMultitenantDistributionCachedMethods enum
cached_methods — derived from the provider schema description.
Values
- get → const CloudfrontMultitenantDistributionCachedMethods
-
const CloudfrontMultitenantDistributionCachedMethods('GET') - head → const CloudfrontMultitenantDistributionCachedMethods
-
const CloudfrontMultitenantDistributionCachedMethods('HEAD') - post → const CloudfrontMultitenantDistributionCachedMethods
-
const CloudfrontMultitenantDistributionCachedMethods('POST') - put → const CloudfrontMultitenantDistributionCachedMethods
-
const CloudfrontMultitenantDistributionCachedMethods('PUT') - patch → const CloudfrontMultitenantDistributionCachedMethods
-
const CloudfrontMultitenantDistributionCachedMethods('PATCH') - options → const CloudfrontMultitenantDistributionCachedMethods
-
const CloudfrontMultitenantDistributionCachedMethods('OPTIONS') - delete → const CloudfrontMultitenantDistributionCachedMethods
-
const CloudfrontMultitenantDistributionCachedMethods('DELETE')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
The Terraform-side string literal this enum value encodes to.
Convention: emitted exactly as it appears in provider docs (typically
SCREAMING_SNAKE_CASEfor GCP).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CloudfrontMultitenantDistributionCachedMethods> - A constant List of the values in this enum, in order of their declaration.