CloudfrontMultitenantDistributionStringSchema class final
Typed helper for the tenant_config.parameter_definition.definition.string_schema block of
aws_cloudfront_multitenant_distribution (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudfrontMultitenantDistributionStringSchema({TfArg<
String> ? comment, TfArg<String> ? defaultValue, required TfArg<bool> required}) -
const
Properties
-
comment
→ TfArg<
String> ? -
final
-
defaultValue
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
required
→ TfArg<
bool> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited