CloudwatchEventConnectionInvocationHttpParameters class final
Typed helper for the auth_parameters.invocation_http_parameters block of
aws_cloudwatch_event_connection (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudwatchEventConnectionInvocationHttpParameters({List<
CloudwatchEventConnectionBody> ? body, List<CloudwatchEventConnectionHeader> ? header, List<CloudwatchEventConnectionQueryString> ? queryString}) -
const
Properties
-
body
→ List<
CloudwatchEventConnectionBody> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
header
→ List<
CloudwatchEventConnectionHeader> ? -
final
-
queryString
→ List<
CloudwatchEventConnectionQueryString> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited