CloudwatchEventConnectionResourceParameters class final
Typed helper for the invocation_connectivity_parameters.resource_parameters block of
aws_cloudwatch_event_connection (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
CloudwatchEventConnectionResourceParameters({required TfArg<
String> resourceConfigurationArn}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resourceConfigurationArn
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited