CodebuildFleetComputeConfiguration class final
Typed helper for the compute_configuration block of
aws_codebuild_fleet (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CodebuildFleetComputeConfiguration({TfArg<
num> ? disk, TfArg<String> ? instanceType, CodebuildFleetMachineType? machineType, TfArg<num> ? memory, TfArg<num> ? vcpu}) -
const
Properties
-
disk
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instanceType
→ TfArg<
String> ? -
final
- machineType → CodebuildFleetMachineType?
-
final
-
memory
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
vcpu
→ TfArg<
num> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited