CodebuildProjectArtifacts class final

Typed helper for the artifacts block of aws_codebuild_project (derived from provider schema).

Annotations
  • @immutable

Constructors

CodebuildProjectArtifacts({TfArg<String>? artifactIdentifier, TfArg<CodebuildProjectBucketOwnerAccess>? bucketOwnerAccess, TfArg<bool>? encryptionDisabled, TfArg<String>? location, TfArg<String>? name, TfArg<CodebuildProjectNamespaceType>? namespaceType, TfArg<bool>? overrideArtifactName, TfArg<CodebuildProjectPackaging>? packaging, TfArg<String>? path, required TfArg<CodebuildProjectArtifactsType> type})
const

Properties

artifactIdentifier → TfArg<String>?
final
bucketOwnerAccess → TfArg<CodebuildProjectBucketOwnerAccess>?
final
encryptionDisabled → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
location → TfArg<String>?
final
name → TfArg<String>?
final
namespaceType → TfArg<CodebuildProjectNamespaceType>?
final
overrideArtifactName → TfArg<bool>?
final
packaging → TfArg<CodebuildProjectPackaging>?
final
path → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<CodebuildProjectArtifactsType>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited