CodebuildProjectCache class final

Typed helper for the cache block of aws_codebuild_project (derived from provider schema).

Annotations
  • @immutable

Constructors

CodebuildProjectCache({TfArg<String>? cacheNamespace, TfArg<String>? location, List<CodebuildProjectModes>? modes, CodebuildProjectCacheType? type})
const

Properties

cacheNamespace → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
location → TfArg<String>?
final
modes → List<CodebuildProjectModes>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CodebuildProjectCacheType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited