CodebuildProjectHostKernel extension type
host_kernel — derived from the provider schema description.
Constructors
-
CodebuildProjectHostKernel.arg(TfArg<
String> arg) -
const
- CodebuildProjectHostKernel.expression(String template)
- CodebuildProjectHostKernel.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- linuxKernel4 → const CodebuildProjectHostKernel
- linuxKernel6 → const CodebuildProjectHostKernel
- linuxKernelLatest → const CodebuildProjectHostKernel
-
values
→ const List<
CodebuildProjectHostKernel>