CodebuildProjectSource class final

Typed helper for the source block of aws_codebuild_project (derived from provider schema).

Annotations
  • @immutable

Constructors

CodebuildProjectSource({TfArg<String>? buildspec, TfArg<num>? gitCloneDepth, TfArg<bool>? insecureSsl, TfArg<String>? location, TfArg<bool>? reportBuildStatus, required CodebuildProjectSecondarySourcesType type, CodebuildProjectAuth? auth, CodebuildProjectBuildStatusConfig? buildStatusConfig, CodebuildProjectGitSubmodulesConfig? gitSubmodulesConfig})
const

Properties

auth → CodebuildProjectAuth?
final
buildspec → TfArg<String>?
final
buildStatusConfig → CodebuildProjectBuildStatusConfig?
final
gitCloneDepth → TfArg<num>?
final
gitSubmodulesConfig → CodebuildProjectGitSubmodulesConfig?
final
hashCode → int
The hash code for this object.
no setterinherited
insecureSsl → TfArg<bool>?
final
location → TfArg<String>?
final
reportBuildStatus → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CodebuildProjectSecondarySourcesType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited