CodebuildReportGroupExportConfig class final
Typed helper for the export_config block of
aws_codebuild_report_group (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- CodebuildReportGroupExportConfig({required CodebuildReportGroupExportConfigType type, CodebuildReportGroupS3Destination? s3Destination})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s3Destination → CodebuildReportGroupS3Destination?
-
final
- type → CodebuildReportGroupExportConfigType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited