CodedeployDeploymentConfigTimeBasedCanary class final

Typed helper for the traffic_routing_config.time_based_canary block of aws_codedeploy_deployment_config (derived from provider schema).

Annotations
  • @immutable

Constructors

CodedeployDeploymentConfigTimeBasedCanary({TfArg<num>? interval, TfArg<num>? percentage})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
interval → TfArg<num>?
final
percentage → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited