CodedeployDeploymentConfigTrafficRoutingConfig class final
Typed helper for the traffic_routing_config block of
aws_codedeploy_deployment_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CodedeployDeploymentConfigTrafficRoutingConfig({TfArg<
CodedeployDeploymentConfigTrafficRoutingConfigType> ? type, CodedeployDeploymentConfigTimeBased? timeBased}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeBased → CodedeployDeploymentConfigTimeBased?
-
final
-
type
→ TfArg<
CodedeployDeploymentConfigTrafficRoutingConfigType> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited