CodedeployDeploymentGroupLoadBalancerInfo class final
Typed helper for the load_balancer_info block of
aws_codedeploy_deployment_group (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CodedeployDeploymentGroupLoadBalancerInfo({List<
CodedeployDeploymentGroupElbInfo> ? elbInfo, List<CodedeployDeploymentGroupTargetGroupInfo> ? targetGroupInfo, CodedeployDeploymentGroupTargetGroupPairInfo? targetGroupPairInfo}) -
const
Properties
-
elbInfo
→ List<
CodedeployDeploymentGroupElbInfo> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetGroupInfo
→ List<
CodedeployDeploymentGroupTargetGroupInfo> ? -
final
- targetGroupPairInfo → CodedeployDeploymentGroupTargetGroupPairInfo?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited