CodegurureviewerRepositoryAssociationKmsKeyDetails class final

Typed helper for the kms_key_details block of aws_codegurureviewer_repository_association (derived from provider schema).

Annotations
  • @immutable

Properties

encryptionOption → CodegurureviewerRepositoryAssociationEncryptionOption?
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → RefTo<AwsKmsKey>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited