CodepipelineCustomActionTypeConfigurationProperty class final

Typed helper for the configuration_property block of aws_codepipeline_custom_action_type (derived from provider schema).

Annotations
  • @immutable

Constructors

CodepipelineCustomActionTypeConfigurationProperty({TfArg<String>? description, required TfArg<bool> key, required TfArg<String> name, TfArg<bool>? queryable, required TfArg<bool> required, required TfArg<bool> secret, TfArg<CodepipelineCustomActionType>? type})
const

Properties

description → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
key → TfArg<bool>
final
name → TfArg<String>
final
queryable → TfArg<bool>?
final
required → TfArg<bool>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret → TfArg<bool>
final
type → TfArg<CodepipelineCustomActionType>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited