CodepipelineWebhookAuthenticationConfiguration class final

Typed helper for the authentication_configuration block of aws_codepipeline_webhook (derived from provider schema).

Annotations
  • @immutable

Constructors

CodepipelineWebhookAuthenticationConfiguration({TfArg<String>? allowedIpRange, TfArg<String>? secretToken})
const

Properties

allowedIpRange → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretToken → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited