CognitoUserPoolWebAuthnConfiguration class final
Typed helper for the web_authn_configuration block of
aws_cognito_user_pool (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CognitoUserPoolWebAuthnConfiguration({TfArg<
String> ? relyingPartyId, TfArg<CognitoUserPoolUserVerification> ? userVerification}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
relyingPartyId
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userVerification
→ TfArg<
CognitoUserPoolUserVerification> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited