ComprehendEntityRecognizerEntityTypes class final

Typed helper for the input_data_config.entity_types block of aws_comprehend_entity_recognizer (derived from provider schema).

Annotations
  • @immutable

Constructors

ComprehendEntityRecognizerEntityTypes({required TfArg<String> type})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited