ComprehendEntityRecognizerVpcConfig class final
Typed helper for the vpc_config block of
aws_comprehend_entity_recognizer (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComprehendEntityRecognizerVpcConfig({required TfArg<
List< securityGroupIds, required TfArg<RefTo< >AwsSecurityGroup> >List< subnets})RefTo< >AwsSubnet> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
securityGroupIds
→ TfArg<
List< RefTo< >AwsSecurityGroup> > -
final
-
subnets
→ TfArg<
List< RefTo< >AwsSubnet> > -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited