ConfigConfigRuleSource class final

Typed helper for the source block of aws_config_config_rule (derived from provider schema).

Annotations
  • @immutable

Constructors

ConfigConfigRuleSource({required TfArg<ConfigConfigRuleOwner> owner, TfArg<String>? sourceIdentifier, ConfigConfigRuleCustomPolicyDetails? customPolicyDetails, List<ConfigConfigRuleSourceDetail>? sourceDetail})
const

Properties

customPolicyDetails → ConfigConfigRuleCustomPolicyDetails?
final
hashCode → int
The hash code for this object.
no setterinherited
owner → TfArg<ConfigConfigRuleOwner>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDetail → List<ConfigConfigRuleSourceDetail>?
final
sourceIdentifier → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited