ConnectInstanceStorageConfigKinesisVideoStreamConfig class final

Typed helper for the storage_config.kinesis_video_stream_config block of aws_connect_instance_storage_config (derived from provider schema).

Annotations
  • @immutable

Constructors

ConnectInstanceStorageConfigKinesisVideoStreamConfig({required TfArg<String> prefix, required TfArg<num> retentionPeriodHours, required ConnectInstanceStorageConfigEncryptionConfig encryptionConfig})
const

Properties

encryptionConfig → ConnectInstanceStorageConfigEncryptionConfig
final
hashCode → int
The hash code for this object.
no setterinherited
prefix → TfArg<String>
final
retentionPeriodHours → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited