ConnectQueueStatus extension type
Connect Queue enum for status.
Constructors
-
ConnectQueueStatus.arg(TfArg<
String> arg) -
const
- ConnectQueueStatus.expression(String template)
- ConnectQueueStatus.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- disabled → const ConnectQueueStatus
- enabled → const ConnectQueueStatus
-
values
→ const List<
ConnectQueueStatus>