ConnectQuickConnectUserConfig class final

Typed helper for the quick_connect_config.user_config block of aws_connect_quick_connect (derived from provider schema).

Annotations
  • @immutable

Constructors

ConnectQuickConnectUserConfig({required TfArg<String> contactFlowId, required TfArg<String> userId})
const

Properties

contactFlowId → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited