CustomerprofilesDomainRuleBasedMatching class final

Typed helper for the rule_based_matching block of aws_customerprofiles_domain (derived from provider schema).

Annotations
  • @immutable

Constructors

CustomerprofilesDomainRuleBasedMatching({required TfArg<bool> enabled, TfArg<num>? maxAllowedRuleLevelForMatching, TfArg<num>? maxAllowedRuleLevelForMerging, CustomerprofilesDomainStatus? status, CustomerprofilesDomainAttributeTypesSelector? attributeTypesSelector, CustomerprofilesDomainConflictResolution? conflictResolution, CustomerprofilesDomainExportingConfig? exportingConfig, List<CustomerprofilesDomainMatchingRules>? matchingRules})
const

Properties

attributeTypesSelector → CustomerprofilesDomainAttributeTypesSelector?
final
conflictResolution → CustomerprofilesDomainConflictResolution?
final
enabled → TfArg<bool>
final
exportingConfig → CustomerprofilesDomainExportingConfig?
final
hashCode → int
The hash code for this object.
no setterinherited
matchingRules → List<CustomerprofilesDomainMatchingRules>?
final
maxAllowedRuleLevelForMatching → TfArg<num>?
final
maxAllowedRuleLevelForMerging → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CustomerprofilesDomainStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited