DataEc2HostFilter class final

Typed helper for the filter block of aws_ec2_host (derived from provider schema).

Annotations
  • @immutable

Constructors

DataEc2HostFilter({required TfArg<String> name, required TfArg<List<String>> values})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → TfArg<List<String>>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited