DataEcsTaskExecutionContainerOverrides class final

Typed helper for the overrides.container_overrides block of aws_ecs_task_execution (derived from provider schema).

Annotations
  • @immutable

Constructors

DataEcsTaskExecutionContainerOverrides({TfArg<List<String>>? command, TfArg<num>? cpu, TfArg<num>? memory, TfArg<num>? memoryReservation, required TfArg<String> name, List<DataEcsTaskExecutionEnvironment>? environment, List<DataEcsTaskExecutionResourceRequirements>? resourceRequirements})
const

Properties

command → TfArg<List<String>>?
final
cpu → TfArg<num>?
final
environment → List<DataEcsTaskExecutionEnvironment>?
final
hashCode → int
The hash code for this object.
no setterinherited
memory → TfArg<num>?
final
memoryReservation → TfArg<num>?
final
name → TfArg<String>
final
resourceRequirements → List<DataEcsTaskExecutionResourceRequirements>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited