DataEcsTaskExecutionOverrides class final

Typed helper for the overrides block of aws_ecs_task_execution (derived from provider schema).

Annotations
  • @immutable

Constructors

DataEcsTaskExecutionOverrides({TfArg<String>? cpu, RefTo<AwsIamRole>? executionRoleArn, TfArg<String>? memory, RefTo<AwsIamRole>? taskRoleArn, List<DataEcsTaskExecutionContainerOverrides>? containerOverrides})
const

Properties

containerOverrides → List<DataEcsTaskExecutionContainerOverrides>?
final
cpu → TfArg<String>?
final
executionRoleArn → RefTo<AwsIamRole>?
final
hashCode → int
The hash code for this object.
no setterinherited
memory → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskRoleArn → RefTo<AwsIamRole>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited