DataGlueScriptDagNode class final

Typed helper for the dag_node block of aws_glue_script (derived from provider schema).

Annotations
  • @immutable

Constructors

DataGlueScriptDagNode({required TfArg<String> id, TfArg<num>? lineNumber, required TfArg<String> nodeType, required List<DataGlueScriptArgs> args})
const

Properties

args → List<DataGlueScriptArgs>
final
hashCode → int
The hash code for this object.
no setterinherited
id → TfArg<String>
final
lineNumber → TfArg<num>?
final
nodeType → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited