DataIdentitystoreUserExternalId class final

Typed helper for the alternate_identifier.external_id block of aws_identitystore_user (derived from provider schema).

Annotations
  • @immutable

Constructors

DataIdentitystoreUserExternalId({required TfArg<String> id, required TfArg<String> issuer})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → TfArg<String>
final
issuer → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited