DataNetworkmanagerCoreNetworkPolicyDocumentEdgeLocationAssociation class final

Typed helper for the segment_actions.edge_location_association block of aws_networkmanager_core_network_policy_document (derived from provider schema).

Annotations
  • @immutable

Constructors

DataNetworkmanagerCoreNetworkPolicyDocumentEdgeLocationAssociation({required TfArg<String> edgeLocation, required TfArg<String> peerEdgeLocation, required TfArg<List<String>> routingPolicyNames})
const

Properties

edgeLocation → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
peerEdgeLocation → TfArg<String>
final
routingPolicyNames → TfArg<List<String>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited