DataNetworkmanagerCoreNetworkPolicyDocumentRuleDefinitionAction class final

Typed helper for the routing_policies.routing_policy_rules.rule_definition.action block of aws_networkmanager_core_network_policy_document (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<String>
final
value → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited