DataNetworkmanagerCoreNetworkPolicyDocumentVia class final

Typed helper for the segment_actions.via block of aws_networkmanager_core_network_policy_document (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
networkFunctionGroups → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withEdgeOverride → List<DataNetworkmanagerCoreNetworkPolicyDocumentWithEdgeOverride>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited