DataSsmPatchBaselinesFilter class final

Typed helper for the filter block of aws_ssm_patch_baselines (derived from provider schema).

Annotations
  • @immutable

Constructors

DataSsmPatchBaselinesFilter({required TfArg<String> key, required TfArg<List<String>> values})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → TfArg<List<String>>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited