DataexchangeEventActionEncryption class final

Typed helper for the action.export_revision_to_s3.encryption block of aws_dataexchange_event_action (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyArn → RefTo<AwsKmsKey>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DataexchangeEventActionType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited