DatasyncLocationFsxOntapFileSystemSmb class final

Typed helper for the protocol.smb block of aws_datasync_location_fsx_ontap_file_system (derived from provider schema).

Annotations
  • @immutable

Constructors

DatasyncLocationFsxOntapFileSystemSmb({TfArg<String>? domain, required Sensitive<String> password, required TfArg<String> user, required DatasyncLocationFsxOntapFileSystemSmbMountOptions mountOptions})
const

Properties

domain → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
mountOptions → DatasyncLocationFsxOntapFileSystemSmbMountOptions
final
password → Sensitive<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited