DatasyncLocationFsxOpenzfsFileSystemMountOptions class final

Typed helper for the protocol.nfs.mount_options block of aws_datasync_location_fsx_openzfs_file_system (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → TfArg<DatasyncLocationFsxOpenzfsFileSystemVersion>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited