DatasyncTaskReportConfig class final

Typed helper for the task_report_config block of aws_datasync_task (derived from provider schema).

Annotations
  • @immutable

Constructors

DatasyncTaskReportConfig({DatasyncTaskOutputType? outputType, DatasyncTaskReportLevel? reportLevel, DatasyncTaskS3ObjectVersioning? s3ObjectVersioning, DatasyncTaskReportOverrides? reportOverrides, required DatasyncTaskS3Destination s3Destination})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
outputType → DatasyncTaskOutputType?
final
reportLevel → DatasyncTaskReportLevel?
final
reportOverrides → DatasyncTaskReportOverrides?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Destination → DatasyncTaskS3Destination
final
s3ObjectVersioning → DatasyncTaskS3ObjectVersioning?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited