DatazoneAssetTypeFormsInput class final

Typed helper for the forms_input block of aws_datazone_asset_type (derived from provider schema).

Annotations
  • @immutable

Constructors

DatazoneAssetTypeFormsInput({required TfArg<String> mapBlockKey, TfArg<bool>? required, required TfArg<String> typeIdentifier, required TfArg<String> typeRevision})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
mapBlockKey → TfArg<String>
final
required → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeIdentifier → TfArg<String>
final
typeRevision → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited