DatazoneEnvironmentUserParameters class final

Typed helper for the user_parameters block of aws_datazone_environment (derived from provider schema).

Annotations
  • @immutable

Constructors

DatazoneEnvironmentUserParameters({TfArg<String>? name, TfArg<String>? value})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited