DatazonePolicyGrantCreateDomainUnit class final

Typed helper for the detail.create_domain_unit block of aws_datazone_policy_grant (derived from provider schema).

Annotations
  • @immutable

Constructors

DatazonePolicyGrantCreateDomainUnit({TfArg<bool>? includeChildDomainUnits})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeChildDomainUnits → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited