DbProxyTargetDatabaseDbClusterIdentifier class final
The DbProxyTargetDatabase.dbClusterIdentifier choice: sets db_cluster_identifier.
- Inheritance
-
- Object
- DbProxyTargetDatabase
- DbProxyTargetDatabaseDbClusterIdentifier
Constructors
-
DbProxyTargetDatabaseDbClusterIdentifier(TfArg<
String> dbClusterIdentifier) -
const
Properties
-
dbClusterIdentifier
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited