DirectoryServiceDirectoryVpcSettings class final

Typed helper for the vpc_settings block of aws_directory_service_directory (derived from provider schema).

Annotations
  • @immutable

Constructors

DirectoryServiceDirectoryVpcSettings({required TfArg<List<RefTo<AwsSubnet>>> subnetIds, required RefTo<AwsVpc> vpcId})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetIds → TfArg<List<RefTo<AwsSubnet>>>
final
vpcId → RefTo<AwsVpc>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited