DlmLifecyclePolicyEncryptionConfiguration class final

Typed helper for the policy_details.action.cross_region_copy.encryption_configuration block of aws_dlm_lifecycle_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

DlmLifecyclePolicyEncryptionConfiguration({TfArg<String>? cmkArn, TfArg<bool>? encrypted})
const

Properties

cmkArn → TfArg<String>?
final
encrypted → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited