DlmLifecyclePolicyFastRestoreRule class final

Typed helper for the policy_details.schedule.fast_restore_rule block of aws_dlm_lifecycle_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

DlmLifecyclePolicyFastRestoreRule({required TfArg<List<String>> availabilityZones, TfArg<num>? count, TfArg<num>? interval, TfArg<DlmLifecyclePolicyDeprecateRuleIntervalUnit>? intervalUnit})
const

Properties

availabilityZones → TfArg<List<String>>
final
count → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
interval → TfArg<num>?
final
intervalUnit → TfArg<DlmLifecyclePolicyDeprecateRuleIntervalUnit>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited