DmsDataProviderRedshiftSettings class final

Typed helper for the settings.redshift_settings block of aws_dms_data_provider (derived from provider schema).

Annotations
  • @immutable

Constructors

DmsDataProviderRedshiftSettings({TfArg<String>? databaseName, TfArg<num>? port, TfArg<String>? s3AccessRoleArn, TfArg<String>? s3Path, TfArg<String>? serverName})
const

Properties

databaseName → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
port → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3AccessRoleArn → TfArg<String>?
final
s3Path → TfArg<String>?
final
serverName → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited