DmsEndpointPostgresSettings class final

Typed helper for the postgres_settings block of aws_dms_endpoint (derived from provider schema).

Annotations
  • @immutable

Constructors

DmsEndpointPostgresSettings({TfArg<String>? afterConnectScript, DmsEndpointMysqlSettingsAuthenticationMethod? authenticationMethod, TfArg<String>? babelfishDatabaseName, TfArg<bool>? captureDdls, DmsEndpointDatabaseMode? databaseMode, TfArg<String>? ddlArtifactsSchema, TfArg<num>? executeTimeout, TfArg<bool>? failTasksOnLobTruncation, TfArg<bool>? heartbeatEnable, TfArg<num>? heartbeatFrequency, TfArg<String>? heartbeatSchema, TfArg<bool>? mapBooleanAsBoolean, TfArg<bool>? mapJsonbAsClob, DmsEndpointMapLongVarcharAs? mapLongVarcharAs, TfArg<num>? maxFileSize, DmsEndpointPluginName? pluginName, TfArg<String>? serviceAccessRoleArn, TfArg<String>? slotName})
const

Properties

afterConnectScript → TfArg<String>?
final
authenticationMethod → DmsEndpointMysqlSettingsAuthenticationMethod?
final
babelfishDatabaseName → TfArg<String>?
final
captureDdls → TfArg<bool>?
final
databaseMode → DmsEndpointDatabaseMode?
final
ddlArtifactsSchema → TfArg<String>?
final
executeTimeout → TfArg<num>?
final
failTasksOnLobTruncation → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
heartbeatEnable → TfArg<bool>?
final
heartbeatFrequency → TfArg<num>?
final
heartbeatSchema → TfArg<String>?
final
mapBooleanAsBoolean → TfArg<bool>?
final
mapJsonbAsClob → TfArg<bool>?
final
mapLongVarcharAs → DmsEndpointMapLongVarcharAs?
final
maxFileSize → TfArg<num>?
final
pluginName → DmsEndpointPluginName?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccessRoleArn → TfArg<String>?
final
slotName → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited