DmsMigrationProjectTargetDataProviderDescriptor class final

Typed helper for the target_data_provider_descriptor block of aws_dms_migration_project (derived from provider schema).

Annotations
  • @immutable

Constructors

DmsMigrationProjectTargetDataProviderDescriptor({required TfArg<String> dataProviderArn, TfArg<String>? secretsManagerAccessRoleArn, TfArg<String>? secretsManagerSecretId})
const

Properties

dataProviderArn → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretsManagerAccessRoleArn → TfArg<String>?
final
secretsManagerSecretId → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited