DocdbClusterInstanceIdentifierPrefix class final
The DocdbClusterInstanceIdentifier.identifierPrefix choice: sets identifier_prefix.
- Inheritance
-
- Object
- DocdbClusterInstanceIdentifier
- DocdbClusterInstanceIdentifierPrefix
Constructors
-
DocdbClusterInstanceIdentifierPrefix(TfArg<
String> identifierPrefix) -
const
Properties
-
argMap
→ Map<
String, TfArg< Object?> > -
The resource arguments behind encode, as the caller's
TfArgs.no setteroverride - blockKey → String
-
The Terraform argument this choice sets.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
identifierPrefix
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited