DynamodbTableExportIncrementalExportSpecification class final

Typed helper for the incremental_export_specification block of aws_dynamodb_table_export (derived from provider schema).

Annotations
  • @immutable

Constructors

DynamodbTableExportIncrementalExportSpecification({TfArg<String>? exportFromTime, TfArg<String>? exportToTime, DynamodbTableExportViewType? exportViewType})
const

Properties

exportFromTime → TfArg<String>?
final
exportToTime → TfArg<String>?
final
exportViewType → DynamodbTableExportViewType?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited