Ec2CapacityBlockReservationInstancePlatform enum
Ec2 Capacity Block Reservation Instance enum for instance_platform.
Values
- linuxUnix → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Linux/UNIX') - redHatEnterpriseLinux → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Red Hat Enterprise Linux') - suseLinux → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('SUSE Linux') - windows → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Windows') - windowsWithSqlServer → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Windows with SQL Server') - windowsWithSqlServerEnterprise → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Windows with SQL Server Enterprise') - windowsWithSqlServerStandard → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Windows with SQL Server Standard') - windowsWithSqlServerWeb → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Windows with SQL Server Web') - linuxWithSqlServerStandard → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Linux with SQL Server Standard') - linuxWithSqlServerWeb → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Linux with SQL Server Web') - linuxWithSqlServerEnterprise → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Linux with SQL Server Enterprise') - rhelWithSqlServerStandard → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('RHEL with SQL Server Standard') - rhelWithSqlServerEnterprise → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('RHEL with SQL Server Enterprise') - rhelWithSqlServerWeb → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('RHEL with SQL Server Web') - rhelWithHa → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('RHEL with HA') - rhelWithHaAndSqlServerStandard → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('RHEL with HA and SQL Server Standard') - rhelWithHaAndSqlServerEnterprise → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('RHEL with HA and SQL Server Enterprise') - ubuntuPro → const Ec2CapacityBlockReservationInstancePlatform
-
const Ec2CapacityBlockReservationInstancePlatform('Ubuntu Pro')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terraformValue → String
-
The Terraform-side string literal this enum value encodes to.
Convention: emitted exactly as it appears in provider docs (typically
SCREAMING_SNAKE_CASEfor GCP).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Ec2CapacityBlockReservationInstancePlatform> - A constant List of the values in this enum, in order of their declaration.