Ec2ClientVpnEndpointTransitGatewayConfiguration class final

Typed helper for the transit_gateway_configuration block of aws_ec2_client_vpn_endpoint (derived from provider schema).

Annotations
  • @immutable

Constructors

Ec2ClientVpnEndpointTransitGatewayConfiguration({Ec2ClientVpnEndpointAvailabilityZone? availabilityZone, TfArg<String>? transitGatewayId})
const

Properties

availabilityZone → Ec2ClientVpnEndpointAvailabilityZone?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitGatewayId → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited