EcsCapacityProviderAutoScalingGroupProvider class final

Typed helper for the auto_scaling_group_provider block of aws_ecs_capacity_provider (derived from provider schema).

Annotations
  • @immutable

Constructors

EcsCapacityProviderAutoScalingGroupProvider({required TfArg<String> autoScalingGroupArn, TfArg<EcsCapacityProviderManagedDraining>? managedDraining, TfArg<EcsCapacityProviderManagedTerminationProtection>? managedTerminationProtection, EcsCapacityProviderManagedScaling? managedScaling})
const

Properties

autoScalingGroupArn → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
managedDraining → TfArg<EcsCapacityProviderManagedDraining>?
final
managedScaling → EcsCapacityProviderManagedScaling?
final
managedTerminationProtection → TfArg<EcsCapacityProviderManagedTerminationProtection>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited