EcsCapacityProviderTotalLocalStorageGb class final

Typed helper for the managed_instances_provider.instance_launch_template.instance_requirements.total_local_storage_gb block of aws_ecs_capacity_provider (derived from provider schema).

Annotations
  • @immutable

Constructors

EcsCapacityProviderTotalLocalStorageGb({TfArg<num>? max, TfArg<num>? min})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
max → TfArg<num>?
final
min → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited