EcsDaemonTaskDefinitionRepositoryCredentials class final

Typed helper for the container_definition.repository_credentials block of aws_ecs_daemon_task_definition (derived from provider schema).

Annotations
  • @immutable

Constructors

EcsDaemonTaskDefinitionRepositoryCredentials({required TfArg<String> credentialsParameter})
const

Properties

credentialsParameter → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited