EcsServiceAccessLogConfiguration class final

Typed helper for the service_connect_configuration.access_log_configuration block of aws_ecs_service (derived from provider schema).

Annotations
  • @immutable

Constructors

EcsServiceAccessLogConfiguration({required EcsServiceFormat format, EcsServiceIncludeQueryParameters? includeQueryParameters})
const

Properties

format → EcsServiceFormat
final
hashCode → int
The hash code for this object.
no setterinherited
includeQueryParameters → EcsServiceIncludeQueryParameters?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited