EcsTaskDefinitionEfsVolumeConfiguration class final
Typed helper for the volume.efs_volume_configuration block of
aws_ecs_task_definition (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
EcsTaskDefinitionEfsVolumeConfiguration({required TfArg<
String> fileSystemId, TfArg<String> ? rootDirectory, EcsTaskDefinitionTransitEncryption? transitEncryption, TfArg<num> ? transitEncryptionPort, EcsTaskDefinitionEfsVolumeConfigurationAuthorizationConfig? authorizationConfig}) -
const
Properties
-
final
-
fileSystemId
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rootDirectory
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitEncryption → EcsTaskDefinitionTransitEncryption?
-
final
-
transitEncryptionPort
→ TfArg<
num> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited