EcsTaskSetCapacityProviderStrategy class final

Typed helper for the capacity_provider_strategy block of aws_ecs_task_set (derived from provider schema).

Annotations
  • @immutable

Constructors

EcsTaskSetCapacityProviderStrategy({TfArg<num>? base, required TfArg<String> capacityProvider, required TfArg<num> weight})
const

Properties

base → TfArg<num>?
final
capacityProvider → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited