EcsTaskSetComputeCapacityProviderStrategy class final
The EcsTaskSetCompute.capacityProviderStrategy choice: sets capacity_provider_strategy.
- Inheritance
-
- Object
- EcsTaskSetCompute
- EcsTaskSetComputeCapacityProviderStrategy
Constructors
-
EcsTaskSetComputeCapacityProviderStrategy(List<
EcsTaskSetCapacityProviderStrategy> capacityProviderStrategy) -
const
Properties
-
capacityProviderStrategy
→ List<
EcsTaskSetCapacityProviderStrategy> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited