EcsTaskSetLaunchType extension type
Ecs Task Set Launch enum for launch_type.
Constructors
-
EcsTaskSetLaunchType.arg(TfArg<
String> arg) -
const
- EcsTaskSetLaunchType.expression(String template)
- EcsTaskSetLaunchType.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- ec2 → const EcsTaskSetLaunchType
- external → const EcsTaskSetLaunchType
- fargate → const EcsTaskSetLaunchType
- managedInstances → const EcsTaskSetLaunchType
-
values
→ const List<
EcsTaskSetLaunchType>