EcsTaskSetNetworkConfiguration class final

Typed helper for the network_configuration block of aws_ecs_task_set (derived from provider schema).

Annotations
  • @immutable

Constructors

EcsTaskSetNetworkConfiguration({TfArg<bool>? assignPublicIp, TfArg<List<RefTo<AwsSecurityGroup>>>? securityGroups, required TfArg<List<RefTo<AwsSubnet>>> subnets})
const

Properties

assignPublicIp → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroups → TfArg<List<RefTo<AwsSecurityGroup>>>?
final
subnets → TfArg<List<RefTo<AwsSubnet>>>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited