EfsFileSystemLifecyclePolicy class final

Typed helper for the lifecycle_policy block of aws_efs_file_system (derived from provider schema).

Annotations
  • @immutable

Constructors

EfsFileSystemLifecyclePolicy({EfsFileSystemTransitionToArchive? transitionToArchive, EfsFileSystemTransitionToIa? transitionToIa, EfsFileSystemTransitionToPrimaryStorageClass? transitionToPrimaryStorageClass})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitionToArchive → EfsFileSystemTransitionToArchive?
final
transitionToIa → EfsFileSystemTransitionToIa?
final
transitionToPrimaryStorageClass → EfsFileSystemTransitionToPrimaryStorageClass?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited