EksNodeGroupMaxParallelNodesRepairedCount class final
The EksNodeGroupMaxParallelNodesRepaired.maxParallelNodesRepairedCount choice: sets max_parallel_nodes_repaired_count.
- Inheritance
-
- Object
- EksNodeGroupMaxParallelNodesRepaired
- EksNodeGroupMaxParallelNodesRepairedCount
Constructors
-
EksNodeGroupMaxParallelNodesRepairedCount(TfArg<
num> maxParallelNodesRepairedCount) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maxParallelNodesRepairedCount
→ TfArg<
num> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited