EksNodeGroupUpdateConfig class final

Typed helper for the update_config block of aws_eks_node_group (derived from provider schema).

Annotations
  • @immutable

Constructors

EksNodeGroupUpdateConfig({required EksNodeGroupMaxUnavailable maxUnavailable, TfArg<EksNodeGroupUpdateStrategy>? updateStrategy})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxUnavailable → EksNodeGroupMaxUnavailable
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateStrategy → TfArg<EksNodeGroupUpdateStrategy>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited