ElasticacheServerlessCacheEcpuPerSecond class final

Typed helper for the cache_usage_limits.ecpu_per_second block of aws_elasticache_serverless_cache (derived from provider schema).

Annotations
  • @immutable

Constructors

ElasticacheServerlessCacheEcpuPerSecond({TfArg<num>? maximum, TfArg<num>? minimum})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximum → TfArg<num>?
final
minimum → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited