EmrClusterInstanceTypeConfigs class final

Typed helper for the core_instance_fleet.instance_type_configs block of aws_emr_cluster (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

EmrClusterInstanceTypeConfigs({TfArg<String>? bidPrice, TfArg<num>? bidPriceAsPercentageOfOnDemandPrice, required TfArg<String> instanceType, TfArg<num>? weightedCapacity, List<EmrClusterInstanceTypeConfigsEbsConfig>? ebsConfig})
const

Properties

bidPrice → TfArg<String>?
final
bidPriceAsPercentageOfOnDemandPrice → TfArg<num>?
final
ebsConfig → List<EmrClusterInstanceTypeConfigsEbsConfig>?
final
hashCode → int
The hash code for this object.
no setterinherited
instanceType → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weightedCapacity → TfArg<num>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited