EmrserverlessApplicationAutoStopConfiguration class final

Typed helper for the auto_stop_configuration block of aws_emrserverless_application (derived from provider schema).

Annotations
  • @immutable

Constructors

EmrserverlessApplicationAutoStopConfiguration({TfArg<bool>? enabled, TfArg<num>? idleTimeoutMinutes})
const

Properties

enabled → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
idleTimeoutMinutes → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited