EmrserverlessApplicationInitialCapacity class final

Typed helper for the initial_capacity block of aws_emrserverless_application (derived from provider schema).

Annotations
  • @immutable

Constructors

EmrserverlessApplicationInitialCapacity({required TfArg<String> initialCapacityType, EmrserverlessApplicationInitialCapacityConfig? initialCapacityConfig})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialCapacityConfig → EmrserverlessApplicationInitialCapacityConfig?
final
initialCapacityType → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited