EmrserverlessApplicationInitialCapacityConfig class final

Typed helper for the initial_capacity.initial_capacity_config block of aws_emrserverless_application (derived from provider schema).

Annotations
  • @immutable

Constructors

EmrserverlessApplicationInitialCapacityConfig({required TfArg<num> workerCount, EmrserverlessApplicationWorkerConfiguration? workerConfiguration})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workerConfiguration → EmrserverlessApplicationWorkerConfiguration?
final
workerCount → TfArg<num>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited