EmrserverlessApplicationManagedPersistenceMonitoringConfiguration class final

Typed helper for the monitoring_configuration.managed_persistence_monitoring_configuration block of aws_emrserverless_application (derived from provider schema).

Annotations
  • @immutable

Constructors

EmrserverlessApplicationManagedPersistenceMonitoringConfiguration({TfArg<bool>? enabled, RefTo<AwsKmsKey>? encryptionKeyArn})
const

Properties

enabled → TfArg<bool>?
final
encryptionKeyArn → RefTo<AwsKmsKey>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited