EmrserverlessApplicationRuntimeConfiguration class final

Typed helper for the runtime_configuration block of aws_emrserverless_application (derived from provider schema).

Annotations
  • @immutable

Constructors

EmrserverlessApplicationRuntimeConfiguration({required TfArg<String> classification, TfArg<Map<String, String>>? properties})
const

Properties

classification → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
properties → TfArg<Map<String, String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited