FinspaceKxClusterCacheStorageConfigurations class final

Typed helper for the cache_storage_configurations block of aws_finspace_kx_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

FinspaceKxClusterCacheStorageConfigurations({required TfArg<num> size, required TfArg<String> type})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → TfArg<num>
final
type → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited