FlowLogSourceSubnetId class final

The FlowLogSource.subnetId choice: sets subnet_id.

Inheritance

Constructors

FlowLogSourceSubnetId(RefTo<AwsSubnet> subnetId)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetId → RefTo<AwsSubnet>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited