FmsPolicyIcmpTypeCode class final

Typed helper for the security_service_policy_data.policy_option.network_acl_common_policy.network_acl_entry_set.first_entry.icmp_type_code block of aws_fms_policy (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

FmsPolicyIcmpTypeCode({TfArg<num>? code, TfArg<num>? type})
const

Properties

code → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<num>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited