FmsResourceSet class final

Typed helper for the resource_set block of aws_fms_resource_set (derived from provider schema).

Annotations
  • @immutable

Constructors

FmsResourceSet({TfArg<String>? description, required TfArg<String> name, TfArg<String>? resourceSetStatus, TfArg<List<String>>? resourceTypeList, TfArg<String>? updateToken})
const

Properties

description → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
resourceSetStatus → TfArg<String>?
final
resourceTypeList → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateToken → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited