FsxFileCacheLustreConfiguration class final

Typed helper for the lustre_configuration block of aws_fsx_file_cache (derived from provider schema).

Annotations
  • @immutable

Constructors

FsxFileCacheLustreConfiguration({required FsxFileCacheDeploymentType deploymentType, required TfArg<num> perUnitStorageThroughput, TfArg<String>? weeklyMaintenanceStartTime, required List<FsxFileCacheMetadataConfiguration> metadataConfiguration})
const

Properties

deploymentType → FsxFileCacheDeploymentType
final
hashCode → int
The hash code for this object.
no setterinherited
metadataConfiguration → List<FsxFileCacheMetadataConfiguration>
final
perUnitStorageThroughput → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weeklyMaintenanceStartTime → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited