FsxOpenzfsFileSystemClientConfigurations class final

Typed helper for the root_volume_configuration.nfs_exports.client_configurations block of aws_fsx_openzfs_file_system (derived from provider schema).

Annotations
  • @immutable

Constructors

FsxOpenzfsFileSystemClientConfigurations({required TfArg<String> clients, required TfArg<List<String>> options})
const

Properties

clients → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
options → TfArg<List<String>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited