FsxWindowsFileSystemAuditLogConfiguration class final

Typed helper for the audit_log_configuration block of aws_fsx_windows_file_system (derived from provider schema).

Annotations
  • @immutable

Constructors

FsxWindowsFileSystemAuditLogConfiguration({TfArg<String>? auditLogDestination, TfArg<FsxWindowsFileSystemFileAccessAuditLogLevel>? fileAccessAuditLogLevel, TfArg<FsxWindowsFileSystemFileShareAccessAuditLogLevel>? fileShareAccessAuditLogLevel})
const

Properties

auditLogDestination → TfArg<String>?
final
fileAccessAuditLogLevel → TfArg<FsxWindowsFileSystemFileAccessAuditLogLevel>?
final
fileShareAccessAuditLogLevel → TfArg<FsxWindowsFileSystemFileShareAccessAuditLogLevel>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited