FsxWindowsFileSystemDiskIopsConfiguration class final

Typed helper for the disk_iops_configuration block of aws_fsx_windows_file_system (derived from provider schema).

Annotations
  • @immutable

Constructors

FsxWindowsFileSystemDiskIopsConfiguration({TfArg<num>? iops, TfArg<FsxWindowsFileSystemMode>? mode})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
iops → TfArg<num>?
final
mode → TfArg<FsxWindowsFileSystemMode>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited