GameliftGameServerGroupTargetTrackingConfiguration class final
Typed helper for the auto_scaling_policy.target_tracking_configuration block of
aws_gamelift_game_server_group (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
GameliftGameServerGroupTargetTrackingConfiguration({required TfArg<
num> targetValue}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetValue
→ TfArg<
num> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited