GameliftScriptStorageLocation class final

Typed helper for the storage_location block of aws_gamelift_script (derived from provider schema).

Annotations
  • @immutable

Constructors

GameliftScriptStorageLocation({required RefTo<AwsS3Bucket> bucket, required TfArg<String> key, TfArg<String>? objectVersion, required RefTo<AwsIamRole> roleArn})
const

Properties

bucket → RefTo<AwsS3Bucket>
final
hashCode → int
The hash code for this object.
no setterinherited
key → TfArg<String>
final
objectVersion → TfArg<String>?
final
roleArn → RefTo<AwsIamRole>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited