GlobalacceleratorCustomRoutingEndpointGroupDestinationConfiguration class final

Typed helper for the destination_configuration block of aws_globalaccelerator_custom_routing_endpoint_group (derived from provider schema).

Annotations
  • @immutable

Constructors

GlobalacceleratorCustomRoutingEndpointGroupDestinationConfiguration({required TfArg<num> fromPort, required List<TfArg<GlobalacceleratorCustomRoutingEndpointGroupProtocols>> protocols, required TfArg<num> toPort})
const

Properties

fromPort → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
protocols → List<TfArg<GlobalacceleratorCustomRoutingEndpointGroupProtocols>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toPort → TfArg<num>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited