GlueCrawlerLakeFormationConfiguration class final

Typed helper for the lake_formation_configuration block of aws_glue_crawler (derived from provider schema).

Annotations
  • @immutable

Constructors

GlueCrawlerLakeFormationConfiguration({TfArg<String>? accountId, TfArg<bool>? useLakeFormationCredentials})
const

Properties

accountId → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useLakeFormationCredentials → TfArg<bool>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited