GlueDataCatalogEncryptionSettingsConnectionPasswordEncryption class final

Typed helper for the data_catalog_encryption_settings.connection_password_encryption block of aws_glue_data_catalog_encryption_settings (derived from provider schema).

Annotations
  • @immutable

Constructors

GlueDataCatalogEncryptionSettingsConnectionPasswordEncryption({TfArg<String>? awsKmsKeyId, required TfArg<bool> returnConnectionPasswordEncrypted})
const

Properties

awsKmsKeyId → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
returnConnectionPasswordEncrypted → TfArg<bool>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited