GlueDataCatalogEncryptionSettingsEncryptionAtRest class final

Typed helper for the data_catalog_encryption_settings.encryption_at_rest block of aws_glue_data_catalog_encryption_settings (derived from provider schema).

Annotations
  • @immutable

Constructors

GlueDataCatalogEncryptionSettingsEncryptionAtRest({required GlueDataCatalogEncryptionSettingsCatalogEncryptionMode catalogEncryptionMode, TfArg<String>? catalogEncryptionServiceRole, TfArg<String>? sseAwsKmsKeyId})
const

Properties

catalogEncryptionMode → GlueDataCatalogEncryptionSettingsCatalogEncryptionMode
final
catalogEncryptionServiceRole → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sseAwsKmsKeyId → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited