IdentitystoreUserPhoneNumbers class final

Typed helper for the phone_numbers block of aws_identitystore_user (derived from provider schema).

Annotations
  • @immutable

Constructors

IdentitystoreUserPhoneNumbers({TfArg<bool>? primary, TfArg<String>? type, TfArg<String>? value})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
primary → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<String>?
final
value → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited