ImagebuilderDistributionConfigurationAmiDistributionConfiguration class final

Typed helper for the distribution.ami_distribution_configuration block of aws_imagebuilder_distribution_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

ImagebuilderDistributionConfigurationAmiDistributionConfiguration({TfArg<Map<String, String>>? amiTags, TfArg<String>? description, RefTo<AwsKmsKey>? kmsKeyId, TfArg<String>? name, TfArg<List<String>>? targetAccountIds, ImagebuilderDistributionConfigurationLaunchPermission? launchPermission})
const

Properties

amiTags → TfArg<Map<String, String>>?
final
description → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → RefTo<AwsKmsKey>?
final
launchPermission → ImagebuilderDistributionConfigurationLaunchPermission?
final
name → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetAccountIds → TfArg<List<String>>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited