ImagebuilderDistributionConfigurationS3ExportConfiguration class final

Typed helper for the distribution.s3_export_configuration block of aws_imagebuilder_distribution_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

ImagebuilderDistributionConfigurationS3ExportConfiguration({required ImagebuilderDistributionConfigurationDiskImageFormat diskImageFormat, required RefTo<AwsIamRole> roleName, required RefTo<AwsS3Bucket> s3Bucket, TfArg<String>? s3Prefix})
const

Properties

diskImageFormat → ImagebuilderDistributionConfigurationDiskImageFormat
final
hashCode → int
The hash code for this object.
no setterinherited
roleName → RefTo<AwsIamRole>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Bucket → RefTo<AwsS3Bucket>
final
s3Prefix → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited