ImagebuilderImagePipelineImageScanningConfiguration class final

Typed helper for the image_scanning_configuration block of aws_imagebuilder_image_pipeline (derived from provider schema).

Annotations
  • @immutable

Constructors

ImagebuilderImagePipelineImageScanningConfiguration({TfArg<bool>? imageScanningEnabled, ImagebuilderImagePipelineEcrConfiguration? ecrConfiguration})
const

Properties

ecrConfiguration → ImagebuilderImagePipelineEcrConfiguration?
final
hashCode → int
The hash code for this object.
no setterinherited
imageScanningEnabled → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited