ImagebuilderImagePipelineLoggingConfiguration class final

Typed helper for the logging_configuration block of aws_imagebuilder_image_pipeline (derived from provider schema).

Annotations
  • @immutable

Constructors

ImagebuilderImagePipelineLoggingConfiguration({TfArg<String>? imageLogGroupName, TfArg<String>? pipelineLogGroupName})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageLogGroupName → TfArg<String>?
final
pipelineLogGroupName → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited