ImagebuilderImageScanningConfiguration class final
Typed helper for the image_scanning_configuration block of
aws_imagebuilder_image (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ImagebuilderImageScanningConfiguration({TfArg<
bool> ? imageScanningEnabled, ImagebuilderImageEcrConfiguration? ecrConfiguration}) -
const
Properties
- ecrConfiguration → ImagebuilderImageEcrConfiguration?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imageScanningEnabled
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited