ImagebuilderImageTestsConfiguration class final

Typed helper for the image_tests_configuration block of aws_imagebuilder_image (derived from provider schema).

Annotations
  • @immutable

Constructors

ImagebuilderImageTestsConfiguration({TfArg<bool>? imageTestsEnabled, TfArg<num>? timeoutMinutes})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageTestsEnabled → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutMinutes → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited