ImagebuilderImageWorkflow class final

Typed helper for the workflow block of aws_imagebuilder_image (derived from provider schema).

Annotations
  • @immutable

Constructors

ImagebuilderImageWorkflow({TfArg<ImagebuilderImageOnFailure>? onFailure, TfArg<String>? parallelGroup, required TfArg<String> workflowArn, List<ImagebuilderImageParameter>? parameter})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
onFailure → TfArg<ImagebuilderImageOnFailure>?
final
parallelGroup → TfArg<String>?
final
parameter → List<ImagebuilderImageParameter>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workflowArn → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited