ImagebuilderInfrastructureConfigurationInstanceMetadataOptions class final

Typed helper for the instance_metadata_options block of aws_imagebuilder_infrastructure_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

ImagebuilderInfrastructureConfigurationInstanceMetadataOptions({TfArg<num>? httpPutResponseHopLimit, TfArg<ImagebuilderInfrastructureConfigurationHttpTokens>? httpTokens})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpPutResponseHopLimit → TfArg<num>?
final
httpTokens → TfArg<ImagebuilderInfrastructureConfigurationHttpTokens>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited