ImagebuilderLifecyclePolicyDetail class final
Typed helper for the policy_detail block of
aws_imagebuilder_lifecycle_policy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ImagebuilderLifecyclePolicyDetail({List<
ImagebuilderLifecyclePolicyAction> ? action, List<ImagebuilderLifecyclePolicyExclusionRules> ? exclusionRules, List<ImagebuilderLifecyclePolicyFilter> ? filter}) -
const
Properties
-
action
→ List<
ImagebuilderLifecyclePolicyAction> ? -
final
-
exclusionRules
→ List<
ImagebuilderLifecyclePolicyExclusionRules> ? -
final
-
filter
→ List<
ImagebuilderLifecyclePolicyFilter> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited