ImagebuilderLifecyclePolicyIncludeResources class final

Typed helper for the policy_detail.action.include_resources block of aws_imagebuilder_lifecycle_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

ImagebuilderLifecyclePolicyIncludeResources({TfArg<bool>? amis, TfArg<bool>? containers, TfArg<bool>? snapshots})
const

Properties

amis → TfArg<bool>?
final
containers → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshots → TfArg<bool>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited