ImagebuilderLifecyclePolicyLastLaunched class final

Typed helper for the policy_detail.exclusion_rules.amis.last_launched block of aws_imagebuilder_lifecycle_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

ImagebuilderLifecyclePolicyLastLaunched({required ImagebuilderLifecyclePolicyUnit unit, required TfArg<num> value})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → ImagebuilderLifecyclePolicyUnit
final
value → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited