ImagebuilderLifecyclePolicyRecipe class final

Typed helper for the resource_selection.recipe block of aws_imagebuilder_lifecycle_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

ImagebuilderLifecyclePolicyRecipe({required TfArg<String> name, required TfArg<String> semanticVersion})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticVersion → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited