Inspector2FilterSourceLayerHash class final
Typed helper for the filter_criteria.vulnerable_packages.source_layer_hash block of
aws_inspector2_filter (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Inspector2FilterSourceLayerHash({required Inspector2FilterAwsAccountIdComparison comparison, required TfArg<
String> value}) -
const
Properties
- comparison → Inspector2FilterAwsAccountIdComparison
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited