InstanceMarketOptions class final
Typed helper for the instance_market_options block of
aws_instance (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
InstanceMarketOptions({TfArg<
InstanceMarketType> ? marketType, InstanceSpotOptions? spotOptions}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
marketType
→ TfArg<
InstanceMarketType> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spotOptions → InstanceSpotOptions?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited