InstanceMetadataOptions class final

Typed helper for the metadata_options block of aws_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

InstanceMetadataOptions({InstanceHttpEndpoint? httpEndpoint, InstanceHttpProtocolIpv6? httpProtocolIpv6, TfArg<num>? httpPutResponseHopLimit, InstanceHttpTokens? httpTokens, InstanceMetadataTags? instanceMetadataTags})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpEndpoint → InstanceHttpEndpoint?
final
httpProtocolIpv6 → InstanceHttpProtocolIpv6?
final
httpPutResponseHopLimit → TfArg<num>?
final
httpTokens → InstanceHttpTokens?
final
instanceMetadataTags → InstanceMetadataTags?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited