InstanceSecondaryNetworkInterface class final

Typed helper for the secondary_network_interface block of aws_instance (derived from provider schema).

Annotations
  • @immutable

Constructors

InstanceSecondaryNetworkInterface({TfArg<bool>? deleteOnTermination, TfArg<num>? deviceIndex, TfArg<String>? interfaceType, required TfArg<num> networkCardIndex, TfArg<num>? privateIpAddressCount, required TfArg<String> secondarySubnetId})
const

Properties

deleteOnTermination → TfArg<bool>?
final
deviceIndex → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
interfaceType → TfArg<String>?
final
networkCardIndex → TfArg<num>
final
privateIpAddressCount → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondarySubnetId → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited