IotTopicRuleErrorAction class final

Typed helper for the error_action block of aws_iot_topic_rule (derived from provider schema).

Annotations
  • @immutable

Properties

cloudwatchAlarm → IotTopicRuleCloudwatchAlarm?
final
cloudwatchLogs → IotTopicRuleCloudwatchLogs?
final
cloudwatchMetric → IotTopicRuleCloudwatchMetric?
final
dynamodb → IotTopicRuleDynamodb?
final
dynamodbv2 → IotTopicRuleDynamodbv2?
final
elasticsearch → IotTopicRuleElasticsearch?
final
firehose → IotTopicRuleFirehose?
final
hashCode → int
The hash code for this object.
no setterinherited
http → IotTopicRuleHttp?
final
iotAnalytics → IotTopicRuleIotAnalytics?
final
iotEvents → IotTopicRuleIotEvents?
final
kafka → IotTopicRuleKafka?
final
kinesis → IotTopicRuleKinesis?
final
lambda → IotTopicRuleLambda?
final
republish → IotTopicRuleRepublish?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3 → IotTopicRuleS3?
final
sns → IotTopicRuleSns?
final
sqs → IotTopicRuleSqs?
final
stepFunctions → IotTopicRuleStepFunctions?
final
timestream → IotTopicRuleTimestream?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited