IotTopicRuleHttp class final

Typed helper for the http block of aws_iot_topic_rule (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

IotTopicRuleHttp({TfArg<String>? confirmationUrl, required TfArg<String> url, List<IotTopicRuleHttpHeader>? httpHeader})
const

Properties

confirmationUrl → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
httpHeader → List<IotTopicRuleHttpHeader>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited