KendraDataSourceTarget class final

Typed helper for the custom_document_enrichment_configuration.inline_configurations.target block of aws_kendra_data_source (derived from provider schema).

Annotations
  • @immutable

Constructors

KendraDataSourceTarget({TfArg<String>? targetDocumentAttributeKey, TfArg<bool>? targetDocumentAttributeValueDeletion, KendraDataSourceTargetDocumentAttributeValue? targetDocumentAttributeValue})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetDocumentAttributeKey → TfArg<String>?
final
targetDocumentAttributeValue → KendraDataSourceTargetDocumentAttributeValue?
final
targetDocumentAttributeValueDeletion → TfArg<bool>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited