KendraIndexDocumentMetadataConfigurationUpdates class final

Typed helper for the document_metadata_configuration_updates block of aws_kendra_index (derived from provider schema).

Annotations
  • @immutable

Constructors

KendraIndexDocumentMetadataConfigurationUpdates({required TfArg<String> name, required TfArg<KendraIndexType> type, KendraIndexRelevance? relevance, KendraIndexSearch? search})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
relevance → KendraIndexRelevance?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
type → TfArg<KendraIndexType>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited