KeyspacesKeyspaceReplicationSpecification class final

Typed helper for the replication_specification block of aws_keyspaces_keyspace (derived from provider schema).

Annotations
  • @immutable

Constructors

KeyspacesKeyspaceReplicationSpecification({TfArg<List<String>>? regionList, KeyspacesKeyspaceReplicationStrategy? replicationStrategy})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
regionList → TfArg<List<String>>?
final
replicationStrategy → KeyspacesKeyspaceReplicationStrategy?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited