KinesisAnalyticsApplicationReferenceDataSources class final

Typed helper for the reference_data_sources block of aws_kinesis_analytics_application (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3 → KinesisAnalyticsApplicationS3
final
schema → KinesisAnalyticsApplicationInputsSchema
final
tableName → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited