KinesisFirehoseDeliveryStreamDataFormatConversionConfiguration class final

Typed helper for the extended_s3_configuration.data_format_conversion_configuration block of aws_kinesis_firehose_delivery_stream (derived from provider schema).

Annotations
  • @immutable

Properties

enabled → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
inputFormatConfiguration → KinesisFirehoseDeliveryStreamInputFormatConfiguration
final
outputFormatConfiguration → KinesisFirehoseDeliveryStreamOutputFormatConfiguration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaConfiguration → KinesisFirehoseDeliveryStreamSchemaConfiguration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited