LakeformationOptInTable class final

Typed helper for the resource_data.table block of aws_lakeformation_opt_in (derived from provider schema).

Annotations
  • @immutable

Constructors

LakeformationOptInTable({TfArg<String>? catalogId, required TfArg<String> databaseName, TfArg<String>? name, TfArg<bool>? wildcard})
const

Properties

catalogId → TfArg<String>?
final
databaseName → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wildcard → TfArg<bool>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited