LambdaEventSourceMappingProvisionedPollerConfig class final

Typed helper for the provisioned_poller_config block of aws_lambda_event_source_mapping (derived from provider schema).

Annotations
  • @immutable

Constructors

LambdaEventSourceMappingProvisionedPollerConfig({TfArg<num>? maximumPollers, TfArg<num>? minimumPollers, TfArg<String>? pollerGroupName})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximumPollers → TfArg<num>?
final
minimumPollers → TfArg<num>?
final
pollerGroupName → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited