LambdaEventSourceMappingScalingConfig class final

Typed helper for the scaling_config block of aws_lambda_event_source_mapping (derived from provider schema).

Annotations
  • @immutable

Constructors

LambdaEventSourceMappingScalingConfig({TfArg<num>? maximumConcurrency})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximumConcurrency → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited