LambdaEventSourceMappingSchemaValidationConfig class final

Typed helper for the amazon_managed_kafka_event_source_config.schema_registry_config.schema_validation_config block of aws_lambda_event_source_mapping (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Properties

attribute → LambdaEventSourceMappingAttribute?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited