LambdaEventSourceMappingSelfManagedEventSource class final

Typed helper for the self_managed_event_source block of aws_lambda_event_source_mapping (derived from provider schema).

Annotations
  • @immutable

Constructors

LambdaEventSourceMappingSelfManagedEventSource({required TfArg<Map<String, String>> endpoints})
const

Properties

endpoints → TfArg<Map<String, String>>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited