LambdaFunctionDurableConfig class final

Typed helper for the durable_config block of aws_lambda_function (derived from provider schema).

Annotations
  • @immutable

Constructors

LambdaFunctionDurableConfig({required TfArg<num> executionTimeout, TfArg<num>? retentionPeriod})
const

Properties

executionTimeout → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
retentionPeriod → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited