LaunchConfigurationRootBlockDevice class final

Typed helper for the root_block_device block of aws_launch_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

LaunchConfigurationRootBlockDevice({TfArg<bool>? deleteOnTermination, TfArg<bool>? encrypted, TfArg<num>? iops, TfArg<num>? throughput, TfArg<num>? volumeSize, TfArg<String>? volumeType})
const

Properties

deleteOnTermination → TfArg<bool>?
final
encrypted → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
iops → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
throughput → TfArg<num>?
final
volumeSize → TfArg<num>?
final
volumeType → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited