LaunchTemplateNetworkInterfaces class final

Typed helper for the network_interfaces block of aws_launch_template (derived from provider schema).

Annotations
  • @immutable

Constructors

LaunchTemplateNetworkInterfaces({TfArg<String>? associateCarrierIpAddress, TfArg<String>? associatePublicIpAddress, TfArg<String>? deleteOnTermination, TfArg<String>? description, TfArg<num>? deviceIndex, TfArg<num>? enaQueueCount, TfArg<LaunchTemplateNetworkInterfacesInterfaceType>? interfaceType, TfArg<num>? ipv4AddressCount, TfArg<List<String>>? ipv4Addresses, TfArg<num>? ipv4PrefixCount, TfArg<List<String>>? ipv4Prefixes, TfArg<num>? ipv6AddressCount, TfArg<List<String>>? ipv6Addresses, TfArg<num>? ipv6PrefixCount, TfArg<List<String>>? ipv6Prefixes, TfArg<num>? networkCardIndex, TfArg<String>? networkInterfaceId, TfArg<String>? primaryIpv6, TfArg<String>? privateIpAddress, TfArg<List<RefTo<AwsSecurityGroup>>>? securityGroups, RefTo<AwsSubnet>? subnetId, LaunchTemplateConnectionTrackingSpecification? connectionTrackingSpecification, LaunchTemplateEnaSrdSpecification? enaSrdSpecification})
const

Properties

associateCarrierIpAddress → TfArg<String>?
final
associatePublicIpAddress → TfArg<String>?
final
connectionTrackingSpecification → LaunchTemplateConnectionTrackingSpecification?
final
deleteOnTermination → TfArg<String>?
final
description → TfArg<String>?
final
deviceIndex → TfArg<num>?
final
enaQueueCount → TfArg<num>?
final
enaSrdSpecification → LaunchTemplateEnaSrdSpecification?
final
hashCode → int
The hash code for this object.
no setterinherited
interfaceType → TfArg<LaunchTemplateNetworkInterfacesInterfaceType>?
final
ipv4AddressCount → TfArg<num>?
final
ipv4Addresses → TfArg<List<String>>?
final
ipv4PrefixCount → TfArg<num>?
final
ipv4Prefixes → TfArg<List<String>>?
final
ipv6AddressCount → TfArg<num>?
final
ipv6Addresses → TfArg<List<String>>?
final
ipv6PrefixCount → TfArg<num>?
final
ipv6Prefixes → TfArg<List<String>>?
final
networkCardIndex → TfArg<num>?
final
networkInterfaceId → TfArg<String>?
final
primaryIpv6 → TfArg<String>?
final
privateIpAddress → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroups → TfArg<List<RefTo<AwsSecurityGroup>>>?
final
subnetId → RefTo<AwsSubnet>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited