LbSubnetMappingChoice class final

The LbSubnet.subnetMapping choice: sets subnet_mapping.

Inheritance

Constructors

LbSubnetMappingChoice(List<LbSubnetMapping> subnetMapping)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetMapping → List<LbSubnetMapping>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited