LbSubnetSubnets class final

The LbSubnet.subnets choice: sets subnets.

Inheritance

Constructors

LbSubnetSubnets(TfArg<List<RefTo<AwsSubnet>>> subnets)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnets → TfArg<List<RefTo<AwsSubnet>>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited