LexBotIntent class final

Typed helper for the intent block of aws_lex_bot (derived from provider schema).

Annotations
  • @immutable

Constructors

LexBotIntent({required TfArg<String> intentName, required TfArg<String> intentVersion})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
intentName → TfArg<String>
final
intentVersion → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited