LexBotProcessBehavior extension type
Lex Bot Process enum for process_behavior.
Constructors
-
LexBotProcessBehavior.arg(TfArg<
String> arg) -
const
- LexBotProcessBehavior.expression(String template)
- LexBotProcessBehavior.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- build → const LexBotProcessBehavior
- save → const LexBotProcessBehavior
-
values
→ const List<
LexBotProcessBehavior>