LexIntentConfirmationPrompt class final

Typed helper for the confirmation_prompt block of aws_lex_intent (derived from provider schema).

Annotations
  • @immutable

Constructors

LexIntentConfirmationPrompt({required TfArg<num> maxAttempts, TfArg<String>? responseCard, required List<LexIntentMessage> message})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxAttempts → TfArg<num>
final
message → List<LexIntentMessage>
final
responseCard → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited