Lexv2modelsIntentBedrockKnowledgeStoreConfiguration class final

Typed helper for the qna_intent_configuration.data_source_configuration.bedrock_knowledge_store_configuration block of aws_lexv2models_intent (derived from provider schema).

Annotations
  • @immutable

Constructors

Lexv2modelsIntentBedrockKnowledgeStoreConfiguration({required TfArg<String> bedrockKnowledgeBaseArn, TfArg<bool>? exactResponse, List<Lexv2modelsIntentBedrockKnowledgeStoreConfigurationExactResponseFields>? exactResponseFields})
const

Properties

bedrockKnowledgeBaseArn → TfArg<String>
final
exactResponse → TfArg<bool>?
final
exactResponseFields → List<Lexv2modelsIntentBedrockKnowledgeStoreConfigurationExactResponseFields>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited