Lexv2modelsIntentBedrockModelConfiguration class final
Typed helper for the qna_intent_configuration.bedrock_model_configuration block of
aws_lexv2models_intent (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsIntentBedrockModelConfiguration({TfArg<
String> ? customPrompt, required TfArg<String> modelArn, TfArg<String> ? traceStatus, List<Lexv2modelsIntentGuardrail> ? guardrail}) -
const
Properties
-
customPrompt
→ TfArg<
String> ? -
final
-
guardrail
→ List<
Lexv2modelsIntentGuardrail> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modelArn
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
traceStatus
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited