Lexv2modelsIntentConfirmationSetting class final
Typed helper for the confirmation_setting block of
aws_lexv2models_intent (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsIntentConfirmationSetting({TfArg<
bool> ? active, List<Lexv2modelsIntentCodeHook> ? codeHook, List<Lexv2modelsIntentConfirmationConditional> ? confirmationConditional, List<Lexv2modelsIntentConfirmationNextStep> ? confirmationNextStep, List<Lexv2modelsIntentConfirmationResponse> ? confirmationResponse, List<Lexv2modelsIntentDeclinationConditional> ? declinationConditional, List<Lexv2modelsIntentDeclinationNextStep> ? declinationNextStep, List<Lexv2modelsIntentDeclinationResponse> ? declinationResponse, List<Lexv2modelsIntentElicitationCodeHook> ? elicitationCodeHook, List<Lexv2modelsIntentFailureConditional> ? failureConditional, List<Lexv2modelsIntentFailureNextStep> ? failureNextStep, List<Lexv2modelsIntentFailureResponse> ? failureResponse, List<Lexv2modelsIntentPromptSpecification> ? promptSpecification}) -
const
Properties
-
active
→ TfArg<
bool> ? -
final
-
codeHook
→ List<
Lexv2modelsIntentCodeHook> ? -
final
-
confirmationConditional
→ List<
Lexv2modelsIntentConfirmationConditional> ? -
final
-
confirmationNextStep
→ List<
Lexv2modelsIntentConfirmationNextStep> ? -
final
-
confirmationResponse
→ List<
Lexv2modelsIntentConfirmationResponse> ? -
final
-
declinationConditional
→ List<
Lexv2modelsIntentDeclinationConditional> ? -
final
-
declinationNextStep
→ List<
Lexv2modelsIntentDeclinationNextStep> ? -
final
-
declinationResponse
→ List<
Lexv2modelsIntentDeclinationResponse> ? -
final
-
elicitationCodeHook
→ List<
Lexv2modelsIntentElicitationCodeHook> ? -
final
-
failureConditional
→ List<
Lexv2modelsIntentFailureConditional> ? -
final
-
failureNextStep
→ List<
Lexv2modelsIntentFailureNextStep> ? -
final
-
failureResponse
→ List<
Lexv2modelsIntentFailureResponse> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
promptSpecification
→ List<
Lexv2modelsIntentPromptSpecification> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited