Lexv2modelsIntentDialogAction class final

Typed helper for the closing_setting.next_step.dialog_action block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

Lexv2modelsIntentDialogAction({TfArg<String>? slotToElicit, TfArg<bool>? suppressNextMessage, required TfArg<String> type})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slotToElicit → TfArg<String>?
final
suppressNextMessage → TfArg<bool>?
final
type → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited