Lexv2modelsIntentFulfillmentCodeHook class final

Typed helper for the fulfillment_code_hook block of aws_lexv2models_intent (derived from provider schema).

Annotations
  • @immutable

Constructors

Lexv2modelsIntentFulfillmentCodeHook({TfArg<bool>? active, required TfArg<bool> enabled, List<Lexv2modelsIntentFulfillmentUpdatesSpecification>? fulfillmentUpdatesSpecification, List<Lexv2modelsIntentPostFulfillmentStatusSpecification>? postFulfillmentStatusSpecification})
const

Properties

active → TfArg<bool>?
final
enabled → TfArg<bool>
final
fulfillmentUpdatesSpecification → List<Lexv2modelsIntentFulfillmentUpdatesSpecification>?
final
hashCode → int
The hash code for this object.
no setterinherited
postFulfillmentStatusSpecification → List<Lexv2modelsIntentPostFulfillmentStatusSpecification>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited