Lexv2modelsIntentImageResponseCard class final

Typed helper for the closing_setting.closing_response.message_group.message.image_response_card block of aws_lexv2models_intent (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

Lexv2modelsIntentImageResponseCard({TfArg<String>? imageUrl, TfArg<String>? subtitle, required TfArg<String> title, List<Lexv2modelsIntentButton>? button})
const

Properties

button → List<Lexv2modelsIntentButton>?
final
hashCode → int
The hash code for this object.
no setterinherited
imageUrl → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → TfArg<String>?
final
title → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited