Lexv2modelsIntentMessageGroup class final
Typed helper for the closing_setting.closing_response.message_group block of
aws_lexv2models_intent (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsIntentMessageGroup({List<
Lexv2modelsIntentMessage> ? message, List<Lexv2modelsIntentVariation> ? variation}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
message
→ List<
Lexv2modelsIntentMessage> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
variation
→ List<
Lexv2modelsIntentVariation> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited