Lexv2modelsIntentOpensearchConfiguration class final

Typed helper for the qna_intent_configuration.data_source_configuration.opensearch_configuration block of aws_lexv2models_intent (derived from provider schema).

Annotations
  • @immutable

Constructors

Lexv2modelsIntentOpensearchConfiguration({required TfArg<String> domainEndpoint, TfArg<bool>? exactResponse, TfArg<List<String>>? includeFields, required TfArg<String> indexName, List<Lexv2modelsIntentOpensearchConfigurationExactResponseFields>? exactResponseFields})
const

Properties

domainEndpoint → TfArg<String>
final
exactResponse → TfArg<bool>?
final
exactResponseFields → List<Lexv2modelsIntentOpensearchConfigurationExactResponseFields>?
final
hashCode → int
The hash code for this object.
no setterinherited
includeFields → TfArg<List<String>>?
final
indexName → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited