Lexv2modelsIntentSampleUtterance class final

Typed helper for the sample_utterance block of aws_lexv2models_intent (derived from provider schema).

Annotations
  • @immutable

Constructors

Lexv2modelsIntentSampleUtterance({required TfArg<String> utterance})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
utterance → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited