Lexv2modelsIntentUpdateResponse class final

Typed helper for the fulfillment_code_hook.fulfillment_updates_specification.update_response block of aws_lexv2models_intent (derived from provider schema).

Annotations
  • @immutable

Constructors

Lexv2modelsIntentUpdateResponse({TfArg<bool>? allowInterrupt, required TfArg<num> frequencyInSeconds, List<Lexv2modelsIntentMessageGroup>? messageGroup})
const

Properties

allowInterrupt → TfArg<bool>?
final
frequencyInSeconds → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
messageGroup → List<Lexv2modelsIntentMessageGroup>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited