Lexv2modelsSlotMessageGroup class final
Typed helper for the value_elicitation_setting.prompt_specification.message_group block of
aws_lexv2models_slot (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsSlotMessageGroup({List<
Lexv2modelsSlotMessage> ? message, List<Lexv2modelsSlotVariation> ? variation}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
message
→ List<
Lexv2modelsSlotMessage> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
variation
→ List<
Lexv2modelsSlotVariation> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited