Lexv2modelsSlotTextInputSpecification class final
Typed helper for the value_elicitation_setting.prompt_specification.prompt_attempts_specification.text_input_specification block of
aws_lexv2models_slot (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsSlotTextInputSpecification({required TfArg<
num> startTimeoutMs}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
startTimeoutMs
→ TfArg<
num> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited