Lexv2modelsSlotTypeAdvancedRecognitionSetting class final

Typed helper for the value_selection_setting.advanced_recognition_setting block of aws_lexv2models_slot_type (derived from provider schema).

Annotations
  • @immutable

Properties

audioRecognitionStrategy → Lexv2modelsSlotTypeAudioRecognitionStrategy?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited