LightsailContainerServiceDeploymentVersionContainer class final

Typed helper for the container block of aws_lightsail_container_service_deployment_version (derived from provider schema).

Annotations
  • @immutable

Constructors

LightsailContainerServiceDeploymentVersionContainer({TfArg<List<String>>? command, required TfArg<String> containerName, TfArg<Map<String, String>>? environment, required TfArg<String> image, TfArg<Map<String, String>>? ports})
const

Properties

command → TfArg<List<String>>?
final
containerName → TfArg<String>
final
environment → TfArg<Map<String, String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
image → TfArg<String>
final
ports → TfArg<Map<String, String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited