LightsailDistributionDefaultCacheBehavior class final

Typed helper for the default_cache_behavior block of aws_lightsail_distribution (derived from provider schema).

Annotations
  • @immutable

Constructors

LightsailDistributionDefaultCacheBehavior({required TfArg<String> behavior})
const

Properties

behavior → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited