Macie2ClassificationExportConfigurationS3Destination class final

Typed helper for the s3_destination block of aws_macie2_classification_export_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

Macie2ClassificationExportConfigurationS3Destination({required RefTo<AwsS3Bucket> bucketName, TfArg<String>? keyPrefix, required RefTo<AwsKmsKey> kmsKeyArn})
const

Properties

bucketName → RefTo<AwsS3Bucket>
final
hashCode → int
The hash code for this object.
no setterinherited
keyPrefix → TfArg<String>?
final
kmsKeyArn → RefTo<AwsKmsKey>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited