Macie2ClassificationJobBucketDefinitions class final

Typed helper for the s3_job_definition.bucket_definitions block of aws_macie2_classification_job (derived from provider schema).

Annotations
  • @immutable

Constructors

Macie2ClassificationJobBucketDefinitions({required TfArg<String> accountId, required TfArg<List<String>> buckets})
const

Properties

accountId → TfArg<String>
final
buckets → TfArg<List<String>>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited