Macie2ClassificationJobExcludesSimpleScopeTerm class final
Typed helper for the s3_job_definition.scoping.excludes.and.simple_scope_term block of
aws_macie2_classification_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Macie2ClassificationJobExcludesSimpleScopeTerm({Macie2ClassificationJobComparator? comparator, Macie2ClassificationJobSimpleScopeTermKey? key, TfArg<
List< ? values})String> > -
const
Properties
- comparator → Macie2ClassificationJobComparator?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Macie2ClassificationJobSimpleScopeTermKey?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ TfArg<
List< ?String> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited