Macie2ClassificationJobScopingExcludes class final
Typed helper for the s3_job_definition.scoping.excludes block of
aws_macie2_classification_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
and
→ List<
Macie2ClassificationJobScopingAnd> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited