MailmanagerIngressPointTrustStore class final

Typed helper for the ingress_point_configuration.tls_auth_configuration.trust_store block of aws_mailmanager_ingress_point (derived from provider schema).

Annotations
  • @immutable

Constructors

MailmanagerIngressPointTrustStore({required TfArg<String> caContent, TfArg<String>? crlContent, RefTo<AwsKmsKey>? kmsKeyArn})
const

Properties

caContent → TfArg<String>
final
crlContent → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyArn → RefTo<AwsKmsKey>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited