MailmanagerRuleSetArchive class final
Typed helper for the rule.action.archive block of
aws_mailmanager_rule_set (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
MailmanagerRuleSetArchive({MailmanagerRuleSetActionFailurePolicy? actionFailurePolicy, required TfArg<
String> targetArchive}) -
const
Properties
- actionFailurePolicy → MailmanagerRuleSetActionFailurePolicy?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetArchive
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited