MailmanagerRuleSetIsInAddressList class final
Typed helper for the rule.condition.boolean_expression.evaluate.is_in_address_list block of
aws_mailmanager_rule_set (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
MailmanagerRuleSetIsInAddressList({required TfArg<
List< addressLists, required TfArg<String> >MailmanagerRuleSetIsInAddressListAttribute> attribute}) -
const
Properties
-
addressLists
→ TfArg<
List< String> > -
final
-
attribute
→ TfArg<
MailmanagerRuleSetIsInAddressListAttribute> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited