MailmanagerRuleSetRelay class final

Typed helper for the rule.action.relay block of aws_mailmanager_rule_set (derived from provider schema).

Annotations
  • @immutable

Constructors

MailmanagerRuleSetRelay({TfArg<MailmanagerRuleSetActionFailurePolicy>? actionFailurePolicy, TfArg<MailmanagerRuleSetMailFrom>? mailFrom, required TfArg<String> relay})
const

Properties

actionFailurePolicy → TfArg<MailmanagerRuleSetActionFailurePolicy>?
final
hashCode → int
The hash code for this object.
no setterinherited
mailFrom → TfArg<MailmanagerRuleSetMailFrom>?
final
relay → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited