MskClusterPrometheus class final

Typed helper for the open_monitoring.prometheus block of aws_msk_cluster (derived from provider schema).

Annotations
  • @immutable

Constructors

MskClusterPrometheus({MskClusterJmxExporter? jmxExporter, MskClusterNodeExporter? nodeExporter})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
jmxExporter → MskClusterJmxExporter?
final
nodeExporter → MskClusterNodeExporter?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited