NetworkInterfaceAttachment class final

Typed helper for the attachment block of aws_network_interface (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkInterfaceAttachment({required TfArg<num> deviceIndex, required TfArg<String> instance, TfArg<num>? networkCardIndex})
const

Properties

deviceIndex → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
instance → TfArg<String>
final
networkCardIndex → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited