NetworkfirewallFirewallPolicyOverride class final

Typed helper for the firewall_policy.stateful_rule_group_reference.override block of aws_networkfirewall_firewall_policy (derived from provider schema).

Annotations
  • @immutable

Properties

action → NetworkfirewallFirewallPolicyAction?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited