NetworkfirewallRuleGroupHeader class final

Typed helper for the rule_group.rules_source.stateful_rule.header block of aws_networkfirewall_rule_group (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkfirewallRuleGroupHeader({required TfArg<String> destination, required TfArg<String> destinationPort, required NetworkfirewallRuleGroupDirection direction, required NetworkfirewallRuleGroupProtocol protocol, required TfArg<String> source, required TfArg<String> sourcePort})
const

Properties

destination → TfArg<String>
final
destinationPort → TfArg<String>
final
direction → NetworkfirewallRuleGroupDirection
final
hashCode → int
The hash code for this object.
no setterinherited
protocol → NetworkfirewallRuleGroupProtocol
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → TfArg<String>
final
sourcePort → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited