NetworkfirewallRuleGroupRulesSource class final

Typed helper for the rule_group.rules_source block of aws_networkfirewall_rule_group (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkfirewallRuleGroupRulesSource({TfArg<String>? rulesString, NetworkfirewallRuleGroupRulesSourceList? rulesSourceList, List<NetworkfirewallRuleGroupStatefulRule>? statefulRule, NetworkfirewallRuleGroupStatelessRulesAndCustomActions? statelessRulesAndCustomActions})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rulesSourceList → NetworkfirewallRuleGroupRulesSourceList?
final
rulesString → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statefulRule → List<NetworkfirewallRuleGroupStatefulRule>?
final
statelessRulesAndCustomActions → NetworkfirewallRuleGroupStatelessRulesAndCustomActions?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited