NetworkfirewallRuleGroupRulesSourceList class final

Typed helper for the rule_group.rules_source.rules_source_list block of aws_networkfirewall_rule_group (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkfirewallRuleGroupRulesSourceList({required NetworkfirewallRuleGroupGeneratedRulesType generatedRulesType, required List<NetworkfirewallRuleGroupTargetTypes> targetTypes, required TfArg<List<String>> targets})
const

Properties

generatedRulesType → NetworkfirewallRuleGroupGeneratedRulesType
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targets → TfArg<List<String>>
final
targetTypes → List<NetworkfirewallRuleGroupTargetTypes>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited