NetworkfirewallRuleGroupSource class final

Typed helper for the rule_group.rules_source.stateless_rules_and_custom_actions.stateless_rule.rule_definition.match_attributes.source block of aws_networkfirewall_rule_group (derived from provider schema).

Annotations
  • @immutable

Constructors

NetworkfirewallRuleGroupSource({required TfArg<String> addressDefinition})
const

Properties

addressDefinition → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited