NetworkflowmonitorMonitorRemoteResource class final
Typed helper for the remote_resource block of
aws_networkflowmonitor_monitor (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkflowmonitorMonitorRemoteResource({required TfArg<
String> identifier, required NetworkflowmonitorMonitorRemoteResourceType type}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
identifier
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → NetworkflowmonitorMonitorRemoteResourceType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited