ObservabilityadminCentralizationRuleForOrganizationSourceMetricsConfiguration class final

Typed helper for the rule.source.source_metrics_configuration block of aws_observabilityadmin_centralization_rule_for_organization (derived from provider schema).

Annotations
  • @immutable

Constructors

ObservabilityadminCentralizationRuleForOrganizationSourceMetricsConfiguration({required TfArg<String> metricsSelectionCriteria})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
metricsSelectionCriteria → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited