ObservabilityadminTelemetryRuleAdvancedEventSelectors class final
Typed helper for the rule.destination_configuration.cloudtrail_parameters.advanced_event_selectors block of
aws_observabilityadmin_telemetry_rule (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ObservabilityadminTelemetryRuleAdvancedEventSelectors({TfArg<
String> ? name, List<ObservabilityadminTelemetryRuleFieldSelectors> ? fieldSelectors}) -
const
Properties
-
fieldSelectors
→ List<
ObservabilityadminTelemetryRuleFieldSelectors> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited