ObservabilityadminTelemetryRuleForOrganizationConditions class final
Typed helper for the rule.destination_configuration.waf_logging_parameters.logging_filter.filters.conditions block of
aws_observabilityadmin_telemetry_rule_for_organization (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ObservabilityadminTelemetryRuleForOrganizationConditions({List<
ObservabilityadminTelemetryRuleForOrganizationActionCondition> ? actionCondition, List<ObservabilityadminTelemetryRuleForOrganizationLabelNameCondition> ? labelNameCondition}) -
const
Properties
-
actionCondition
→ List<
ObservabilityadminTelemetryRuleForOrganizationActionCondition> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labelNameCondition
→ List<
ObservabilityadminTelemetryRuleForOrganizationLabelNameCondition> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited