ObservabilityadminTelemetryRuleForOrganizationFieldSelectors class final

Typed helper for the rule.destination_configuration.cloudtrail_parameters.advanced_event_selectors.field_selectors block of aws_observabilityadmin_telemetry_rule_for_organization (derived from provider schema).

Annotations
  • @immutable

Constructors

ObservabilityadminTelemetryRuleForOrganizationFieldSelectors({TfArg<List<String>>? endsWith, TfArg<List<String>>? equals, required TfArg<String> field, TfArg<List<String>>? notEndsWith, TfArg<List<String>>? notEquals, TfArg<List<String>>? notStartsWith, TfArg<List<String>>? startsWith})
const

Properties

endsWith → TfArg<List<String>>?
final
equals → TfArg<List<String>>?
final
field → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
notEndsWith → TfArg<List<String>>?
final
notEquals → TfArg<List<String>>?
final
notStartsWith → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startsWith → TfArg<List<String>>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited