ObservabilityadminTelemetryRuleForOrganizationLabelNameCondition class final

Typed helper for the rule.destination_configuration.waf_logging_parameters.logging_filter.filters.conditions.label_name_condition block of aws_observabilityadmin_telemetry_rule_for_organization (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
labelName → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited