ObservabilityadminTelemetryRuleForOrganizationLogDeliveryParameters class final
Typed helper for the rule.destination_configuration.log_delivery_parameters block of
aws_observabilityadmin_telemetry_rule_for_organization (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logTypes
→ List<
ObservabilityadminTelemetryRuleForOrganizationLogTypes> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited