ObservabilityadminTelemetryRuleForOrganizationRedactedFields class final
Typed helper for the rule.destination_configuration.waf_logging_parameters.redacted_fields block of
aws_observabilityadmin_telemetry_rule_for_organization (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ObservabilityadminTelemetryRuleForOrganizationRedactedFields({TfArg<
String> ? method, TfArg<String> ? queryString, TfArg<String> ? uriPath, List<ObservabilityadminTelemetryRuleForOrganizationSingleHeader> ? singleHeader}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
method
→ TfArg<
String> ? -
final
-
queryString
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
singleHeader
→ List<
ObservabilityadminTelemetryRuleForOrganizationSingleHeader> ? -
final
-
uriPath
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited