ObservabilityadminTelemetryRuleForOrganizationWafLoggingParameters class final
Typed helper for the rule.destination_configuration.waf_logging_parameters block of
aws_observabilityadmin_telemetry_rule_for_organization (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ObservabilityadminTelemetryRuleForOrganizationWafLoggingParameters({ObservabilityadminTelemetryRuleForOrganizationLogType? logType, List<
ObservabilityadminTelemetryRuleForOrganizationLoggingFilter> ? loggingFilter, List<ObservabilityadminTelemetryRuleForOrganizationRedactedFields> ? redactedFields}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
loggingFilter
→ List<
ObservabilityadminTelemetryRuleForOrganizationLoggingFilter> ? -
final
- logType → ObservabilityadminTelemetryRuleForOrganizationLogType?
-
final
-
redactedFields
→ List<
ObservabilityadminTelemetryRuleForOrganizationRedactedFields> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited