ObservabilityadminTelemetryRuleVpcFlowLogParameters class final

Typed helper for the rule.destination_configuration.vpc_flow_log_parameters block of aws_observabilityadmin_telemetry_rule (derived from provider schema).

Annotations
  • @immutable

Constructors

ObservabilityadminTelemetryRuleVpcFlowLogParameters({TfArg<String>? logFormat, TfArg<num>? maxAggregationInterval, TfArg<String>? trafficType})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
logFormat → TfArg<String>?
final
maxAggregationInterval → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trafficType → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited