OpensearchDomainSoftwareUpdateOptions class final

Typed helper for the software_update_options block of aws_opensearch_domain (derived from provider schema).

Annotations
  • @immutable

Constructors

OpensearchDomainSoftwareUpdateOptions({TfArg<bool>? autoSoftwareUpdateEnabled})
const

Properties

autoSoftwareUpdateEnabled → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited