PaymentcryptographyKeyAttributes class final

Typed helper for the key_attributes block of aws_paymentcryptography_key (derived from provider schema).

Annotations
  • @immutable

Constructors

PaymentcryptographyKeyAttributes({required PaymentcryptographyKeyAlgorithm keyAlgorithm, required PaymentcryptographyKeyClass keyClass, required PaymentcryptographyKeyUsage keyUsage, List<PaymentcryptographyKeyModesOfUse>? keyModesOfUse})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyAlgorithm → PaymentcryptographyKeyAlgorithm
final
keyClass → PaymentcryptographyKeyClass
final
keyModesOfUse → List<PaymentcryptographyKeyModesOfUse>?
final
keyUsage → PaymentcryptographyKeyUsage
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited