PipesPipeArrayProperties class final

Typed helper for the target_parameters.batch_job_parameters.array_properties block of aws_pipes_pipe (derived from provider schema).

Annotations
  • @immutable

Constructors

PipesPipeArrayProperties({TfArg<num>? size})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → TfArg<num>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited