PipesPipeSourceParametersSqsQueueParameters class final

Typed helper for the source_parameters.sqs_queue_parameters block of aws_pipes_pipe (derived from provider schema).

Annotations
  • @immutable

Constructors

PipesPipeSourceParametersSqsQueueParameters({TfArg<num>? batchSize, TfArg<num>? maximumBatchingWindowInSeconds})
const

Properties

batchSize → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
maximumBatchingWindowInSeconds → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited