PipesPipeTargetParametersServiceLambdaFunctionParameters class final
The PipesPipeTargetParametersService.lambdaFunctionParameters choice: sets lambda_function_parameters.
- Inheritance
-
- Object
- PipesPipeTargetParametersService
- PipesPipeTargetParametersServiceLambdaFunctionParameters
Constructors
- PipesPipeTargetParametersServiceLambdaFunctionParameters(PipesPipeLambdaFunctionParameters lambdaFunctionParameters)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lambdaFunctionParameters → PipesPipeLambdaFunctionParameters
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited