PrometheusQueryLoggingConfigurationFilters class final

Typed helper for the destination.filters block of aws_prometheus_query_logging_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

PrometheusQueryLoggingConfigurationFilters({required TfArg<num> qspThreshold})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
qspThreshold → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited