PrometheusScraperExporter class final

Typed helper for the exporter block of aws_prometheus_scraper (derived from provider schema).

Annotations
  • @immutable

Constructors

PrometheusScraperExporter({List<PrometheusScraperOpensearch>? opensearch})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
opensearch → List<PrometheusScraperOpensearch>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited