PrometheusScraperVpc class final

Typed helper for the source.vpc block of aws_prometheus_scraper (derived from provider schema).

Annotations
  • @immutable

Constructors

PrometheusScraperVpc({required TfArg<List<RefTo<AwsSecurityGroup>>> securityGroupIds, required TfArg<List<RefTo<AwsSubnet>>> subnetIds})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroupIds → TfArg<List<RefTo<AwsSecurityGroup>>>
final
subnetIds → TfArg<List<RefTo<AwsSubnet>>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited