QuicksightAnalysisAggregationFunction class final

Typed helper for the definition.filter_groups.filters.numeric_equality_filter.aggregation_function block of aws_quicksight_analysis (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightAnalysisAggregationFunction({TfArg<String>? categoricalAggregationFunction, TfArg<String>? dateAggregationFunction, QuicksightAnalysisNumericalAggregationFunction? numericalAggregationFunction})
const

Properties

categoricalAggregationFunction → TfArg<String>?
final
dateAggregationFunction → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
numericalAggregationFunction → QuicksightAnalysisNumericalAggregationFunction?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited