QuicksightAnalysisAggregationSortConfiguration class final

Typed helper for the definition.filter_groups.filters.top_bottom_filter.aggregation_sort_configuration block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightAnalysisAggregationSortConfiguration({required TfArg<String> sortDirection, required QuicksightAnalysisAggregationFunction aggregationFunction, required QuicksightAnalysisColumn column})
const

Properties

aggregationFunction → QuicksightAnalysisAggregationFunction
final
column → QuicksightAnalysisColumn
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortDirection → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited