QuicksightAnalysisColumnSort class final

Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.sort_configuration.category_sort.column_sort block of aws_quicksight_analysis (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightAnalysisColumnSort({required TfArg<String> direction, QuicksightAnalysisAggregationFunction? aggregationFunction, required QuicksightAnalysisColumn sortBy})
const

Properties

aggregationFunction → QuicksightAnalysisAggregationFunction?
final
direction → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortBy → QuicksightAnalysisColumn
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited