QuicksightAnalysisColumnSubtotalOptions class final

Typed helper for the definition.sheets.visuals.pivot_table_visual.chart_configuration.total_options.column_subtotal_options block of aws_quicksight_analysis (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightAnalysisColumnSubtotalOptions({TfArg<String>? customLabel, TfArg<String>? fieldLevel, TfArg<String>? totalsVisibility, List<QuicksightAnalysisFieldLevelOptions>? fieldLevelOptions, QuicksightAnalysisCellStyle? metricHeaderCellStyle, QuicksightAnalysisCellStyle? totalCellStyle, QuicksightAnalysisCellStyle? valueCellStyle})
const

Properties

customLabel → TfArg<String>?
final
fieldLevel → TfArg<String>?
final
fieldLevelOptions → List<QuicksightAnalysisFieldLevelOptions>?
final
hashCode → int
The hash code for this object.
no setterinherited
metricHeaderCellStyle → QuicksightAnalysisCellStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCellStyle → QuicksightAnalysisCellStyle?
final
totalsVisibility → TfArg<String>?
final
valueCellStyle → QuicksightAnalysisCellStyle?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited