QuicksightAnalysisColumnTotalOptions class final
Typed helper for the definition.sheets.visuals.pivot_table_visual.chart_configuration.total_options.column_total_options block of
aws_quicksight_analysis (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
QuicksightAnalysisColumnTotalOptions({TfArg<
String> ? customLabel, TfArg<String> ? placement, TfArg<String> ? scrollStatus, TfArg<String> ? totalsVisibility, QuicksightAnalysisCellStyle? metricHeaderCellStyle, QuicksightAnalysisCellStyle? totalCellStyle, QuicksightAnalysisCellStyle? valueCellStyle}) -
const
Properties
-
customLabel
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metricHeaderCellStyle → QuicksightAnalysisCellStyle?
-
final
-
placement
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scrollStatus
→ TfArg<
String> ? -
final
- totalCellStyle → QuicksightAnalysisCellStyle?
-
final
-
totalsVisibility
→ TfArg<
String> ? -
final
- valueCellStyle → QuicksightAnalysisCellStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited