QuicksightAnalysisCustomContentVisual class final

Typed helper for the definition.sheets.visuals.custom_content_visual block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightAnalysisCustomContentVisual({required TfArg<String> dataSetIdentifier, required TfArg<String> visualId, List<QuicksightAnalysisActions>? actions, QuicksightAnalysisCustomContentVisualChartConfiguration? chartConfiguration, QuicksightAnalysisSubtitle? subtitle, QuicksightAnalysisSubtitle? title})
const

Properties

actions → List<QuicksightAnalysisActions>?
final
chartConfiguration → QuicksightAnalysisCustomContentVisualChartConfiguration?
final
dataSetIdentifier → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → QuicksightAnalysisSubtitle?
final
title → QuicksightAnalysisSubtitle?
final
visualId → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited