QuicksightAnalysisDataLabelOptions class final

Typed helper for the definition.sheets.visuals.funnel_chart_visual.chart_configuration.data_label_options block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightAnalysisDataLabelOptions({TfArg<String>? categoryLabelVisibility, TfArg<String>? labelColor, TfArg<String>? measureDataLabelStyle, TfArg<String>? measureLabelVisibility, TfArg<String>? position, TfArg<String>? visibility, QuicksightAnalysisFontConfiguration? labelFontConfiguration})
const

Properties

categoryLabelVisibility → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
labelColor → TfArg<String>?
final
labelFontConfiguration → QuicksightAnalysisFontConfiguration?
final
measureDataLabelStyle → TfArg<String>?
final
measureLabelVisibility → TfArg<String>?
final
position → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibility → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited