QuicksightAnalysisDataLabelTypes class final

Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.data_labels.data_label_types block of aws_quicksight_analysis (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Properties

dataPathLabelType → QuicksightAnalysisDataPathLabelType?
final
fieldLabelType → QuicksightAnalysisFieldLabelType?
final
hashCode → int
The hash code for this object.
no setterinherited
maximumLabelType → QuicksightAnalysisSelectAllOptions?
final
minimumLabelType → QuicksightAnalysisSelectAllOptions?
final
rangeEndsLabelType → QuicksightAnalysisSelectAllOptions?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited