QuicksightAnalysisDataLabels class final

Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.data_labels block of aws_quicksight_analysis (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightAnalysisDataLabels({TfArg<String>? categoryLabelVisibility, TfArg<String>? labelColor, TfArg<String>? labelContent, TfArg<String>? measureLabelVisibility, TfArg<String>? overlap, TfArg<String>? position, TfArg<String>? visibility, List<QuicksightAnalysisDataLabelTypes>? dataLabelTypes, QuicksightAnalysisFontConfiguration? labelFontConfiguration})
const

Properties

categoryLabelVisibility → TfArg<String>?
final
dataLabelTypes → List<QuicksightAnalysisDataLabelTypes>?
final
hashCode → int
The hash code for this object.
no setterinherited
labelColor → TfArg<String>?
final
labelContent → TfArg<String>?
final
labelFontConfiguration → QuicksightAnalysisFontConfiguration?
final
measureLabelVisibility → TfArg<String>?
final
overlap → TfArg<String>?
final
position → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibility → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited