QuicksightAnalysisDateTimeParameterDeclarationDefaultValues class final

Typed helper for the definition.parameter_declarations.date_time_parameter_declaration.default_values block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Properties

dynamicValue → QuicksightAnalysisDynamicValue?
final
hashCode → int
The hash code for this object.
no setterinherited
rollingDate → QuicksightAnalysisRollingDate?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staticValues → TfArg<List<String>>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited