QuicksightAnalysisDynamicConfiguration class final

Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.reference_lines.data_configuration.dynamic_configuration block of aws_quicksight_analysis (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightAnalysisDynamicConfiguration({required QuicksightAnalysisNumericalAggregationFunction calculation, required QuicksightAnalysisColumn column, required QuicksightAnalysisAggregationFunction measureAggregationFunction})
const

Properties

calculation → QuicksightAnalysisNumericalAggregationFunction
final
column → QuicksightAnalysisColumn
final
hashCode → int
The hash code for this object.
no setterinherited
measureAggregationFunction → QuicksightAnalysisAggregationFunction
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited