QuicksightAnalysisFilledMapVisualConditionalFormattingOptions class final
Typed helper for the definition.sheets.visuals.filled_map_visual.conditional_formatting.conditional_formatting_options block of
aws_quicksight_analysis (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightAnalysisFilledMapVisualConditionalFormattingOptions({required QuicksightAnalysisShape shape})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → QuicksightAnalysisShape
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited