QuicksightAnalysisFunnelChartVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.funnel_chart_visual.chart_configuration block of
aws_quicksight_analysis (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightAnalysisFunnelChartVisualChartConfiguration({QuicksightAnalysisCategoryLabelOptions? categoryLabelOptions, QuicksightAnalysisDataLabelOptions? dataLabelOptions, QuicksightAnalysisFunnelChartVisualFieldWells? fieldWells, QuicksightAnalysisFunnelChartVisualSortConfiguration? sortConfiguration, QuicksightAnalysisTooltip? tooltip, QuicksightAnalysisCategoryLabelOptions? valueLabelOptions, QuicksightAnalysisVisualPalette? visualPalette})
-
const
Properties
- categoryLabelOptions → QuicksightAnalysisCategoryLabelOptions?
-
final
- dataLabelOptions → QuicksightAnalysisDataLabelOptions?
-
final
- fieldWells → QuicksightAnalysisFunnelChartVisualFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortConfiguration → QuicksightAnalysisFunnelChartVisualSortConfiguration?
-
final
- tooltip → QuicksightAnalysisTooltip?
-
final
- valueLabelOptions → QuicksightAnalysisCategoryLabelOptions?
-
final
- visualPalette → QuicksightAnalysisVisualPalette?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited