QuicksightAnalysisHeatMapVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.heat_map_visual.chart_configuration block of
aws_quicksight_analysis (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightAnalysisHeatMapVisualChartConfiguration({QuicksightAnalysisColorScale? colorScale, QuicksightAnalysisCategoryLabelOptions? columnLabelOptions, QuicksightAnalysisDataLabels? dataLabels, QuicksightAnalysisHeatMapVisualFieldWells? fieldWells, QuicksightAnalysisLegend? legend, QuicksightAnalysisCategoryLabelOptions? rowLabelOptions, QuicksightAnalysisHeatMapVisualSortConfiguration? sortConfiguration, QuicksightAnalysisTooltip? tooltip})
-
const
Properties
- colorScale → QuicksightAnalysisColorScale?
-
final
- columnLabelOptions → QuicksightAnalysisCategoryLabelOptions?
-
final
- dataLabels → QuicksightAnalysisDataLabels?
-
final
- fieldWells → QuicksightAnalysisHeatMapVisualFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → QuicksightAnalysisLegend?
-
final
- rowLabelOptions → QuicksightAnalysisCategoryLabelOptions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortConfiguration → QuicksightAnalysisHeatMapVisualSortConfiguration?
-
final
- tooltip → QuicksightAnalysisTooltip?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited