QuicksightAnalysisHeatMapVisualSortConfiguration class final

Typed helper for the definition.sheets.visuals.heat_map_visual.chart_configuration.sort_configuration block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightAnalysisHeatMapVisualSortConfiguration({QuicksightAnalysisCategoryItemsLimit? heatMapColumnItemsLimitConfiguration, List<QuicksightAnalysisCategorySort>? heatMapColumnSort, QuicksightAnalysisCategoryItemsLimit? heatMapRowItemsLimitConfiguration, List<QuicksightAnalysisCategorySort>? heatMapRowSort})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
heatMapColumnItemsLimitConfiguration → QuicksightAnalysisCategoryItemsLimit?
final
heatMapColumnSort → List<QuicksightAnalysisCategorySort>?
final
heatMapRowItemsLimitConfiguration → QuicksightAnalysisCategoryItemsLimit?
final
heatMapRowSort → List<QuicksightAnalysisCategorySort>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited