QuicksightAnalysisHistogramVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.histogram_visual.chart_configuration block of
aws_quicksight_analysis (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightAnalysisHistogramVisualChartConfiguration({QuicksightAnalysisBinOptions? binOptions, QuicksightAnalysisDataLabels? dataLabels, QuicksightAnalysisHistogramVisualFieldWells? fieldWells, QuicksightAnalysisTooltip? tooltip, QuicksightAnalysisVisualPalette? visualPalette, QuicksightAnalysisCategoryAxis? xAxisDisplayOptions, QuicksightAnalysisCategoryLabelOptions? xAxisLabelOptions, QuicksightAnalysisCategoryAxis? yAxisDisplayOptions})
-
const
Properties
- binOptions → QuicksightAnalysisBinOptions?
-
final
- dataLabels → QuicksightAnalysisDataLabels?
-
final
- fieldWells → QuicksightAnalysisHistogramVisualFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltip → QuicksightAnalysisTooltip?
-
final
- visualPalette → QuicksightAnalysisVisualPalette?
-
final
- xAxisDisplayOptions → QuicksightAnalysisCategoryAxis?
-
final
- xAxisLabelOptions → QuicksightAnalysisCategoryLabelOptions?
-
final
- yAxisDisplayOptions → QuicksightAnalysisCategoryAxis?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited