QuicksightAnalysisNumericalMeasureField class final
Typed helper for the definition.sheets.visuals.gauge_chart_visual.chart_configuration.field_wells.target_values.numerical_measure_field block of
aws_quicksight_analysis (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
QuicksightAnalysisNumericalMeasureField({required TfArg<
String> fieldId, QuicksightAnalysisNumericalAggregationFunction? aggregationFunction, required QuicksightAnalysisColumn column, QuicksightAnalysisNumberFormatConfiguration? formatConfiguration}) -
const
Properties
- aggregationFunction → QuicksightAnalysisNumericalAggregationFunction?
-
final
- column → QuicksightAnalysisColumn
-
final
-
fieldId
→ TfArg<
String> -
final
- formatConfiguration → QuicksightAnalysisNumberFormatConfiguration?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited