QuicksightAnalysisParameterControlsList class final

Typed helper for the definition.sheets.parameter_controls.list block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightAnalysisParameterControlsList({required TfArg<String> parameterControlId, required TfArg<String> sourceParameterName, required TfArg<String> title, TfArg<String>? type, QuicksightAnalysisCascadingControlConfiguration? cascadingControlConfiguration, QuicksightAnalysisListDisplayOptions? displayOptions, QuicksightAnalysisParameterControlsSelectableValues? selectableValues})
const

Properties

cascadingControlConfiguration → QuicksightAnalysisCascadingControlConfiguration?
final
displayOptions → QuicksightAnalysisListDisplayOptions?
final
hashCode → int
The hash code for this object.
no setterinherited
parameterControlId → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectableValues → QuicksightAnalysisParameterControlsSelectableValues?
final
sourceParameterName → TfArg<String>
final
title → TfArg<String>
final
type → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited