QuicksightAnalysisParameterControlsSelectableValues class final
Typed helper for the definition.sheets.parameter_controls.dropdown.selectable_values block of
aws_quicksight_analysis (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
QuicksightAnalysisParameterControlsSelectableValues({TfArg<
List< ? values, QuicksightAnalysisColumn? linkToDataSetColumn})String> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- linkToDataSetColumn → QuicksightAnalysisColumn?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ TfArg<
List< ?String> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited