QuicksightAnalysisPivotTableVisualFieldOptions class final

Typed helper for the definition.sheets.visuals.pivot_table_visual.chart_configuration.field_options block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Properties

dataPathOptions → List<QuicksightAnalysisDataPathOptions>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedFieldOptions → List<QuicksightAnalysisPivotTableVisualSelectedFieldOptions>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited