QuicksightAnalysisRowAlternateColorOptions class final

Typed helper for the definition.sheets.visuals.pivot_table_visual.chart_configuration.table_options.row_alternate_color_options block of aws_quicksight_analysis (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightAnalysisRowAlternateColorOptions({TfArg<List<String>>? rowAlternateColors, TfArg<String>? status})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rowAlternateColors → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited