QuicksightAnalysisShape class final

Typed helper for the definition.sheets.visuals.filled_map_visual.conditional_formatting.conditional_formatting_options.shape block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightAnalysisShape({required TfArg<String> fieldId, QuicksightAnalysisFormat? format})
const

Properties

fieldId → TfArg<String>
final
format → QuicksightAnalysisFormat?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited