QuicksightAnalysisSheetVisualScopingConfigurations class final

Typed helper for the definition.filter_groups.scope_configuration.selected_sheets.sheet_visual_scoping_configurations block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightAnalysisSheetVisualScopingConfigurations({required TfArg<String> scope, required TfArg<String> sheetId, TfArg<List<String>>? visualIds})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → TfArg<String>
final
sheetId → TfArg<String>
final
visualIds → TfArg<List<String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited