QuicksightAnalysisSideSpecificBorder class final

Typed helper for the definition.sheets.visuals.pivot_table_visual.chart_configuration.table_options.cell_style.border.side_specific_border block of aws_quicksight_analysis (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Properties

bottom → QuicksightAnalysisUniformBorder
final
hashCode → int
The hash code for this object.
no setterinherited
innerHorizontal → QuicksightAnalysisUniformBorder
final
innerVertical → QuicksightAnalysisUniformBorder
final
left → QuicksightAnalysisUniformBorder
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → QuicksightAnalysisUniformBorder
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited