QuicksightAnalysisSmallMultiplesOptions class final

Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.small_multiples_options block of aws_quicksight_analysis (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightAnalysisSmallMultiplesOptions({TfArg<num>? maxVisibleColumns, TfArg<num>? maxVisibleRows, QuicksightAnalysisPanelConfiguration? panelConfiguration})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxVisibleColumns → TfArg<num>?
final
maxVisibleRows → TfArg<num>?
final
panelConfiguration → QuicksightAnalysisPanelConfiguration?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited