QuicksightAnalysisSourceTemplate class final

Typed helper for the source_entity.source_template block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightAnalysisSourceTemplate({required TfArg<String> arn, required List<QuicksightAnalysisDataSetReferences> dataSetReferences})
const

Properties

arn → TfArg<String>
final
dataSetReferences → List<QuicksightAnalysisDataSetReferences>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited