QuicksightAnalysisTableVisualCell class final

Typed helper for the definition.sheets.visuals.table_visual.conditional_formatting.conditional_formatting_options.cell block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightAnalysisTableVisualCell({required TfArg<String> fieldId, QuicksightAnalysisTextFormat? textFormat})
const

Properties

fieldId → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textFormat → QuicksightAnalysisTextFormat?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited