QuicksightAnalysisTableVisualTotalOptions class final

Typed helper for the definition.sheets.visuals.table_visual.chart_configuration.total_options block of aws_quicksight_analysis (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightAnalysisTableVisualTotalOptions({TfArg<String>? customLabel, TfArg<String>? placement, TfArg<String>? scrollStatus, TfArg<String>? totalsVisibility, QuicksightAnalysisCellStyle? totalCellStyle})
const

Properties

customLabel → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
placement → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollStatus → TfArg<String>?
final
totalCellStyle → QuicksightAnalysisCellStyle?
final
totalsVisibility → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited