QuicksightDashboardBoxPlotOptions class final

Typed helper for the definition.sheets.visuals.box_plot_visual.chart_configuration.box_plot_options block of aws_quicksight_dashboard (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDashboardBoxPlotOptions({TfArg<String>? allDataPointsVisibility, TfArg<String>? outlierVisibility, QuicksightDashboardStyleOptions? styleOptions})
const

Properties

allDataPointsVisibility → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
outlierVisibility → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleOptions → QuicksightDashboardStyleOptions?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited