QuicksightDashboardComboChartVisualSortConfiguration class final
Typed helper for the definition.sheets.visuals.combo_chart_visual.chart_configuration.sort_configuration block of
aws_quicksight_dashboard (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
QuicksightDashboardComboChartVisualSortConfiguration({QuicksightDashboardCategoryItemsLimit? categoryItemsLimit, List<
QuicksightDashboardCategorySort> ? categorySort, QuicksightDashboardCategoryItemsLimit? colorItemsLimit, List<QuicksightDashboardCategorySort> ? colorSort}) -
const
Properties
- categoryItemsLimit → QuicksightDashboardCategoryItemsLimit?
-
final
-
categorySort
→ List<
QuicksightDashboardCategorySort> ? -
final
- colorItemsLimit → QuicksightDashboardCategoryItemsLimit?
-
final
-
colorSort
→ List<
QuicksightDashboardCategorySort> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited