QuicksightDashboardCustomContentVisual class final

Typed helper for the definition.sheets.visuals.custom_content_visual block of aws_quicksight_dashboard (derived from provider schema).

Annotations
  • @immutable

Properties

actions → List<QuicksightDashboardActions>?
final
chartConfiguration → QuicksightDashboardCustomContentVisualChartConfiguration?
final
dataSetIdentifier → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → QuicksightDashboardSubtitle?
final
title → QuicksightDashboardSubtitle?
final
visualId → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited