QuicksightDashboardFunnelChartVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.funnel_chart_visual.chart_configuration block of
aws_quicksight_dashboard (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightDashboardFunnelChartVisualChartConfiguration({QuicksightDashboardCategoryLabelOptions? categoryLabelOptions, QuicksightDashboardDataLabelOptions? dataLabelOptions, QuicksightDashboardFunnelChartVisualFieldWells? fieldWells, QuicksightDashboardFunnelChartVisualSortConfiguration? sortConfiguration, QuicksightDashboardTooltip? tooltip, QuicksightDashboardCategoryLabelOptions? valueLabelOptions, QuicksightDashboardVisualPalette? visualPalette})
-
const
Properties
- categoryLabelOptions → QuicksightDashboardCategoryLabelOptions?
-
final
- dataLabelOptions → QuicksightDashboardDataLabelOptions?
-
final
- fieldWells → QuicksightDashboardFunnelChartVisualFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortConfiguration → QuicksightDashboardFunnelChartVisualSortConfiguration?
-
final
- tooltip → QuicksightDashboardTooltip?
-
final
- valueLabelOptions → QuicksightDashboardCategoryLabelOptions?
-
final
- visualPalette → QuicksightDashboardVisualPalette?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited