QuicksightDashboardGeospatialMapVisualChartConfiguration class final

Typed helper for the definition.sheets.visuals.geospatial_map_visual.chart_configuration block of aws_quicksight_dashboard (derived from provider schema).

Annotations
  • @immutable

Properties

fieldWells → QuicksightDashboardGeospatialMapVisualFieldWells?
final
hashCode → int
The hash code for this object.
no setterinherited
legend → QuicksightDashboardLegend?
final
mapStyleOptions → QuicksightDashboardMapStyleOptions?
final
pointStyleOptions → QuicksightDashboardPointStyleOptions?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltip → QuicksightDashboardTooltip?
final
visualPalette → QuicksightDashboardVisualPalette?
final
windowOptions → QuicksightDashboardWindowOptions?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited