QuicksightDashboardGeospatialMapVisualFieldWells class final
Typed helper for the definition.sheets.visuals.geospatial_map_visual.chart_configuration.field_wells block of
aws_quicksight_dashboard (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightDashboardGeospatialMapVisualFieldWells({QuicksightDashboardGeospatialMapAggregatedFieldWells? geospatialMapAggregatedFieldWells})
-
const
Properties
- geospatialMapAggregatedFieldWells → QuicksightDashboardGeospatialMapAggregatedFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited