QuicksightDashboardHeatMapVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.heat_map_visual.chart_configuration block of
aws_quicksight_dashboard (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightDashboardHeatMapVisualChartConfiguration({QuicksightDashboardColorScale? colorScale, QuicksightDashboardCategoryLabelOptions? columnLabelOptions, QuicksightDashboardDataLabels? dataLabels, QuicksightDashboardHeatMapVisualFieldWells? fieldWells, QuicksightDashboardLegend? legend, QuicksightDashboardCategoryLabelOptions? rowLabelOptions, QuicksightDashboardHeatMapVisualSortConfiguration? sortConfiguration, QuicksightDashboardTooltip? tooltip})
-
const
Properties
- colorScale → QuicksightDashboardColorScale?
-
final
- columnLabelOptions → QuicksightDashboardCategoryLabelOptions?
-
final
- dataLabels → QuicksightDashboardDataLabels?
-
final
- fieldWells → QuicksightDashboardHeatMapVisualFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → QuicksightDashboardLegend?
-
final
- rowLabelOptions → QuicksightDashboardCategoryLabelOptions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortConfiguration → QuicksightDashboardHeatMapVisualSortConfiguration?
-
final
- tooltip → QuicksightDashboardTooltip?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited