QuicksightDashboardHeatMapVisualSortConfiguration class final

Typed helper for the definition.sheets.visuals.heat_map_visual.chart_configuration.sort_configuration block of aws_quicksight_dashboard (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDashboardHeatMapVisualSortConfiguration({QuicksightDashboardCategoryItemsLimit? heatMapColumnItemsLimitConfiguration, List<QuicksightDashboardCategorySort>? heatMapColumnSort, QuicksightDashboardCategoryItemsLimit? heatMapRowItemsLimitConfiguration, List<QuicksightDashboardCategorySort>? heatMapRowSort})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
heatMapColumnItemsLimitConfiguration → QuicksightDashboardCategoryItemsLimit?
final
heatMapColumnSort → List<QuicksightDashboardCategorySort>?
final
heatMapRowItemsLimitConfiguration → QuicksightDashboardCategoryItemsLimit?
final
heatMapRowSort → List<QuicksightDashboardCategorySort>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited