QuicksightDashboardNumericAxisOptionsRange class final
Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.category_axis.data_options.numeric_axis_options.range block of
aws_quicksight_dashboard (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
- QuicksightDashboardNumericAxisOptionsRange({QuicksightDashboardDataDriven? dataDriven, QuicksightDashboardMinMax? minMax})
-
const
Properties
- dataDriven → QuicksightDashboardDataDriven?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- minMax → QuicksightDashboardMinMax?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited