QuicksightDashboardRadarChartVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.radar_chart_visual.chart_configuration block of
aws_quicksight_dashboard (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
QuicksightDashboardRadarChartVisualChartConfiguration({TfArg<
String> ? alternateBandColorsVisibility, TfArg<String> ? alternateBandEvenColor, TfArg<String> ? alternateBandOddColor, TfArg<String> ? shape, TfArg<num> ? startAngle, QuicksightDashboardBaseSeriesSettings? baseSeriesSettings, QuicksightDashboardCategoryAxis? categoryAxis, QuicksightDashboardCategoryLabelOptions? categoryLabelOptions, QuicksightDashboardCategoryAxis? colorAxis, QuicksightDashboardCategoryLabelOptions? colorLabelOptions, QuicksightDashboardRadarChartVisualFieldWells? fieldWells, QuicksightDashboardLegend? legend, QuicksightDashboardComboChartVisualSortConfiguration? sortConfiguration, QuicksightDashboardVisualPalette? visualPalette}) -
const
Properties
-
alternateBandColorsVisibility
→ TfArg<
String> ? -
final
-
alternateBandEvenColor
→ TfArg<
String> ? -
final
-
alternateBandOddColor
→ TfArg<
String> ? -
final
- baseSeriesSettings → QuicksightDashboardBaseSeriesSettings?
-
final
- categoryAxis → QuicksightDashboardCategoryAxis?
-
final
- categoryLabelOptions → QuicksightDashboardCategoryLabelOptions?
-
final
- colorAxis → QuicksightDashboardCategoryAxis?
-
final
- colorLabelOptions → QuicksightDashboardCategoryLabelOptions?
-
final
- fieldWells → QuicksightDashboardRadarChartVisualFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → QuicksightDashboardLegend?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shape
→ TfArg<
String> ? -
final
- sortConfiguration → QuicksightDashboardComboChartVisualSortConfiguration?
-
final
-
startAngle
→ TfArg<
num> ? -
final
- visualPalette → QuicksightDashboardVisualPalette?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited