QuicksightDashboardStringFormatConfiguration class final

Typed helper for the definition.column_configurations.format_configuration.string_format_configuration block of aws_quicksight_dashboard (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
nullValueFormatConfiguration → QuicksightDashboardNullValueFormatConfiguration?
final
numericFormatConfiguration → QuicksightDashboardNumericFormatConfiguration?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited