QuicksightDashboardTreeMapVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.tree_map_visual.chart_configuration block of
aws_quicksight_dashboard (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightDashboardTreeMapVisualChartConfiguration({QuicksightDashboardCategoryLabelOptions? colorLabelOptions, QuicksightDashboardColorScale? colorScale, QuicksightDashboardDataLabels? dataLabels, QuicksightDashboardTreeMapVisualFieldWells? fieldWells, QuicksightDashboardCategoryLabelOptions? groupLabelOptions, QuicksightDashboardLegend? legend, QuicksightDashboardCategoryLabelOptions? sizeLabelOptions, QuicksightDashboardTreeMapVisualSortConfiguration? sortConfiguration, QuicksightDashboardTooltip? tooltip})
-
const
Properties
- colorLabelOptions → QuicksightDashboardCategoryLabelOptions?
-
final
- colorScale → QuicksightDashboardColorScale?
-
final
- dataLabels → QuicksightDashboardDataLabels?
-
final
- fieldWells → QuicksightDashboardTreeMapVisualFieldWells?
-
final
- groupLabelOptions → QuicksightDashboardCategoryLabelOptions?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → QuicksightDashboardLegend?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeLabelOptions → QuicksightDashboardCategoryLabelOptions?
-
final
- sortConfiguration → QuicksightDashboardTreeMapVisualSortConfiguration?
-
final
- tooltip → QuicksightDashboardTooltip?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited