QuicksightDataSetCastColumnTypeOperation class final

Typed helper for the logical_table_map.data_transforms.cast_column_type_operation block of aws_quicksight_data_set (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDataSetCastColumnTypeOperation({required TfArg<String> columnName, TfArg<String>? format, required TfArg<String> newColumnType})
const

Properties

columnName → TfArg<String>
final
format → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
newColumnType → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited