QuicksightDataSetColumnLevelPermissionRules class final

Typed helper for the column_level_permission_rules block of aws_quicksight_data_set (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDataSetColumnLevelPermissionRules({TfArg<List<String>>? columnNames, TfArg<List<String>>? principals})
const

Properties

columnNames → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
principals → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited