QuicksightDataSetCreateColumnsOperation class final

Typed helper for the logical_table_map.data_transforms.create_columns_operation block of aws_quicksight_data_set (derived from provider schema).

Annotations
  • @immutable

Properties

columns → List<QuicksightDataSetCreateColumnsOperationColumns>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited