QuicksightDataSetCustomSql class final

Typed helper for the physical_table_map.custom_sql block of aws_quicksight_data_set (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDataSetCustomSql({required TfArg<String> dataSourceArn, required TfArg<String> name, required TfArg<String> sqlQuery, List<QuicksightDataSetColumns>? columns})
const

Properties

columns → List<QuicksightDataSetColumns>?
final
dataSourceArn → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlQuery → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited