QuicksightDataSetIncrementalRefresh class final

Typed helper for the refresh_properties.refresh_configuration.incremental_refresh block of aws_quicksight_data_set (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDataSetIncrementalRefresh({required QuicksightDataSetLookbackWindow lookbackWindow})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lookbackWindow → QuicksightDataSetLookbackWindow
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited