QuicksightDataSetPhysicalTableMap class final

Typed helper for the physical_table_map block of aws_quicksight_data_set (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDataSetPhysicalTableMap({required TfArg<String> physicalTableMapId, QuicksightDataSetCustomSql? customSql, QuicksightDataSetRelationalTable? relationalTable, QuicksightDataSetS3Source? s3Source})
const

Properties

customSql → QuicksightDataSetCustomSql?
final
hashCode → int
The hash code for this object.
no setterinherited
physicalTableMapId → TfArg<String>
final
relationalTable → QuicksightDataSetRelationalTable?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Source → QuicksightDataSetS3Source?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited