QuicksightDataSetRelationalTable class final

Typed helper for the physical_table_map.relational_table block of aws_quicksight_data_set (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDataSetRelationalTable({TfArg<String>? catalog, required TfArg<String> dataSourceArn, required TfArg<String> name, TfArg<String>? schema, required List<QuicksightDataSetInputColumns> inputColumns})
const

Properties

catalog → TfArg<String>?
final
dataSourceArn → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
inputColumns → List<QuicksightDataSetInputColumns>
final
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited