QuicksightDataSetRowLevelPermissionDataSet class final

Typed helper for the row_level_permission_data_set block of aws_quicksight_data_set (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDataSetRowLevelPermissionDataSet({required TfArg<String> arn, TfArg<String>? formatVersion, TfArg<String>? namespace, required TfArg<String> permissionPolicy, TfArg<String>? status})
const

Properties

arn → TfArg<String>
final
formatVersion → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
namespace → TfArg<String>?
final
permissionPolicy → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited