QuicksightDataSetSource class final

Typed helper for the logical_table_map.source block of aws_quicksight_data_set (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDataSetSource({TfArg<String>? dataSetArn, TfArg<String>? physicalTableId, QuicksightDataSetJoinInstruction? joinInstruction})
const

Properties

dataSetArn → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
joinInstruction → QuicksightDataSetJoinInstruction?
final
physicalTableId → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited