QuicksightDataSourceOracle class final

Typed helper for the parameters.oracle block of aws_quicksight_data_source (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightDataSourceOracle({required TfArg<String> database, required TfArg<String> host, required TfArg<num> port})
const

Properties

database → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
host → TfArg<String>
final
port → TfArg<num>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited