QuicksightTemplateColumnGroupSchemaList class final

Typed helper for the definition.data_set_configuration.column_group_schema_list block of aws_quicksight_template (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightTemplateColumnGroupSchemaList({TfArg<String>? name, List<QuicksightTemplateColumnGroupColumnSchemaList>? columnGroupColumnSchemaList})
const

Properties

columnGroupColumnSchemaList → List<QuicksightTemplateColumnGroupColumnSchemaList>?
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited