QuicksightTemplateCustomContentVisualChartConfiguration class final

Typed helper for the definition.sheets.visuals.custom_content_visual.chart_configuration block of aws_quicksight_template (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightTemplateCustomContentVisualChartConfiguration({TfArg<String>? contentType, TfArg<String>? contentUrl, TfArg<String>? imageScaling})
const

Properties

contentType → TfArg<String>?
final
contentUrl → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
imageScaling → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited