QuicksightTemplateCustomNarrative class final

Typed helper for the definition.sheets.visuals.insight_visual.insight_configuration.custom_narrative block of aws_quicksight_template (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightTemplateCustomNarrative({required TfArg<String> narrative})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
narrative → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited