QuicksightTemplateDataLabelTypes class final
Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.data_labels.data_label_types block of
aws_quicksight_template (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
- QuicksightTemplateDataLabelTypes({QuicksightTemplateDataPathLabelType? dataPathLabelType, QuicksightTemplateFieldLabelType? fieldLabelType, QuicksightTemplateSelectAllOptions? maximumLabelType, QuicksightTemplateSelectAllOptions? minimumLabelType, QuicksightTemplateSelectAllOptions? rangeEndsLabelType})
-
const
Properties
- dataPathLabelType → QuicksightTemplateDataPathLabelType?
-
final
- fieldLabelType → QuicksightTemplateFieldLabelType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximumLabelType → QuicksightTemplateSelectAllOptions?
-
final
- minimumLabelType → QuicksightTemplateSelectAllOptions?
-
final
- rangeEndsLabelType → QuicksightTemplateSelectAllOptions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited