QuicksightTemplateDataPathLabelType class final

Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.data_labels.data_label_types.data_path_label_type block of aws_quicksight_template (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightTemplateDataPathLabelType({TfArg<String>? fieldId, TfArg<String>? fieldValue, TfArg<String>? visibility})
const

Properties

fieldId → TfArg<String>?
final
fieldValue → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibility → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited