QuicksightTemplateDropdownDisplayOptions class final

Typed helper for the definition.sheets.filter_controls.dropdown.display_options block of aws_quicksight_template (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectAllOptions → QuicksightTemplateSelectAllOptions?
final
titleOptions → QuicksightTemplateTitleOptions?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited