QuicksightTemplateFilledMapVisualChartConfiguration class final

Typed helper for the definition.sheets.visuals.filled_map_visual.chart_configuration block of aws_quicksight_template (derived from provider schema).

Annotations
  • @immutable

Properties

fieldWells → QuicksightTemplateFilledMapVisualFieldWells?
final
hashCode → int
The hash code for this object.
no setterinherited
legend → QuicksightTemplateLegend?
final
mapStyleOptions → QuicksightTemplateMapStyleOptions?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortConfiguration → QuicksightTemplateFilledMapVisualSortConfiguration?
final
tooltip → QuicksightTemplateTooltip?
final
windowOptions → QuicksightTemplateWindowOptions?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited