QuicksightTemplateHeatMapVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.heat_map_visual.chart_configuration block of
aws_quicksight_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightTemplateHeatMapVisualChartConfiguration({QuicksightTemplateColorScale? colorScale, QuicksightTemplateCategoryLabelOptions? columnLabelOptions, QuicksightTemplateDataLabels? dataLabels, QuicksightTemplateHeatMapVisualFieldWells? fieldWells, QuicksightTemplateLegend? legend, QuicksightTemplateCategoryLabelOptions? rowLabelOptions, QuicksightTemplateHeatMapVisualSortConfiguration? sortConfiguration, QuicksightTemplateTooltip? tooltip})
-
const
Properties
- colorScale → QuicksightTemplateColorScale?
-
final
- columnLabelOptions → QuicksightTemplateCategoryLabelOptions?
-
final
- dataLabels → QuicksightTemplateDataLabels?
-
final
- fieldWells → QuicksightTemplateHeatMapVisualFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → QuicksightTemplateLegend?
-
final
- rowLabelOptions → QuicksightTemplateCategoryLabelOptions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortConfiguration → QuicksightTemplateHeatMapVisualSortConfiguration?
-
final
- tooltip → QuicksightTemplateTooltip?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited