QuicksightTemplateHistogramVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.histogram_visual.chart_configuration block of
aws_quicksight_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightTemplateHistogramVisualChartConfiguration({QuicksightTemplateBinOptions? binOptions, QuicksightTemplateDataLabels? dataLabels, QuicksightTemplateHistogramVisualFieldWells? fieldWells, QuicksightTemplateTooltip? tooltip, QuicksightTemplateVisualPalette? visualPalette, QuicksightTemplateCategoryAxis? xAxisDisplayOptions, QuicksightTemplateCategoryLabelOptions? xAxisLabelOptions, QuicksightTemplateCategoryAxis? yAxisDisplayOptions})
-
const
Properties
- binOptions → QuicksightTemplateBinOptions?
-
final
- dataLabels → QuicksightTemplateDataLabels?
-
final
- fieldWells → QuicksightTemplateHistogramVisualFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltip → QuicksightTemplateTooltip?
-
final
- visualPalette → QuicksightTemplateVisualPalette?
-
final
- xAxisDisplayOptions → QuicksightTemplateCategoryAxis?
-
final
- xAxisLabelOptions → QuicksightTemplateCategoryLabelOptions?
-
final
- yAxisDisplayOptions → QuicksightTemplateCategoryAxis?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited