QuicksightTemplateLabelConfiguration class final

Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.reference_lines.label_configuration block of aws_quicksight_template (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightTemplateLabelConfiguration({TfArg<String>? fontColor, TfArg<String>? horizontalPosition, TfArg<String>? verticalPosition, QuicksightTemplateCustomLabelConfiguration? customLabelConfiguration, QuicksightTemplateFontConfiguration? fontConfiguration, QuicksightTemplateValueLabelConfiguration? valueLabelConfiguration})
const

Properties

customLabelConfiguration → QuicksightTemplateCustomLabelConfiguration?
final
fontColor → TfArg<String>?
final
fontConfiguration → QuicksightTemplateFontConfiguration?
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalPosition → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueLabelConfiguration → QuicksightTemplateValueLabelConfiguration?
final
verticalPosition → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited