QuicksightTemplateNumberDisplayFormatConfiguration class final
Typed helper for the definition.column_configurations.format_configuration.date_time_format_configuration.numeric_format_configuration.number_display_format_configuration block of
aws_quicksight_template (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
QuicksightTemplateNumberDisplayFormatConfiguration({TfArg<
String> ? numberScale, TfArg<String> ? prefix, TfArg<String> ? suffix, QuicksightTemplateDecimalPlacesConfiguration? decimalPlacesConfiguration, QuicksightTemplateNegativeValueConfiguration? negativeValueConfiguration, QuicksightTemplateNullValueFormatConfiguration? nullValueFormatConfiguration, QuicksightTemplateSeparatorConfiguration? separatorConfiguration}) -
const
Properties
- decimalPlacesConfiguration → QuicksightTemplateDecimalPlacesConfiguration?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- negativeValueConfiguration → QuicksightTemplateNegativeValueConfiguration?
-
final
- nullValueFormatConfiguration → QuicksightTemplateNullValueFormatConfiguration?
-
final
-
numberScale
→ TfArg<
String> ? -
final
-
prefix
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separatorConfiguration → QuicksightTemplateSeparatorConfiguration?
-
final
-
suffix
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited