QuicksightTemplateNumericalAggregationFunction class final

Typed helper for the definition.filter_groups.filters.numeric_equality_filter.aggregation_function.numerical_aggregation_function block of aws_quicksight_template (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightTemplateNumericalAggregationFunction({TfArg<String>? simpleNumericalAggregation, QuicksightTemplatePercentileAggregation? percentileAggregation})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
percentileAggregation → QuicksightTemplatePercentileAggregation?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simpleNumericalAggregation → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited