QuicksightTemplatePivotTableVisualTotalOptions class final
Typed helper for the definition.sheets.visuals.pivot_table_visual.chart_configuration.total_options block of
aws_quicksight_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightTemplatePivotTableVisualTotalOptions({QuicksightTemplateColumnSubtotalOptions? columnSubtotalOptions, QuicksightTemplateColumnTotalOptions? columnTotalOptions, QuicksightTemplateColumnSubtotalOptions? rowSubtotalOptions, QuicksightTemplateColumnTotalOptions? rowTotalOptions})
-
const
Properties
- columnSubtotalOptions → QuicksightTemplateColumnSubtotalOptions?
-
final
- columnTotalOptions → QuicksightTemplateColumnTotalOptions?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rowSubtotalOptions → QuicksightTemplateColumnSubtotalOptions?
-
final
- rowTotalOptions → QuicksightTemplateColumnTotalOptions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited