QuicksightTemplateScatterPlotVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.scatter_plot_visual.chart_configuration block of
aws_quicksight_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightTemplateScatterPlotVisualChartConfiguration({QuicksightTemplateDataLabels? dataLabels, QuicksightTemplateScatterPlotVisualFieldWells? fieldWells, QuicksightTemplateLegend? legend, QuicksightTemplateTooltip? tooltip, QuicksightTemplateVisualPalette? visualPalette, QuicksightTemplateCategoryAxis? xAxisDisplayOptions, QuicksightTemplateCategoryLabelOptions? xAxisLabelOptions, QuicksightTemplateCategoryAxis? yAxisDisplayOptions, QuicksightTemplateCategoryLabelOptions? yAxisLabelOptions})
-
const
Properties
- dataLabels → QuicksightTemplateDataLabels?
-
final
- fieldWells → QuicksightTemplateScatterPlotVisualFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → QuicksightTemplateLegend?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tooltip → QuicksightTemplateTooltip?
-
final
- visualPalette → QuicksightTemplateVisualPalette?
-
final
- xAxisDisplayOptions → QuicksightTemplateCategoryAxis?
-
final
- xAxisLabelOptions → QuicksightTemplateCategoryLabelOptions?
-
final
- yAxisDisplayOptions → QuicksightTemplateCategoryAxis?
-
final
- yAxisLabelOptions → QuicksightTemplateCategoryLabelOptions?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited