QuicksightTemplateSectionBasedLayout class final

Typed helper for the definition.sheets.layouts.configuration.section_based_layout block of aws_quicksight_template (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightTemplateSectionBasedLayout({required List<QuicksightTemplateBodySections> bodySections, QuicksightTemplateSectionBasedCanvasSizeOptions? canvasSizeOptions, required QuicksightTemplateFooterSections footerSections, required QuicksightTemplateFooterSections headerSections})
const

Properties

bodySections → List<QuicksightTemplateBodySections>
final
canvasSizeOptions → QuicksightTemplateSectionBasedCanvasSizeOptions?
final
footerSections → QuicksightTemplateFooterSections
final
hashCode → int
The hash code for this object.
no setterinherited
headerSections → QuicksightTemplateFooterSections
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited