QuicksightTemplateStringParameterDeclaration class final

Typed helper for the definition.parameters_declarations.string_parameter_declaration block of aws_quicksight_template (derived from provider schema).

Annotations
  • @immutable

Properties

defaultValues → QuicksightTemplateStringParameterDeclarationDefaultValues?
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
parameterValueType → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valuesWhenUnset → QuicksightTemplateDateTimeParameterDeclarationValuesWhenUnset?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited