QuicksightTemplateTableVisualSelectedFieldOptions class final

Typed helper for the definition.sheets.visuals.table_visual.chart_configuration.field_options.selected_field_options block of aws_quicksight_template (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightTemplateTableVisualSelectedFieldOptions({TfArg<String>? customLabel, required TfArg<String> fieldId, TfArg<String>? visibility, TfArg<String>? width, QuicksightTemplateUrlStyling? urlStyling})
const

Properties

customLabel → TfArg<String>?
final
fieldId → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urlStyling → QuicksightTemplateUrlStyling?
final
visibility → TfArg<String>?
final
width → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited