QuicksightTemplateTableVisualTableOptions class final

Typed helper for the definition.sheets.visuals.table_visual.chart_configuration.table_options block of aws_quicksight_template (derived from provider schema).

Annotations
  • @immutable

Properties

cellStyle → QuicksightTemplateCellStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
headerStyle → QuicksightTemplateCellStyle?
final
orientation → TfArg<String>?
final
rowAlternateColorOptions → QuicksightTemplateRowAlternateColorOptions?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited