QuicksightTemplateTextFormat class final

Typed helper for the definition.sheets.visuals.pivot_table_visual.conditional_formatting.conditional_formatting_options.cell.text_format block of aws_quicksight_template (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

QuicksightTemplateTextFormat({required QuicksightTemplateForegroundColor backgroundColor, QuicksightTemplateIcon? icon, required QuicksightTemplateForegroundColor textColor})
const

Properties

backgroundColor → QuicksightTemplateForegroundColor
final
hashCode → int
The hash code for this object.
no setterinherited
icon → QuicksightTemplateIcon?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → QuicksightTemplateForegroundColor
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited