QuicksightTemplateTreeMapVisualSortConfiguration class final
Typed helper for the definition.sheets.visuals.tree_map_visual.chart_configuration.sort_configuration block of
aws_quicksight_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
QuicksightTemplateTreeMapVisualSortConfiguration({QuicksightTemplateCategoryItemsLimit? treeMapGroupItemsLimitConfiguration, List<
QuicksightTemplateCategorySort> ? treeMapSort}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- treeMapGroupItemsLimitConfiguration → QuicksightTemplateCategoryItemsLimit?
-
final
-
treeMapSort
→ List<
QuicksightTemplateCategorySort> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited