QuicksightTemplateUniqueValues class final

Typed helper for the definition.sheets.visuals.insight_visual.insight_configuration.computation.unique_values block of aws_quicksight_template (derived from provider schema).

Annotations
  • @immutable

Constructors

QuicksightTemplateUniqueValues({required TfArg<String> computationId, TfArg<String>? name, QuicksightTemplateTrendGroups? category})
const

Properties

category → QuicksightTemplateTrendGroups?
final
computationId → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited