QuicksightTemplateWaterfallVisualChartConfiguration class final
Typed helper for the definition.sheets.visuals.waterfall_visual.chart_configuration block of
aws_quicksight_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- QuicksightTemplateWaterfallVisualChartConfiguration({QuicksightTemplateCategoryAxis? categoryAxisDisplayOptions, QuicksightTemplateCategoryLabelOptions? categoryAxisLabelOptions, QuicksightTemplateDataLabels? dataLabels, QuicksightTemplateWaterfallVisualFieldWells? fieldWells, QuicksightTemplateLegend? legend, QuicksightTemplateCategoryAxis? primaryYAxisDisplayOptions, QuicksightTemplateCategoryLabelOptions? primaryYAxisLabelOptions, QuicksightTemplateWaterfallVisualSortConfiguration? sortConfiguration, QuicksightTemplateVisualPalette? visualPalette, QuicksightTemplateWaterfallChartOptions? waterfallChartOptions})
-
const
Properties
- categoryAxisDisplayOptions → QuicksightTemplateCategoryAxis?
-
final
- categoryAxisLabelOptions → QuicksightTemplateCategoryLabelOptions?
-
final
- dataLabels → QuicksightTemplateDataLabels?
-
final
- fieldWells → QuicksightTemplateWaterfallVisualFieldWells?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → QuicksightTemplateLegend?
-
final
- primaryYAxisDisplayOptions → QuicksightTemplateCategoryAxis?
-
final
- primaryYAxisLabelOptions → QuicksightTemplateCategoryLabelOptions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortConfiguration → QuicksightTemplateWaterfallVisualSortConfiguration?
-
final
- visualPalette → QuicksightTemplateVisualPalette?
-
final
- waterfallChartOptions → QuicksightTemplateWaterfallChartOptions?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited