RamResourceShareConfiguration class final

Typed helper for the resource_share_configuration block of aws_ram_resource_share (derived from provider schema).

Annotations
  • @immutable

Constructors

RamResourceShareConfiguration({TfArg<bool>? retainSharingOnAccountLeaveOrganization})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
retainSharingOnAccountLeaveOrganization → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited