RedshiftIdcApplicationReadWriteAccess class final

Typed helper for the service_integration.s3_access_grants.read_write_access block of aws_redshift_idc_application (derived from provider schema).

Annotations
  • @immutable

Constructors

RedshiftIdcApplicationReadWriteAccess({required RedshiftIdcApplicationAuthorization authorization})
const

Properties

authorization → RedshiftIdcApplicationAuthorization
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited