RedshiftIdcApplicationServiceIntegration class final

Typed helper for the service_integration block of aws_redshift_idc_application (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
lakeFormation → List<RedshiftIdcApplicationLakeFormation>?
final
redshift → List<RedshiftIdcApplicationRedshift>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3AccessGrants → List<RedshiftIdcApplicationS3AccessGrants>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited