RedshiftserverlessNamespaceAdminPasswordAdminUserPassword class final

The RedshiftserverlessNamespaceAdminPassword.adminUserPassword choice: sets admin_user_password.

Inheritance

Constructors

RedshiftserverlessNamespaceAdminPasswordAdminUserPassword(TfArg<String> adminUserPassword)
const

Properties

adminUserPassword → TfArg<String>
final
argMap → Map<String, TfArg<Object?>>
The resource arguments behind encode, as the caller's TfArgs.
no setteroverride
blockKey → String
The Terraform argument this choice sets.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited