ResourcegroupsGroupResourceQuery class final

Typed helper for the resource_query block of aws_resourcegroups_group (derived from provider schema).

Annotations
  • @immutable

Constructors

ResourcegroupsGroupResourceQuery({required TfArg<String> query, ResourcegroupsGroupType? type})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
query → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ResourcegroupsGroupType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited