S3BucketNotificationTopic class final

Typed helper for the topic block of aws_s3_bucket_notification (derived from provider schema).

Annotations
  • @immutable

Constructors

S3BucketNotificationTopic({required TfArg<List<String>> events, TfArg<String>? filterPrefix, TfArg<String>? filterSuffix, TfArg<String>? id, required RefTo<AwsSnsTopic> topicArn})
const

Properties

events → TfArg<List<String>>
final
filterPrefix → TfArg<String>?
final
filterSuffix → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topicArn → RefTo<AwsSnsTopic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited