S3BucketObjectStorageClass enum

S3 Bucket Object Storage enum for storage_class.

Inheritance
Available extensions

Values

standard → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('STANDARD')
reducedRedundancy → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('REDUCED_REDUNDANCY')
glacier → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('GLACIER')
standardIa → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('STANDARD_IA')
onezoneIa → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('ONEZONE_IA')
intelligentTiering → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('INTELLIGENT_TIERING')
deepArchive → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('DEEP_ARCHIVE')
outposts → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('OUTPOSTS')
glacierIr → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('GLACIER_IR')
snow → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('SNOW')
expressOnezone → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('EXPRESS_ONEZONE')
fsxOpenzfs → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('FSX_OPENZFS')
fsxOntap → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('FSX_ONTAP')
awsBackupWarm → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('AWS_BACKUP_WARM')
awsBackupLowCostWarm → const S3BucketObjectStorageClass
const S3BucketObjectStorageClass('AWS_BACKUP_LOW_COST_WARM')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terraformValue → String
The Terraform-side string literal this enum value encodes to. Convention: emitted exactly as it appears in provider docs (typically SCREAMING_SNAKE_CASE for GCP).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<S3BucketObjectStorageClass>
A constant List of the values in this enum, in order of their declaration.