S3BucketReplicationConfigurationAnd class final

Typed helper for the rule.filter.and block of aws_s3_bucket_replication_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

S3BucketReplicationConfigurationAnd({TfArg<String>? prefix, TfArg<Map<String, String>>? tags})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
prefix → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → TfArg<Map<String, String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited