S3BucketReplicationConfigurationEncryptionConfiguration class final

Typed helper for the rule.destination.encryption_configuration block of aws_s3_bucket_replication_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

S3BucketReplicationConfigurationEncryptionConfiguration({required TfArg<String> replicaKmsKeyId})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
replicaKmsKeyId → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited