S3ObjectCopyAccessAcl class final

The S3ObjectCopyAccess.acl choice: sets acl.

Inheritance

Constructors

S3ObjectCopyAccessAcl(S3ObjectCopyAcl acl)
const

Properties

acl → S3ObjectCopyAcl
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited