S3ObjectServerSideEncryption extension type
S3 Object Server Side enum for server_side_encryption.
Constructors
-
S3ObjectServerSideEncryption.arg(TfArg<
String> arg) -
const
- S3ObjectServerSideEncryption.expression(String template)
- S3ObjectServerSideEncryption.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- aes256 → const S3ObjectServerSideEncryption
- awsBackup → const S3ObjectServerSideEncryption
- awsFsx → const S3ObjectServerSideEncryption
- awsKms → const S3ObjectServerSideEncryption
- awsKmsDsse → const S3ObjectServerSideEncryption
-
values
→ const List<
S3ObjectServerSideEncryption>