S3controlStorageLensConfiguration class final
Typed helper for the storage_lens_configuration block of
aws_s3control_storage_lens_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
S3controlStorageLensConfiguration({required TfArg<
bool> enabled, TfArg<String> ? prefixDelimiter, required S3controlStorageLensConfigurationAccountLevel accountLevel, S3controlStorageLensConfigurationAwsOrg? awsOrg, S3controlStorageLensConfigurationDataExport? dataExport, S3controlStorageLensConfigurationExclude? exclude, S3controlStorageLensConfigurationExpandedPrefixesDataExport? expandedPrefixesDataExport, S3controlStorageLensConfigurationInclude? include}) -
const
Properties
- accountLevel → S3controlStorageLensConfigurationAccountLevel
-
final
- awsOrg → S3controlStorageLensConfigurationAwsOrg?
-
final
- dataExport → S3controlStorageLensConfigurationDataExport?
-
final
-
enabled
→ TfArg<
bool> -
final
- exclude → S3controlStorageLensConfigurationExclude?
-
final
- expandedPrefixesDataExport → S3controlStorageLensConfigurationExpandedPrefixesDataExport?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- include → S3controlStorageLensConfigurationInclude?
-
final
-
prefixDelimiter
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited