S3controlStorageLensConfigurationEncryption class final

Typed helper for the storage_lens_configuration.data_export.s3_bucket_destination.encryption block of aws_s3control_storage_lens_configuration (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sseKms → S3controlStorageLensConfigurationSseKms?
final
sseS3 → List<S3controlStorageLensConfigurationSseS3>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited