S3controlStorageLensConfigurationPrefixLevel class final

Typed helper for the storage_lens_configuration.account_level.bucket_level.prefix_level block of aws_s3control_storage_lens_configuration (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageMetrics → S3controlStorageLensConfigurationStorageMetrics
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited