S3filesSynchronizationConfigurationImportDataRule class final

Typed helper for the import_data_rule block of aws_s3files_synchronization_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

S3filesSynchronizationConfigurationImportDataRule({required TfArg<String> prefix, required TfArg<num> sizeLessThan, required S3filesSynchronizationConfigurationTrigger trigger})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
prefix → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeLessThan → TfArg<num>
final
trigger → S3filesSynchronizationConfigurationTrigger
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited