SagemakerAlgorithmBaseModel class final

Typed helper for the inference_specification.containers.base_model block of aws_sagemaker_algorithm (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerAlgorithmBaseModel({TfArg<String>? hubContentName, TfArg<String>? hubContentVersion, TfArg<String>? recipeName})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hubContentName → TfArg<String>?
final
hubContentVersion → TfArg<String>?
final
recipeName → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited