SagemakerAlgorithmDataSourceS3DataType extension type
s3_data_type — derived from the provider schema description.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- augmentedmanifestfile → const SagemakerAlgorithmDataSourceS3DataType
- converse → const SagemakerAlgorithmDataSourceS3DataType
- manifestfile → const SagemakerAlgorithmDataSourceS3DataType
- s3prefix → const SagemakerAlgorithmDataSourceS3DataType
-
values
→ const List<
SagemakerAlgorithmDataSourceS3DataType>