SagemakerAlgorithmFileSystemType extension type
file_system_type — derived from the provider schema description.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- efs → const SagemakerAlgorithmFileSystemType
- fsxlustre → const SagemakerAlgorithmFileSystemType
-
values
→ const List<
SagemakerAlgorithmFileSystemType>