SagemakerAlgorithmStoppingCondition class final

Typed helper for the validation_specification.validation_profiles.training_job_definition.stopping_condition block of aws_sagemaker_algorithm (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerAlgorithmStoppingCondition({TfArg<num>? maxPendingTimeInSeconds, TfArg<num>? maxRuntimeInSeconds, TfArg<num>? maxWaitTimeInSeconds})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxPendingTimeInSeconds → TfArg<num>?
final
maxRuntimeInSeconds → TfArg<num>?
final
maxWaitTimeInSeconds → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited