SagemakerAlgorithmSupportedTuningJobObjectiveMetrics class final

Typed helper for the training_specification.supported_tuning_job_objective_metrics block of aws_sagemaker_algorithm (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
metricName → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → SagemakerAlgorithmSupportedTuningJobObjectiveMetricsType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited