SagemakerAlgorithmTrainingChannels class final

Typed helper for the training_specification.training_channels block of aws_sagemaker_algorithm (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerAlgorithmTrainingChannels({TfArg<String>? description, TfArg<bool>? isRequired, required TfArg<String> name, List<SagemakerAlgorithmSupportedCompressionTypes>? supportedCompressionTypes, required TfArg<List<String>> supportedContentTypes, required List<SagemakerAlgorithmSupportedInputModes> supportedInputModes})
const

Properties

description → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
isRequired → TfArg<bool>?
final
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedCompressionTypes → List<SagemakerAlgorithmSupportedCompressionTypes>?
final
supportedContentTypes → TfArg<List<String>>
final
supportedInputModes → List<SagemakerAlgorithmSupportedInputModes>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited