SagemakerAlgorithmTransformInputS3DataSource class final

Typed helper for the validation_specification.validation_profiles.transform_job_definition.transform_input.data_source.s3_data_source block of aws_sagemaker_algorithm (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerAlgorithmTransformInputS3DataSource({required SagemakerAlgorithmDataSourceS3DataType s3DataType, required TfArg<String> s3Uri})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3DataType → SagemakerAlgorithmDataSourceS3DataType
final
s3Uri → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited