SagemakerAlgorithmValidationProfiles class final

Typed helper for the validation_specification.validation_profiles block of aws_sagemaker_algorithm (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerAlgorithmValidationProfiles({required TfArg<String> profileName, List<SagemakerAlgorithmTrainingJobDefinition>? trainingJobDefinition, List<SagemakerAlgorithmTransformJobDefinition>? transformJobDefinition})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
profileName → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingJobDefinition → List<SagemakerAlgorithmTrainingJobDefinition>?
final
transformJobDefinition → List<SagemakerAlgorithmTransformJobDefinition>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited