SagemakerAppImageConfigKernelSpec class final

Typed helper for the kernel_gateway_image_config.kernel_spec block of aws_sagemaker_app_image_config (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerAppImageConfigKernelSpec({TfArg<String>? displayName, required TfArg<String> name})
const

Properties

displayName → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited