SagemakerDataQualityJobDefinitionMonitoringOutputs class final

Typed helper for the data_quality_job_output_config.monitoring_outputs block of aws_sagemaker_data_quality_job_definition (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Output → SagemakerDataQualityJobDefinitionS3Output
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited