SagemakerDataQualityJobDefinitionNetworkConfig class final

Typed helper for the network_config block of aws_sagemaker_data_quality_job_definition (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerDataQualityJobDefinitionNetworkConfig({TfArg<bool>? enableInterContainerTrafficEncryption, TfArg<bool>? enableNetworkIsolation, SagemakerDataQualityJobDefinitionVpcConfig? vpcConfig})
const

Properties

enableInterContainerTrafficEncryption → TfArg<bool>?
final
enableNetworkIsolation → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcConfig → SagemakerDataQualityJobDefinitionVpcConfig?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited