SagemakerDomainCodeEditorAppSettings class final
Typed helper for the default_user_settings.code_editor_app_settings block of
aws_sagemaker_domain (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SagemakerDomainCodeEditorAppSettings({TfArg<
String> ? builtInLifecycleConfigArn, TfArg<List< ? lifecycleConfigArns, SagemakerDomainAppLifecycleManagement? appLifecycleManagement, List<String> >SagemakerDomainCustomImage> ? customImage, SagemakerDomainDefaultResourceSpec? defaultResourceSpec}) -
const
Properties
- appLifecycleManagement → SagemakerDomainAppLifecycleManagement?
-
final
-
builtInLifecycleConfigArn
→ TfArg<
String> ? -
final
-
customImage
→ List<
SagemakerDomainCustomImage> ? -
final
- defaultResourceSpec → SagemakerDomainDefaultResourceSpec?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lifecycleConfigArns
→ TfArg<
List< ?String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited