SagemakerDomainCustomPosixUserConfig class final

Typed helper for the default_space_settings.custom_posix_user_config block of aws_sagemaker_domain (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

SagemakerDomainCustomPosixUserConfig({required TfArg<num> gid, required TfArg<num> uid})
const

Properties

gid → TfArg<num>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid → TfArg<num>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited