SagemakerDomainRStudioServerProDomainSettings class final

Typed helper for the domain_settings.r_studio_server_pro_domain_settings block of aws_sagemaker_domain (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerDomainRStudioServerProDomainSettings({required TfArg<String> domainExecutionRoleArn, TfArg<String>? rStudioConnectUrl, TfArg<String>? rStudioPackageManagerUrl, SagemakerDomainDefaultResourceSpec? defaultResourceSpec})
const

Properties

defaultResourceSpec → SagemakerDomainDefaultResourceSpec?
final
domainExecutionRoleArn → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
rStudioConnectUrl → TfArg<String>?
final
rStudioPackageManagerUrl → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited