SagemakerFeatureGroupOnlineStoreConfig class final

Typed helper for the online_store_config block of aws_sagemaker_feature_group (derived from provider schema).

Annotations
  • @immutable

Properties

enableOnlineStore → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityConfig → SagemakerFeatureGroupSecurityConfig?
final
storageType → SagemakerFeatureGroupStorageType?
final
ttlDuration → SagemakerFeatureGroupTtlDuration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited