SagemakerFlowDefinitionHumanLoopConfig class final

Typed helper for the human_loop_config block of aws_sagemaker_flow_definition (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerFlowDefinitionHumanLoopConfig({required TfArg<String> humanTaskUiArn, TfArg<num>? taskAvailabilityLifetimeInSeconds, required TfArg<num> taskCount, required TfArg<String> taskDescription, TfArg<List<String>>? taskKeywords, TfArg<num>? taskTimeLimitInSeconds, required TfArg<String> taskTitle, required TfArg<String> workteamArn, SagemakerFlowDefinitionPublicWorkforceTaskPrice? publicWorkforceTaskPrice})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
humanTaskUiArn → TfArg<String>
final
publicWorkforceTaskPrice → SagemakerFlowDefinitionPublicWorkforceTaskPrice?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskAvailabilityLifetimeInSeconds → TfArg<num>?
final
taskCount → TfArg<num>
final
taskDescription → TfArg<String>
final
taskKeywords → TfArg<List<String>>?
final
taskTimeLimitInSeconds → TfArg<num>?
final
taskTitle → TfArg<String>
final
workteamArn → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited