SagemakerFlowDefinitionOutputConfig class final

Typed helper for the output_config block of aws_sagemaker_flow_definition (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerFlowDefinitionOutputConfig({RefTo<AwsKmsKey>? kmsKeyId, required TfArg<String> s3OutputPath})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → RefTo<AwsKmsKey>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3OutputPath → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited