SagemakerHyperParameterTuningJobHyperParameterTuningResourceConfig class final

Typed helper for the training_job_definition.hyper_parameter_tuning_resource_config block of aws_sagemaker_hyper_parameter_tuning_job (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Properties

allocationStrategy → SagemakerHyperParameterTuningJobAllocationStrategy?
final
hashCode → int
The hash code for this object.
no setterinherited
instanceConfigs → List<SagemakerHyperParameterTuningJobInstanceConfigs>?
final
instanceCount → TfArg<num>?
final
instanceType → SagemakerHyperParameterTuningJobInstanceType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volumeKmsKeyId → TfArg<String>?
final
volumeSizeInGb → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited