SagemakerHyperParameterTuningJobObjective class final
Typed helper for the config.objective block of
aws_sagemaker_hyper_parameter_tuning_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SagemakerHyperParameterTuningJobObjective({required TfArg<
String> metricName, required TfArg<SagemakerHyperParameterTuningJobType> type}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metricName
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
→ TfArg<
SagemakerHyperParameterTuningJobType> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited