SagemakerHyperParameterTuningJobStrategyConfig class final

Typed helper for the config.strategy_config block of aws_sagemaker_hyper_parameter_tuning_job (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
hyperbandStrategyConfig → List<SagemakerHyperParameterTuningJobHyperbandStrategyConfig>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited