SagemakerHyperParameterTuningJobTrainingJobDefinitions class final
Typed helper for the training_job_definitions block of
aws_sagemaker_hyper_parameter_tuning_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SagemakerHyperParameterTuningJobTrainingJobDefinitions({TfArg<
String> ? definitionName, TfArg<bool> ? enableInterContainerTrafficEncryption, TfArg<bool> ? enableManagedSpotTraining, TfArg<bool> ? enableNetworkIsolation, TfArg<Map< ? environment, TfArg<String, String> >List< ? retryStrategy, required RefTo<Object?> >AwsIamRole> roleArn, TfArg<Map< ? staticHyperParameters, List<String, String> >SagemakerHyperParameterTuningJobAlgorithmSpecification> ? algorithmSpecification, List<SagemakerHyperParameterTuningJobCheckpointConfig> ? checkpointConfig, List<SagemakerHyperParameterTuningJobHyperParameterRanges> ? hyperParameterRanges, SagemakerHyperParameterTuningJobTrainingJobDefinitionsResources? resources, List<SagemakerHyperParameterTuningJobInputDataConfig> ? inputDataConfig, List<SagemakerHyperParameterTuningJobOutputDataConfig> ? outputDataConfig, List<SagemakerHyperParameterTuningJobStoppingCondition> ? stoppingCondition, List<SagemakerHyperParameterTuningJobTuningObjective> ? tuningObjective, List<SagemakerHyperParameterTuningJobVpcConfig> ? vpcConfig}) -
const
Properties
-
algorithmSpecification
→ List<
SagemakerHyperParameterTuningJobAlgorithmSpecification> ? -
final
-
checkpointConfig
→ List<
SagemakerHyperParameterTuningJobCheckpointConfig> ? -
final
-
definitionName
→ TfArg<
String> ? -
final
-
enableInterContainerTrafficEncryption
→ TfArg<
bool> ? -
final
-
enableManagedSpotTraining
→ TfArg<
bool> ? -
final
-
enableNetworkIsolation
→ TfArg<
bool> ? -
final
-
environment
→ TfArg<
Map< ?String, String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hyperParameterRanges
→ List<
SagemakerHyperParameterTuningJobHyperParameterRanges> ? -
final
-
inputDataConfig
→ List<
SagemakerHyperParameterTuningJobInputDataConfig> ? -
final
-
outputDataConfig
→ List<
SagemakerHyperParameterTuningJobOutputDataConfig> ? -
final
- resources → SagemakerHyperParameterTuningJobTrainingJobDefinitionsResources?
-
final
-
retryStrategy
→ TfArg<
List< ?Object?> > -
final
-
roleArn
→ RefTo<
AwsIamRole> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
staticHyperParameters
→ TfArg<
Map< ?String, String> > -
final
-
stoppingCondition
→ List<
SagemakerHyperParameterTuningJobStoppingCondition> ? -
final
-
tuningObjective
→ List<
SagemakerHyperParameterTuningJobTuningObjective> ? -
final
-
vpcConfig
→ List<
SagemakerHyperParameterTuningJobVpcConfig> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited