SagemakerHyperParameterTuningJobWarmStartConfig class final

Typed helper for the warm_start_config block of aws_sagemaker_hyper_parameter_tuning_job (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
parentHyperParameterTuningJobs → List<SagemakerHyperParameterTuningJobParentHyperParameterTuningJobs>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
warmStartType → SagemakerHyperParameterTuningJobWarmStartType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited