SagemakerModelCardSecurityConfig class final

Typed helper for the security_config block of aws_sagemaker_model_card (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerModelCardSecurityConfig({required RefTo<AwsKmsKey> kmsKeyId})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → RefTo<AwsKmsKey>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited