SagemakerModelContainer class final

Typed helper for the container block of aws_sagemaker_model (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerModelContainer({TfArg<String>? containerHostname, TfArg<Map<String, String>>? environment, TfArg<String>? image, TfArg<String>? inferenceSpecificationName, TfArg<SagemakerModelContainerMode>? mode, TfArg<String>? modelDataUrl, TfArg<String>? modelPackageName, List<SagemakerModelAdditionalModelDataSource>? additionalModelDataSource, SagemakerModelImageConfig? imageConfig, SagemakerModelDataSource? modelDataSource, SagemakerModelMultiModelConfig? multiModelConfig})
const

Properties

additionalModelDataSource → List<SagemakerModelAdditionalModelDataSource>?
final
containerHostname → TfArg<String>?
final
environment → TfArg<Map<String, String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
image → TfArg<String>?
final
imageConfig → SagemakerModelImageConfig?
final
inferenceSpecificationName → TfArg<String>?
final
mode → TfArg<SagemakerModelContainerMode>?
final
modelDataSource → SagemakerModelDataSource?
final
modelDataUrl → TfArg<String>?
final
modelPackageName → TfArg<String>?
final
multiModelConfig → SagemakerModelMultiModelConfig?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited