SagemakerModelDataSource class final

Typed helper for the container.model_data_source block of aws_sagemaker_model (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

SagemakerModelDataSource({required List<SagemakerModelS3DataSource> s3DataSource})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3DataSource → List<SagemakerModelS3DataSource>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited