SagemakerMonitoringScheduleNetworkConfig class final

Typed helper for the monitoring_schedule_config.monitoring_job_definition.network_config block of aws_sagemaker_monitoring_schedule (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerMonitoringScheduleNetworkConfig({TfArg<bool>? enableInterContainerTrafficEncryption, TfArg<bool>? enableNetworkIsolation, SagemakerMonitoringScheduleVpcConfig? vpcConfig})
const

Properties

enableInterContainerTrafficEncryption → TfArg<bool>?
final
enableNetworkIsolation → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcConfig → SagemakerMonitoringScheduleVpcConfig?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited