SagemakerSpaceEfsFileSystem class final

Typed helper for the space_settings.custom_file_system.efs_file_system block of aws_sagemaker_space (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerSpaceEfsFileSystem({required TfArg<String> fileSystemId})
const

Properties

fileSystemId → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited