SagemakerTrainingJobAlgorithmSpecification class final

Typed helper for the algorithm_specification block of aws_sagemaker_training_job (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerTrainingJobAlgorithmSpecification({TfArg<String>? algorithmName, TfArg<List<String>>? containerArguments, TfArg<List<String>>? containerEntrypoint, TfArg<bool>? enableSagemakerMetricsTimeSeries, TfArg<String>? trainingImage, SagemakerTrainingJobTrainingInputMode? trainingInputMode, List<SagemakerTrainingJobMetricDefinitions>? metricDefinitions, List<SagemakerTrainingJobTrainingImageConfig>? trainingImageConfig})
const

Properties

algorithmName → TfArg<String>?
final
containerArguments → TfArg<List<String>>?
final
containerEntrypoint → TfArg<List<String>>?
final
enableSagemakerMetricsTimeSeries → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
metricDefinitions → List<SagemakerTrainingJobMetricDefinitions>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingImage → TfArg<String>?
final
trainingImageConfig → List<SagemakerTrainingJobTrainingImageConfig>?
final
trainingInputMode → SagemakerTrainingJobTrainingInputMode?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited