SagemakerTrainingJobExperimentConfig class final

Typed helper for the experiment_config block of aws_sagemaker_training_job (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerTrainingJobExperimentConfig({TfArg<String>? experimentName, TfArg<String>? runName, TfArg<String>? trialComponentDisplayName, TfArg<String>? trialName})
const

Properties

experimentName → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runName → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trialComponentDisplayName → TfArg<String>?
final
trialName → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited