SagemakerTrainingJobFileSystemDataSource class final

Typed helper for the input_data_config.data_source.file_system_data_source block of aws_sagemaker_training_job (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerTrainingJobFileSystemDataSource({required TfArg<String> directoryPath, required SagemakerTrainingJobFileSystemAccessMode fileSystemAccessMode, required TfArg<String> fileSystemId, required SagemakerTrainingJobFileSystemType fileSystemType})
const

Properties

directoryPath → TfArg<String>
final
fileSystemAccessMode → SagemakerTrainingJobFileSystemAccessMode
final
fileSystemId → TfArg<String>
final
fileSystemType → SagemakerTrainingJobFileSystemType
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited