SagemakerTrainingJobInputDataConfig class final

Typed helper for the input_data_config block of aws_sagemaker_training_job (derived from provider schema).

Annotations
  • @immutable

Properties

channelName → TfArg<String>
final
compressionType → SagemakerTrainingJobInputDataConfigCompressionType?
final
contentType → TfArg<String>?
final
dataSource → List<SagemakerTrainingJobDataSource>?
final
hashCode → int
The hash code for this object.
no setterinherited
inputMode → SagemakerTrainingJobInputMode?
final
recordWrapperType → SagemakerTrainingJobRecordWrapperType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffleConfig → List<SagemakerTrainingJobShuffleConfig>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited