SagemakerUserProfileCodeEditorAppSettings class final

Typed helper for the user_settings.code_editor_app_settings block of aws_sagemaker_user_profile (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerUserProfileCodeEditorAppSettings({TfArg<String>? builtInLifecycleConfigArn, TfArg<List<String>>? lifecycleConfigArns, SagemakerUserProfileAppLifecycleManagement? appLifecycleManagement, List<SagemakerUserProfileCustomImage>? customImage, SagemakerUserProfileDefaultResourceSpec? defaultResourceSpec})
const

Properties

appLifecycleManagement → SagemakerUserProfileAppLifecycleManagement?
final
builtInLifecycleConfigArn → TfArg<String>?
final
customImage → List<SagemakerUserProfileCustomImage>?
final
defaultResourceSpec → SagemakerUserProfileDefaultResourceSpec?
final
hashCode → int
The hash code for this object.
no setterinherited
lifecycleConfigArns → TfArg<List<String>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited