SagemakerUserProfileRStudioServerProAppSettings class final

Typed helper for the user_settings.r_studio_server_pro_app_settings block of aws_sagemaker_user_profile (derived from provider schema).

Annotations
  • @immutable

Properties

accessStatus → SagemakerUserProfileAccessStatus?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userGroup → SagemakerUserProfileUserGroup?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited