SecretsmanagerSecretVersionSecretString class final
The SecretsmanagerSecretVersionSecret.secretString choice: sets secret_string.
- Inheritance
-
- Object
- SecretsmanagerSecretVersionSecret
- SecretsmanagerSecretVersionSecretString
Constructors
-
SecretsmanagerSecretVersionSecretString(Sensitive<
String> secretString) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretString
→ Sensitive<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited