SecurityhubAutomationRuleNote class final

Typed helper for the actions.finding_fields_update.note block of aws_securityhub_automation_rule (derived from provider schema).

Annotations
  • @immutable

Constructors

SecurityhubAutomationRuleNote({required TfArg<String> text, required TfArg<String> updatedBy})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → TfArg<String>
final
updatedBy → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited