SecurityhubAutomationRuleNoteUpdatedAt class final

Typed helper for the criteria.note_updated_at block of aws_securityhub_automation_rule (derived from provider schema).

Annotations
  • @immutable

Properties

dateRange → List<SecurityhubAutomationRuleDateRange>?
final
end → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited