SecurityhubConfigurationPolicyDisabledControlIdentifiers class final
The SecurityhubConfigurationPolicyControlIdentifiers.disabledControlIdentifiers choice: sets disabled_control_identifiers.
- Inheritance
-
- Object
- SecurityhubConfigurationPolicyControlIdentifiers
- SecurityhubConfigurationPolicyDisabledControlIdentifiers
Constructors
-
SecurityhubConfigurationPolicyDisabledControlIdentifiers(TfArg<
List< disabledControlIdentifiers)String> > -
const
Properties
-
disabledControlIdentifiers
→ TfArg<
List< String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited