SecurityhubConfigurationPolicyEnabledControlIdentifiers class final
The SecurityhubConfigurationPolicyControlIdentifiers.enabledControlIdentifiers choice: sets enabled_control_identifiers.
- Inheritance
-
- Object
- SecurityhubConfigurationPolicyControlIdentifiers
- SecurityhubConfigurationPolicyEnabledControlIdentifiers
Constructors
-
SecurityhubConfigurationPolicyEnabledControlIdentifiers(TfArg<
List< enabledControlIdentifiers)String> > -
const
Properties
-
enabledControlIdentifiers
→ TfArg<
List< String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited