SecurityhubConfigurationPolicyString class final

Typed helper for the configuration_policy.security_controls_configuration.security_control_custom_parameter.parameter.string block of aws_securityhub_configuration_policy (derived from provider schema).

Annotations
  • @immutable

Constructors

SecurityhubConfigurationPolicyString({required TfArg<String> value})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited