SecurityhubInsightNoteUpdatedAt class final

Typed helper for the filters.note_updated_at block of aws_securityhub_insight (derived from provider schema).

Annotations
  • @immutable

Constructors

SecurityhubInsightNoteUpdatedAt({TfArg<String>? end, TfArg<String>? start, SecurityhubInsightDateRange? dateRange})
const

Properties

dateRange → SecurityhubInsightDateRange?
final
end → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited