SecurityhubInsightProcessPath class final

Typed helper for the filters.process_path block of aws_securityhub_insight (derived from provider schema).

Annotations
  • @immutable

Constructors

SecurityhubInsightProcessPath({required TfArg<String> comparison, required TfArg<String> value})
const

Properties

comparison → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited