SecurityhubOrganizationConfiguration class final

Typed helper for the organization_configuration block of aws_securityhub_organization_configuration (derived from provider schema).

Annotations
  • @immutable

Constructors

SecurityhubOrganizationConfiguration({required SecurityhubOrganizationConfigurationType configurationType})
const

Properties

configurationType → SecurityhubOrganizationConfigurationType
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited