SecuritylakeCustomLogSourceConfiguration class final
Typed helper for the configuration block of
aws_securitylake_custom_log_source (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SecuritylakeCustomLogSourceConfiguration({List<
SecuritylakeCustomLogSourceCrawlerConfiguration> ? crawlerConfiguration, List<SecuritylakeCustomLogSourceProviderIdentity> ? providerIdentity}) -
const
Properties
-
crawlerConfiguration
→ List<
SecuritylakeCustomLogSourceCrawlerConfiguration> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
providerIdentity
→ List<
SecuritylakeCustomLogSourceProviderIdentity> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited