SecuritylakeSubscriberCustomLogSourceResource class final

Typed helper for the source.custom_log_source_resource block of aws_securitylake_subscriber (derived from provider schema).

Annotations
  • @immutable

Constructors

SecuritylakeSubscriberCustomLogSourceResource({required TfArg<String> sourceName, TfArg<String>? sourceVersion})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceName → TfArg<String>
final
sourceVersion → TfArg<String>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited