ServicecatalogServiceActionDefinition class final

Typed helper for the definition block of aws_servicecatalog_service_action (derived from provider schema).

Annotations
  • @immutable

Constructors

ServicecatalogServiceActionDefinition({TfArg<String>? assumeRole, required TfArg<String> name, TfArg<String>? parameters, TfArg<ServicecatalogServiceActionType>? type, required TfArg<String> version})
const

Properties

assumeRole → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>
final
parameters → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<ServicecatalogServiceActionType>?
final
version → TfArg<String>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited