Sesv2ConfigurationSetEventDestinationTargetEventBridgeDestination class final
The Sesv2ConfigurationSetEventDestinationTarget.eventBridgeDestination choice: sets event_bridge_destination.
- Inheritance
-
- Object
- Sesv2ConfigurationSetEventDestinationTarget
- Sesv2ConfigurationSetEventDestinationTargetEventBridgeDestination
Constructors
- Sesv2ConfigurationSetEventDestinationTargetEventBridgeDestination(Sesv2ConfigurationSetEventDestinationEventBridgeDestination eventBridgeDestination)
-
const
Properties
- blockKey → String
-
The Terraform argument this choice sets.
no setteroverride
- eventBridgeDestination → Sesv2ConfigurationSetEventDestinationEventBridgeDestination
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited