Sesv2ConfigurationSetReputationOptions class final

Typed helper for the reputation_options block of aws_sesv2_configuration_set (derived from provider schema).

Annotations
  • @immutable

Constructors

Sesv2ConfigurationSetReputationOptions({TfArg<bool>? reputationMetricsEnabled})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
reputationMetricsEnabled → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited