SpotInstanceRequestCpuOptions class final

Typed helper for the cpu_options block of aws_spot_instance_request (derived from provider schema).

Annotations
  • @immutable

Constructors

SpotInstanceRequestCpuOptions({TfArg<SpotInstanceRequestAmdSevSnp>? amdSevSnp, TfArg<num>? coreCount, TfArg<SpotInstanceRequestNestedVirtualization>? nestedVirtualization, TfArg<num>? threadsPerCore})
const

Properties

amdSevSnp → TfArg<SpotInstanceRequestAmdSevSnp>?
final
coreCount → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
nestedVirtualization → TfArg<SpotInstanceRequestNestedVirtualization>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadsPerCore → TfArg<num>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited