SpotInstanceRequestEphemeralBlockDevice class final

Typed helper for the ephemeral_block_device block of aws_spot_instance_request (derived from provider schema).

Annotations
  • @immutable

Constructors

SpotInstanceRequestEphemeralBlockDevice({required TfArg<String> deviceName, TfArg<bool>? noDevice, TfArg<String>? virtualName})
const

Properties

deviceName → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
noDevice → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
virtualName → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited