SpotInstanceRequestRootBlockDevice class final

Typed helper for the root_block_device block of aws_spot_instance_request (derived from provider schema).

Annotations
  • @immutable

Constructors

SpotInstanceRequestRootBlockDevice({TfArg<bool>? deleteOnTermination, TfArg<bool>? encrypted, TfArg<num>? iops, RefTo<AwsKmsKey>? kmsKeyId, TfArg<Map<String, String>>? tags, TfArg<Map<String, String>>? tagsAll, TfArg<num>? throughput, TfArg<num>? volumeSize, SpotInstanceRequestVolumeType? volumeType})
const

Properties

deleteOnTermination → TfArg<bool>?
final
encrypted → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
iops → TfArg<num>?
final
kmsKeyId → RefTo<AwsKmsKey>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → TfArg<Map<String, String>>?
final
tagsAll → TfArg<Map<String, String>>?
final
throughput → TfArg<num>?
final
volumeSize → TfArg<num>?
final
volumeType → SpotInstanceRequestVolumeType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited