SpotInstanceRequestUserDataBase64 class final
The SpotInstanceRequestUserData.userDataBase64 choice: sets user_data_base64.
- Inheritance
-
- Object
- SpotInstanceRequestUserData
- SpotInstanceRequestUserDataBase64
Constructors
-
SpotInstanceRequestUserDataBase64(TfArg<
String> userDataBase64) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userDataBase64
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited