TimestreamqueryScheduledQueryTargetConfiguration class final

Typed helper for the target_configuration block of aws_timestreamquery_scheduled_query (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestreamConfiguration → List<TimestreamqueryScheduledQueryTimestreamConfiguration>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited