TimestreamqueryScheduledQueryTimestreamConfiguration class final

Typed helper for the target_configuration.timestream_configuration block of aws_timestreamquery_scheduled_query (derived from provider schema).

Annotations
  • @immutable

Constructors

TimestreamqueryScheduledQueryTimestreamConfiguration({required TfArg<String> databaseName, TfArg<String>? measureNameColumn, required TfArg<String> tableName, required TfArg<String> timeColumn, List<TimestreamqueryScheduledQueryDimensionMapping>? dimensionMapping, List<TimestreamqueryScheduledQueryMixedMeasureMapping>? mixedMeasureMapping, List<TimestreamqueryScheduledQueryMultiMeasureMappings>? multiMeasureMappings})
const

Properties

databaseName → TfArg<String>
final
dimensionMapping → List<TimestreamqueryScheduledQueryDimensionMapping>?
final
hashCode → int
The hash code for this object.
no setterinherited
measureNameColumn → TfArg<String>?
final
mixedMeasureMapping → List<TimestreamqueryScheduledQueryMixedMeasureMapping>?
final
multiMeasureMappings → List<TimestreamqueryScheduledQueryMultiMeasureMappings>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableName → TfArg<String>
final
timeColumn → TfArg<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited