TimestreamwriteTableMagneticStoreRejectedDataLocation class final

Typed helper for the magnetic_store_write_properties.magnetic_store_rejected_data_location block of aws_timestreamwrite_table (derived from provider schema).

Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Configuration → TimestreamwriteTableS3Configuration?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited