TransferWorkflowCopyStepDetails class final

Typed helper for the on_exception_steps.copy_step_details block of aws_transfer_workflow (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

TransferWorkflowCopyStepDetails({TfArg<String>? name, TransferWorkflowOverwriteExisting? overwriteExisting, TfArg<String>? sourceFileLocation, TransferWorkflowDestinationFileLocation? destinationFileLocation})
const

Properties

destinationFileLocation → TransferWorkflowDestinationFileLocation?
final
hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
overwriteExisting → TransferWorkflowOverwriteExisting?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceFileLocation → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited