TransferWorkflowCustomStepDetails class final

Typed helper for the on_exception_steps.custom_step_details block of aws_transfer_workflow (derived from provider schema). Shared by every block of this shape in the resource.

Annotations
  • @immutable

Constructors

TransferWorkflowCustomStepDetails({TfArg<String>? name, TfArg<String>? sourceFileLocation, TfArg<String>? target, TfArg<num>? timeoutSeconds})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceFileLocation → TfArg<String>?
final
target → TfArg<String>?
final
timeoutSeconds → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited