VerifiedpermissionsIdentitySourceOpenIdConnectConfigurationGroupConfiguration class final

Typed helper for the configuration.open_id_connect_configuration.group_configuration block of aws_verifiedpermissions_identity_source (derived from provider schema).

Annotations
  • @immutable

Constructors

VerifiedpermissionsIdentitySourceOpenIdConnectConfigurationGroupConfiguration({required TfArg<String> groupClaim, required TfArg<String> groupEntityType})
const

Properties

groupClaim → TfArg<String>
final
groupEntityType → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited