WafRateBasedRulePredicates class final

Typed helper for the predicates block of aws_waf_rate_based_rule (derived from provider schema).

Annotations
  • @immutable

Constructors

WafRateBasedRulePredicates({required TfArg<String> dataId, required TfArg<bool> negated, required TfArg<WafRateBasedRuleType> type})
const

Properties

dataId → TfArg<String>
final
hashCode → int
The hash code for this object.
no setterinherited
negated → TfArg<bool>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TfArg<WafRateBasedRuleType>
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited