Wafv2RegexPatternSetRegularExpression class final

Typed helper for the regular_expression block of aws_wafv2_regex_pattern_set (derived from provider schema).

Annotations
  • @immutable

Constructors

Wafv2RegexPatternSetRegularExpression({required TfArg<String> regexString})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
regexString → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited