Wafv2RuleGroupLabelNamespace class final

Typed helper for the rule.statement.rate_based_statement.custom_key.label_namespace block of aws_wafv2_rule_group (derived from provider schema).

Annotations
  • @immutable

Constructors

Wafv2RuleGroupLabelNamespace({required TfArg<String> namespace})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
namespace → TfArg<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited