WorkspacesDirectoryAccessEndpointConfig class final

Typed helper for the workspace_access_properties.access_endpoint_config block of aws_workspaces_directory (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkspacesDirectoryAccessEndpointConfig({List<TfArg<WorkspacesDirectoryInternetFallbackProtocols>>? internetFallbackProtocols, required List<WorkspacesDirectoryAccessEndpoints> accessEndpoints})
const

Properties

accessEndpoints → List<WorkspacesDirectoryAccessEndpoints>
final
hashCode → int
The hash code for this object.
no setterinherited
internetFallbackProtocols → List<TfArg<WorkspacesDirectoryInternetFallbackProtocols>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited