WorkspacesDirectorySamlProperties class final

Typed helper for the saml_properties block of aws_workspaces_directory (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkspacesDirectorySamlProperties({TfArg<String>? relayStateParameterName, WorkspacesDirectorySamlPropertiesStatus? status, TfArg<String>? userAccessUrl})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
relayStateParameterName → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → WorkspacesDirectorySamlPropertiesStatus?
final
userAccessUrl → TfArg<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited