WorkspacesDirectorySelfServicePermissions class final

Typed helper for the self_service_permissions block of aws_workspaces_directory (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkspacesDirectorySelfServicePermissions({TfArg<bool>? changeComputeType, TfArg<bool>? increaseVolumeSize, TfArg<bool>? rebuildWorkspace, TfArg<bool>? restartWorkspace, TfArg<bool>? switchRunningMode})
const

Properties

changeComputeType → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
increaseVolumeSize → TfArg<bool>?
final
rebuildWorkspace → TfArg<bool>?
final
restartWorkspace → TfArg<bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
switchRunningMode → TfArg<bool>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited