WorkspacesDirectoryWorkspaceCreationProperties class final

Typed helper for the workspace_creation_properties block of aws_workspaces_directory (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkspacesDirectoryWorkspaceCreationProperties({TfArg<String>? customSecurityGroupId, TfArg<String>? defaultOu, TfArg<bool>? enableInternetAccess, TfArg<bool>? enableMaintenanceMode, TfArg<bool>? userEnabledAsLocalAdministrator})
const

Properties

customSecurityGroupId → TfArg<String>?
final
defaultOu → TfArg<String>?
final
enableInternetAccess → TfArg<bool>?
final
enableMaintenanceMode → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userEnabledAsLocalAdministrator → TfArg<bool>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited