WorkspacesWorkspaceProperties class final

Typed helper for the workspace_properties block of aws_workspaces_workspace (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkspacesWorkspaceProperties({WorkspacesWorkspaceComputeTypeName? computeTypeName, TfArg<num>? rootVolumeSizeGib, WorkspacesWorkspaceRunningMode? runningMode, TfArg<num>? runningModeAutoStopTimeoutInMinutes, TfArg<num>? userVolumeSizeGib})
const

Properties

computeTypeName → WorkspacesWorkspaceComputeTypeName?
final
hashCode → int
The hash code for this object.
no setterinherited
rootVolumeSizeGib → TfArg<num>?
final
runningMode → WorkspacesWorkspaceRunningMode?
final
runningModeAutoStopTimeoutInMinutes → TfArg<num>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userVolumeSizeGib → TfArg<num>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited