WorkspaceswebDataProtectionSettingsInlineRedactionConfiguration class final

Typed helper for the inline_redaction_configuration block of aws_workspacesweb_data_protection_settings (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkspaceswebDataProtectionSettingsInlineRedactionConfiguration({TfArg<num>? globalConfidenceLevel, TfArg<List<String>>? globalEnforcedUrls, TfArg<List<String>>? globalExemptUrls, List<WorkspaceswebDataProtectionSettingsInlineRedactionPattern>? inlineRedactionPattern})
const

Properties

globalConfidenceLevel → TfArg<num>?
final
globalEnforcedUrls → TfArg<List<String>>?
final
globalExemptUrls → TfArg<List<String>>?
final
hashCode → int
The hash code for this object.
no setterinherited
inlineRedactionPattern → List<WorkspaceswebDataProtectionSettingsInlineRedactionPattern>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited