WorkspaceswebSessionLoggerS3 class final

Typed helper for the log_configuration.s3 block of aws_workspacesweb_session_logger (derived from provider schema).

Annotations
  • @immutable

Constructors

WorkspaceswebSessionLoggerS3({required RefTo<AwsS3Bucket> bucket, TfArg<String>? bucketOwner, required TfArg<WorkspaceswebSessionLoggerFolderStructure> folderStructure, TfArg<String>? keyPrefix, required TfArg<WorkspaceswebSessionLoggerLogFileFormat> logFileFormat})
const

Properties

bucket → RefTo<AwsS3Bucket>
final
bucketOwner → TfArg<String>?
final
folderStructure → TfArg<WorkspaceswebSessionLoggerFolderStructure>
final
hashCode → int
The hash code for this object.
no setterinherited
keyPrefix → TfArg<String>?
final
logFileFormat → TfArg<WorkspaceswebSessionLoggerLogFileFormat>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited