WorkspaceswebUserSettingsCookieSynchronizationConfiguration class final
Typed helper for the cookie_synchronization_configuration block of
aws_workspacesweb_user_settings (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
WorkspaceswebUserSettingsCookieSynchronizationConfiguration({List<
WorkspaceswebUserSettingsAllowlist> ? allowlist, List<WorkspaceswebUserSettingsBlocklist> ? blocklist}) -
const
Properties
-
allowlist
→ List<
WorkspaceswebUserSettingsAllowlist> ? -
final
-
blocklist
→ List<
WorkspaceswebUserSettingsBlocklist> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited