transfer library
AWS Transfer Family.
Classes
- AwsTransferAccess
-
Factory wrapper for
aws_transfer_access. - AwsTransferAgreement
-
Factory wrapper for
aws_transfer_agreement. - AwsTransferCertificate
-
Factory wrapper for
aws_transfer_certificate. - AwsTransferConnector
-
Factory wrapper for
aws_transfer_connector. - AwsTransferHostKey
-
Factory wrapper for
aws_transfer_host_key. - AwsTransferProfile
-
Factory wrapper for
aws_transfer_profile. - AwsTransferServer
-
Factory wrapper for
aws_transfer_server. - AwsTransferSshKey
-
Factory wrapper for
aws_transfer_ssh_key. - AwsTransferTag
-
Factory wrapper for
aws_transfer_tag. - AwsTransferUser
-
Factory wrapper for
aws_transfer_user. - AwsTransferWebApp
-
Factory wrapper for
aws_transfer_web_app. - AwsTransferWebAppCustomization
-
Factory wrapper for
aws_transfer_web_app_customization. - AwsTransferWorkflow
-
Factory wrapper for
aws_transfer_workflow. - TransferAccessHomeDirectoryMappings
-
Typed helper for the
home_directory_mappingsblock ofaws_transfer_access(derived from provider schema). - TransferAccessPosixProfile
-
Typed helper for the
posix_profileblock ofaws_transfer_access(derived from provider schema). - TransferConnectorAs2Config
-
Typed helper for the
as2_configblock ofaws_transfer_connector(derived from provider schema). - TransferConnectorEgressConfig
-
Typed helper for the
egress_configblock ofaws_transfer_connector(derived from provider schema). - TransferConnectorSftpConfig
-
Typed helper for the
sftp_configblock ofaws_transfer_connector(derived from provider schema). - TransferConnectorVpcLattice
-
Typed helper for the
egress_config.vpc_latticeblock ofaws_transfer_connector(derived from provider schema). - TransferHostKeyBody
-
Exactly one of
host_key_body,host_key_body_woonaws_transfer_host_key: the provider rejects none and more than one, so each variant sets one of them. - TransferHostKeyBodyChoice
-
The TransferHostKeyBody.hostKeyBody choice: sets
host_key_body. - TransferHostKeyBodyWo
-
The TransferHostKeyBody.hostKeyBodyWo choice: sets
host_key_body_wo. - TransferServerEndpointDetails
-
Typed helper for the
endpoint_detailsblock ofaws_transfer_server(derived from provider schema). - TransferServerOnPartialUpload
-
Typed helper for the
workflow_details.on_partial_uploadblock ofaws_transfer_server(derived from provider schema). - TransferServerOnUpload
-
Typed helper for the
workflow_details.on_uploadblock ofaws_transfer_server(derived from provider schema). - TransferServerProtocolDetails
-
Typed helper for the
protocol_detailsblock ofaws_transfer_server(derived from provider schema). - TransferServerS3StorageOptions
-
Typed helper for the
s3_storage_optionsblock ofaws_transfer_server(derived from provider schema). - TransferServerWorkflowDetails
-
Typed helper for the
workflow_detailsblock ofaws_transfer_server(derived from provider schema). - TransferUserHomeDirectoryMappings
-
Typed helper for the
home_directory_mappingsblock ofaws_transfer_user(derived from provider schema). - TransferUserPosixProfile
-
Typed helper for the
posix_profileblock ofaws_transfer_user(derived from provider schema). - TransferWebAppEndpointDetails
-
Typed helper for the
endpoint_detailsblock ofaws_transfer_web_app(derived from provider schema). - TransferWebAppIdentityCenterConfig
-
Typed helper for the
identity_provider_details.identity_center_configblock ofaws_transfer_web_app(derived from provider schema). - TransferWebAppIdentityProviderDetails
-
Typed helper for the
identity_provider_detailsblock ofaws_transfer_web_app(derived from provider schema). - TransferWebAppVpc
-
Typed helper for the
endpoint_details.vpcblock ofaws_transfer_web_app(derived from provider schema). - TransferWorkflowCopyStepDetails
-
Typed helper for the
on_exception_steps.copy_step_detailsblock ofaws_transfer_workflow(derived from provider schema). Shared by every block of this shape in the resource. - TransferWorkflowCustomStepDetails
-
Typed helper for the
on_exception_steps.custom_step_detailsblock ofaws_transfer_workflow(derived from provider schema). Shared by every block of this shape in the resource. - TransferWorkflowDecryptStepDetails
-
Typed helper for the
on_exception_steps.decrypt_step_detailsblock ofaws_transfer_workflow(derived from provider schema). Shared by every block of this shape in the resource. - TransferWorkflowDeleteStepDetails
-
Typed helper for the
on_exception_steps.delete_step_detailsblock ofaws_transfer_workflow(derived from provider schema). Shared by every block of this shape in the resource. - TransferWorkflowDestinationFileLocation
-
Typed helper for the
on_exception_steps.copy_step_details.destination_file_locationblock ofaws_transfer_workflow(derived from provider schema). Shared by every block of this shape in the resource. - TransferWorkflowEfsFileLocation
-
Typed helper for the
on_exception_steps.copy_step_details.destination_file_location.efs_file_locationblock ofaws_transfer_workflow(derived from provider schema). Shared by every block of this shape in the resource. - TransferWorkflowOnExceptionSteps
-
Typed helper for the
on_exception_stepsblock ofaws_transfer_workflow(derived from provider schema). - TransferWorkflowS3FileLocation
-
Typed helper for the
on_exception_steps.copy_step_details.destination_file_location.s3_file_locationblock ofaws_transfer_workflow(derived from provider schema). Shared by every block of this shape in the resource. - TransferWorkflowSteps
-
Typed helper for the
stepsblock ofaws_transfer_workflow(derived from provider schema). - TransferWorkflowTagStepDetails
-
Typed helper for the
on_exception_steps.tag_step_detailsblock ofaws_transfer_workflow(derived from provider schema). Shared by every block of this shape in the resource. - TransferWorkflowTagStepDetailsTags
-
Typed helper for the
on_exception_steps.tag_step_details.tagsblock ofaws_transfer_workflow(derived from provider schema). Shared by every block of this shape in the resource.
Enums
- TransferAccessHomeDirectoryType
-
Transfer Access Home Directory enum for
home_directory_type. - TransferCertificateUsage
-
Transfer Certificate enum for
usage. - TransferConnectorCompression
-
compression— derived from the provider schema description. - TransferConnectorEncryptionAlgorithm
-
encryption_algorithm— derived from the provider schema description. - TransferConnectorMdnResponse
-
mdn_response— derived from the provider schema description. - TransferConnectorMdnSigningAlgorithm
-
mdn_signing_algorithm— derived from the provider schema description. - TransferConnectorSigningAlgorithm
-
signing_algorithm— derived from the provider schema description. - TransferProfileType
-
Transfer Profile enum for
profile_type. - TransferServerAs2Transports
-
as2_transports— derived from the provider schema description. - TransferServerDirectoryListingOptimization
-
directory_listing_optimization— derived from the provider schema description. - TransferServerDomain
-
Transfer Server enum for
domain. - TransferServerEndpointType
-
Transfer Server Endpoint enum for
endpoint_type. - TransferServerIdentityProviderType
-
Transfer Server Identity Provider enum for
identity_provider_type. - TransferServerIpAddressType
-
Transfer Server Ip Address enum for
ip_address_type. - TransferServerProtocols
-
Transfer Server enum for
protocols. - TransferServerSecurityPolicyName
-
Transfer Server Security Policy enum for
security_policy_name. - TransferServerSetStatOption
-
set_stat_option— derived from the provider schema description. - TransferServerSftpAuthenticationMethods
-
Transfer Server Sftp Authentication enum for
sftp_authentication_methods. - TransferServerTlsSessionResumptionMode
-
tls_session_resumption_mode— derived from the provider schema description. - TransferUserHomeDirectoryType
-
Transfer User Home Directory enum for
home_directory_type. - TransferWebAppEndpointPolicy
-
Transfer Web App Endpoint enum for
web_app_endpoint_policy. - TransferWorkflowDecryptStepDetailsType
-
type— derived from the provider schema description. - TransferWorkflowOverwriteExisting
-
overwrite_existing— derived from the provider schema description. - TransferWorkflowType
-
type— derived from the provider schema description.