verifiedaccess library

AWS Verified Access.

Classes

AwsVerifiedaccessEndpoint
Factory wrapper for aws_verifiedaccess_endpoint.
AwsVerifiedaccessGroup
Factory wrapper for aws_verifiedaccess_group.
AwsVerifiedaccessInstance
Factory wrapper for aws_verifiedaccess_instance.
AwsVerifiedaccessInstanceLoggingConfiguration
Factory wrapper for aws_verifiedaccess_instance_logging_configuration.
AwsVerifiedaccessInstanceTrustProviderAttachment
Factory wrapper for aws_verifiedaccess_instance_trust_provider_attachment.
AwsVerifiedaccessTrustProvider
Factory wrapper for aws_verifiedaccess_trust_provider.
VerifiedaccessEndpointCidrOptions
Typed helper for the cidr_options block of aws_verifiedaccess_endpoint (derived from provider schema).
VerifiedaccessEndpointLoadBalancerOptions
Typed helper for the load_balancer_options block of aws_verifiedaccess_endpoint (derived from provider schema).
VerifiedaccessEndpointNetworkInterfaceOptions
Typed helper for the network_interface_options block of aws_verifiedaccess_endpoint (derived from provider schema).
VerifiedaccessEndpointPortRange
Typed helper for the cidr_options.port_range block of aws_verifiedaccess_endpoint (derived from provider schema). Shared by every block of this shape in the resource.
VerifiedaccessEndpointRdsOptions
Typed helper for the rds_options block of aws_verifiedaccess_endpoint (derived from provider schema).
VerifiedaccessEndpointSseSpecification
Typed helper for the sse_specification block of aws_verifiedaccess_endpoint (derived from provider schema).
VerifiedaccessGroupSseConfiguration
Typed helper for the sse_configuration block of aws_verifiedaccess_group (derived from provider schema).
VerifiedaccessInstanceLoggingConfigurationAccessLogs
Typed helper for the access_logs block of aws_verifiedaccess_instance_logging_configuration (derived from provider schema).
VerifiedaccessInstanceLoggingConfigurationCloudwatchLogs
Typed helper for the access_logs.cloudwatch_logs block of aws_verifiedaccess_instance_logging_configuration (derived from provider schema).
VerifiedaccessInstanceLoggingConfigurationKinesisDataFirehose
Typed helper for the access_logs.kinesis_data_firehose block of aws_verifiedaccess_instance_logging_configuration (derived from provider schema).
VerifiedaccessInstanceLoggingConfigurationS3
Typed helper for the access_logs.s3 block of aws_verifiedaccess_instance_logging_configuration (derived from provider schema).
VerifiedaccessTrustProviderDeviceOptions
Typed helper for the device_options block of aws_verifiedaccess_trust_provider (derived from provider schema).
VerifiedaccessTrustProviderNativeApplicationOidcOptions
Typed helper for the native_application_oidc_options block of aws_verifiedaccess_trust_provider (derived from provider schema).
VerifiedaccessTrustProviderOidcOptions
Typed helper for the oidc_options block of aws_verifiedaccess_trust_provider (derived from provider schema).
VerifiedaccessTrustProviderSseSpecification
Typed helper for the sse_specification block of aws_verifiedaccess_trust_provider (derived from provider schema).

Enums

VerifiedaccessEndpointAttachmentType
Verifiedaccess Endpoint Attachment enum for attachment_type.
VerifiedaccessEndpointCidrOptionsProtocol
protocol — derived from the provider schema description.
VerifiedaccessEndpointLoadBalancerOptionsProtocol
protocol — derived from the provider schema description.
VerifiedaccessEndpointType
Verifiedaccess Endpoint enum for endpoint_type.
VerifiedaccessTrustProviderDeviceTrustProviderType
Verifiedaccess Trust Provider Device Trust Provider enum for device_trust_provider_type.
VerifiedaccessTrustProviderType
Verifiedaccess Trust Provider enum for trust_provider_type.
VerifiedaccessTrustProviderUserTrustProviderType
Verifiedaccess Trust Provider User Trust Provider enum for user_trust_provider_type.