api_gateway library
AWS API Gateway (REST APIs).
Classes
- ApiGatewayDocumentationPartLocation
-
Typed helper for the
locationblock ofaws_api_gateway_documentation_part(derived from provider schema). - ApiGatewayDomainNameEndpointConfiguration
-
Typed helper for the
endpoint_configurationblock ofaws_api_gateway_domain_name(derived from provider schema). - ApiGatewayDomainNameMutualTlsAuthentication
-
Typed helper for the
mutual_tls_authenticationblock ofaws_api_gateway_domain_name(derived from provider schema). - ApiGatewayIntegrationTlsConfig
-
Typed helper for the
tls_configblock ofaws_api_gateway_integration(derived from provider schema). - ApiGatewayMethodSettings
-
Typed helper for the
settingsblock ofaws_api_gateway_method_settings(derived from provider schema). - ApiGatewayRestApiEndpointConfiguration
-
Typed helper for the
endpoint_configurationblock ofaws_api_gateway_rest_api(derived from provider schema). - ApiGatewayStageAccessLogSettings
-
Typed helper for the
access_log_settingsblock ofaws_api_gateway_stage(derived from provider schema). - ApiGatewayStageCanarySettings
-
Typed helper for the
canary_settingsblock ofaws_api_gateway_stage(derived from provider schema). - ApiGatewayUsagePlanApiStages
-
Typed helper for the
api_stagesblock ofaws_api_gateway_usage_plan(derived from provider schema). - ApiGatewayUsagePlanQuotaSettings
-
Typed helper for the
quota_settingsblock ofaws_api_gateway_usage_plan(derived from provider schema). - ApiGatewayUsagePlanThrottle
-
Typed helper for the
api_stages.throttleblock ofaws_api_gateway_usage_plan(derived from provider schema). - ApiGatewayUsagePlanThrottleSettings
-
Typed helper for the
throttle_settingsblock ofaws_api_gateway_usage_plan(derived from provider schema). - AwsApiGatewayAccount
-
Factory wrapper for
aws_api_gateway_account. - AwsApiGatewayApiKey
-
Factory wrapper for
aws_api_gateway_api_key. - AwsApiGatewayAuthorizer
-
Factory wrapper for
aws_api_gateway_authorizer. - AwsApiGatewayBasePathMapping
-
Factory wrapper for
aws_api_gateway_base_path_mapping. - AwsApiGatewayClientCertificate
-
Factory wrapper for
aws_api_gateway_client_certificate. - AwsApiGatewayDeployment
-
Factory wrapper for
aws_api_gateway_deployment. - AwsApiGatewayDocumentationPart
-
Factory wrapper for
aws_api_gateway_documentation_part. - AwsApiGatewayDocumentationVersion
-
Factory wrapper for
aws_api_gateway_documentation_version. - AwsApiGatewayDomainName
-
Factory wrapper for
aws_api_gateway_domain_name. - AwsApiGatewayDomainNameAccessAssociation
-
Factory wrapper for
aws_api_gateway_domain_name_access_association. - AwsApiGatewayGatewayResponse
-
Factory wrapper for
aws_api_gateway_gateway_response. - AwsApiGatewayIntegration
-
Factory wrapper for
aws_api_gateway_integration. - AwsApiGatewayIntegrationResponse
-
Factory wrapper for
aws_api_gateway_integration_response. - AwsApiGatewayMethod
-
Factory wrapper for
aws_api_gateway_method. - AwsApiGatewayMethodResponse
-
Factory wrapper for
aws_api_gateway_method_response. - AwsApiGatewayMethodSettings
-
Factory wrapper for
aws_api_gateway_method_settings. - AwsApiGatewayModel
-
Factory wrapper for
aws_api_gateway_model. - AwsApiGatewayRequestValidator
-
Factory wrapper for
aws_api_gateway_request_validator. - AwsApiGatewayResource
-
Factory wrapper for
aws_api_gateway_resource. - AwsApiGatewayRestApi
-
Factory wrapper for
aws_api_gateway_rest_api. - AwsApiGatewayRestApiPolicy
-
Factory wrapper for
aws_api_gateway_rest_api_policy. - AwsApiGatewayRestApiPut
-
Factory wrapper for
aws_api_gateway_rest_api_put. - AwsApiGatewayStage
-
Factory wrapper for
aws_api_gateway_stage. - AwsApiGatewayUsagePlan
-
Factory wrapper for
aws_api_gateway_usage_plan. - AwsApiGatewayUsagePlanKey
-
Factory wrapper for
aws_api_gateway_usage_plan_key. - AwsApiGatewayVpcLink
-
Factory wrapper for
aws_api_gateway_vpc_link.
Enums
- ApiGatewayAuthorizerType
-
Api Gateway Authorizer enum for
type. - ApiGatewayDomainNameAccessAssociationSourceType
-
Api Gateway Domain Name Access Association Source enum for
access_association_source_type. - ApiGatewayDomainNameEndpointAccessMode
-
Api Gateway Domain Name Endpoint Access enum for
endpoint_access_mode. - ApiGatewayDomainNameIpAddressType
-
ip_address_type— derived from the provider schema description. - ApiGatewayDomainNameRoutingMode
-
Api Gateway Domain Name Routing enum for
routing_mode. - ApiGatewayDomainNameSecurityPolicy
-
Api Gateway Domain Name Security enum for
security_policy. - ApiGatewayDomainNameTypes
-
types— derived from the provider schema description. - ApiGatewayIntegrationConnectionType
-
Api Gateway Integration Connection enum for
connection_type. - ApiGatewayIntegrationPassthroughBehavior
-
Api Gateway Integration Passthrough enum for
passthrough_behavior. - ApiGatewayIntegrationResponseTransferMode
-
Api Gateway Integration Response Transfer enum for
response_transfer_mode. - ApiGatewayIntegrationType
-
Api Gateway Integration enum for
type. - ApiGatewayMethodSettingsLoggingLevel
-
logging_level— derived from the provider schema description. -
unauthorized_cache_control_header_strategy— derived from the provider schema description. - ApiGatewayRestApiEndpointAccessMode
-
Api Gateway Rest Api Endpoint Access enum for
endpoint_access_mode. - ApiGatewayRestApiIpAddressType
-
ip_address_type— derived from the provider schema description. - ApiGatewayRestApiKeySource
-
Api Gateway Rest Api Key enum for
api_key_source. - ApiGatewayRestApiPutRestApiMode
-
Api Gateway Rest Api Put Rest Api enum for
put_rest_api_mode. - ApiGatewayRestApiSecurityPolicy
-
Api Gateway Rest Api Security enum for
security_policy. - ApiGatewayRestApiTypes
-
types— derived from the provider schema description. - ApiGatewayStageCacheClusterSize
-
Api Gateway Stage Cache Cluster enum for
cache_cluster_size. - ApiGatewayUsagePlanPeriod
-
period— derived from the provider schema description.