appautoscaling library
AWS Application Auto Scaling.
Classes
- AppautoscalingPolicyCustomizedCapacityMetricSpecification
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specification.customized_capacity_metric_specificationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyCustomizedLoadMetricSpecification
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specification.customized_load_metric_specificationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyCustomizedMetricSpecification
-
Typed helper for the
target_tracking_scaling_policy_configuration.customized_metric_specificationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyCustomizedScalingMetricSpecification
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specification.customized_scaling_metric_specificationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyDimension
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specification.customized_capacity_metric_specification.metric_data_query.metric_stat.metric.dimensionblock ofaws_appautoscaling_policy(derived from provider schema). Shared by every block of this shape in the resource. - AppautoscalingPolicyDimensions
-
Typed helper for the
target_tracking_scaling_policy_configuration.customized_metric_specification.dimensionsblock ofaws_appautoscaling_policy(derived from provider schema). Shared by every block of this shape in the resource. - AppautoscalingPolicyMetric
-
Typed helper for the
target_tracking_scaling_policy_configuration.customized_metric_specification.metrics.metric_stat.metricblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyMetricDataQuery
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specification.customized_capacity_metric_specification.metric_data_queryblock ofaws_appautoscaling_policy(derived from provider schema). Shared by every block of this shape in the resource. - AppautoscalingPolicyMetricDataQueryMetricStat
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specification.customized_capacity_metric_specification.metric_data_query.metric_statblock ofaws_appautoscaling_policy(derived from provider schema). Shared by every block of this shape in the resource. - AppautoscalingPolicyMetrics
-
Typed helper for the
target_tracking_scaling_policy_configuration.customized_metric_specification.metricsblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyMetricStat
-
Typed helper for the
target_tracking_scaling_policy_configuration.customized_metric_specification.metrics.metric_statblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyMetricStatMetric
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specification.customized_capacity_metric_specification.metric_data_query.metric_stat.metricblock ofaws_appautoscaling_policy(derived from provider schema). Shared by every block of this shape in the resource. - AppautoscalingPolicyPredefinedLoadMetricSpecification
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specification.predefined_load_metric_specificationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyPredefinedMetricPairSpecification
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specification.predefined_metric_pair_specificationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyPredefinedMetricSpecification
-
Typed helper for the
target_tracking_scaling_policy_configuration.predefined_metric_specificationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyPredefinedScalingMetricSpecification
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specification.predefined_scaling_metric_specificationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyPredictiveScalingPolicyConfiguration
-
Typed helper for the
predictive_scaling_policy_configurationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyPredictiveScalingPolicyConfigurationMetricSpecification
-
Typed helper for the
predictive_scaling_policy_configuration.metric_specificationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyStepAdjustment
-
Typed helper for the
step_scaling_policy_configuration.step_adjustmentblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyStepScalingPolicyConfiguration
-
Typed helper for the
step_scaling_policy_configurationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyTargetTrackingScalingPolicyConfiguration
-
Typed helper for the
target_tracking_scaling_policy_configurationblock ofaws_appautoscaling_policy(derived from provider schema). - AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecification
-
The AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationMetricSpecification.customizedMetricSpecification choice: sets
customized_metric_specification. - AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationMetricSpecification
-
At most one of
customized_metric_specification,predefined_metric_specificationon thetarget_tracking_scaling_policy_configurationblock ofaws_appautoscaling_policy: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationPredefinedMetricSpecification
-
The AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationMetricSpecification.predefinedMetricSpecification choice: sets
predefined_metric_specification. - AppautoscalingScheduledActionScalableTargetAction
-
Typed helper for the
scalable_target_actionblock ofaws_appautoscaling_scheduled_action(derived from provider schema). - AppautoscalingTargetSuspendedState
-
Typed helper for the
suspended_stateblock ofaws_appautoscaling_target(derived from provider schema). - AwsAppautoscalingPolicy
-
Factory wrapper for
aws_appautoscaling_policy. - AwsAppautoscalingScheduledAction
-
Factory wrapper for
aws_appautoscaling_scheduled_action. - AwsAppautoscalingTarget
-
Factory wrapper for
aws_appautoscaling_target.
Enums
- AppautoscalingPolicyAdjustmentType
-
adjustment_type— derived from the provider schema description. - AppautoscalingPolicyMaxCapacityBreachBehavior
-
max_capacity_breach_behavior— derived from the provider schema description. - AppautoscalingPolicyMetricAggregationType
-
metric_aggregation_type— derived from the provider schema description. - AppautoscalingPolicyMode
-
mode— derived from the provider schema description. - AppautoscalingPolicyStatistic
-
statistic— derived from the provider schema description. - AppautoscalingPolicyType
-
Appautoscaling Policy enum for
policy_type.