appmesh library
AWS App Mesh.
Classes
- AppmeshGatewayRouteGrpcRoute
-
Typed helper for the
spec.grpc_routeblock ofaws_appmesh_gateway_route(derived from provider schema). - AppmeshGatewayRouteGrpcRouteAction
-
Typed helper for the
spec.grpc_route.actionblock ofaws_appmesh_gateway_route(derived from provider schema). - AppmeshGatewayRouteGrpcRouteMatch
-
Typed helper for the
spec.grpc_route.matchblock ofaws_appmesh_gateway_route(derived from provider schema). - AppmeshGatewayRouteHeader
-
Typed helper for the
spec.http2_route.match.headerblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteHeaderMatch
-
Typed helper for the
spec.http2_route.match.header.matchblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteHostname
-
Typed helper for the
spec.http2_route.match.hostnameblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteHttp2Route
-
Typed helper for the
spec.http2_routeblock ofaws_appmesh_gateway_route(derived from provider schema). - AppmeshGatewayRouteHttp2RouteAction
-
Typed helper for the
spec.http2_route.actionblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteHttp2RouteMatch
-
Typed helper for the
spec.http2_route.matchblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteHttpRoute
-
Typed helper for the
spec.http_routeblock ofaws_appmesh_gateway_route(derived from provider schema). - AppmeshGatewayRoutePath
-
Typed helper for the
spec.http2_route.match.pathblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRoutePrefix
-
Typed helper for the
spec.http2_route.action.rewrite.prefixblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteQueryParameter
-
Typed helper for the
spec.http2_route.match.query_parameterblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteQueryParameterMatch
-
Typed helper for the
spec.http2_route.match.query_parameter.matchblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteRange
-
Typed helper for the
spec.http2_route.match.header.match.rangeblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteRewrite
-
Typed helper for the
spec.http2_route.action.rewriteblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteRewriteHostname
-
Typed helper for the
spec.http2_route.action.rewrite.hostnameblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteRewritePath
-
Typed helper for the
spec.http2_route.action.rewrite.pathblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteSpec
-
Typed helper for the
specblock ofaws_appmesh_gateway_route(derived from provider schema). - AppmeshGatewayRouteSpecGrpcRoute
-
The AppmeshGatewayRouteSpecRoute.grpcRoute choice: sets
grpc_route. - AppmeshGatewayRouteSpecHttp2Route
-
The AppmeshGatewayRouteSpecRoute.http2Route choice: sets
http2_route. - AppmeshGatewayRouteSpecHttpRoute
-
The AppmeshGatewayRouteSpecRoute.httpRoute choice: sets
http_route. - AppmeshGatewayRouteSpecRoute
-
Exactly one of
grpc_route,http2_route,http_routeon thespecblock ofaws_appmesh_gateway_route: the provider rejects none and more than one, so each variant sets one of them. - AppmeshGatewayRouteTarget
-
Typed helper for the
spec.grpc_route.action.targetblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshGatewayRouteVirtualService
-
Typed helper for the
spec.grpc_route.action.target.virtual_serviceblock ofaws_appmesh_gateway_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshMeshEgressFilter
-
Typed helper for the
spec.egress_filterblock ofaws_appmesh_mesh(derived from provider schema). - AppmeshMeshServiceDiscovery
-
Typed helper for the
spec.service_discoveryblock ofaws_appmesh_mesh(derived from provider schema). - AppmeshMeshSpec
-
Typed helper for the
specblock ofaws_appmesh_mesh(derived from provider schema). - AppmeshRouteAction
-
Typed helper for the
spec.grpc_route.actionblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteGrpcRoute
-
Typed helper for the
spec.grpc_routeblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteGrpcRouteIdle
-
Typed helper for the
spec.grpc_route.timeout.idleblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteGrpcRouteMatch
-
Typed helper for the
spec.grpc_route.matchblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteGrpcRoutePerRequest
-
Typed helper for the
spec.grpc_route.timeout.per_requestblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteGrpcRoutePerRetryTimeout
-
Typed helper for the
spec.grpc_route.retry_policy.per_retry_timeoutblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteGrpcRouteRetryPolicy
-
Typed helper for the
spec.grpc_route.retry_policyblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteGrpcRouteTimeout
-
Typed helper for the
spec.grpc_route.timeoutblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteHeader
-
Typed helper for the
spec.http2_route.match.headerblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteHttp2Route
-
Typed helper for the
spec.http2_routeblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteHttp2RouteIdle
-
Typed helper for the
spec.http2_route.timeout.idleblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteHttp2RouteMatch
-
Typed helper for the
spec.http2_route.matchblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteHttp2RoutePerRequest
-
Typed helper for the
spec.http2_route.timeout.per_requestblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteHttp2RoutePerRetryTimeout
-
Typed helper for the
spec.http2_route.retry_policy.per_retry_timeoutblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteHttp2RouteRetryPolicy
-
Typed helper for the
spec.http2_route.retry_policyblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteHttp2RouteTimeout
-
Typed helper for the
spec.http2_route.timeoutblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteHttpRoute
-
Typed helper for the
spec.http_routeblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteMetadata
-
Typed helper for the
spec.grpc_route.match.metadatablock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteMetadataMatch
-
Typed helper for the
spec.grpc_route.match.metadata.matchblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRoutePath
-
Typed helper for the
spec.http2_route.match.pathblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteQueryParameter
-
Typed helper for the
spec.http2_route.match.query_parameterblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteQueryParameterMatch
-
Typed helper for the
spec.http2_route.match.query_parameter.matchblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteRange
-
Typed helper for the
spec.grpc_route.match.metadata.match.rangeblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshRouteSpec
-
Typed helper for the
specblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteTcpRoute
-
Typed helper for the
spec.tcp_routeblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteTcpRouteMatch
-
Typed helper for the
spec.tcp_route.matchblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteTcpRouteTimeout
-
Typed helper for the
spec.tcp_route.timeoutblock ofaws_appmesh_route(derived from provider schema). - AppmeshRouteWeightedTarget
-
Typed helper for the
spec.grpc_route.action.weighted_targetblock ofaws_appmesh_route(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualGatewayAccessLog
-
Typed helper for the
spec.logging.access_logblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayAcm
-
Typed helper for the
spec.listener.tls.certificate.acmblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayBackendDefaults
-
Typed helper for the
spec.backend_defaultsblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayCertificate
-
Typed helper for the
spec.listener.tls.certificateblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayCertificateFile
-
Typed helper for the
spec.listener.tls.certificate.fileblock ofaws_appmesh_virtual_gateway(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualGatewayClientPolicy
-
Typed helper for the
spec.backend_defaults.client_policyblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayClientPolicyTls
-
Typed helper for the
spec.backend_defaults.client_policy.tlsblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayConnectionPool
-
Typed helper for the
spec.listener.connection_poolblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayFile
-
Typed helper for the
spec.logging.access_log.fileblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayFormat
-
Typed helper for the
spec.logging.access_log.file.formatblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayGrpc
-
Typed helper for the
spec.listener.connection_pool.grpcblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayHealthCheck
-
Typed helper for the
spec.listener.health_checkblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayHttp
-
Typed helper for the
spec.listener.connection_pool.httpblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayHttp2
-
Typed helper for the
spec.listener.connection_pool.http2block ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayJson
-
Typed helper for the
spec.logging.access_log.file.format.jsonblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayListener
-
Typed helper for the
spec.listenerblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayLogging
-
Typed helper for the
spec.loggingblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayMatch
-
Typed helper for the
spec.listener.tls.validation.subject_alternative_names.matchblock ofaws_appmesh_virtual_gateway(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualGatewayPortMapping
-
Typed helper for the
spec.listener.port_mappingblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewaySds
-
Typed helper for the
spec.listener.tls.certificate.sdsblock ofaws_appmesh_virtual_gateway(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualGatewaySpec
-
Typed helper for the
specblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewaySubjectAlternativeNames
-
Typed helper for the
spec.listener.tls.validation.subject_alternative_namesblock ofaws_appmesh_virtual_gateway(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualGatewayTls
-
Typed helper for the
spec.listener.tlsblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayTlsCertificate
-
Exactly one of
file,sdson thespec.backend_defaults.client_policy.tls.certificateblock ofaws_appmesh_virtual_gateway: the provider rejects none and more than one, so each variant sets one of them. - AppmeshVirtualGatewayTlsCertificateFile
-
The AppmeshVirtualGatewayTlsCertificate.file choice: sets
file. - AppmeshVirtualGatewayTlsCertificateSds
-
The AppmeshVirtualGatewayTlsCertificate.sds choice: sets
sds. - AppmeshVirtualGatewayTlsValidation
-
Typed helper for the
spec.backend_defaults.client_policy.tls.validationblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayTrust
-
Typed helper for the
spec.listener.tls.validation.trustblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayTrustAcm
-
Typed helper for the
spec.backend_defaults.client_policy.tls.validation.trust.acmblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayTrustFile
-
Typed helper for the
spec.listener.tls.validation.trust.fileblock ofaws_appmesh_virtual_gateway(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualGatewayValidation
-
Typed helper for the
spec.listener.tls.validationblock ofaws_appmesh_virtual_gateway(derived from provider schema). - AppmeshVirtualGatewayValidationTrust
-
Exactly one of
acm,file,sdson thespec.backend_defaults.client_policy.tls.validation.trustblock ofaws_appmesh_virtual_gateway: the provider rejects none and more than one, so each variant sets one of them. - AppmeshVirtualGatewayValidationTrustAcm
-
The AppmeshVirtualGatewayValidationTrust.acm choice: sets
acm. - AppmeshVirtualGatewayValidationTrustFile
-
The AppmeshVirtualGatewayValidationTrust.file choice: sets
file. - AppmeshVirtualGatewayValidationTrustSds
-
The AppmeshVirtualGatewayValidationTrust.sds choice: sets
sds. - AppmeshVirtualNodeAccessLog
-
Typed helper for the
spec.logging.access_logblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeAcm
-
Typed helper for the
spec.listener.tls.certificate.acmblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeAwsCloudMap
-
Typed helper for the
spec.service_discovery.aws_cloud_mapblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeBackend
-
Typed helper for the
spec.backendblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeBackendDefaults
-
Typed helper for the
spec.backend_defaultsblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeBaseEjectionDuration
-
Typed helper for the
spec.listener.outlier_detection.base_ejection_durationblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeCertificate
-
Typed helper for the
spec.listener.tls.certificateblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeCertificateFile
-
Typed helper for the
spec.listener.tls.certificate.fileblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeClientPolicy
-
Typed helper for the
spec.backend_defaults.client_policyblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeClientPolicyTls
-
Typed helper for the
spec.backend_defaults.client_policy.tlsblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeConnectionPool
-
Typed helper for the
spec.listener.connection_poolblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeConnectionPoolGrpc
-
Typed helper for the
spec.listener.connection_pool.grpcblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeConnectionPoolHttp
-
Typed helper for the
spec.listener.connection_pool.httpblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeConnectionPoolHttp2
-
Typed helper for the
spec.listener.connection_pool.http2block ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeConnectionPoolTcp
-
Typed helper for the
spec.listener.connection_pool.tcpblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeDns
-
Typed helper for the
spec.service_discovery.dnsblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeFile
-
Typed helper for the
spec.logging.access_log.fileblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeFormat
-
Typed helper for the
spec.logging.access_log.file.formatblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeHealthCheck
-
Typed helper for the
spec.listener.health_checkblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeIdle
-
Typed helper for the
spec.listener.timeout.grpc.idleblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeInterval
-
Typed helper for the
spec.listener.outlier_detection.intervalblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeJson
-
Typed helper for the
spec.logging.access_log.file.format.jsonblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeListener
-
Typed helper for the
spec.listenerblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeLogging
-
Typed helper for the
spec.loggingblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeMatch
-
Typed helper for the
spec.listener.tls.validation.subject_alternative_names.matchblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeOutlierDetection
-
Typed helper for the
spec.listener.outlier_detectionblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodePerRequest
-
Typed helper for the
spec.listener.timeout.grpc.per_requestblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodePortMapping
-
Typed helper for the
spec.listener.port_mappingblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeSds
-
Typed helper for the
spec.listener.tls.certificate.sdsblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeServiceDiscovery
-
At most one of
aws_cloud_map,dnson thespec.service_discoveryblock ofaws_appmesh_virtual_node: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - AppmeshVirtualNodeServiceDiscoveryAwsCloudMap
-
The AppmeshVirtualNodeServiceDiscovery.awsCloudMap choice: sets
aws_cloud_map. - AppmeshVirtualNodeServiceDiscoveryDns
-
The AppmeshVirtualNodeServiceDiscovery.dns choice: sets
dns. - AppmeshVirtualNodeSpec
-
Typed helper for the
specblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeSubjectAlternativeNames
-
Typed helper for the
spec.listener.tls.validation.subject_alternative_namesblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeTimeout
-
Typed helper for the
spec.listener.timeoutblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeTimeoutGrpc
-
Typed helper for the
spec.listener.timeout.grpcblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeTimeoutHttp
-
Typed helper for the
spec.listener.timeout.httpblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeTimeoutHttp2
-
Typed helper for the
spec.listener.timeout.http2block ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeTimeoutTcp
-
Typed helper for the
spec.listener.timeout.tcpblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeTls
-
Typed helper for the
spec.listener.tlsblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeTlsCertificate
-
Typed helper for the
spec.backend_defaults.client_policy.tls.certificateblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeTlsValidation
-
Typed helper for the
spec.backend_defaults.client_policy.tls.validationblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeTrust
-
Typed helper for the
spec.listener.tls.validation.trustblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeTrustAcm
-
Typed helper for the
spec.backend_defaults.client_policy.tls.validation.trust.acmblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeTrustFile
-
Typed helper for the
spec.listener.tls.validation.trust.fileblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeValidation
-
Typed helper for the
spec.listener.tls.validationblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualNodeValidationTrust
-
Typed helper for the
spec.backend_defaults.client_policy.tls.validation.trustblock ofaws_appmesh_virtual_node(derived from provider schema). Shared by every block of this shape in the resource. - AppmeshVirtualNodeVirtualService
-
Typed helper for the
spec.backend.virtual_serviceblock ofaws_appmesh_virtual_node(derived from provider schema). - AppmeshVirtualRouterListener
-
Typed helper for the
spec.listenerblock ofaws_appmesh_virtual_router(derived from provider schema). - AppmeshVirtualRouterPortMapping
-
Typed helper for the
spec.listener.port_mappingblock ofaws_appmesh_virtual_router(derived from provider schema). - AppmeshVirtualRouterSpec
-
Typed helper for the
specblock ofaws_appmesh_virtual_router(derived from provider schema). - AppmeshVirtualServiceProvider
-
At most one of
virtual_node,virtual_routeron thespec.providerblock ofaws_appmesh_virtual_service: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - AppmeshVirtualServiceProviderVirtualNode
-
The AppmeshVirtualServiceProvider.virtualNode choice: sets
virtual_node. - AppmeshVirtualServiceProviderVirtualRouter
-
The AppmeshVirtualServiceProvider.virtualRouter choice: sets
virtual_router. - AppmeshVirtualServiceSpec
-
Typed helper for the
specblock ofaws_appmesh_virtual_service(derived from provider schema). - AppmeshVirtualServiceVirtualNode
-
Typed helper for the
spec.provider.virtual_nodeblock ofaws_appmesh_virtual_service(derived from provider schema). - AppmeshVirtualServiceVirtualRouter
-
Typed helper for the
spec.provider.virtual_routerblock ofaws_appmesh_virtual_service(derived from provider schema). - AwsAppmeshGatewayRoute
-
Factory wrapper for
aws_appmesh_gateway_route. - AwsAppmeshMesh
-
Factory wrapper for
aws_appmesh_mesh. - AwsAppmeshRoute
-
Factory wrapper for
aws_appmesh_route. - AwsAppmeshVirtualGateway
-
Factory wrapper for
aws_appmesh_virtual_gateway. - AwsAppmeshVirtualNode
-
Factory wrapper for
aws_appmesh_virtual_node. - AwsAppmeshVirtualRouter
-
Factory wrapper for
aws_appmesh_virtual_router. - AwsAppmeshVirtualService
-
Factory wrapper for
aws_appmesh_virtual_service.
Enums
- AppmeshMeshIpPreference
-
ip_preference— derived from the provider schema description. - AppmeshMeshType
-
type— derived from the provider schema description. - AppmeshRouteUnit
-
unit— derived from the provider schema description. - AppmeshVirtualGatewayMode
-
mode— derived from the provider schema description. - AppmeshVirtualGatewayProtocol
-
protocol— derived from the provider schema description. - AppmeshVirtualNodeIpPreference
-
ip_preference— derived from the provider schema description. - AppmeshVirtualNodeMode
-
mode— derived from the provider schema description. - AppmeshVirtualNodeProtocol
-
protocol— derived from the provider schema description. - AppmeshVirtualNodeResponseType
-
response_type— derived from the provider schema description. - AppmeshVirtualNodeUnit
-
unit— derived from the provider schema description. - AppmeshVirtualRouterProtocol
-
protocol— derived from the provider schema description.