arcregionswitch library
AWS ARC Region switch plans.
Classes
- ArcregionswitchPlanArcRoutingControlConfig
-
Typed helper for the
workflow.step.arc_routing_control_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanAsg
-
Typed helper for the
workflow.step.ec2_asg_capacity_increase_config.asgblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanAssociatedAlarms
-
Typed helper for the
associated_alarmsblock ofaws_arcregionswitch_plan(derived from provider schema). - ArcregionswitchPlanAuroraProvisionedScalingConfig
-
Typed helper for the
workflow.step.aurora_provisioned_scaling_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanAuroraServerlessScalingConfig
-
Typed helper for the
workflow.step.aurora_serverless_scaling_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanConditions
-
Typed helper for the
triggers.conditionsblock ofaws_arcregionswitch_plan(derived from provider schema). - ArcregionswitchPlanCustomActionLambdaConfig
-
Typed helper for the
workflow.step.custom_action_lambda_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanCustomActionLambdaConfigUngraceful
-
Typed helper for the
workflow.step.custom_action_lambda_config.ungracefulblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanDocumentDbConfig
-
Typed helper for the
workflow.step.document_db_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanDocumentDbConfigUngraceful
-
Typed helper for the
workflow.step.document_db_config.ungracefulblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanEc2AsgCapacityIncreaseConfig
-
Typed helper for the
workflow.step.ec2_asg_capacity_increase_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanEc2AsgCapacityIncreaseConfigUngraceful
-
Typed helper for the
workflow.step.ec2_asg_capacity_increase_config.ungracefulblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanEcsCapacityIncreaseConfig
-
Typed helper for the
workflow.step.ecs_capacity_increase_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanEksClusters
-
Typed helper for the
workflow.step.eks_resource_scaling_config.eks_clustersblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanEksResourceScalingConfig
-
Typed helper for the
workflow.step.eks_resource_scaling_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanExecutionApprovalConfig
-
Typed helper for the
workflow.step.execution_approval_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanGlobalAuroraConfig
-
Typed helper for the
workflow.step.global_aurora_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanKubernetesResourceType
-
Typed helper for the
workflow.step.eks_resource_scaling_config.kubernetes_resource_typeblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanLambda
-
Typed helper for the
workflow.step.custom_action_lambda_config.lambdablock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanLambdaEventSourceMappingConfig
-
Typed helper for the
workflow.step.lambda_event_source_mapping_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanNeptuneGlobalDatabaseConfig
-
Typed helper for the
workflow.step.neptune_global_database_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanParallelConfig
-
Typed helper for the
workflow.step.parallel_configblock ofaws_arcregionswitch_plan(derived from provider schema). - ArcregionswitchPlanParallelConfigStep
-
Typed helper for the
workflow.step.parallel_config.stepblock ofaws_arcregionswitch_plan(derived from provider schema). - ArcregionswitchPlanRdsCreateCrossRegionReadReplicaConfig
-
Typed helper for the
workflow.step.rds_create_cross_region_read_replica_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanRdsPromoteReadReplicaConfig
-
Typed helper for the
workflow.step.rds_promote_read_replica_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanRecordSet
-
Typed helper for the
workflow.step.route53_health_check_config.record_setblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanRegionAndRoutingControls
-
Typed helper for the
workflow.step.arc_routing_control_config.region_and_routing_controlsblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanRegionEventSourceMapping
-
Typed helper for the
workflow.step.lambda_event_source_mapping_config.region_event_source_mappingblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanRegionSwitchPlanConfig
-
Typed helper for the
workflow.step.region_switch_plan_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanReportConfiguration
-
Typed helper for the
report_configurationblock ofaws_arcregionswitch_plan(derived from provider schema). - ArcregionswitchPlanReportOutput
-
Typed helper for the
report_configuration.report_outputblock ofaws_arcregionswitch_plan(derived from provider schema). - ArcregionswitchPlanResources
-
Typed helper for the
workflow.step.eks_resource_scaling_config.scaling_resources.resourcesblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanRoute53HealthCheckConfig
-
Typed helper for the
workflow.step.route53_health_check_configblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanRoutingControl
-
Typed helper for the
workflow.step.arc_routing_control_config.region_and_routing_controls.routing_controlblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanS3Configuration
-
Typed helper for the
report_configuration.report_output.s3_configurationblock ofaws_arcregionswitch_plan(derived from provider schema). - ArcregionswitchPlanScalingResources
-
Typed helper for the
workflow.step.eks_resource_scaling_config.scaling_resourcesblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanService
-
Typed helper for the
workflow.step.ecs_capacity_increase_config.serviceblock ofaws_arcregionswitch_plan(derived from provider schema). Shared by every block of this shape in the resource. - ArcregionswitchPlanStep
-
Typed helper for the
workflow.stepblock ofaws_arcregionswitch_plan(derived from provider schema). - ArcregionswitchPlanTriggers
-
Typed helper for the
triggersblock ofaws_arcregionswitch_plan(derived from provider schema). - ArcregionswitchPlanWorkflow
-
Typed helper for the
workflowblock ofaws_arcregionswitch_plan(derived from provider schema). - AwsArcregionswitchPlan
-
Factory wrapper for
aws_arcregionswitch_plan.
Enums
- ArcregionswitchPlanAction
-
action— derived from the provider schema description. - ArcregionswitchPlanAlarmType
-
alarm_type— derived from the provider schema description. - ArcregionswitchPlanBehavior
-
behavior— derived from the provider schema description. - ArcregionswitchPlanCondition
-
condition— derived from the provider schema description. - ArcregionswitchPlanEc2AsgCapacityIncreaseConfigCapacityMonitoringApproach
-
capacity_monitoring_approach— derived from the provider schema description. - ArcregionswitchPlanEcsCapacityIncreaseConfigCapacityMonitoringApproach
-
capacity_monitoring_approach— derived from the provider schema description. - ArcregionswitchPlanEksResourceScalingConfigCapacityMonitoringApproach
-
capacity_monitoring_approach— derived from the provider schema description. - ArcregionswitchPlanExecutionBlockType
-
execution_block_type— derived from the provider schema description. - ArcregionswitchPlanLambdaEventSourceMappingConfigAction
-
action— derived from the provider schema description. - ArcregionswitchPlanRecoveryApproach
-
Arcregionswitch Plan Recovery enum for
recovery_approach. - ArcregionswitchPlanRegionToRun
-
region_to_run— derived from the provider schema description. - ArcregionswitchPlanState
-
state— derived from the provider schema description. - ArcregionswitchPlanUngracefulBehavior
-
behavior— derived from the provider schema description. - ArcregionswitchPlanUngracefulUngraceful
-
ungraceful— derived from the provider schema description. - ArcregionswitchPlanWorkflowTargetAction
-
workflow_target_action— derived from the provider schema description.