arczonalshift library
AWS ARC zonal shift.
Classes
- ArczonalshiftZonalAutoshiftConfigurationAllowedWindows
-
The ArczonalshiftZonalAutoshiftConfigurationWindows.allowedWindows choice: sets
allowed_windows. - ArczonalshiftZonalAutoshiftConfigurationBlockedWindows
-
The ArczonalshiftZonalAutoshiftConfigurationWindows.blockedWindows choice: sets
blocked_windows. - ArczonalshiftZonalAutoshiftConfigurationBlockingAlarms
-
Typed helper for the
blocking_alarmsblock ofaws_arczonalshift_zonal_autoshift_configuration(derived from provider schema). - ArczonalshiftZonalAutoshiftConfigurationOutcomeAlarms
-
Typed helper for the
outcome_alarmsblock ofaws_arczonalshift_zonal_autoshift_configuration(derived from provider schema). - ArczonalshiftZonalAutoshiftConfigurationWindows
-
At most one of
allowed_windows,blocked_windowsonaws_arczonalshift_zonal_autoshift_configuration: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - AwsArczonalshiftAutoshiftObserverNotificationStatus
-
Factory wrapper for
aws_arczonalshift_autoshift_observer_notification_status. - AwsArczonalshiftZonalAutoshiftConfiguration
-
Factory wrapper for
aws_arczonalshift_zonal_autoshift_configuration.
Enums
- ArczonalshiftAutoshiftObserverNotificationStatus
-
Arczonalshift Autoshift Observer Notification enum for
status. - ArczonalshiftZonalAutoshiftConfigurationType
-
type— derived from the provider schema description. - ArczonalshiftZonalAutoshiftConfigurationZonalAutoshiftStatus
-
Arczonalshift Zonal Autoshift Configuration Zonal Autoshift enum for
zonal_autoshift_status.