backup library
AWS Backup.
Classes
- AwsBackupFramework
-
Factory wrapper for
aws_backup_framework. - AwsBackupGlobalSettings
-
Factory wrapper for
aws_backup_global_settings. - AwsBackupLogicallyAirGappedVault
-
Factory wrapper for
aws_backup_logically_air_gapped_vault. - AwsBackupPlan
-
Factory wrapper for
aws_backup_plan. - AwsBackupRegionSettings
-
Factory wrapper for
aws_backup_region_settings. - AwsBackupReportPlan
-
Factory wrapper for
aws_backup_report_plan. - AwsBackupRestoreTestingPlan
-
Factory wrapper for
aws_backup_restore_testing_plan. - AwsBackupRestoreTestingSelection
-
Factory wrapper for
aws_backup_restore_testing_selection. - AwsBackupSelection
-
Factory wrapper for
aws_backup_selection. - AwsBackupVault
-
Factory wrapper for
aws_backup_vault. - AwsBackupVaultLockConfiguration
-
Factory wrapper for
aws_backup_vault_lock_configuration. - AwsBackupVaultNotifications
-
Factory wrapper for
aws_backup_vault_notifications. - AwsBackupVaultPolicy
-
Factory wrapper for
aws_backup_vault_policy. - BackupFrameworkControl
-
Typed helper for the
controlblock ofaws_backup_framework(derived from provider schema). - BackupFrameworkInputParameter
-
Typed helper for the
control.input_parameterblock ofaws_backup_framework(derived from provider schema). - BackupFrameworkScope
-
Typed helper for the
control.scopeblock ofaws_backup_framework(derived from provider schema). - BackupPlanAdvancedBackupSetting
-
Typed helper for the
advanced_backup_settingblock ofaws_backup_plan(derived from provider schema). - BackupPlanCopyAction
-
Typed helper for the
rule.copy_actionblock ofaws_backup_plan(derived from provider schema). - BackupPlanLifecycle
-
Typed helper for the
rule.lifecycleblock ofaws_backup_plan(derived from provider schema). Shared by every block of this shape in the resource. - BackupPlanRule
-
Typed helper for the
ruleblock ofaws_backup_plan(derived from provider schema). - BackupPlanScanAction
-
Typed helper for the
rule.scan_actionblock ofaws_backup_plan(derived from provider schema). - BackupPlanScanSetting
-
Typed helper for the
scan_settingblock ofaws_backup_plan(derived from provider schema). - BackupReportPlanReportDeliveryChannel
-
Typed helper for the
report_delivery_channelblock ofaws_backup_report_plan(derived from provider schema). - BackupReportPlanReportSetting
-
Typed helper for the
report_settingblock ofaws_backup_report_plan(derived from provider schema). - BackupRestoreTestingPlanRecoveryPointSelection
-
Typed helper for the
recovery_point_selectionblock ofaws_backup_restore_testing_plan(derived from provider schema). - BackupRestoreTestingSelectionProtectedResource
-
Exactly one of
protected_resource_arns,protected_resource_conditionsonaws_backup_restore_testing_selection: the provider rejects none and more than one, so each variant sets one of them. - BackupRestoreTestingSelectionProtectedResourceArns
-
The BackupRestoreTestingSelectionProtectedResource.protectedResourceArns choice: sets
protected_resource_arns. - BackupRestoreTestingSelectionProtectedResourceConditions
-
Typed helper for the
protected_resource_conditionsblock ofaws_backup_restore_testing_selection(derived from provider schema). - BackupRestoreTestingSelectionProtectedResourceConditionsChoice
-
The BackupRestoreTestingSelectionProtectedResource.protectedResourceConditions choice: sets
protected_resource_conditions. - BackupRestoreTestingSelectionStringEquals
-
Typed helper for the
protected_resource_conditions.string_equalsblock ofaws_backup_restore_testing_selection(derived from provider schema). - BackupRestoreTestingSelectionStringNotEquals
-
Typed helper for the
protected_resource_conditions.string_not_equalsblock ofaws_backup_restore_testing_selection(derived from provider schema). - BackupSelectionCondition
-
Typed helper for the
conditionblock ofaws_backup_selection(derived from provider schema). - BackupSelectionStringEquals
-
Typed helper for the
condition.string_equalsblock ofaws_backup_selection(derived from provider schema). - BackupSelectionStringLike
-
Typed helper for the
condition.string_likeblock ofaws_backup_selection(derived from provider schema). - BackupSelectionStringNotEquals
-
Typed helper for the
condition.string_not_equalsblock ofaws_backup_selection(derived from provider schema). - BackupSelectionStringNotLike
-
Typed helper for the
condition.string_not_likeblock ofaws_backup_selection(derived from provider schema). - BackupSelectionTag
-
Typed helper for the
selection_tagblock ofaws_backup_selection(derived from provider schema).
Enums
- BackupPlanMalwareScanner
-
malware_scanner— derived from the provider schema description. - BackupPlanResourceType
-
resource_type— derived from the provider schema description. - BackupPlanScanMode
-
scan_mode— derived from the provider schema description. - BackupReportPlanFormats
-
formats— derived from the provider schema description. - BackupReportPlanReportTemplate
-
report_template— derived from the provider schema description. - BackupRestoreTestingPlanAlgorithm
-
algorithm— derived from the provider schema description. - BackupRestoreTestingPlanRecoveryPointTypes
-
recovery_point_types— derived from the provider schema description. - BackupSelectionType
-
type— derived from the provider schema description. - BackupVaultNotificationsBackupVaultEvents
-
Backup Vault Notifications Backup Vault enum for
backup_vault_events.