bedrockagent library
AWS Bedrock Agents and knowledge bases.
Classes
- AwsBedrockagentAgent
-
Factory wrapper for
aws_bedrockagent_agent. - AwsBedrockagentAgentActionGroup
-
Factory wrapper for
aws_bedrockagent_agent_action_group. - AwsBedrockagentAgentAlias
-
Factory wrapper for
aws_bedrockagent_agent_alias. - AwsBedrockagentAgentCollaborator
-
Factory wrapper for
aws_bedrockagent_agent_collaborator. - AwsBedrockagentAgentKnowledgeBaseAssociation
-
Factory wrapper for
aws_bedrockagent_agent_knowledge_base_association. - AwsBedrockagentDataSource
-
Factory wrapper for
aws_bedrockagent_data_source. - AwsBedrockagentFlow
-
Factory wrapper for
aws_bedrockagent_flow. - AwsBedrockagentKnowledgeBase
-
Factory wrapper for
aws_bedrockagent_knowledge_base. - AwsBedrockagentPrompt
-
Factory wrapper for
aws_bedrockagent_prompt. - BedrockagentAgentActionGroupApiSchema
-
At most one of
payload,s3on theapi_schemablock ofaws_bedrockagent_agent_action_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - BedrockagentAgentActionGroupApiSchemaPayload
-
The BedrockagentAgentActionGroupApiSchema.payload choice: sets
payload. - BedrockagentAgentActionGroupApiSchemaS3
-
The BedrockagentAgentActionGroupApiSchema.s3 choice: sets
s3. - BedrockagentAgentActionGroupDefinition
-
At most one of
description,parent_action_group_signatureonaws_bedrockagent_agent_action_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - BedrockagentAgentActionGroupDefinitionDescription
-
The BedrockagentAgentActionGroupDefinition.description choice: sets
description. - BedrockagentAgentActionGroupDefinitionParentActionGroupSignature
-
The BedrockagentAgentActionGroupDefinition.parentActionGroupSignature choice: sets
parent_action_group_signature. - BedrockagentAgentActionGroupExecutor
-
Typed helper for the
action_group_executorblock ofaws_bedrockagent_agent_action_group(derived from provider schema). - BedrockagentAgentActionGroupFunctions
-
Typed helper for the
function_schema.member_functions.functionsblock ofaws_bedrockagent_agent_action_group(derived from provider schema). - BedrockagentAgentActionGroupFunctionSchema
-
Typed helper for the
function_schemablock ofaws_bedrockagent_agent_action_group(derived from provider schema). - BedrockagentAgentActionGroupMemberFunctions
-
Typed helper for the
function_schema.member_functionsblock ofaws_bedrockagent_agent_action_group(derived from provider schema). - BedrockagentAgentActionGroupParameters
-
Typed helper for the
function_schema.member_functions.functions.parametersblock ofaws_bedrockagent_agent_action_group(derived from provider schema). - BedrockagentAgentActionGroupS3
-
Typed helper for the
api_schema.s3block ofaws_bedrockagent_agent_action_group(derived from provider schema). - BedrockagentAgentCollaboratorAgentDescriptor
-
Typed helper for the
agent_descriptorblock ofaws_bedrockagent_agent_collaborator(derived from provider schema). - BedrockagentDataSourceAudioExtractionConfiguration
-
Typed helper for the
data_source_configuration.managed_knowledge_base_connector_configuration.media_extraction_configuration.audio_extraction_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceBedrockDataAutomationConfiguration
-
Typed helper for the
vector_ingestion_configuration.parsing_configuration.bedrock_data_automation_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceBedrockFoundationModelConfiguration
-
Typed helper for the
vector_ingestion_configuration.parsing_configuration.bedrock_foundation_model_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceChunkingConfiguration
-
Typed helper for the
vector_ingestion_configuration.chunking_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceConfiguration
-
Typed helper for the
data_source_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceConfluenceConfiguration
-
Typed helper for the
data_source_configuration.confluence_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceConfluenceConfigurationCrawlerConfiguration
-
Typed helper for the
data_source_configuration.confluence_configuration.crawler_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentDataSourceConfluenceConfigurationSourceConfiguration
-
Typed helper for the
data_source_configuration.confluence_configuration.source_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceCrawlerLimits
-
Typed helper for the
data_source_configuration.web_configuration.crawler_configuration.crawler_limitsblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceCustomTransformationConfiguration
-
Typed helper for the
vector_ingestion_configuration.custom_transformation_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceDeletionProtectionConfiguration
-
Typed helper for the
data_source_configuration.managed_knowledge_base_connector_configuration.deletion_protection_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceFilterConfiguration
-
Typed helper for the
data_source_configuration.confluence_configuration.crawler_configuration.filter_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentDataSourceFilters
-
Typed helper for the
data_source_configuration.confluence_configuration.crawler_configuration.filter_configuration.pattern_object_filter.filtersblock ofaws_bedrockagent_data_source(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentDataSourceFixedSizeChunkingConfiguration
-
Typed helper for the
vector_ingestion_configuration.chunking_configuration.fixed_size_chunking_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceHierarchicalChunkingConfiguration
-
Typed helper for the
vector_ingestion_configuration.chunking_configuration.hierarchical_chunking_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceImageExtractionConfiguration
-
Typed helper for the
data_source_configuration.managed_knowledge_base_connector_configuration.media_extraction_configuration.image_extraction_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceIntermediateStorage
-
Typed helper for the
vector_ingestion_configuration.custom_transformation_configuration.intermediate_storageblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceLevelConfiguration
-
Typed helper for the
vector_ingestion_configuration.chunking_configuration.hierarchical_chunking_configuration.level_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceManagedKnowledgeBaseConnectorConfiguration
-
Typed helper for the
data_source_configuration.managed_knowledge_base_connector_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceMediaExtractionConfiguration
-
Typed helper for the
data_source_configuration.managed_knowledge_base_connector_configuration.media_extraction_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceParsingConfiguration
-
Typed helper for the
vector_ingestion_configuration.parsing_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceParsingPrompt
-
Typed helper for the
vector_ingestion_configuration.parsing_configuration.bedrock_foundation_model_configuration.parsing_promptblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourcePatternObjectFilter
-
Typed helper for the
data_source_configuration.confluence_configuration.crawler_configuration.filter_configuration.pattern_object_filterblock ofaws_bedrockagent_data_source(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentDataSourceS3Configuration
-
Typed helper for the
data_source_configuration.s3_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceS3Location
-
Typed helper for the
vector_ingestion_configuration.custom_transformation_configuration.intermediate_storage.s3_locationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceSalesforceConfiguration
-
Typed helper for the
data_source_configuration.salesforce_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceSalesforceConfigurationSourceConfiguration
-
Typed helper for the
data_source_configuration.salesforce_configuration.source_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceSeedUrls
-
Typed helper for the
data_source_configuration.web_configuration.source_configuration.url_configuration.seed_urlsblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceSemanticChunkingConfiguration
-
Typed helper for the
vector_ingestion_configuration.chunking_configuration.semantic_chunking_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceServerSideEncryptionConfiguration
-
Typed helper for the
server_side_encryption_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). -
Typed helper for the
data_source_configuration.share_point_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). -
Typed helper for the
data_source_configuration.share_point_configuration.source_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceStrategy
-
At most one of
fixed_size_chunking_configuration,hierarchical_chunking_configuration,semantic_chunking_configurationon thevector_ingestion_configuration.chunking_configurationblock ofaws_bedrockagent_data_source: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - BedrockagentDataSourceStrategyFixedSizeChunkingConfiguration
-
The BedrockagentDataSourceStrategy.fixedSizeChunkingConfiguration choice: sets
fixed_size_chunking_configuration. - BedrockagentDataSourceStrategyHierarchicalChunkingConfiguration
-
The BedrockagentDataSourceStrategy.hierarchicalChunkingConfiguration choice: sets
hierarchical_chunking_configuration. - BedrockagentDataSourceStrategySemanticChunkingConfiguration
-
The BedrockagentDataSourceStrategy.semanticChunkingConfiguration choice: sets
semantic_chunking_configuration. - BedrockagentDataSourceTransformation
-
Typed helper for the
vector_ingestion_configuration.custom_transformation_configuration.transformationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceTransformationFunction
-
Typed helper for the
vector_ingestion_configuration.custom_transformation_configuration.transformation.transformation_functionblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceTransformationLambdaConfiguration
-
Typed helper for the
vector_ingestion_configuration.custom_transformation_configuration.transformation.transformation_function.transformation_lambda_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceUrlConfiguration
-
Typed helper for the
data_source_configuration.web_configuration.source_configuration.url_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceVectorIngestionConfiguration
-
Typed helper for the
vector_ingestion_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceVideoExtractionConfiguration
-
Typed helper for the
data_source_configuration.managed_knowledge_base_connector_configuration.media_extraction_configuration.video_extraction_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceWebConfiguration
-
Typed helper for the
data_source_configuration.web_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceWebConfigurationCrawlerConfiguration
-
Typed helper for the
data_source_configuration.web_configuration.crawler_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentDataSourceWebConfigurationSourceConfiguration
-
Typed helper for the
data_source_configuration.web_configuration.source_configurationblock ofaws_bedrockagent_data_source(derived from provider schema). - BedrockagentFlowAgent
-
Typed helper for the
definition.node.configuration.agentblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowAny
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.tool_configuration.tool_choice.anyblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowAuto
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.tool_configuration.tool_choice.autoblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowCachePoint
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.text.cache_pointblock ofaws_bedrockagent_flow(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentFlowChat
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.chatblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowCollector
-
Typed helper for the
definition.node.configuration.collectorblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowCondition
-
Typed helper for the
definition.node.configuration.conditionblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowConditional
-
Typed helper for the
definition.connection.configuration.conditionalblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowConditionCondition
-
Typed helper for the
definition.node.configuration.condition.conditionblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowConfigurationInput
-
Typed helper for the
definition.node.configuration.inputblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowConfigurationOutput
-
Typed helper for the
definition.node.configuration.outputblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowConnection
-
Typed helper for the
definition.connectionblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowConnectionConfiguration
-
Exactly one of
conditional,dataon thedefinition.connection.configurationblock ofaws_bedrockagent_flow: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentFlowConnectionConfigurationConditional
-
The BedrockagentFlowConnectionConfiguration.conditional choice: sets
conditional. - BedrockagentFlowConnectionConfigurationData
-
The BedrockagentFlowConnectionConfiguration.data choice: sets
data. - BedrockagentFlowContent
-
Exactly one of
cache_point,texton thedefinition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.message.contentblock ofaws_bedrockagent_flow: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentFlowContentCachePoint
-
The BedrockagentFlowContent.cachePoint choice: sets
cache_point. - BedrockagentFlowContentText
-
The BedrockagentFlowContent.text choice: sets
text. - BedrockagentFlowData
-
Typed helper for the
definition.connection.configuration.datablock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowDefinition
-
Typed helper for the
definitionblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowGuardrailConfiguration
-
Typed helper for the
definition.node.configuration.knowledge_base.guardrail_configurationblock ofaws_bedrockagent_flow(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentFlowInferenceConfiguration
-
Typed helper for the
definition.node.configuration.knowledge_base.inference_configurationblock ofaws_bedrockagent_flow(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentFlowInline
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inlineblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowInlineCode
-
Typed helper for the
definition.node.configuration.inline_codeblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowInput
-
Typed helper for the
definition.node.inputblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowInputSchema
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.tool_configuration.tool.tool_spec.input_schemablock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowInputVariable
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.input_variableblock ofaws_bedrockagent_flow(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentFlowIterator
-
Typed helper for the
definition.node.configuration.iteratorblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowKnowledgeBase
-
Typed helper for the
definition.node.configuration.knowledge_baseblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowLambdaFunction
-
Typed helper for the
definition.node.configuration.lambda_functionblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowLex
-
Typed helper for the
definition.node.configuration.lexblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowMessage
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.messageblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowNode
-
Typed helper for the
definition.nodeblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowNodeConfiguration
-
Exactly one of
agent,collector,condition,inline_code,input,iterator,knowledge_base,lambda_function,lex,output,prompt,retrieval,storageon thedefinition.node.configurationblock ofaws_bedrockagent_flow: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentFlowNodeConfigurationAgent
-
The BedrockagentFlowNodeConfiguration.agent choice: sets
agent. - BedrockagentFlowNodeConfigurationCollector
-
The BedrockagentFlowNodeConfiguration.collector choice: sets
collector. - BedrockagentFlowNodeConfigurationCondition
-
The BedrockagentFlowNodeConfiguration.condition choice: sets
condition. - BedrockagentFlowNodeConfigurationInlineCode
-
The BedrockagentFlowNodeConfiguration.inlineCode choice: sets
inline_code. - BedrockagentFlowNodeConfigurationInput
-
The BedrockagentFlowNodeConfiguration.input choice: sets
input. - BedrockagentFlowNodeConfigurationIterator
-
The BedrockagentFlowNodeConfiguration.iterator choice: sets
iterator. - BedrockagentFlowNodeConfigurationKnowledgeBase
-
The BedrockagentFlowNodeConfiguration.knowledgeBase choice: sets
knowledge_base. - BedrockagentFlowNodeConfigurationLambdaFunction
-
The BedrockagentFlowNodeConfiguration.lambdaFunction choice: sets
lambda_function. - BedrockagentFlowNodeConfigurationLex
-
The BedrockagentFlowNodeConfiguration.lex choice: sets
lex. - BedrockagentFlowNodeConfigurationOutput
-
The BedrockagentFlowNodeConfiguration.output choice: sets
output. - BedrockagentFlowNodeConfigurationPrompt
-
The BedrockagentFlowNodeConfiguration.prompt choice: sets
prompt. - BedrockagentFlowNodeConfigurationRetrieval
-
The BedrockagentFlowNodeConfiguration.retrieval choice: sets
retrieval. - BedrockagentFlowNodeConfigurationStorage
-
The BedrockagentFlowNodeConfiguration.storage choice: sets
storage. - BedrockagentFlowOutput
-
Typed helper for the
definition.node.outputblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowPrompt
-
Typed helper for the
definition.node.configuration.promptblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowResource
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.resourceblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowRetrieval
-
Typed helper for the
definition.node.configuration.retrievalblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowS3
-
Typed helper for the
definition.node.configuration.retrieval.service_configuration.s3block ofaws_bedrockagent_flow(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentFlowServiceConfiguration
-
Typed helper for the
definition.node.configuration.retrieval.service_configurationblock ofaws_bedrockagent_flow(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentFlowSourceConfiguration
-
Exactly one of
inline,resourceon thedefinition.node.configuration.prompt.source_configurationblock ofaws_bedrockagent_flow: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentFlowSourceConfigurationInline
-
The BedrockagentFlowSourceConfiguration.inline choice: sets
inline. - BedrockagentFlowSourceConfigurationResource
-
The BedrockagentFlowSourceConfiguration.resource choice: sets
resource. - BedrockagentFlowStorage
-
Typed helper for the
definition.node.configuration.storageblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowSystem
-
Exactly one of
cache_point,texton thedefinition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.systemblock ofaws_bedrockagent_flow: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentFlowSystemCachePoint
-
The BedrockagentFlowSystem.cachePoint choice: sets
cache_point. - BedrockagentFlowSystemText
-
The BedrockagentFlowSystem.text choice: sets
text. - BedrockagentFlowTemplateConfiguration
-
Exactly one of
chat,texton thedefinition.node.configuration.prompt.source_configuration.inline.template_configurationblock ofaws_bedrockagent_flow: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentFlowTemplateConfigurationChat
-
The BedrockagentFlowTemplateConfiguration.chat choice: sets
chat. - BedrockagentFlowTemplateConfigurationText
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.textblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowTemplateConfigurationTextChoice
-
The BedrockagentFlowTemplateConfiguration.text choice: sets
text. - BedrockagentFlowText
-
Typed helper for the
definition.node.configuration.knowledge_base.inference_configuration.textblock ofaws_bedrockagent_flow(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentFlowTool
-
Exactly one of
cache_point,tool_specon thedefinition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.tool_configuration.toolblock ofaws_bedrockagent_flow: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentFlowToolCachePoint
-
The BedrockagentFlowTool.cachePoint choice: sets
cache_point. - BedrockagentFlowToolChoice
-
Exactly one of
any,auto,toolon thedefinition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.tool_configuration.tool_choiceblock ofaws_bedrockagent_flow: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentFlowToolChoiceAny
-
The BedrockagentFlowToolChoice.any choice: sets
any. - BedrockagentFlowToolChoiceAuto
-
The BedrockagentFlowToolChoice.auto choice: sets
auto. - BedrockagentFlowToolChoiceTool
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.tool_configuration.tool_choice.toolblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowToolChoiceToolOption
-
The BedrockagentFlowToolChoice.tool choice: sets
tool. - BedrockagentFlowToolConfiguration
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.tool_configurationblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowToolSpec
-
Typed helper for the
definition.node.configuration.prompt.source_configuration.inline.template_configuration.chat.tool_configuration.tool.tool_specblock ofaws_bedrockagent_flow(derived from provider schema). - BedrockagentFlowToolSpecChoice
-
The BedrockagentFlowTool.toolSpec choice: sets
tool_spec. - BedrockagentKnowledgeBaseAudio
-
Typed helper for the
knowledge_base_configuration.managed_knowledge_base_configuration.embedding_model_configuration.bedrock_embedding_model_configuration.audioblock ofaws_bedrockagent_knowledge_base(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentKnowledgeBaseAwsDataCatalogConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.storage_configuration.aws_data_catalog_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseBedrockEmbeddingModelConfiguration
-
Typed helper for the
knowledge_base_configuration.managed_knowledge_base_configuration.embedding_model_configuration.bedrock_embedding_model_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentKnowledgeBaseColumn
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.query_generation_configuration.generation_context.table.columnblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseConfiguration
-
Typed helper for the
knowledge_base_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseCuratedQuery
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.query_generation_configuration.generation_context.curated_queryblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseEmbeddingModelConfiguration
-
Typed helper for the
knowledge_base_configuration.managed_knowledge_base_configuration.embedding_model_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentKnowledgeBaseGenerationContext
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.query_generation_configuration.generation_contextblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseKendraKnowledgeBaseConfiguration
-
Typed helper for the
knowledge_base_configuration.kendra_knowledge_base_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseManagedKnowledgeBaseConfiguration
-
Typed helper for the
knowledge_base_configuration.managed_knowledge_base_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseMongoDbAtlasConfiguration
-
Typed helper for the
storage_configuration.mongo_db_atlas_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseMongoDbAtlasConfigurationFieldMapping
-
Typed helper for the
storage_configuration.mongo_db_atlas_configuration.field_mappingblock ofaws_bedrockagent_knowledge_base(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentKnowledgeBaseNeptuneAnalyticsConfiguration
-
Typed helper for the
storage_configuration.neptune_analytics_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseNeptuneAnalyticsConfigurationFieldMapping
-
Typed helper for the
storage_configuration.neptune_analytics_configuration.field_mappingblock ofaws_bedrockagent_knowledge_base(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentKnowledgeBaseOpensearchManagedClusterConfiguration
-
Typed helper for the
storage_configuration.opensearch_managed_cluster_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseOpensearchServerlessConfiguration
-
Typed helper for the
storage_configuration.opensearch_serverless_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBasePineconeConfiguration
-
Typed helper for the
storage_configuration.pinecone_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseProvisionedConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.query_engine_configuration.provisioned_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseProvisionedConfigurationAuthConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.query_engine_configuration.provisioned_configuration.auth_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseQueryEngineConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.query_engine_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseQueryGenerationConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.query_generation_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseRdsConfiguration
-
Typed helper for the
storage_configuration.rds_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseRdsConfigurationFieldMapping
-
Typed helper for the
storage_configuration.rds_configuration.field_mappingblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseRedisEnterpriseCloudConfiguration
-
Typed helper for the
storage_configuration.redis_enterprise_cloud_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseRedisEnterpriseCloudConfigurationFieldMapping
-
Typed helper for the
storage_configuration.redis_enterprise_cloud_configuration.field_mappingblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseRedshiftConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseRedshiftConfigurationStorageConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.storage_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseS3Location
-
Typed helper for the
knowledge_base_configuration.vector_knowledge_base_configuration.supplemental_data_storage_configuration.storage_location.s3_locationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseS3VectorsConfiguration
-
Typed helper for the
storage_configuration.s3_vectors_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseSegmentationConfiguration
-
Typed helper for the
knowledge_base_configuration.managed_knowledge_base_configuration.embedding_model_configuration.bedrock_embedding_model_configuration.audio.segmentation_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentKnowledgeBaseServerlessConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.query_engine_configuration.serverless_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseServerlessConfigurationAuthConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.query_engine_configuration.serverless_configuration.auth_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseServerSideEncryptionConfiguration
-
Typed helper for the
knowledge_base_configuration.managed_knowledge_base_configuration.server_side_encryption_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseSqlKnowledgeBaseConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseStorageConfiguration
-
Typed helper for the
storage_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseStorageConfigurationRedshiftConfiguration
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.storage_configuration.redshift_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseStorageLocation
-
Typed helper for the
knowledge_base_configuration.vector_knowledge_base_configuration.supplemental_data_storage_configuration.storage_locationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseSupplementalDataStorageConfiguration
-
Typed helper for the
knowledge_base_configuration.vector_knowledge_base_configuration.supplemental_data_storage_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseTable
-
Typed helper for the
knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration.query_generation_configuration.generation_context.tableblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseVectorKnowledgeBaseConfiguration
-
Typed helper for the
knowledge_base_configuration.vector_knowledge_base_configurationblock ofaws_bedrockagent_knowledge_base(derived from provider schema). - BedrockagentKnowledgeBaseVideo
-
Typed helper for the
knowledge_base_configuration.managed_knowledge_base_configuration.embedding_model_configuration.bedrock_embedding_model_configuration.videoblock ofaws_bedrockagent_knowledge_base(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentPromptAgent
-
Typed helper for the
variant.gen_ai_resource.agentblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptAny
-
Typed helper for the
variant.template_configuration.chat.tool_configuration.tool_choice.anyblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptAuto
-
Typed helper for the
variant.template_configuration.chat.tool_configuration.tool_choice.autoblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptCachePoint
-
Typed helper for the
variant.template_configuration.text.cache_pointblock ofaws_bedrockagent_prompt(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentPromptChat
-
Typed helper for the
variant.template_configuration.chatblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptContent
-
Exactly one of
cache_point,texton thevariant.template_configuration.chat.message.contentblock ofaws_bedrockagent_prompt: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentPromptContentCachePoint
-
The BedrockagentPromptContent.cachePoint choice: sets
cache_point. - BedrockagentPromptContentText
-
The BedrockagentPromptContent.text choice: sets
text. - BedrockagentPromptGenAiResource
-
Typed helper for the
variant.gen_ai_resourceblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptInferenceConfiguration
-
Typed helper for the
variant.inference_configurationblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptInferenceConfigurationText
-
Typed helper for the
variant.inference_configuration.textblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptInputSchema
-
Typed helper for the
variant.template_configuration.chat.tool_configuration.tool.tool_spec.input_schemablock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptInputVariable
-
Typed helper for the
variant.template_configuration.chat.input_variableblock ofaws_bedrockagent_prompt(derived from provider schema). Shared by every block of this shape in the resource. - BedrockagentPromptMessage
-
Typed helper for the
variant.template_configuration.chat.messageblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptMetadata
-
Typed helper for the
variant.metadatablock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptModel
-
Exactly one of
gen_ai_resource,model_idon thevariantblock ofaws_bedrockagent_prompt: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentPromptModelGenAiResource
-
The BedrockagentPromptModel.genAiResource choice: sets
gen_ai_resource. - BedrockagentPromptModelId
-
The BedrockagentPromptModel.modelId choice: sets
model_id. - BedrockagentPromptSystem
-
Exactly one of
cache_point,texton thevariant.template_configuration.chat.systemblock ofaws_bedrockagent_prompt: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentPromptSystemCachePoint
-
The BedrockagentPromptSystem.cachePoint choice: sets
cache_point. - BedrockagentPromptSystemText
-
The BedrockagentPromptSystem.text choice: sets
text. - BedrockagentPromptTemplateConfiguration
-
Exactly one of
chat,texton thevariant.template_configurationblock ofaws_bedrockagent_prompt: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentPromptTemplateConfigurationChat
-
The BedrockagentPromptTemplateConfiguration.chat choice: sets
chat. - BedrockagentPromptTemplateConfigurationText
-
Typed helper for the
variant.template_configuration.textblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptTemplateConfigurationTextChoice
-
The BedrockagentPromptTemplateConfiguration.text choice: sets
text. - BedrockagentPromptTool
-
Exactly one of
cache_point,tool_specon thevariant.template_configuration.chat.tool_configuration.toolblock ofaws_bedrockagent_prompt: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentPromptToolCachePoint
-
The BedrockagentPromptTool.cachePoint choice: sets
cache_point. - BedrockagentPromptToolChoice
-
Exactly one of
any,auto,toolon thevariant.template_configuration.chat.tool_configuration.tool_choiceblock ofaws_bedrockagent_prompt: the provider rejects none and more than one, so each variant sets one of them. - BedrockagentPromptToolChoiceAny
-
The BedrockagentPromptToolChoice.any choice: sets
any. - BedrockagentPromptToolChoiceAuto
-
The BedrockagentPromptToolChoice.auto choice: sets
auto. - BedrockagentPromptToolChoiceTool
-
Typed helper for the
variant.template_configuration.chat.tool_configuration.tool_choice.toolblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptToolChoiceToolOption
-
The BedrockagentPromptToolChoice.tool choice: sets
tool. - BedrockagentPromptToolConfiguration
-
Typed helper for the
variant.template_configuration.chat.tool_configurationblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptToolSpec
-
Typed helper for the
variant.template_configuration.chat.tool_configuration.tool.tool_specblock ofaws_bedrockagent_prompt(derived from provider schema). - BedrockagentPromptToolSpecChoice
-
The BedrockagentPromptTool.toolSpec choice: sets
tool_spec. - BedrockagentPromptVariant
-
Typed helper for the
variantblock ofaws_bedrockagent_prompt(derived from provider schema).
Enums
- BedrockagentAgentActionGroupCustomControl
-
custom_control— derived from the provider schema description. - BedrockagentAgentActionGroupParentActionGroupSignature
-
Bedrockagent Agent Action Group Parent Action Group enum for
parent_action_group_signature. - BedrockagentAgentActionGroupState
-
Bedrockagent Agent Action Group enum for
action_group_state. - BedrockagentAgentActionGroupType
-
type— derived from the provider schema description. - BedrockagentAgentCollaboration
-
Bedrockagent Agent enum for
agent_collaboration. - BedrockagentAgentCollaboratorRelayConversationHistory
-
Bedrockagent Agent Collaborator Relay Conversation enum for
relay_conversation_history. - BedrockagentAgentKnowledgeBaseAssociationAgentVersion
-
Bedrockagent Agent Knowledge Base Association Agent enum for
agent_version. - BedrockagentAgentKnowledgeBaseAssociationKnowledgeBaseState
-
Bedrockagent Agent Knowledge Base Association Knowledge Base enum for
knowledge_base_state. - BedrockagentDataSourceAudioExtractionStatus
-
audio_extraction_status— derived from the provider schema description. - BedrockagentDataSourceChunkingStrategy
-
chunking_strategy— derived from the provider schema description. - BedrockagentDataSourceConfluenceConfigurationAuthType
-
auth_type— derived from the provider schema description. - BedrockagentDataSourceConfluenceConfigurationHostType
-
host_type— derived from the provider schema description. - BedrockagentDataSourceDataDeletionPolicy
-
Bedrockagent Data Source Data Deletion enum for
data_deletion_policy. - BedrockagentDataSourceDeletionProtectionStatus
-
deletion_protection_status— derived from the provider schema description. - BedrockagentDataSourceImageExtractionStatus
-
image_extraction_status— derived from the provider schema description. - BedrockagentDataSourceParsingModality
-
parsing_modality— derived from the provider schema description. - BedrockagentDataSourceParsingStrategy
-
parsing_strategy— derived from the provider schema description. - BedrockagentDataSourceSalesforceConfigurationAuthType
-
auth_type— derived from the provider schema description. - BedrockagentDataSourceScope
-
scope— derived from the provider schema description. -
auth_type— derived from the provider schema description. -
host_type— derived from the provider schema description. - BedrockagentDataSourceStepToApply
-
step_to_apply— derived from the provider schema description. - BedrockagentDataSourceType
-
type— derived from the provider schema description. - BedrockagentDataSourceVideoExtractionStatus
-
video_extraction_status— derived from the provider schema description. - BedrockagentFlowCachePointType
-
type— derived from the provider schema description. - BedrockagentFlowCategory
-
category— derived from the provider schema description. - BedrockagentFlowConnectionType
-
type— derived from the provider schema description. - BedrockagentFlowInputType
-
type— derived from the provider schema description. - BedrockagentFlowLanguage
-
language— derived from the provider schema description. - BedrockagentFlowNodeType
-
type— derived from the provider schema description. - BedrockagentFlowRole
-
role— derived from the provider schema description. - BedrockagentFlowTemplateType
-
template_type— derived from the provider schema description. - BedrockagentKnowledgeBaseConfigurationType
-
type— derived from the provider schema description. - BedrockagentKnowledgeBaseEmbeddingDataType
-
embedding_data_type— derived from the provider schema description. - BedrockagentKnowledgeBaseEmbeddingModelType
-
embedding_model_type— derived from the provider schema description. - BedrockagentKnowledgeBaseInclusion
-
inclusion— derived from the provider schema description. - BedrockagentKnowledgeBaseProvisionedConfigurationType
-
type— derived from the provider schema description. - BedrockagentKnowledgeBaseQueryEngineConfigurationType
-
type— derived from the provider schema description. - BedrockagentKnowledgeBaseRedshiftConfigurationType
-
type— derived from the provider schema description. - BedrockagentKnowledgeBaseServerlessConfigurationType
-
type— derived from the provider schema description. - BedrockagentKnowledgeBaseSqlKnowledgeBaseConfigurationType
-
type— derived from the provider schema description. - BedrockagentKnowledgeBaseStorageConfigurationType
-
type— derived from the provider schema description. - BedrockagentKnowledgeBaseStorageLocationType
-
type— derived from the provider schema description. - BedrockagentPromptRole
-
role— derived from the provider schema description. - BedrockagentPromptTemplateType
-
template_type— derived from the provider schema description. - BedrockagentPromptType
-
type— derived from the provider schema description.