budgets library
AWS Budgets.
Classes
- AwsBudgetsBudget
-
Factory wrapper for
aws_budgets_budget. - AwsBudgetsBudgetAction
-
Factory wrapper for
aws_budgets_budget_action. - BudgetsBudgetActionDefinition
-
Typed helper for the
definitionblock ofaws_budgets_budget_action(derived from provider schema). - BudgetsBudgetActionIamActionDefinition
-
Typed helper for the
definition.iam_action_definitionblock ofaws_budgets_budget_action(derived from provider schema). - BudgetsBudgetActionScpActionDefinition
-
Typed helper for the
definition.scp_action_definitionblock ofaws_budgets_budget_action(derived from provider schema). - BudgetsBudgetActionSsmActionDefinition
-
Typed helper for the
definition.ssm_action_definitionblock ofaws_budgets_budget_action(derived from provider schema). - BudgetsBudgetActionSubscriber
-
Typed helper for the
subscriberblock ofaws_budgets_budget_action(derived from provider schema). - BudgetsBudgetActionThreshold
-
Typed helper for the
action_thresholdblock ofaws_budgets_budget_action(derived from provider schema). - BudgetsBudgetAnd
-
Typed helper for the
filter_expression.andblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetAndAnd
-
Typed helper for the
filter_expression.and.andblock ofaws_budgets_budget(derived from provider schema). Shared by every block of this shape in the resource. - BudgetsBudgetAndCostCategories
-
Typed helper for the
filter_expression.and.cost_categoriesblock ofaws_budgets_budget(derived from provider schema). Shared by every block of this shape in the resource. - BudgetsBudgetAndDimensions
-
Typed helper for the
filter_expression.and.dimensionsblock ofaws_budgets_budget(derived from provider schema). Shared by every block of this shape in the resource. - BudgetsBudgetAndNot
-
Typed helper for the
filter_expression.and.notblock ofaws_budgets_budget(derived from provider schema). Shared by every block of this shape in the resource. - BudgetsBudgetAndOr
-
Typed helper for the
filter_expression.and.orblock ofaws_budgets_budget(derived from provider schema). Shared by every block of this shape in the resource. - BudgetsBudgetAndTags
-
Typed helper for the
filter_expression.and.tagsblock ofaws_budgets_budget(derived from provider schema). Shared by every block of this shape in the resource. - BudgetsBudgetAutoAdjustData
-
Typed helper for the
auto_adjust_datablock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetCostCategories
-
Typed helper for the
filter_expression.cost_categoriesblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetCostFilter
-
Typed helper for the
cost_filterblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetCostTypes
-
Typed helper for the
cost_typesblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetDimensions
-
Typed helper for the
filter_expression.dimensionsblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetFilterExpression
-
Typed helper for the
filter_expressionblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetFilterExpressionTags
-
Typed helper for the
filter_expression.tagsblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetHistoricalOptions
-
Typed helper for the
auto_adjust_data.historical_optionsblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetMeasure
-
At most one of
cost_types,metricsonaws_budgets_budget: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - BudgetsBudgetMeasureCostTypes
-
The BudgetsBudgetMeasure.costTypes choice: sets
cost_types. - BudgetsBudgetMeasureMetrics
-
The BudgetsBudgetMeasure.metrics choice: sets
metrics. - BudgetsBudgetName
-
At most one of
name,name_prefixonaws_budgets_budget: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - BudgetsBudgetNameChoice
-
The BudgetsBudgetName.name choice: sets
name. - BudgetsBudgetNamePrefix
-
The BudgetsBudgetName.namePrefix choice: sets
name_prefix. - BudgetsBudgetNot
-
Typed helper for the
filter_expression.notblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetNotification
-
Typed helper for the
notificationblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetOr
-
Typed helper for the
filter_expression.orblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetPlannedLimit
-
Typed helper for the
planned_limitblock ofaws_budgets_budget(derived from provider schema). - BudgetsBudgetScope
-
At most one of
cost_filter,filter_expressiononaws_budgets_budget: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - BudgetsBudgetScopeCostFilter
-
The BudgetsBudgetScope.costFilter choice: sets
cost_filter. - BudgetsBudgetScopeFilterExpression
-
The BudgetsBudgetScope.filterExpression choice: sets
filter_expression.
Enums
- BudgetsBudgetActionApprovalModel
-
Budgets Budget Action Approval enum for
approval_model. - BudgetsBudgetActionNotificationType
-
Budgets Budget Action Notification enum for
notification_type. - BudgetsBudgetActionSubscriptionType
-
subscription_type— derived from the provider schema description. - BudgetsBudgetActionSubType
-
action_sub_type— derived from the provider schema description. - BudgetsBudgetActionThresholdType
-
action_threshold_type— derived from the provider schema description. - BudgetsBudgetActionType
-
Budgets Budget Action enum for
action_type. - BudgetsBudgetAutoAdjustType
-
auto_adjust_type— derived from the provider schema description. - BudgetsBudgetComparisonOperator
-
comparison_operator— derived from the provider schema description. - BudgetsBudgetKey
-
key— derived from the provider schema description. - BudgetsBudgetMatchOptions
-
match_options— derived from the provider schema description. - BudgetsBudgetMetrics
-
Budgets Budget enum for
metrics. - BudgetsBudgetNotificationType
-
notification_type— derived from the provider schema description. - BudgetsBudgetThresholdType
-
threshold_type— derived from the provider schema description. - BudgetsBudgetTimeUnit
-
Budgets Budget Time enum for
time_unit. - BudgetsBudgetType
-
Budgets Budget enum for
budget_type.