cloudformation library
AWS CloudFormation.
Classes
- AwsCloudformationStack
-
Factory wrapper for
aws_cloudformation_stack. - AwsCloudformationStackInstances
-
Factory wrapper for
aws_cloudformation_stack_instances. - AwsCloudformationStackSet
-
Factory wrapper for
aws_cloudformation_stack_set. - AwsCloudformationStackSetInstance
-
Factory wrapper for
aws_cloudformation_stack_set_instance. - AwsCloudformationType
-
Factory wrapper for
aws_cloudformation_type. - CloudformationStackInstancesDeploymentTargets
-
Typed helper for the
deployment_targetsblock ofaws_cloudformation_stack_instances(derived from provider schema). - CloudformationStackInstancesDeploymentTargetsChoice
-
The CloudformationStackInstancesTargets.deploymentTargets choice: sets
deployment_targets. - CloudformationStackInstancesFailureTolerance
-
At most one of
failure_tolerance_count,failure_tolerance_percentageon theoperation_preferencesblock ofaws_cloudformation_stack_instances: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudformationStackInstancesFailureToleranceCount
-
The CloudformationStackInstancesFailureTolerance.failureToleranceCount choice: sets
failure_tolerance_count. - CloudformationStackInstancesFailureTolerancePercentage
-
The CloudformationStackInstancesFailureTolerance.failureTolerancePercentage choice: sets
failure_tolerance_percentage. - CloudformationStackInstancesMaxConcurrent
-
At most one of
max_concurrent_count,max_concurrent_percentageon theoperation_preferencesblock ofaws_cloudformation_stack_instances: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudformationStackInstancesMaxConcurrentCount
-
The CloudformationStackInstancesMaxConcurrent.maxConcurrentCount choice: sets
max_concurrent_count. - CloudformationStackInstancesMaxConcurrentPercentage
-
The CloudformationStackInstancesMaxConcurrent.maxConcurrentPercentage choice: sets
max_concurrent_percentage. - CloudformationStackInstancesOperationPreferences
-
Typed helper for the
operation_preferencesblock ofaws_cloudformation_stack_instances(derived from provider schema). - CloudformationStackInstancesTargets
-
At most one of
accounts,deployment_targetsonaws_cloudformation_stack_instances: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudformationStackInstancesTargetsAccounts
-
The CloudformationStackInstancesTargets.accounts choice: sets
accounts. - CloudformationStackSetAutoDeployment
-
Typed helper for the
auto_deploymentblock ofaws_cloudformation_stack_set(derived from provider schema). - CloudformationStackSetFailureTolerance
-
At most one of
failure_tolerance_count,failure_tolerance_percentageon theoperation_preferencesblock ofaws_cloudformation_stack_set: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudformationStackSetFailureToleranceCount
-
The CloudformationStackSetFailureTolerance.failureToleranceCount choice: sets
failure_tolerance_count. - CloudformationStackSetFailureTolerancePercentage
-
The CloudformationStackSetFailureTolerance.failureTolerancePercentage choice: sets
failure_tolerance_percentage. - CloudformationStackSetInstanceDeploymentTargets
-
Typed helper for the
deployment_targetsblock ofaws_cloudformation_stack_set_instance(derived from provider schema). - CloudformationStackSetInstanceFailureTolerance
-
At most one of
failure_tolerance_count,failure_tolerance_percentageon theoperation_preferencesblock ofaws_cloudformation_stack_set_instance: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudformationStackSetInstanceFailureToleranceCount
-
The CloudformationStackSetInstanceFailureTolerance.failureToleranceCount choice: sets
failure_tolerance_count. - CloudformationStackSetInstanceFailureTolerancePercentage
-
The CloudformationStackSetInstanceFailureTolerance.failureTolerancePercentage choice: sets
failure_tolerance_percentage. - CloudformationStackSetInstanceMaxConcurrent
-
At most one of
max_concurrent_count,max_concurrent_percentageon theoperation_preferencesblock ofaws_cloudformation_stack_set_instance: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudformationStackSetInstanceMaxConcurrentCount
-
The CloudformationStackSetInstanceMaxConcurrent.maxConcurrentCount choice: sets
max_concurrent_count. - CloudformationStackSetInstanceMaxConcurrentPercentage
-
The CloudformationStackSetInstanceMaxConcurrent.maxConcurrentPercentage choice: sets
max_concurrent_percentage. - CloudformationStackSetInstanceOperationPreferences
-
Typed helper for the
operation_preferencesblock ofaws_cloudformation_stack_set_instance(derived from provider schema). - CloudformationStackSetInstanceTarget
-
At most one of
account_id,deployment_targetsonaws_cloudformation_stack_set_instance: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudformationStackSetInstanceTargetAccountId
-
The CloudformationStackSetInstanceTarget.accountId choice: sets
account_id. - CloudformationStackSetInstanceTargetDeploymentTargets
-
The CloudformationStackSetInstanceTarget.deploymentTargets choice: sets
deployment_targets. - CloudformationStackSetInstanceTargetRegion
-
At most one of
region,stack_set_instance_regiononaws_cloudformation_stack_set_instance: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudformationStackSetInstanceTargetRegionChoice
-
The CloudformationStackSetInstanceTargetRegion.region choice: sets
region. - CloudformationStackSetInstanceTargetRegionStackSetInstanceRegion
-
The CloudformationStackSetInstanceTargetRegion.stackSetInstanceRegion choice: sets
stack_set_instance_region. - CloudformationStackSetManagedExecution
-
Typed helper for the
managed_executionblock ofaws_cloudformation_stack_set(derived from provider schema). - CloudformationStackSetMaxConcurrent
-
At most one of
max_concurrent_count,max_concurrent_percentageon theoperation_preferencesblock ofaws_cloudformation_stack_set: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudformationStackSetMaxConcurrentCount
-
The CloudformationStackSetMaxConcurrent.maxConcurrentCount choice: sets
max_concurrent_count. - CloudformationStackSetMaxConcurrentPercentage
-
The CloudformationStackSetMaxConcurrent.maxConcurrentPercentage choice: sets
max_concurrent_percentage. - CloudformationStackSetOperationPreferences
-
Typed helper for the
operation_preferencesblock ofaws_cloudformation_stack_set(derived from provider schema). - CloudformationStackSetTemplate
-
At most one of
template_body,template_urlonaws_cloudformation_stack_set: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudformationStackSetTemplateBody
-
The CloudformationStackSetTemplate.templateBody choice: sets
template_body. - CloudformationStackSetTemplateUrl
-
The CloudformationStackSetTemplate.templateUrl choice: sets
template_url. - CloudformationTypeLoggingConfig
-
Typed helper for the
logging_configblock ofaws_cloudformation_type(derived from provider schema).
Enums
- CloudformationStackCapabilities
-
Cloudformation Stack enum for
capabilities. - CloudformationStackInstancesCallAs
-
Cloudformation Stack Instances Call enum for
call_as. - CloudformationStackInstancesConcurrencyMode
-
concurrency_mode— derived from the provider schema description. - CloudformationStackInstancesRegionConcurrencyType
-
region_concurrency_type— derived from the provider schema description. - CloudformationStackOnFailure
-
Cloudformation Stack On enum for
on_failure. - CloudformationStackSetCallAs
-
Cloudformation Stack Set Call enum for
call_as. - CloudformationStackSetCapabilities
-
Cloudformation Stack Set enum for
capabilities. - CloudformationStackSetInstanceCallAs
-
Cloudformation Stack Set Instance Call enum for
call_as. - CloudformationStackSetInstanceConcurrencyMode
-
concurrency_mode— derived from the provider schema description. - CloudformationStackSetInstanceRegionConcurrencyType
-
region_concurrency_type— derived from the provider schema description. - CloudformationStackSetPermissionModel
-
Cloudformation Stack Set Permission enum for
permission_model. - CloudformationStackSetRegionConcurrencyType
-
region_concurrency_type— derived from the provider schema description. - CloudformationType
-
Cloudformation enum for
type.