cloudfront library
AWS CloudFront.
Classes
- AwsCloudfrontAnycastIpList
-
Factory wrapper for
aws_cloudfront_anycast_ip_list. - AwsCloudfrontCachePolicy
-
Factory wrapper for
aws_cloudfront_cache_policy. - AwsCloudfrontConnectionFunction
-
Factory wrapper for
aws_cloudfront_connection_function. - AwsCloudfrontConnectionGroup
-
Factory wrapper for
aws_cloudfront_connection_group. - AwsCloudfrontContinuousDeploymentPolicy
-
Factory wrapper for
aws_cloudfront_continuous_deployment_policy. - AwsCloudfrontDistribution
-
Factory wrapper for
aws_cloudfront_distribution. - AwsCloudfrontDistributionTenant
-
Factory wrapper for
aws_cloudfront_distribution_tenant. - AwsCloudfrontFieldLevelEncryptionConfig
-
Factory wrapper for
aws_cloudfront_field_level_encryption_config. - AwsCloudfrontFieldLevelEncryptionProfile
-
Factory wrapper for
aws_cloudfront_field_level_encryption_profile. - AwsCloudfrontFunction
-
Factory wrapper for
aws_cloudfront_function. - AwsCloudfrontKeyGroup
-
Factory wrapper for
aws_cloudfront_key_group. - AwsCloudfrontKeyValueStore
-
Factory wrapper for
aws_cloudfront_key_value_store. - AwsCloudfrontMonitoringSubscription
-
Factory wrapper for
aws_cloudfront_monitoring_subscription. - AwsCloudfrontMultitenantDistribution
-
Factory wrapper for
aws_cloudfront_multitenant_distribution. - AwsCloudfrontOriginAccessControl
-
Factory wrapper for
aws_cloudfront_origin_access_control. - AwsCloudfrontOriginAccessIdentity
-
Factory wrapper for
aws_cloudfront_origin_access_identity. - AwsCloudfrontOriginRequestPolicy
-
Factory wrapper for
aws_cloudfront_origin_request_policy. - AwsCloudfrontPublicKey
-
Factory wrapper for
aws_cloudfront_public_key. - AwsCloudfrontRealtimeLogConfig
-
Factory wrapper for
aws_cloudfront_realtime_log_config. - AwsCloudfrontResponseHeadersPolicy
-
Factory wrapper for
aws_cloudfront_response_headers_policy. - AwsCloudfrontTrustStore
-
Factory wrapper for
aws_cloudfront_trust_store. - AwsCloudfrontVpcOrigin
-
Factory wrapper for
aws_cloudfront_vpc_origin. - CloudfrontCachePolicyCookies
-
Typed helper for the
parameters_in_cache_key_and_forwarded_to_origin.cookies_config.cookiesblock ofaws_cloudfront_cache_policy(derived from provider schema). - CloudfrontCachePolicyCookiesConfig
-
Typed helper for the
parameters_in_cache_key_and_forwarded_to_origin.cookies_configblock ofaws_cloudfront_cache_policy(derived from provider schema). - CloudfrontCachePolicyHeaders
-
Typed helper for the
parameters_in_cache_key_and_forwarded_to_origin.headers_config.headersblock ofaws_cloudfront_cache_policy(derived from provider schema). - CloudfrontCachePolicyHeadersConfig
-
Typed helper for the
parameters_in_cache_key_and_forwarded_to_origin.headers_configblock ofaws_cloudfront_cache_policy(derived from provider schema). - CloudfrontCachePolicyParametersInCacheKeyAndForwardedToOrigin
-
Typed helper for the
parameters_in_cache_key_and_forwarded_to_originblock ofaws_cloudfront_cache_policy(derived from provider schema). - CloudfrontCachePolicyQueryStrings
-
Typed helper for the
parameters_in_cache_key_and_forwarded_to_origin.query_strings_config.query_stringsblock ofaws_cloudfront_cache_policy(derived from provider schema). - CloudfrontCachePolicyQueryStringsConfig
-
Typed helper for the
parameters_in_cache_key_and_forwarded_to_origin.query_strings_configblock ofaws_cloudfront_cache_policy(derived from provider schema). - CloudfrontConnectionFunctionConfig
-
Typed helper for the
connection_function_configblock ofaws_cloudfront_connection_function(derived from provider schema). - CloudfrontConnectionFunctionKeyValueStoreAssociation
-
Typed helper for the
connection_function_config.key_value_store_associationblock ofaws_cloudfront_connection_function(derived from provider schema). - CloudfrontContinuousDeploymentPolicySessionStickinessConfig
-
Typed helper for the
traffic_config.single_weight_config.session_stickiness_configblock ofaws_cloudfront_continuous_deployment_policy(derived from provider schema). - CloudfrontContinuousDeploymentPolicySingleHeaderConfig
-
Typed helper for the
traffic_config.single_header_configblock ofaws_cloudfront_continuous_deployment_policy(derived from provider schema). - CloudfrontContinuousDeploymentPolicySingleWeightConfig
-
Typed helper for the
traffic_config.single_weight_configblock ofaws_cloudfront_continuous_deployment_policy(derived from provider schema). - CloudfrontContinuousDeploymentPolicyStagingDistributionDnsNames
-
Typed helper for the
staging_distribution_dns_namesblock ofaws_cloudfront_continuous_deployment_policy(derived from provider schema). - CloudfrontContinuousDeploymentPolicyTrafficConfig
-
Typed helper for the
traffic_configblock ofaws_cloudfront_continuous_deployment_policy(derived from provider schema). - CloudfrontDistributionCacheTagConfig
-
Typed helper for the
cache_tag_configblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionConnectionFunctionAssociation
-
Typed helper for the
connection_function_associationblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionCookies
-
Typed helper for the
default_cache_behavior.forwarded_values.cookiesblock ofaws_cloudfront_distribution(derived from provider schema). Shared by every block of this shape in the resource. - CloudfrontDistributionCustomErrorResponse
-
Typed helper for the
custom_error_responseblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionCustomHeader
-
Typed helper for the
origin.custom_headerblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionCustomOriginConfig
-
Typed helper for the
origin.custom_origin_configblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionDefaultCacheBehavior
-
Typed helper for the
default_cache_behaviorblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionFailoverCriteria
-
Typed helper for the
origin_group.failover_criteriablock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionForwardedValues
-
Typed helper for the
default_cache_behavior.forwarded_valuesblock ofaws_cloudfront_distribution(derived from provider schema). Shared by every block of this shape in the resource. - CloudfrontDistributionFunctionAssociation
-
Typed helper for the
default_cache_behavior.function_associationblock ofaws_cloudfront_distribution(derived from provider schema). Shared by every block of this shape in the resource. - CloudfrontDistributionGeoRestriction
-
Typed helper for the
restrictions.geo_restrictionblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionGrpcConfig
-
Typed helper for the
default_cache_behavior.grpc_configblock ofaws_cloudfront_distribution(derived from provider schema). Shared by every block of this shape in the resource. - CloudfrontDistributionLambdaFunctionAssociation
-
Typed helper for the
default_cache_behavior.lambda_function_associationblock ofaws_cloudfront_distribution(derived from provider schema). Shared by every block of this shape in the resource. - CloudfrontDistributionLoggingConfig
-
Typed helper for the
logging_configblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionMember
-
Typed helper for the
origin_group.memberblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionOrderedCacheBehavior
-
Typed helper for the
ordered_cache_behaviorblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionOrigin
-
Typed helper for the
originblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionOriginGroup
-
Typed helper for the
origin_groupblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionOriginMtlsConfig
-
Typed helper for the
origin.custom_origin_config.origin_mtls_configblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionOriginShield
-
Typed helper for the
origin.origin_shieldblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionRestrictions
-
Typed helper for the
restrictionsblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionS3OriginConfig
-
Typed helper for the
origin.s3_origin_configblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionTenantCertificate
-
Typed helper for the
customizations.certificateblock ofaws_cloudfront_distribution_tenant(derived from provider schema). - CloudfrontDistributionTenantCustomizations
-
Typed helper for the
customizationsblock ofaws_cloudfront_distribution_tenant(derived from provider schema). - CloudfrontDistributionTenantDomain
-
Typed helper for the
domainblock ofaws_cloudfront_distribution_tenant(derived from provider schema). - CloudfrontDistributionTenantGeoRestriction
-
Typed helper for the
customizations.geo_restrictionblock ofaws_cloudfront_distribution_tenant(derived from provider schema). - CloudfrontDistributionTenantManagedCertificateRequest
-
Typed helper for the
managed_certificate_requestblock ofaws_cloudfront_distribution_tenant(derived from provider schema). - CloudfrontDistributionTenantParameter
-
Typed helper for the
parameterblock ofaws_cloudfront_distribution_tenant(derived from provider schema). - CloudfrontDistributionTenantWebAcl
-
Typed helper for the
customizations.web_aclblock ofaws_cloudfront_distribution_tenant(derived from provider schema). - CloudfrontDistributionTrustStoreConfig
-
Typed helper for the
viewer_mtls_config.trust_store_configblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionViewerCertificate
-
Typed helper for the
viewer_certificateblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionViewerMtlsConfig
-
Typed helper for the
viewer_mtls_configblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontDistributionVpcOriginConfig
-
Typed helper for the
origin.vpc_origin_configblock ofaws_cloudfront_distribution(derived from provider schema). - CloudfrontFieldLevelEncryptionConfigContentTypeProfileConfig
-
Typed helper for the
content_type_profile_configblock ofaws_cloudfront_field_level_encryption_config(derived from provider schema). - CloudfrontFieldLevelEncryptionConfigContentTypeProfiles
-
Typed helper for the
content_type_profile_config.content_type_profilesblock ofaws_cloudfront_field_level_encryption_config(derived from provider schema). - CloudfrontFieldLevelEncryptionConfigContentTypeProfilesItems
-
Typed helper for the
content_type_profile_config.content_type_profiles.itemsblock ofaws_cloudfront_field_level_encryption_config(derived from provider schema). - CloudfrontFieldLevelEncryptionConfigQueryArgProfileConfig
-
Typed helper for the
query_arg_profile_configblock ofaws_cloudfront_field_level_encryption_config(derived from provider schema). - CloudfrontFieldLevelEncryptionConfigQueryArgProfiles
-
Typed helper for the
query_arg_profile_config.query_arg_profilesblock ofaws_cloudfront_field_level_encryption_config(derived from provider schema). - CloudfrontFieldLevelEncryptionConfigQueryArgProfilesItems
-
Typed helper for the
query_arg_profile_config.query_arg_profiles.itemsblock ofaws_cloudfront_field_level_encryption_config(derived from provider schema). - CloudfrontFieldLevelEncryptionProfileEncryptionEntities
-
Typed helper for the
encryption_entitiesblock ofaws_cloudfront_field_level_encryption_profile(derived from provider schema). - CloudfrontFieldLevelEncryptionProfileFieldPatterns
-
Typed helper for the
encryption_entities.items.field_patternsblock ofaws_cloudfront_field_level_encryption_profile(derived from provider schema). - CloudfrontFieldLevelEncryptionProfileItems
-
Typed helper for the
encryption_entities.itemsblock ofaws_cloudfront_field_level_encryption_profile(derived from provider schema). - CloudfrontMonitoringSubscription
-
Typed helper for the
monitoring_subscriptionblock ofaws_cloudfront_monitoring_subscription(derived from provider schema). - CloudfrontMonitoringSubscriptionRealtimeMetricsSubscriptionConfig
-
Typed helper for the
monitoring_subscription.realtime_metrics_subscription_configblock ofaws_cloudfront_monitoring_subscription(derived from provider schema). - CloudfrontMultitenantDistributionActiveTrustedKeyGroups
-
Typed helper for the
active_trusted_key_groupsblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionAllowedMethods
-
Typed helper for the
cache_behavior.allowed_methodsblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). Shared by every block of this shape in the resource. - CloudfrontMultitenantDistributionCacheBehavior
-
Typed helper for the
cache_behaviorblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionCustomErrorResponse
-
Typed helper for the
custom_error_responseblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionCustomHeader
-
Typed helper for the
origin.custom_headerblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionCustomOriginConfig
-
Typed helper for the
origin.custom_origin_configblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionDefaultCacheBehavior
-
Typed helper for the
default_cache_behaviorblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionDefinition
-
Typed helper for the
tenant_config.parameter_definition.definitionblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionFailoverCriteria
-
Typed helper for the
origin_group.failover_criteriablock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionFunctionAssociation
-
Typed helper for the
cache_behavior.function_associationblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). Shared by every block of this shape in the resource. - CloudfrontMultitenantDistributionGeoRestriction
-
Typed helper for the
restrictions.geo_restrictionblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionItems
-
Typed helper for the
active_trusted_key_groups.itemsblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionLambdaFunctionAssociation
-
Typed helper for the
cache_behavior.lambda_function_associationblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). Shared by every block of this shape in the resource. - CloudfrontMultitenantDistributionMember
-
Typed helper for the
origin_group.memberblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionOrigin
-
Typed helper for the
originblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionOriginGroup
-
Typed helper for the
origin_groupblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionOriginMtlsConfig
-
Typed helper for the
origin.custom_origin_config.origin_mtls_configblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionOriginShield
-
Typed helper for the
origin.origin_shieldblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionParameterDefinition
-
Typed helper for the
tenant_config.parameter_definitionblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionRestrictions
-
Typed helper for the
restrictionsblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionStringSchema
-
Typed helper for the
tenant_config.parameter_definition.definition.string_schemablock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionTenantConfig
-
Typed helper for the
tenant_configblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionTrustedKeyGroups
-
Typed helper for the
cache_behavior.trusted_key_groupsblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). Shared by every block of this shape in the resource. - CloudfrontMultitenantDistributionViewerCertificate
-
Typed helper for the
viewer_certificateblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontMultitenantDistributionVpcOriginConfig
-
Typed helper for the
origin.vpc_origin_configblock ofaws_cloudfront_multitenant_distribution(derived from provider schema). - CloudfrontOriginRequestPolicyCookies
-
Typed helper for the
cookies_config.cookiesblock ofaws_cloudfront_origin_request_policy(derived from provider schema). - CloudfrontOriginRequestPolicyCookiesConfig
-
Typed helper for the
cookies_configblock ofaws_cloudfront_origin_request_policy(derived from provider schema). - CloudfrontOriginRequestPolicyHeaders
-
Typed helper for the
headers_config.headersblock ofaws_cloudfront_origin_request_policy(derived from provider schema). - CloudfrontOriginRequestPolicyHeadersConfig
-
Typed helper for the
headers_configblock ofaws_cloudfront_origin_request_policy(derived from provider schema). - CloudfrontOriginRequestPolicyQueryStrings
-
Typed helper for the
query_strings_config.query_stringsblock ofaws_cloudfront_origin_request_policy(derived from provider schema). - CloudfrontOriginRequestPolicyQueryStringsConfig
-
Typed helper for the
query_strings_configblock ofaws_cloudfront_origin_request_policy(derived from provider schema). - CloudfrontPublicKeyName
-
At most one of
name,name_prefixonaws_cloudfront_public_key: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudfrontPublicKeyNameChoice
-
The CloudfrontPublicKeyName.name choice: sets
name. - CloudfrontPublicKeyNamePrefix
-
The CloudfrontPublicKeyName.namePrefix choice: sets
name_prefix. - CloudfrontRealtimeLogConfigEndpoint
-
Typed helper for the
endpointblock ofaws_cloudfront_realtime_log_config(derived from provider schema). - CloudfrontRealtimeLogConfigKinesisStreamConfig
-
Typed helper for the
endpoint.kinesis_stream_configblock ofaws_cloudfront_realtime_log_config(derived from provider schema). - CloudfrontResponseHeadersPolicyAccessControlAllowHeaders
-
Typed helper for the
cors_config.access_control_allow_headersblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyAccessControlAllowMethods
-
Typed helper for the
cors_config.access_control_allow_methodsblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyAccessControlAllowOrigins
-
Typed helper for the
cors_config.access_control_allow_originsblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyAccessControlExposeHeaders
-
Typed helper for the
cors_config.access_control_expose_headersblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyContentSecurityPolicy
-
Typed helper for the
security_headers_config.content_security_policyblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyContentTypeOptions
-
Typed helper for the
security_headers_config.content_type_optionsblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyCorsConfig
-
Typed helper for the
cors_configblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyCustomHeadersConfig
-
Typed helper for the
custom_headers_configblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyCustomHeadersConfigItems
-
Typed helper for the
custom_headers_config.itemsblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyFrameOptions
-
Typed helper for the
security_headers_config.frame_optionsblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyReferrerPolicy
-
Typed helper for the
security_headers_config.referrer_policyblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyRemoveHeadersConfig
-
Typed helper for the
remove_headers_configblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyRemoveHeadersConfigItems
-
Typed helper for the
remove_headers_config.itemsblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicySecurityHeadersConfig
-
Typed helper for the
security_headers_configblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyServerTimingHeadersConfig
-
Typed helper for the
server_timing_headers_configblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyStrictTransportSecurity
-
Typed helper for the
security_headers_config.strict_transport_securityblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontResponseHeadersPolicyXssProtection
-
Typed helper for the
security_headers_config.xss_protectionblock ofaws_cloudfront_response_headers_policy(derived from provider schema). - CloudfrontTrustStoreCaCertificatesBundleS3Location
-
Typed helper for the
ca_certificates_bundle_source.ca_certificates_bundle_s3_locationblock ofaws_cloudfront_trust_store(derived from provider schema). - CloudfrontTrustStoreCaCertificatesBundleSource
-
Typed helper for the
ca_certificates_bundle_sourceblock ofaws_cloudfront_trust_store(derived from provider schema). - CloudfrontVpcOriginEndpointConfig
-
Typed helper for the
vpc_origin_endpoint_configblock ofaws_cloudfront_vpc_origin(derived from provider schema). - CloudfrontVpcOriginSslProtocols
-
Typed helper for the
vpc_origin_endpoint_config.origin_ssl_protocolsblock ofaws_cloudfront_vpc_origin(derived from provider schema).
Enums
- CloudfrontCachePolicyCookieBehavior
-
cookie_behavior— derived from the provider schema description. - CloudfrontCachePolicyHeaderBehavior
-
header_behavior— derived from the provider schema description. - CloudfrontCachePolicyQueryStringBehavior
-
query_string_behavior— derived from the provider schema description. - CloudfrontConnectionFunctionRuntime
-
runtime— derived from the provider schema description. - CloudfrontContinuousDeploymentPolicyType
-
type— derived from the provider schema description. - CloudfrontDistributionEventType
-
event_type— derived from the provider schema description. - CloudfrontDistributionForward
-
forward— derived from the provider schema description. - CloudfrontDistributionHttpVersion
-
Cloudfront Distribution Http enum for
http_version. - CloudfrontDistributionIpAddressType
-
ip_address_type— derived from the provider schema description. - CloudfrontDistributionMinimumProtocolVersion
-
minimum_protocol_version— derived from the provider schema description. - CloudfrontDistributionMode
-
mode— derived from the provider schema description. - CloudfrontDistributionOriginProtocolPolicy
-
origin_protocol_policy— derived from the provider schema description. - CloudfrontDistributionOriginSslProtocols
-
origin_ssl_protocols— derived from the provider schema description. - CloudfrontDistributionPriceClass
-
Cloudfront Distribution Price enum for
price_class. - CloudfrontDistributionRestrictionType
-
restriction_type— derived from the provider schema description. - CloudfrontDistributionSslSupportMethod
-
ssl_support_method— derived from the provider schema description. - CloudfrontDistributionTenantAction
-
action— derived from the provider schema description. - CloudfrontDistributionTenantCertificateTransparencyLoggingPreference
-
certificate_transparency_logging_preference— derived from the provider schema description. - CloudfrontDistributionTenantRestrictionType
-
restriction_type— derived from the provider schema description. - CloudfrontDistributionTenantValidationTokenHost
-
validation_token_host— derived from the provider schema description. - CloudfrontDistributionViewerProtocolPolicy
-
viewer_protocol_policy— derived from the provider schema description. - CloudfrontFunctionRuntime
-
Cloudfront Function enum for
runtime. - CloudfrontMonitoringSubscriptionRealtimeMetricsSubscriptionStatus
-
realtime_metrics_subscription_status— derived from the provider schema description. - CloudfrontMultitenantDistributionCachedMethods
-
cached_methods— derived from the provider schema description. - CloudfrontMultitenantDistributionEventType
-
event_type— derived from the provider schema description. - CloudfrontMultitenantDistributionHttpVersion
-
Cloudfront Multitenant Distribution Http enum for
http_version. - CloudfrontMultitenantDistributionIpAddressType
-
ip_address_type— derived from the provider schema description. - CloudfrontMultitenantDistributionMinimumProtocolVersion
-
minimum_protocol_version— derived from the provider schema description. - CloudfrontMultitenantDistributionOriginProtocolPolicy
-
origin_protocol_policy— derived from the provider schema description. - CloudfrontMultitenantDistributionOriginSslProtocols
-
origin_ssl_protocols— derived from the provider schema description. - CloudfrontMultitenantDistributionRestrictionType
-
restriction_type— derived from the provider schema description. - CloudfrontMultitenantDistributionSslSupportMethod
-
ssl_support_method— derived from the provider schema description. - CloudfrontMultitenantDistributionViewerProtocolPolicy
-
viewer_protocol_policy— derived from the provider schema description. - CloudfrontOriginAccessControlOriginType
-
Cloudfront Origin Access Control Origin enum for
origin_access_control_origin_type. - CloudfrontOriginAccessControlSigningBehavior
-
Cloudfront Origin Access Control Signing enum for
signing_behavior. - CloudfrontOriginAccessControlSigningProtocol
-
Cloudfront Origin Access Control Signing enum for
signing_protocol. - CloudfrontOriginRequestPolicyCookieBehavior
-
cookie_behavior— derived from the provider schema description. - CloudfrontOriginRequestPolicyHeaderBehavior
-
header_behavior— derived from the provider schema description. - CloudfrontOriginRequestPolicyQueryStringBehavior
-
query_string_behavior— derived from the provider schema description. - CloudfrontRealtimeLogConfigStreamType
-
stream_type— derived from the provider schema description. - CloudfrontResponseHeadersPolicyFrameOption
-
frame_option— derived from the provider schema description. - CloudfrontResponseHeadersPolicySecurityHeadersConfigReferrerPolicy
-
referrer_policy— derived from the provider schema description. - CloudfrontVpcOriginProtocolPolicy
-
origin_protocol_policy— derived from the provider schema description.