cloudwatch library
AWS CloudWatch (alarms, dashboards, logs, and events).
Classes
- AwsCloudwatchAlarmMuteRule
-
Factory wrapper for
aws_cloudwatch_alarm_mute_rule. - AwsCloudwatchCompositeAlarm
-
Factory wrapper for
aws_cloudwatch_composite_alarm. - AwsCloudwatchContributorInsightRule
-
Factory wrapper for
aws_cloudwatch_contributor_insight_rule. - AwsCloudwatchContributorManagedInsightRule
-
Factory wrapper for
aws_cloudwatch_contributor_managed_insight_rule. - AwsCloudwatchDashboard
-
Factory wrapper for
aws_cloudwatch_dashboard. - AwsCloudwatchEventApiDestination
-
Factory wrapper for
aws_cloudwatch_event_api_destination. - AwsCloudwatchEventArchive
-
Factory wrapper for
aws_cloudwatch_event_archive. - AwsCloudwatchEventBus
-
Factory wrapper for
aws_cloudwatch_event_bus. - AwsCloudwatchEventBusPolicy
-
Factory wrapper for
aws_cloudwatch_event_bus_policy. - AwsCloudwatchEventConnection
-
Factory wrapper for
aws_cloudwatch_event_connection. - AwsCloudwatchEventEndpoint
-
Factory wrapper for
aws_cloudwatch_event_endpoint. - AwsCloudwatchEventPermission
-
Factory wrapper for
aws_cloudwatch_event_permission. - AwsCloudwatchEventRule
-
Factory wrapper for
aws_cloudwatch_event_rule. - AwsCloudwatchEventTarget
-
Factory wrapper for
aws_cloudwatch_event_target. - AwsCloudwatchLogAccountPolicy
-
Factory wrapper for
aws_cloudwatch_log_account_policy. - AwsCloudwatchLogAnomalyDetector
-
Factory wrapper for
aws_cloudwatch_log_anomaly_detector. - AwsCloudwatchLogDataProtectionPolicy
-
Factory wrapper for
aws_cloudwatch_log_data_protection_policy. - AwsCloudwatchLogDelivery
-
Factory wrapper for
aws_cloudwatch_log_delivery. - AwsCloudwatchLogDeliveryDestination
-
Factory wrapper for
aws_cloudwatch_log_delivery_destination. - AwsCloudwatchLogDeliveryDestinationPolicy
-
Factory wrapper for
aws_cloudwatch_log_delivery_destination_policy. - AwsCloudwatchLogDeliverySource
-
Factory wrapper for
aws_cloudwatch_log_delivery_source. - AwsCloudwatchLogDestination
-
Factory wrapper for
aws_cloudwatch_log_destination. - AwsCloudwatchLogDestinationPolicy
-
Factory wrapper for
aws_cloudwatch_log_destination_policy. - AwsCloudwatchLogGroup
-
Factory wrapper for
aws_cloudwatch_log_group. - AwsCloudwatchLogIndexPolicy
-
Factory wrapper for
aws_cloudwatch_log_index_policy. - AwsCloudwatchLogMetricFilter
-
Factory wrapper for
aws_cloudwatch_log_metric_filter. - AwsCloudwatchLogResourcePolicy
-
Factory wrapper for
aws_cloudwatch_log_resource_policy. - AwsCloudwatchLogS3TableIntegrationSource
-
Factory wrapper for
aws_cloudwatch_log_s3_table_integration_source. - AwsCloudwatchLogStorageTierPolicy
-
Factory wrapper for
aws_cloudwatch_log_storage_tier_policy. - AwsCloudwatchLogStream
-
Factory wrapper for
aws_cloudwatch_log_stream. - AwsCloudwatchLogSubscriptionFilter
-
Factory wrapper for
aws_cloudwatch_log_subscription_filter. - AwsCloudwatchLogTransformer
-
Factory wrapper for
aws_cloudwatch_log_transformer. - AwsCloudwatchMetricAlarm
-
Factory wrapper for
aws_cloudwatch_metric_alarm. - AwsCloudwatchMetricStream
-
Factory wrapper for
aws_cloudwatch_metric_stream. - AwsCloudwatchOtelEnrichment
-
Factory wrapper for
aws_cloudwatch_otel_enrichment. - AwsCloudwatchQueryDefinition
-
Factory wrapper for
aws_cloudwatch_query_definition. - CloudwatchAlarmMuteRule
-
Typed helper for the
ruleblock ofaws_cloudwatch_alarm_mute_rule(derived from provider schema). - CloudwatchAlarmMuteRuleMuteTargets
-
Typed helper for the
mute_targetsblock ofaws_cloudwatch_alarm_mute_rule(derived from provider schema). - CloudwatchAlarmMuteRuleSchedule
-
Typed helper for the
rule.scheduleblock ofaws_cloudwatch_alarm_mute_rule(derived from provider schema). - CloudwatchCompositeAlarmActionsSuppressor
-
Typed helper for the
actions_suppressorblock ofaws_cloudwatch_composite_alarm(derived from provider schema). - CloudwatchEventBusDeadLetterConfig
-
Typed helper for the
dead_letter_configblock ofaws_cloudwatch_event_bus(derived from provider schema). - CloudwatchEventBusLogConfig
-
Typed helper for the
log_configblock ofaws_cloudwatch_event_bus(derived from provider schema). - CloudwatchEventConnectionApiKey
-
Typed helper for the
auth_parameters.api_keyblock ofaws_cloudwatch_event_connection(derived from provider schema). - CloudwatchEventConnectionAuth
-
Exactly one of
api_key,basic,oauthon theauth_parametersblock ofaws_cloudwatch_event_connection: the provider rejects none and more than one, so each variant sets one of them. - CloudwatchEventConnectionAuthApiKey
-
The CloudwatchEventConnectionAuth.apiKey choice: sets
api_key. - CloudwatchEventConnectionAuthBasic
-
The CloudwatchEventConnectionAuth.basic choice: sets
basic. - CloudwatchEventConnectionAuthOauth
-
The CloudwatchEventConnectionAuth.oauth choice: sets
oauth. - CloudwatchEventConnectionAuthParameters
-
Typed helper for the
auth_parametersblock ofaws_cloudwatch_event_connection(derived from provider schema). - CloudwatchEventConnectionBasic
-
Typed helper for the
auth_parameters.basicblock ofaws_cloudwatch_event_connection(derived from provider schema). - CloudwatchEventConnectionBody
-
Typed helper for the
auth_parameters.invocation_http_parameters.bodyblock ofaws_cloudwatch_event_connection(derived from provider schema). Shared by every block of this shape in the resource. - CloudwatchEventConnectionClientParameters
-
Typed helper for the
auth_parameters.oauth.client_parametersblock ofaws_cloudwatch_event_connection(derived from provider schema). - CloudwatchEventConnectionConnectivityParameters
-
Typed helper for the
auth_parameters.connectivity_parametersblock ofaws_cloudwatch_event_connection(derived from provider schema). - CloudwatchEventConnectionHeader
-
Typed helper for the
auth_parameters.invocation_http_parameters.headerblock ofaws_cloudwatch_event_connection(derived from provider schema). Shared by every block of this shape in the resource. - CloudwatchEventConnectionInvocationConnectivityParameters
-
Typed helper for the
invocation_connectivity_parametersblock ofaws_cloudwatch_event_connection(derived from provider schema). - CloudwatchEventConnectionInvocationHttpParameters
-
Typed helper for the
auth_parameters.invocation_http_parametersblock ofaws_cloudwatch_event_connection(derived from provider schema). - CloudwatchEventConnectionOauth
-
Typed helper for the
auth_parameters.oauthblock ofaws_cloudwatch_event_connection(derived from provider schema). - CloudwatchEventConnectionOauthHttpParameters
-
Typed helper for the
auth_parameters.oauth.oauth_http_parametersblock ofaws_cloudwatch_event_connection(derived from provider schema). - CloudwatchEventConnectionQueryString
-
Typed helper for the
auth_parameters.invocation_http_parameters.query_stringblock ofaws_cloudwatch_event_connection(derived from provider schema). Shared by every block of this shape in the resource. - CloudwatchEventConnectionResourceParameters
-
Typed helper for the
invocation_connectivity_parameters.resource_parametersblock ofaws_cloudwatch_event_connection(derived from provider schema). Shared by every block of this shape in the resource. - CloudwatchEventEndpointEventBus
-
Typed helper for the
event_busblock ofaws_cloudwatch_event_endpoint(derived from provider schema). - CloudwatchEventEndpointFailoverConfig
-
Typed helper for the
routing_config.failover_configblock ofaws_cloudwatch_event_endpoint(derived from provider schema). - CloudwatchEventEndpointPrimary
-
Typed helper for the
routing_config.failover_config.primaryblock ofaws_cloudwatch_event_endpoint(derived from provider schema). - CloudwatchEventEndpointReplicationConfig
-
Typed helper for the
replication_configblock ofaws_cloudwatch_event_endpoint(derived from provider schema). - CloudwatchEventEndpointRoutingConfig
-
Typed helper for the
routing_configblock ofaws_cloudwatch_event_endpoint(derived from provider schema). - CloudwatchEventEndpointSecondary
-
Typed helper for the
routing_config.failover_config.secondaryblock ofaws_cloudwatch_event_endpoint(derived from provider schema). - CloudwatchEventPermissionCondition
-
Typed helper for the
conditionblock ofaws_cloudwatch_event_permission(derived from provider schema). - CloudwatchEventRuleName
-
At most one of
name,name_prefixonaws_cloudwatch_event_rule: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudwatchEventRuleNameChoice
-
The CloudwatchEventRuleName.name choice: sets
name. - CloudwatchEventRuleNamePrefix
-
The CloudwatchEventRuleName.namePrefix choice: sets
name_prefix. - CloudwatchEventRuleStatus
-
At most one of
is_enabled,stateonaws_cloudwatch_event_rule: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudwatchEventRuleStatusIsEnabled
-
The CloudwatchEventRuleStatus.isEnabled choice: sets
is_enabled. - CloudwatchEventRuleStatusState
-
The CloudwatchEventRuleStatus.state choice: sets
state. - CloudwatchEventTargetAppsyncTarget
-
Typed helper for the
appsync_targetblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetBatchTarget
-
Typed helper for the
batch_targetblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetCapacityProviderStrategy
-
Typed helper for the
ecs_target.capacity_provider_strategyblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetDeadLetterConfig
-
Typed helper for the
dead_letter_configblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetEcsTarget
-
Typed helper for the
ecs_targetblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetHttpTarget
-
Typed helper for the
http_targetblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetInput
-
At most one of
input,input_path,input_transformeronaws_cloudwatch_event_target: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudwatchEventTargetInputChoice
-
The CloudwatchEventTargetInput.input choice: sets
input. - CloudwatchEventTargetInputPath
-
The CloudwatchEventTargetInput.inputPath choice: sets
input_path. - CloudwatchEventTargetInputTransformer
-
Typed helper for the
input_transformerblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetInputTransformerChoice
-
The CloudwatchEventTargetInput.inputTransformer choice: sets
input_transformer. - CloudwatchEventTargetKinesisTarget
-
Typed helper for the
kinesis_targetblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetNetworkConfiguration
-
Typed helper for the
ecs_target.network_configurationblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetOrderedPlacementStrategy
-
Typed helper for the
ecs_target.ordered_placement_strategyblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetPipelineParameterList
-
Typed helper for the
sagemaker_pipeline_target.pipeline_parameter_listblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetPlacementConstraint
-
Typed helper for the
ecs_target.placement_constraintblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetRedshiftTarget
-
Typed helper for the
redshift_targetblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetRetryPolicy
-
Typed helper for the
retry_policyblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetRunCommandTargets
-
Typed helper for the
run_command_targetsblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetSagemakerPipelineTarget
-
Typed helper for the
sagemaker_pipeline_targetblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchEventTargetSqsTarget
-
Typed helper for the
sqs_targetblock ofaws_cloudwatch_event_target(derived from provider schema). - CloudwatchLogDeliveryDestinationConfiguration
-
Typed helper for the
delivery_destination_configurationblock ofaws_cloudwatch_log_delivery_destination(derived from provider schema). - CloudwatchLogGroupName
-
At most one of
name,name_prefixonaws_cloudwatch_log_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudwatchLogGroupNameChoice
-
The CloudwatchLogGroupName.name choice: sets
name. - CloudwatchLogGroupNamePrefix
-
The CloudwatchLogGroupName.namePrefix choice: sets
name_prefix. - CloudwatchLogMetricFilterMetricTransformation
-
Typed helper for the
metric_transformationblock ofaws_cloudwatch_log_metric_filter(derived from provider schema). - CloudwatchLogResourcePolicyScope
-
Exactly one of
policy_name,resource_arnonaws_cloudwatch_log_resource_policy: the provider rejects none and more than one, so each variant sets one of them. - CloudwatchLogResourcePolicyScopePolicyName
-
The CloudwatchLogResourcePolicyScope.policyName choice: sets
policy_name. - CloudwatchLogResourcePolicyScopeResourceArn
-
The CloudwatchLogResourcePolicyScope.resourceArn choice: sets
resource_arn. - CloudwatchLogS3TableIntegrationSourceDataSource
-
Typed helper for the
data_sourceblock ofaws_cloudwatch_log_s3_table_integration_source(derived from provider schema). - CloudwatchLogTransformerAddKeys
-
Typed helper for the
transformer_config.add_keysblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerAddKeysEntry
-
Typed helper for the
transformer_config.add_keys.entryblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerConfig
-
Typed helper for the
transformer_configblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerCopyValue
-
Typed helper for the
transformer_config.copy_valueblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerCopyValueEntry
-
Typed helper for the
transformer_config.copy_value.entryblock ofaws_cloudwatch_log_transformer(derived from provider schema). Shared by every block of this shape in the resource. - CloudwatchLogTransformerCsv
-
Typed helper for the
transformer_config.csvblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerDateTimeConverter
-
Typed helper for the
transformer_config.date_time_converterblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerDeleteKeys
-
Typed helper for the
transformer_config.delete_keysblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerGrok
-
Typed helper for the
transformer_config.grokblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerListToMap
-
Typed helper for the
transformer_config.list_to_mapblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerLowerCaseString
-
Typed helper for the
transformer_config.lower_case_stringblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerMoveKeys
-
Typed helper for the
transformer_config.move_keysblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerParseCloudfront
-
Typed helper for the
transformer_config.parse_cloudfrontblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerParseJson
-
Typed helper for the
transformer_config.parse_jsonblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerParseKeyValue
-
Typed helper for the
transformer_config.parse_key_valueblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerParsePostgres
-
Typed helper for the
transformer_config.parse_postgresblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerParseRoute53
-
Typed helper for the
transformer_config.parse_route53block ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerParseToOcsf
-
Typed helper for the
transformer_config.parse_to_ocsfblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerParseVpc
-
Typed helper for the
transformer_config.parse_vpcblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerParseWaf
-
Typed helper for the
transformer_config.parse_wafblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerRenameKeys
-
Typed helper for the
transformer_config.rename_keysblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerRenameKeysEntry
-
Typed helper for the
transformer_config.rename_keys.entryblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerSplitString
-
Typed helper for the
transformer_config.split_stringblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerSplitStringEntry
-
Typed helper for the
transformer_config.split_string.entryblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerSubstituteString
-
Typed helper for the
transformer_config.substitute_stringblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerSubstituteStringEntry
-
Typed helper for the
transformer_config.substitute_string.entryblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerTrimString
-
Typed helper for the
transformer_config.trim_stringblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerTypeConverter
-
Typed helper for the
transformer_config.type_converterblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerTypeConverterEntry
-
Typed helper for the
transformer_config.type_converter.entryblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchLogTransformerUpperCaseString
-
Typed helper for the
transformer_config.upper_case_stringblock ofaws_cloudwatch_log_transformer(derived from provider schema). - CloudwatchMetricAlarmAggregation
-
At most one of
extended_statistic,statisticonaws_cloudwatch_metric_alarm: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudwatchMetricAlarmAggregationExtendedStatistic
-
The CloudwatchMetricAlarmAggregation.extendedStatistic choice: sets
extended_statistic. - CloudwatchMetricAlarmAggregationStatistic
-
The CloudwatchMetricAlarmAggregation.statistic choice: sets
statistic. - CloudwatchMetricAlarmEvaluationCriteria
-
Typed helper for the
evaluation_criteriablock ofaws_cloudwatch_metric_alarm(derived from provider schema). - CloudwatchMetricAlarmMetric
-
Typed helper for the
metric_query.metricblock ofaws_cloudwatch_metric_alarm(derived from provider schema). - CloudwatchMetricAlarmMetricQuery
-
Typed helper for the
metric_queryblock ofaws_cloudwatch_metric_alarm(derived from provider schema). - CloudwatchMetricAlarmPromqlCriteria
-
Typed helper for the
evaluation_criteria.promql_criteriablock ofaws_cloudwatch_metric_alarm(derived from provider schema). - CloudwatchMetricAlarmSignal
-
Exactly one of
evaluation_criteria,metric_name,metric_queryonaws_cloudwatch_metric_alarm: the provider rejects none and more than one, so each variant sets one of them. - CloudwatchMetricAlarmSignalEvaluationCriteria
-
The CloudwatchMetricAlarmSignal.evaluationCriteria choice: sets
evaluation_criteria. - CloudwatchMetricAlarmSignalMetricName
-
The CloudwatchMetricAlarmSignal.metricName choice: sets
metric_name. - CloudwatchMetricAlarmSignalMetricQuery
-
The CloudwatchMetricAlarmSignal.metricQuery choice: sets
metric_query. - CloudwatchMetricAlarmThreshold
-
At most one of
threshold,threshold_metric_idonaws_cloudwatch_metric_alarm: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudwatchMetricAlarmThresholdChoice
-
The CloudwatchMetricAlarmThreshold.threshold choice: sets
threshold. - CloudwatchMetricAlarmThresholdMetricId
-
The CloudwatchMetricAlarmThreshold.thresholdMetricId choice: sets
threshold_metric_id. - CloudwatchMetricAlarmWarmUpConfiguration
-
Typed helper for the
warm_up_configurationblock ofaws_cloudwatch_metric_alarm(derived from provider schema). - CloudwatchMetricStreamExcludeFilter
-
Typed helper for the
exclude_filterblock ofaws_cloudwatch_metric_stream(derived from provider schema). - CloudwatchMetricStreamExcludeFilterChoice
-
The CloudwatchMetricStreamFilter.excludeFilter choice: sets
exclude_filter. - CloudwatchMetricStreamFilter
-
At most one of
exclude_filter,include_filteronaws_cloudwatch_metric_stream: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudwatchMetricStreamIncludeFilter
-
Typed helper for the
include_filterblock ofaws_cloudwatch_metric_stream(derived from provider schema). - CloudwatchMetricStreamIncludeFilterChoice
-
The CloudwatchMetricStreamFilter.includeFilter choice: sets
include_filter. - CloudwatchMetricStreamIncludeMetric
-
Typed helper for the
statistics_configuration.include_metricblock ofaws_cloudwatch_metric_stream(derived from provider schema). - CloudwatchMetricStreamName
-
At most one of
name,name_prefixonaws_cloudwatch_metric_stream: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CloudwatchMetricStreamNameChoice
-
The CloudwatchMetricStreamName.name choice: sets
name. - CloudwatchMetricStreamNamePrefix
-
The CloudwatchMetricStreamName.namePrefix choice: sets
name_prefix. - CloudwatchMetricStreamStatisticsConfiguration
-
Typed helper for the
statistics_configurationblock ofaws_cloudwatch_metric_stream(derived from provider schema).
Enums
- CloudwatchContributorInsightRuleState
-
Cloudwatch Contributor Insight Rule enum for
rule_state. - CloudwatchEventApiDestinationHttpMethod
-
Cloudwatch Event Api Destination Http enum for
http_method. - CloudwatchEventBusIncludeDetail
-
include_detail— derived from the provider schema description. - CloudwatchEventBusLevel
-
level— derived from the provider schema description. - CloudwatchEventConnectionAuthorizationType
-
Cloudwatch Event Connection Authorization enum for
authorization_type. - CloudwatchEventConnectionHttpMethod
-
http_method— derived from the provider schema description. - CloudwatchEventEndpointState
-
state— derived from the provider schema description. - CloudwatchEventPermissionKey
-
key— derived from the provider schema description. - CloudwatchEventPermissionType
-
type— derived from the provider schema description. - CloudwatchEventRuleState
-
Cloudwatch Event Rule enum for
state. - CloudwatchEventTargetLaunchType
-
launch_type— derived from the provider schema description. - CloudwatchEventTargetOrderedPlacementStrategyType
-
type— derived from the provider schema description. - CloudwatchEventTargetPlacementConstraintType
-
type— derived from the provider schema description. - CloudwatchEventTargetPropagateTags
-
propagate_tags— derived from the provider schema description. - CloudwatchLogAccountPolicyScope
-
Cloudwatch Log Account Policy enum for
scope. - CloudwatchLogAccountPolicyType
-
Cloudwatch Log Account Policy enum for
policy_type. - CloudwatchLogAnomalyDetectorEvaluationFrequency
-
Cloudwatch Log Anomaly Detector Evaluation enum for
evaluation_frequency. - CloudwatchLogDeliveryDestinationOutputFormat
-
Cloudwatch Log Delivery Destination Output enum for
output_format. - CloudwatchLogDeliveryDestinationType
-
Cloudwatch Log Delivery Destination enum for
delivery_destination_type. - CloudwatchLogGroupClass
-
Cloudwatch Log Group enum for
log_group_class. - CloudwatchLogMetricFilterUnit
-
unit— derived from the provider schema description. - CloudwatchLogStorageTierPolicyStorageTier
-
Cloudwatch Log Storage Tier Policy Storage enum for
storage_tier. - CloudwatchLogSubscriptionFilterDistribution
-
Cloudwatch Log Subscription Filter enum for
distribution. - CloudwatchLogSubscriptionFilterEmitSystemFields
-
Cloudwatch Log Subscription Filter Emit System enum for
emit_system_fields. - CloudwatchLogTransformerEventSource
-
event_source— derived from the provider schema description. - CloudwatchLogTransformerFlattenedElement
-
flattened_element— derived from the provider schema description. - CloudwatchLogTransformerOcsfVersion
-
ocsf_version— derived from the provider schema description. - CloudwatchLogTransformerType
-
type— derived from the provider schema description. - CloudwatchMetricAlarmComparisonOperator
-
Cloudwatch Metric Alarm Comparison enum for
comparison_operator. - CloudwatchMetricAlarmEvaluateLowSampleCountPercentiles
-
Cloudwatch Metric Alarm Evaluate Low Sample Count enum for
evaluate_low_sample_count_percentiles. - CloudwatchMetricAlarmMetricUnit
-
unit— derived from the provider schema description. - CloudwatchMetricAlarmStat
-
stat— derived from the provider schema description. - CloudwatchMetricAlarmStatistic
-
Cloudwatch Metric Alarm enum for
statistic. - CloudwatchMetricAlarmTreatMissingData
-
Cloudwatch Metric Alarm Treat Missing enum for
treat_missing_data. - CloudwatchMetricAlarmUnit
-
Cloudwatch Metric Alarm enum for
unit. - CloudwatchMetricStreamOutputFormat
-
Cloudwatch Metric Stream Output enum for
output_format.