codebuild library
AWS CodeBuild.
Classes
- AwsCodebuildFleet
-
Factory wrapper for
aws_codebuild_fleet. - AwsCodebuildProject
-
Factory wrapper for
aws_codebuild_project. - AwsCodebuildReportGroup
-
Factory wrapper for
aws_codebuild_report_group. - AwsCodebuildResourcePolicy
-
Factory wrapper for
aws_codebuild_resource_policy. - AwsCodebuildSourceCredential
-
Factory wrapper for
aws_codebuild_source_credential. - AwsCodebuildWebhook
-
Factory wrapper for
aws_codebuild_webhook. - CodebuildFleetComputeConfiguration
-
Typed helper for the
compute_configurationblock ofaws_codebuild_fleet(derived from provider schema). - CodebuildFleetScalingConfiguration
-
Typed helper for the
scaling_configurationblock ofaws_codebuild_fleet(derived from provider schema). - CodebuildFleetTargetTrackingScalingConfigs
-
Typed helper for the
scaling_configuration.target_tracking_scaling_configsblock ofaws_codebuild_fleet(derived from provider schema). - CodebuildFleetVpcConfig
-
Typed helper for the
vpc_configblock ofaws_codebuild_fleet(derived from provider schema). - CodebuildProjectArtifacts
-
Typed helper for the
artifactsblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectAuth
-
Typed helper for the
secondary_sources.authblock ofaws_codebuild_project(derived from provider schema). Shared by every block of this shape in the resource. - CodebuildProjectBuildBatchConfig
-
Typed helper for the
build_batch_configblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectBuildStatusConfig
-
Typed helper for the
secondary_sources.build_status_configblock ofaws_codebuild_project(derived from provider schema). Shared by every block of this shape in the resource. - CodebuildProjectCache
-
Typed helper for the
cacheblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectCloudwatchLogs
-
Typed helper for the
logs_config.cloudwatch_logsblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectDockerServer
-
Typed helper for the
environment.docker_serverblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectEnvironment
-
Typed helper for the
environmentblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectEnvironmentVariable
-
Typed helper for the
environment.environment_variableblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectFileSystemLocations
-
Typed helper for the
file_system_locationsblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectFleet
-
Typed helper for the
environment.fleetblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectGitSubmodulesConfig
-
Typed helper for the
secondary_sources.git_submodules_configblock ofaws_codebuild_project(derived from provider schema). Shared by every block of this shape in the resource. - CodebuildProjectLogsConfig
-
Typed helper for the
logs_configblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectRegistryCredential
-
Typed helper for the
environment.registry_credentialblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectRestrictions
-
Typed helper for the
build_batch_config.restrictionsblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectS3Logs
-
Typed helper for the
logs_config.s3_logsblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectSecondaryArtifacts
-
Typed helper for the
secondary_artifactsblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectSecondarySources
-
Typed helper for the
secondary_sourcesblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectSecondarySourceVersion
-
Typed helper for the
secondary_source_versionblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectSource
-
Typed helper for the
sourceblock ofaws_codebuild_project(derived from provider schema). - CodebuildProjectVpcConfig
-
Typed helper for the
vpc_configblock ofaws_codebuild_project(derived from provider schema). - CodebuildReportGroupExportConfig
-
Typed helper for the
export_configblock ofaws_codebuild_report_group(derived from provider schema). - CodebuildReportGroupS3Destination
-
Typed helper for the
export_config.s3_destinationblock ofaws_codebuild_report_group(derived from provider schema). - CodebuildWebhookFilter
-
Typed helper for the
filter_group.filterblock ofaws_codebuild_webhook(derived from provider schema). - CodebuildWebhookFilterGroup
-
Typed helper for the
filter_groupblock ofaws_codebuild_webhook(derived from provider schema). - CodebuildWebhookPullRequestBuildPolicy
-
Typed helper for the
pull_request_build_policyblock ofaws_codebuild_webhook(derived from provider schema). - CodebuildWebhookScopeConfiguration
-
Typed helper for the
scope_configurationblock ofaws_codebuild_webhook(derived from provider schema). - CodebuildWebhookTrigger
-
At most one of
branch_filter,filter_grouponaws_codebuild_webhook: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CodebuildWebhookTriggerBranchFilter
-
The CodebuildWebhookTrigger.branchFilter choice: sets
branch_filter. - CodebuildWebhookTriggerFilterGroup
-
The CodebuildWebhookTrigger.filterGroup choice: sets
filter_group.
Enums
- CodebuildFleetComputeType
-
Codebuild Fleet Compute enum for
compute_type. - CodebuildFleetEnvironmentType
-
Codebuild Fleet Environment enum for
environment_type. - CodebuildFleetMachineType
-
machine_type— derived from the provider schema description. - CodebuildFleetMetricType
-
metric_type— derived from the provider schema description. - CodebuildFleetOverflowBehavior
-
Codebuild Fleet Overflow enum for
overflow_behavior. - CodebuildFleetScalingType
-
scaling_type— derived from the provider schema description. - CodebuildProjectArtifactsType
-
type— derived from the provider schema description. - CodebuildProjectAuthType
-
type— derived from the provider schema description. - CodebuildProjectBucketOwnerAccess
-
bucket_owner_access— derived from the provider schema description. - CodebuildProjectCacheType
-
type— derived from the provider schema description. - CodebuildProjectComputeType
-
compute_type— derived from the provider schema description. - CodebuildProjectComputeTypesAllowed
-
compute_types_allowed— derived from the provider schema description. - CodebuildProjectCredentialProvider
-
credential_provider— derived from the provider schema description. - CodebuildProjectEnvironmentType
-
type— derived from the provider schema description. - CodebuildProjectEnvironmentVariableType
-
type— derived from the provider schema description. - CodebuildProjectFileSystemLocationsType
-
type— derived from the provider schema description. - CodebuildProjectHostKernel
-
host_kernel— derived from the provider schema description. - CodebuildProjectImagePullCredentialsType
-
image_pull_credentials_type— derived from the provider schema description. - CodebuildProjectModes
-
modes— derived from the provider schema description. - CodebuildProjectNamespaceType
-
namespace_type— derived from the provider schema description. - CodebuildProjectPackaging
-
packaging— derived from the provider schema description. - CodebuildProjectSecondarySourcesType
-
type— derived from the provider schema description. - CodebuildProjectStatus
-
status— derived from the provider schema description. - CodebuildProjectVisibility
-
Codebuild Project enum for
project_visibility. - CodebuildReportGroupExportConfigType
-
type— derived from the provider schema description. - CodebuildReportGroupPackaging
-
packaging— derived from the provider schema description. - CodebuildReportGroupType
-
Codebuild Report Group enum for
type. - CodebuildSourceCredentialAuthType
-
Codebuild Source Credential Auth enum for
auth_type. - CodebuildSourceCredentialServerType
-
Codebuild Source Credential Server enum for
server_type. - CodebuildWebhookApproverRoles
-
approver_roles— derived from the provider schema description. - CodebuildWebhookBuildType
-
Codebuild Webhook Build enum for
build_type. - CodebuildWebhookRequiresCommentApproval
-
requires_comment_approval— derived from the provider schema description. - CodebuildWebhookScope
-
scope— derived from the provider schema description. - CodebuildWebhookType
-
type— derived from the provider schema description.