codepipeline library
AWS CodePipeline.
Classes
- AwsCodepipeline
-
Factory wrapper for
aws_codepipeline. - AwsCodepipelineCustomActionType
-
Factory wrapper for
aws_codepipeline_custom_action_type. - AwsCodepipelineWebhook
-
Factory wrapper for
aws_codepipeline_webhook. - CodepipelineAction
-
Typed helper for the
stage.actionblock ofaws_codepipeline(derived from provider schema). - CodepipelineArtifactStore
-
Typed helper for the
artifact_storeblock ofaws_codepipeline(derived from provider schema). - CodepipelineBeforeEntry
-
Typed helper for the
stage.before_entryblock ofaws_codepipeline(derived from provider schema). - CodepipelineBranches
-
Typed helper for the
trigger.git_configuration.pull_request.branchesblock ofaws_codepipeline(derived from provider schema). Shared by every block of this shape in the resource. - CodepipelineCondition
-
Typed helper for the
stage.before_entry.conditionblock ofaws_codepipeline(derived from provider schema). Shared by every block of this shape in the resource. - CodepipelineCustomActionTypeConfigurationProperty
-
Typed helper for the
configuration_propertyblock ofaws_codepipeline_custom_action_type(derived from provider schema). - CodepipelineCustomActionTypeInputArtifactDetails
-
Typed helper for the
input_artifact_detailsblock ofaws_codepipeline_custom_action_type(derived from provider schema). - CodepipelineCustomActionTypeOutputArtifactDetails
-
Typed helper for the
output_artifact_detailsblock ofaws_codepipeline_custom_action_type(derived from provider schema). - CodepipelineCustomActionTypeSettings
-
Typed helper for the
settingsblock ofaws_codepipeline_custom_action_type(derived from provider schema). - CodepipelineEncryptionKey
-
Typed helper for the
artifact_store.encryption_keyblock ofaws_codepipeline(derived from provider schema). - CodepipelineFilePaths
-
Typed helper for the
trigger.git_configuration.pull_request.file_pathsblock ofaws_codepipeline(derived from provider schema). Shared by every block of this shape in the resource. - CodepipelineGitConfiguration
-
Typed helper for the
trigger.git_configurationblock ofaws_codepipeline(derived from provider schema). - CodepipelineOnFailure
-
Typed helper for the
stage.on_failureblock ofaws_codepipeline(derived from provider schema). - CodepipelineOnSuccess
-
Typed helper for the
stage.on_successblock ofaws_codepipeline(derived from provider schema). - CodepipelineOutputArtifactsForComputeAction
-
Typed helper for the
stage.action.output_artifacts_for_compute_actionblock ofaws_codepipeline(derived from provider schema). - CodepipelinePullRequest
-
Typed helper for the
trigger.git_configuration.pull_requestblock ofaws_codepipeline(derived from provider schema). - CodepipelinePush
-
Typed helper for the
trigger.git_configuration.pushblock ofaws_codepipeline(derived from provider schema). - CodepipelinePushTags
-
Typed helper for the
trigger.git_configuration.push.tagsblock ofaws_codepipeline(derived from provider schema). - CodepipelineRetryConfiguration
-
Typed helper for the
stage.on_failure.retry_configurationblock ofaws_codepipeline(derived from provider schema). - CodepipelineRule
-
Typed helper for the
stage.before_entry.condition.ruleblock ofaws_codepipeline(derived from provider schema). Shared by every block of this shape in the resource. - CodepipelineRuleTypeId
-
Typed helper for the
stage.before_entry.condition.rule.rule_type_idblock ofaws_codepipeline(derived from provider schema). Shared by every block of this shape in the resource. - CodepipelineStage
-
Typed helper for the
stageblock ofaws_codepipeline(derived from provider schema). - CodepipelineTrigger
-
Typed helper for the
triggerblock ofaws_codepipeline(derived from provider schema). - CodepipelineVariable
-
Typed helper for the
variableblock ofaws_codepipeline(derived from provider schema). - CodepipelineWebhookAuthenticationConfiguration
-
Typed helper for the
authentication_configurationblock ofaws_codepipeline_webhook(derived from provider schema). - CodepipelineWebhookFilter
-
Typed helper for the
filterblock ofaws_codepipeline_webhook(derived from provider schema).
Enums
- CodepipelineCategory
-
category— derived from the provider schema description. - CodepipelineCustomActionType
-
type— derived from the provider schema description. - CodepipelineCustomActionTypeCategory
-
Codepipeline Custom Action Type enum for
category. - CodepipelineEncryptionKeyType
-
type— derived from the provider schema description. - CodepipelineExecutionMode
-
Codepipeline Execution enum for
execution_mode. - CodepipelineOwner
-
owner— derived from the provider schema description. - CodepipelinePipelineType
-
Codepipeline Pipeline enum for
pipeline_type. - CodepipelineResult
-
result— derived from the provider schema description. - CodepipelineRetryMode
-
retry_mode— derived from the provider schema description. - CodepipelineType
-
type— derived from the provider schema description. - CodepipelineWebhookAuthentication
-
Codepipeline Webhook enum for
authentication.