cognito library
AWS Cognito.
Classes
- AwsCognitoIdentityPool
-
Factory wrapper for
aws_cognito_identity_pool. - AwsCognitoIdentityPoolProviderPrincipalTag
-
Factory wrapper for
aws_cognito_identity_pool_provider_principal_tag. - AwsCognitoIdentityPoolRolesAttachment
-
Factory wrapper for
aws_cognito_identity_pool_roles_attachment. - AwsCognitoIdentityProvider
-
Factory wrapper for
aws_cognito_identity_provider. - AwsCognitoLogDeliveryConfiguration
-
Factory wrapper for
aws_cognito_log_delivery_configuration. - AwsCognitoManagedLoginBranding
-
Factory wrapper for
aws_cognito_managed_login_branding. - AwsCognitoManagedUserPoolClient
-
Factory wrapper for
aws_cognito_managed_user_pool_client. - AwsCognitoResourceServer
-
Factory wrapper for
aws_cognito_resource_server. - AwsCognitoRiskConfiguration
-
Factory wrapper for
aws_cognito_risk_configuration. - AwsCognitoUser
-
Factory wrapper for
aws_cognito_user. - AwsCognitoUserGroup
-
Factory wrapper for
aws_cognito_user_group. - AwsCognitoUserInGroup
-
Factory wrapper for
aws_cognito_user_in_group. - AwsCognitoUserPool
-
Factory wrapper for
aws_cognito_user_pool. - AwsCognitoUserPoolClient
-
Factory wrapper for
aws_cognito_user_pool_client. - AwsCognitoUserPoolDomain
-
Factory wrapper for
aws_cognito_user_pool_domain. - AwsCognitoUserPoolUiCustomization
-
Factory wrapper for
aws_cognito_user_pool_ui_customization. - CognitoIdentityPoolCognitoIdentityProviders
-
Typed helper for the
cognito_identity_providersblock ofaws_cognito_identity_pool(derived from provider schema). - CognitoIdentityPoolRolesAttachmentMappingRule
-
Typed helper for the
role_mapping.mapping_ruleblock ofaws_cognito_identity_pool_roles_attachment(derived from provider schema). - CognitoIdentityPoolRolesAttachmentRoleMapping
-
Typed helper for the
role_mappingblock ofaws_cognito_identity_pool_roles_attachment(derived from provider schema). - CognitoLogDeliveryConfigurationCloudWatchLogsConfiguration
-
Typed helper for the
log_configurations.cloud_watch_logs_configurationblock ofaws_cognito_log_delivery_configuration(derived from provider schema). - CognitoLogDeliveryConfigurationFirehoseConfiguration
-
Typed helper for the
log_configurations.firehose_configurationblock ofaws_cognito_log_delivery_configuration(derived from provider schema). - CognitoLogDeliveryConfigurationLogConfigurations
-
Typed helper for the
log_configurationsblock ofaws_cognito_log_delivery_configuration(derived from provider schema). - CognitoLogDeliveryConfigurationS3Configuration
-
Typed helper for the
log_configurations.s3_configurationblock ofaws_cognito_log_delivery_configuration(derived from provider schema). - CognitoManagedLoginBrandingAsset
-
Typed helper for the
assetblock ofaws_cognito_managed_login_branding(derived from provider schema). - CognitoManagedLoginBrandingStyle
-
Exactly one of
settings,use_cognito_provided_valuesonaws_cognito_managed_login_branding: the provider rejects none and more than one, so each variant sets one of them. - CognitoManagedLoginBrandingStyleSettings
-
The CognitoManagedLoginBrandingStyle.settings choice: sets
settings. - CognitoManagedLoginBrandingStyleUseCognitoProvidedValues
-
The CognitoManagedLoginBrandingStyle.useCognitoProvidedValues choice: sets
use_cognito_provided_values. - CognitoManagedUserPoolClientAnalyticsConfiguration
-
Typed helper for the
analytics_configurationblock ofaws_cognito_managed_user_pool_client(derived from provider schema). - CognitoManagedUserPoolClientApplication
-
Exactly one of
application_arn,application_idon theanalytics_configurationblock ofaws_cognito_managed_user_pool_client: the provider rejects none and more than one, so each variant sets one of them. - CognitoManagedUserPoolClientApplicationArn
-
The CognitoManagedUserPoolClientApplication.applicationArn choice: sets
application_arn. - CognitoManagedUserPoolClientApplicationId
-
The CognitoManagedUserPoolClientApplication.applicationId choice: sets
application_id. - CognitoManagedUserPoolClientName
-
Exactly one of
name_pattern,name_prefixonaws_cognito_managed_user_pool_client: the provider rejects none and more than one, so each variant sets one of them. - CognitoManagedUserPoolClientNamePattern
-
The CognitoManagedUserPoolClientName.namePattern choice: sets
name_pattern. - CognitoManagedUserPoolClientNamePrefix
-
The CognitoManagedUserPoolClientName.namePrefix choice: sets
name_prefix. - CognitoManagedUserPoolClientRefreshTokenRotation
-
Typed helper for the
refresh_token_rotationblock ofaws_cognito_managed_user_pool_client(derived from provider schema). - CognitoManagedUserPoolClientTokenValidityUnits
-
Typed helper for the
token_validity_unitsblock ofaws_cognito_managed_user_pool_client(derived from provider schema). - CognitoResourceServerScope
-
Typed helper for the
scopeblock ofaws_cognito_resource_server(derived from provider schema). - CognitoRiskConfigurationAccountTakeoverRiskConfiguration
-
Typed helper for the
account_takeover_risk_configurationblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationAccountTakeoverRiskConfigurationActions
-
Typed helper for the
account_takeover_risk_configuration.actionsblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationBlockEmail
-
Typed helper for the
account_takeover_risk_configuration.notify_configuration.block_emailblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationCompromisedCredentialsRiskConfiguration
-
Typed helper for the
compromised_credentials_risk_configurationblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationCompromisedCredentialsRiskConfigurationActions
-
Typed helper for the
compromised_credentials_risk_configuration.actionsblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationHighAction
-
Typed helper for the
account_takeover_risk_configuration.actions.high_actionblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationLowAction
-
Typed helper for the
account_takeover_risk_configuration.actions.low_actionblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationMediumAction
-
Typed helper for the
account_takeover_risk_configuration.actions.medium_actionblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationMfaEmail
-
Typed helper for the
account_takeover_risk_configuration.notify_configuration.mfa_emailblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationNoActionEmail
-
Typed helper for the
account_takeover_risk_configuration.notify_configuration.no_action_emailblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationNotifyConfiguration
-
Typed helper for the
account_takeover_risk_configuration.notify_configurationblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoRiskConfigurationRiskExceptionConfiguration
-
Typed helper for the
risk_exception_configurationblock ofaws_cognito_risk_configuration(derived from provider schema). - CognitoUserPassword
-
At most one of
password,temporary_passwordonaws_cognito_user: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CognitoUserPasswordChoice
-
The CognitoUserPassword.password choice: sets
password. - CognitoUserPoolAccountRecoverySetting
-
Typed helper for the
account_recovery_settingblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolAddOns
-
Typed helper for the
user_pool_add_onsblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolAdminCreateUserConfig
-
Typed helper for the
admin_create_user_configblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolAdvancedSecurityAdditionalFlows
-
Typed helper for the
user_pool_add_ons.advanced_security_additional_flowsblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolClientAnalyticsConfiguration
-
Typed helper for the
analytics_configurationblock ofaws_cognito_user_pool_client(derived from provider schema). - CognitoUserPoolClientApplication
-
Exactly one of
application_arn,application_idon theanalytics_configurationblock ofaws_cognito_user_pool_client: the provider rejects none and more than one, so each variant sets one of them. - CognitoUserPoolClientApplicationArn
-
The CognitoUserPoolClientApplication.applicationArn choice: sets
application_arn. - CognitoUserPoolClientApplicationId
-
The CognitoUserPoolClientApplication.applicationId choice: sets
application_id. - CognitoUserPoolClientRefreshTokenRotation
-
Typed helper for the
refresh_token_rotationblock ofaws_cognito_user_pool_client(derived from provider schema). - CognitoUserPoolClientTokenValidityUnits
-
Typed helper for the
token_validity_unitsblock ofaws_cognito_user_pool_client(derived from provider schema). - CognitoUserPoolCustomEmailSender
-
Typed helper for the
lambda_config.custom_email_senderblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolCustomSmsSender
-
Typed helper for the
lambda_config.custom_sms_senderblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolDeviceConfiguration
-
Typed helper for the
device_configurationblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolEmailConfiguration
-
Typed helper for the
email_configurationblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolEmailMfaConfiguration
-
Typed helper for the
email_mfa_configurationblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolInviteMessageTemplate
-
Typed helper for the
admin_create_user_config.invite_message_templateblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolLambdaConfig
-
Typed helper for the
lambda_configblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolNumberAttributeConstraints
-
Typed helper for the
schema.number_attribute_constraintsblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolPasswordPolicy
-
Typed helper for the
password_policyblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolPreTokenGenerationConfig
-
Typed helper for the
lambda_config.pre_token_generation_configblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolRecoveryMechanism
-
Typed helper for the
account_recovery_setting.recovery_mechanismblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolSchema
-
Typed helper for the
schemablock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolSignInAttributes
-
At most one of
alias_attributes,username_attributesonaws_cognito_user_pool: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - CognitoUserPoolSignInAttributesAliasAttributes
-
The CognitoUserPoolSignInAttributes.aliasAttributes choice: sets
alias_attributes. - CognitoUserPoolSignInAttributesUsernameAttributes
-
The CognitoUserPoolSignInAttributes.usernameAttributes choice: sets
username_attributes. - CognitoUserPoolSignInPolicy
-
Typed helper for the
sign_in_policyblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolSmsConfiguration
-
Typed helper for the
sms_configurationblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolSoftwareTokenMfaConfiguration
-
Typed helper for the
software_token_mfa_configurationblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolStringAttributeConstraints
-
Typed helper for the
schema.string_attribute_constraintsblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolUserAttributeUpdateSettings
-
Typed helper for the
user_attribute_update_settingsblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolUsernameConfiguration
-
Typed helper for the
username_configurationblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolVerificationMessageTemplate
-
Typed helper for the
verification_message_templateblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserPoolWebAuthnConfiguration
-
Typed helper for the
web_authn_configurationblock ofaws_cognito_user_pool(derived from provider schema). - CognitoUserTemporaryPassword
-
The CognitoUserPassword.temporaryPassword choice: sets
temporary_password.
Enums
- CognitoIdentityPoolRolesAttachmentAmbiguousRoleResolution
-
ambiguous_role_resolution— derived from the provider schema description. - CognitoIdentityPoolRolesAttachmentMatchType
-
match_type— derived from the provider schema description. - CognitoIdentityPoolRolesAttachmentType
-
type— derived from the provider schema description. - CognitoIdentityProviderType
-
Cognito Identity Provider enum for
provider_type. - CognitoLogDeliveryConfigurationEventSource
-
event_source— derived from the provider schema description. - CognitoLogDeliveryConfigurationLogLevel
-
log_level— derived from the provider schema description. - CognitoManagedLoginBrandingCategory
-
category— derived from the provider schema description. - CognitoManagedLoginBrandingColorMode
-
color_mode— derived from the provider schema description. - CognitoManagedLoginBrandingExtension
-
extension— derived from the provider schema description. - CognitoManagedUserPoolClientAllowedOauthFlows
-
Cognito Managed User Pool Client Allowed Oauth enum for
allowed_oauth_flows. - CognitoManagedUserPoolClientExplicitAuthFlows
-
Cognito Managed User Pool Client Explicit Auth enum for
explicit_auth_flows. - CognitoManagedUserPoolClientFeature
-
feature— derived from the provider schema description. - CognitoManagedUserPoolClientPreventUserExistenceErrors
-
Cognito Managed User Pool Client Prevent User Existence enum for
prevent_user_existence_errors. - CognitoRiskConfigurationEventAction
-
event_action— derived from the provider schema description. - CognitoRiskConfigurationEventFilter
-
event_filter— derived from the provider schema description. - CognitoRiskConfigurationHighActionEventAction
-
event_action— derived from the provider schema description. - CognitoUserDesiredDeliveryMediums
-
Cognito User Desired Delivery enum for
desired_delivery_mediums. - CognitoUserMessageAction
-
Cognito User Message enum for
message_action. - CognitoUserPoolAdvancedSecurityMode
-
advanced_security_mode— derived from the provider schema description. - CognitoUserPoolAliasAttributes
-
Cognito User Pool Alias enum for
alias_attributes. - CognitoUserPoolAllowedFirstAuthFactors
-
allowed_first_auth_factors— derived from the provider schema description. - CognitoUserPoolAttributeDataType
-
attribute_data_type— derived from the provider schema description. - CognitoUserPoolAttributesRequireVerificationBeforeUpdate
-
attributes_require_verification_before_update— derived from the provider schema description. - CognitoUserPoolAutoVerifiedAttributes
-
Cognito User Pool Auto Verified enum for
auto_verified_attributes. - CognitoUserPoolClientAllowedOauthFlows
-
Cognito User Pool Client Allowed Oauth enum for
allowed_oauth_flows. - CognitoUserPoolClientExplicitAuthFlows
-
Cognito User Pool Client Explicit Auth enum for
explicit_auth_flows. - CognitoUserPoolClientFeature
-
feature— derived from the provider schema description. - CognitoUserPoolClientPreventUserExistenceErrors
-
Cognito User Pool Client Prevent User Existence enum for
prevent_user_existence_errors. - CognitoUserPoolCustomAuthMode
-
custom_auth_mode— derived from the provider schema description. - CognitoUserPoolCustomEmailSenderLambdaVersion
-
lambda_version— derived from the provider schema description. - CognitoUserPoolDefaultEmailOption
-
default_email_option— derived from the provider schema description. - CognitoUserPoolDeletionProtection
-
Cognito User Pool Deletion enum for
deletion_protection. - CognitoUserPoolEmailSendingAccount
-
email_sending_account— derived from the provider schema description. - CognitoUserPoolMfaConfiguration
-
Cognito User Pool Mfa enum for
mfa_configuration. - CognitoUserPoolPreTokenGenerationConfigLambdaVersion
-
lambda_version— derived from the provider schema description. - CognitoUserPoolRecoveryMechanismName
-
name— derived from the provider schema description. - CognitoUserPoolTier
-
Cognito User Pool enum for
user_pool_tier. - CognitoUserPoolUsernameAttributes
-
Cognito User Pool Username enum for
username_attributes. - CognitoUserPoolUserVerification
-
user_verification— derived from the provider schema description.