comprehend library
AWS Comprehend.
Classes
- AwsComprehendDocumentClassifier
-
Factory wrapper for
aws_comprehend_document_classifier. - AwsComprehendEntityRecognizer
-
Factory wrapper for
aws_comprehend_entity_recognizer. - ComprehendDocumentClassifierAugmentedManifests
-
Typed helper for the
input_data_config.augmented_manifestsblock ofaws_comprehend_document_classifier(derived from provider schema). - ComprehendDocumentClassifierInputDataConfig
-
Typed helper for the
input_data_configblock ofaws_comprehend_document_classifier(derived from provider schema). - ComprehendDocumentClassifierOutputDataConfig
-
Typed helper for the
output_data_configblock ofaws_comprehend_document_classifier(derived from provider schema). - ComprehendDocumentClassifierSource
-
Exactly one of
augmented_manifests,s3_urion theinput_data_configblock ofaws_comprehend_document_classifier: the provider rejects none and more than one, so each variant sets one of them. - ComprehendDocumentClassifierSourceAugmentedManifests
-
The ComprehendDocumentClassifierSource.augmentedManifests choice: sets
augmented_manifests. - ComprehendDocumentClassifierSourceS3Uri
-
The ComprehendDocumentClassifierSource.s3Uri choice: sets
s3_uri. - ComprehendDocumentClassifierVersionName
-
At most one of
version_name,version_name_prefixonaws_comprehend_document_classifier: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - ComprehendDocumentClassifierVersionNameChoice
-
The ComprehendDocumentClassifierVersionName.versionName choice: sets
version_name. - ComprehendDocumentClassifierVersionNamePrefix
-
The ComprehendDocumentClassifierVersionName.versionNamePrefix choice: sets
version_name_prefix. - ComprehendDocumentClassifierVpcConfig
-
Typed helper for the
vpc_configblock ofaws_comprehend_document_classifier(derived from provider schema). - ComprehendEntityRecognizerAnnotations
-
Typed helper for the
input_data_config.annotationsblock ofaws_comprehend_entity_recognizer(derived from provider schema). - ComprehendEntityRecognizerAugmentedManifests
-
Typed helper for the
input_data_config.augmented_manifestsblock ofaws_comprehend_entity_recognizer(derived from provider schema). - ComprehendEntityRecognizerDocuments
-
Typed helper for the
input_data_config.documentsblock ofaws_comprehend_entity_recognizer(derived from provider schema). - ComprehendEntityRecognizerEntityList
-
Typed helper for the
input_data_config.entity_listblock ofaws_comprehend_entity_recognizer(derived from provider schema). - ComprehendEntityRecognizerEntityTypes
-
Typed helper for the
input_data_config.entity_typesblock ofaws_comprehend_entity_recognizer(derived from provider schema). - ComprehendEntityRecognizerInputDataConfig
-
Typed helper for the
input_data_configblock ofaws_comprehend_entity_recognizer(derived from provider schema). - ComprehendEntityRecognizerLabels
-
Exactly one of
annotations,entity_liston theinput_data_configblock ofaws_comprehend_entity_recognizer: the provider rejects none and more than one, so each variant sets one of them. - ComprehendEntityRecognizerLabelsAnnotations
-
The ComprehendEntityRecognizerLabels.annotations choice: sets
annotations. - ComprehendEntityRecognizerLabelsEntityList
-
The ComprehendEntityRecognizerLabels.entityList choice: sets
entity_list. - ComprehendEntityRecognizerSource
-
Exactly one of
augmented_manifests,documentson theinput_data_configblock ofaws_comprehend_entity_recognizer: the provider rejects none and more than one, so each variant sets one of them. - ComprehendEntityRecognizerSourceAugmentedManifests
-
The ComprehendEntityRecognizerSource.augmentedManifests choice: sets
augmented_manifests. - ComprehendEntityRecognizerSourceDocuments
-
The ComprehendEntityRecognizerSource.documents choice: sets
documents. - ComprehendEntityRecognizerVersionName
-
At most one of
version_name,version_name_prefixonaws_comprehend_entity_recognizer: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - ComprehendEntityRecognizerVersionNameChoice
-
The ComprehendEntityRecognizerVersionName.versionName choice: sets
version_name. - ComprehendEntityRecognizerVersionNamePrefix
-
The ComprehendEntityRecognizerVersionName.versionNamePrefix choice: sets
version_name_prefix. - ComprehendEntityRecognizerVpcConfig
-
Typed helper for the
vpc_configblock ofaws_comprehend_entity_recognizer(derived from provider schema).
Enums
- ComprehendDocumentClassifierDataFormat
-
data_format— derived from the provider schema description. - ComprehendDocumentClassifierDocumentType
-
document_type— derived from the provider schema description. - ComprehendDocumentClassifierLabelDelimiter
-
label_delimiter— derived from the provider schema description. - ComprehendDocumentClassifierLanguageCode
-
Comprehend Document Classifier Language enum for
language_code. - ComprehendDocumentClassifierMode
-
Comprehend Document Classifier enum for
mode. - ComprehendDocumentClassifierSplit
-
split— derived from the provider schema description. - ComprehendEntityRecognizerDataFormat
-
data_format— derived from the provider schema description. - ComprehendEntityRecognizerDocumentType
-
document_type— derived from the provider schema description. - ComprehendEntityRecognizerInputFormat
-
input_format— derived from the provider schema description. - ComprehendEntityRecognizerLanguageCode
-
Comprehend Entity Recognizer Language enum for
language_code. - ComprehendEntityRecognizerSplit
-
split— derived from the provider schema description.