config library
AWS Config.
Classes
- AwsConfigAggregateAuthorization
-
Factory wrapper for
aws_config_aggregate_authorization. - AwsConfigConfigRule
-
Factory wrapper for
aws_config_config_rule. - AwsConfigConfigurationAggregator
-
Factory wrapper for
aws_config_configuration_aggregator. - AwsConfigConfigurationRecorder
-
Factory wrapper for
aws_config_configuration_recorder. - AwsConfigConfigurationRecorderStatus
-
Factory wrapper for
aws_config_configuration_recorder_status. - AwsConfigConformancePack
-
Factory wrapper for
aws_config_conformance_pack. - AwsConfigDeliveryChannel
-
Factory wrapper for
aws_config_delivery_channel. - AwsConfigOrganizationConformancePack
-
Factory wrapper for
aws_config_organization_conformance_pack. - AwsConfigOrganizationCustomPolicyRule
-
Factory wrapper for
aws_config_organization_custom_policy_rule. - AwsConfigOrganizationCustomRule
-
Factory wrapper for
aws_config_organization_custom_rule. - AwsConfigOrganizationManagedRule
-
Factory wrapper for
aws_config_organization_managed_rule. - AwsConfigRemediationConfiguration
-
Factory wrapper for
aws_config_remediation_configuration. - AwsConfigRetentionConfiguration
-
Factory wrapper for
aws_config_retention_configuration. - ConfigAggregateAuthorizationAuthorizedAwsRegion
-
The ConfigAggregateAuthorizationRegion.authorizedAwsRegion choice: sets
authorized_aws_region. - ConfigAggregateAuthorizationRegion
-
Exactly one of
authorized_aws_region,regiononaws_config_aggregate_authorization: the provider rejects none and more than one, so each variant sets one of them. - ConfigAggregateAuthorizationRegionChoice
-
The ConfigAggregateAuthorizationRegion.region choice: sets
region. - ConfigConfigRuleCustomPolicyDetails
-
Typed helper for the
source.custom_policy_detailsblock ofaws_config_config_rule(derived from provider schema). - ConfigConfigRuleEvaluationMode
-
Typed helper for the
evaluation_modeblock ofaws_config_config_rule(derived from provider schema). - ConfigConfigRuleScope
-
Typed helper for the
scopeblock ofaws_config_config_rule(derived from provider schema). - ConfigConfigRuleSource
-
Typed helper for the
sourceblock ofaws_config_config_rule(derived from provider schema). - ConfigConfigRuleSourceDetail
-
Typed helper for the
source.source_detailblock ofaws_config_config_rule(derived from provider schema). - ConfigConfigurationAggregatorAccountAggregationSource
-
Typed helper for the
account_aggregation_sourceblock ofaws_config_configuration_aggregator(derived from provider schema). - ConfigConfigurationAggregatorAccountAggregationSourceChoice
-
The ConfigConfigurationAggregatorAggregationSource.accountAggregationSource choice: sets
account_aggregation_source. - ConfigConfigurationAggregatorAggregationSource
-
At most one of
account_aggregation_source,organization_aggregation_sourceonaws_config_configuration_aggregator: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - ConfigConfigurationAggregatorOrganizationAggregationSource
-
Typed helper for the
organization_aggregation_sourceblock ofaws_config_configuration_aggregator(derived from provider schema). - ConfigConfigurationAggregatorOrganizationAggregationSourceChoice
-
The ConfigConfigurationAggregatorAggregationSource.organizationAggregationSource choice: sets
organization_aggregation_source. - ConfigConfigurationRecorderExclusionByResourceTypes
-
Typed helper for the
recording_group.exclusion_by_resource_typesblock ofaws_config_configuration_recorder(derived from provider schema). - ConfigConfigurationRecorderRecordingGroup
-
Typed helper for the
recording_groupblock ofaws_config_configuration_recorder(derived from provider schema). - ConfigConfigurationRecorderRecordingMode
-
Typed helper for the
recording_modeblock ofaws_config_configuration_recorder(derived from provider schema). - ConfigConfigurationRecorderRecordingModeOverride
-
Typed helper for the
recording_mode.recording_mode_overrideblock ofaws_config_configuration_recorder(derived from provider schema). - ConfigConfigurationRecorderRecordingStrategy
-
Typed helper for the
recording_group.recording_strategyblock ofaws_config_configuration_recorder(derived from provider schema). - ConfigConformancePackInputParameter
-
Typed helper for the
input_parameterblock ofaws_config_conformance_pack(derived from provider schema). - ConfigDeliveryChannelSnapshotDeliveryProperties
-
Typed helper for the
snapshot_delivery_propertiesblock ofaws_config_delivery_channel(derived from provider schema). - ConfigOrganizationConformancePackInputParameter
-
Typed helper for the
input_parameterblock ofaws_config_organization_conformance_pack(derived from provider schema). - ConfigOrganizationConformancePackTemplate
-
At most one of
template_body,template_s3_urionaws_config_organization_conformance_pack: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - ConfigOrganizationConformancePackTemplateBody
-
The ConfigOrganizationConformancePackTemplate.templateBody choice: sets
template_body. - ConfigOrganizationConformancePackTemplateS3Uri
-
The ConfigOrganizationConformancePackTemplate.templateS3Uri choice: sets
template_s3_uri. - ConfigRemediationConfigurationExecutionControls
-
Typed helper for the
execution_controlsblock ofaws_config_remediation_configuration(derived from provider schema). - ConfigRemediationConfigurationParameter
-
Typed helper for the
parameterblock ofaws_config_remediation_configuration(derived from provider schema). - ConfigRemediationConfigurationSsmControls
-
Typed helper for the
execution_controls.ssm_controlsblock ofaws_config_remediation_configuration(derived from provider schema).
Enums
- ConfigConfigRuleEventSource
-
event_source— derived from the provider schema description. - ConfigConfigRuleMaximumExecutionFrequency
-
Config Config Rule Maximum Execution enum for
maximum_execution_frequency. - ConfigConfigRuleMessageType
-
message_type— derived from the provider schema description. - ConfigConfigRuleMode
-
mode— derived from the provider schema description. - ConfigConfigRuleOwner
-
owner— derived from the provider schema description. - ConfigConfigRuleSourceDetailMaximumExecutionFrequency
-
maximum_execution_frequency— derived from the provider schema description. - ConfigConfigurationRecorderRecordingFrequency
-
recording_frequency— derived from the provider schema description. - ConfigConfigurationRecorderUseOnly
-
use_only— derived from the provider schema description. - ConfigDeliveryChannelDeliveryFrequency
-
delivery_frequency— derived from the provider schema description. - ConfigOrganizationCustomPolicyRuleMaximumExecutionFrequency
-
Config Organization Custom Policy Rule Maximum Execution enum for
maximum_execution_frequency. - ConfigOrganizationCustomPolicyRuleTriggerTypes
-
Config Organization Custom Policy Rule Trigger enum for
trigger_types. - ConfigOrganizationCustomRuleMaximumExecutionFrequency
-
Config Organization Custom Rule Maximum Execution enum for
maximum_execution_frequency. - ConfigOrganizationCustomRuleTriggerTypes
-
Config Organization Custom Rule Trigger enum for
trigger_types. - ConfigOrganizationManagedRuleMaximumExecutionFrequency
-
Config Organization Managed Rule Maximum Execution enum for
maximum_execution_frequency. - ConfigRemediationConfigurationTargetType
-
Config Remediation Configuration Target enum for
target_type.