datasync library
AWS DataSync.
Classes
- AwsDatasyncAgent
-
Factory wrapper for
aws_datasync_agent. - AwsDatasyncLocationAzureBlob
-
Factory wrapper for
aws_datasync_location_azure_blob. - AwsDatasyncLocationEfs
-
Factory wrapper for
aws_datasync_location_efs. - AwsDatasyncLocationFsxLustreFileSystem
-
Factory wrapper for
aws_datasync_location_fsx_lustre_file_system. - AwsDatasyncLocationFsxOntapFileSystem
-
Factory wrapper for
aws_datasync_location_fsx_ontap_file_system. - AwsDatasyncLocationFsxOpenzfsFileSystem
-
Factory wrapper for
aws_datasync_location_fsx_openzfs_file_system. - AwsDatasyncLocationFsxWindowsFileSystem
-
Factory wrapper for
aws_datasync_location_fsx_windows_file_system. - AwsDatasyncLocationHdfs
-
Factory wrapper for
aws_datasync_location_hdfs. - AwsDatasyncLocationNfs
-
Factory wrapper for
aws_datasync_location_nfs. - AwsDatasyncLocationObjectStorage
-
Factory wrapper for
aws_datasync_location_object_storage. - AwsDatasyncLocationS3
-
Factory wrapper for
aws_datasync_location_s3. - AwsDatasyncLocationSmb
-
Factory wrapper for
aws_datasync_location_smb. - AwsDatasyncTask
-
Factory wrapper for
aws_datasync_task. - DatasyncLocationAzureBlobSasConfiguration
-
Typed helper for the
sas_configurationblock ofaws_datasync_location_azure_blob(derived from provider schema). - DatasyncLocationEfsEc2Config
-
Typed helper for the
ec2_configblock ofaws_datasync_location_efs(derived from provider schema). - DatasyncLocationFsxOntapFileSystemNfs
-
Typed helper for the
protocol.nfsblock ofaws_datasync_location_fsx_ontap_file_system(derived from provider schema). - DatasyncLocationFsxOntapFileSystemNfsMountOptions
-
Typed helper for the
protocol.nfs.mount_optionsblock ofaws_datasync_location_fsx_ontap_file_system(derived from provider schema). - DatasyncLocationFsxOntapFileSystemProtocol
-
Exactly one of
nfs,smbon theprotocolblock ofaws_datasync_location_fsx_ontap_file_system: the provider rejects none and more than one, so each variant sets one of them. - DatasyncLocationFsxOntapFileSystemProtocolNfs
-
The DatasyncLocationFsxOntapFileSystemProtocol.nfs choice: sets
nfs. - DatasyncLocationFsxOntapFileSystemProtocolSmb
-
The DatasyncLocationFsxOntapFileSystemProtocol.smb choice: sets
smb. - DatasyncLocationFsxOntapFileSystemSmb
-
Typed helper for the
protocol.smbblock ofaws_datasync_location_fsx_ontap_file_system(derived from provider schema). - DatasyncLocationFsxOntapFileSystemSmbMountOptions
-
Typed helper for the
protocol.smb.mount_optionsblock ofaws_datasync_location_fsx_ontap_file_system(derived from provider schema). - DatasyncLocationFsxOpenzfsFileSystemMountOptions
-
Typed helper for the
protocol.nfs.mount_optionsblock ofaws_datasync_location_fsx_openzfs_file_system(derived from provider schema). - DatasyncLocationFsxOpenzfsFileSystemNfs
-
Typed helper for the
protocol.nfsblock ofaws_datasync_location_fsx_openzfs_file_system(derived from provider schema). - DatasyncLocationFsxOpenzfsFileSystemProtocol
-
Typed helper for the
protocolblock ofaws_datasync_location_fsx_openzfs_file_system(derived from provider schema). - DatasyncLocationHdfsKerberosKeytab
-
At most one of
kerberos_keytab,kerberos_keytab_base64onaws_datasync_location_hdfs: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DatasyncLocationHdfsKerberosKeytabBase64
-
The DatasyncLocationHdfsKerberosKeytab.kerberosKeytabBase64 choice: sets
kerberos_keytab_base64. - DatasyncLocationHdfsKerberosKeytabChoice
-
The DatasyncLocationHdfsKerberosKeytab.kerberosKeytab choice: sets
kerberos_keytab. - DatasyncLocationHdfsKerberosKrb5Conf
-
At most one of
kerberos_krb5_conf,kerberos_krb5_conf_base64onaws_datasync_location_hdfs: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DatasyncLocationHdfsKerberosKrb5ConfBase64
-
The DatasyncLocationHdfsKerberosKrb5Conf.kerberosKrb5ConfBase64 choice: sets
kerberos_krb5_conf_base64. - DatasyncLocationHdfsKerberosKrb5ConfChoice
-
The DatasyncLocationHdfsKerberosKrb5Conf.kerberosKrb5Conf choice: sets
kerberos_krb5_conf. - DatasyncLocationHdfsNameNode
-
Typed helper for the
name_nodeblock ofaws_datasync_location_hdfs(derived from provider schema). - DatasyncLocationHdfsQopConfiguration
-
Typed helper for the
qop_configurationblock ofaws_datasync_location_hdfs(derived from provider schema). - DatasyncLocationNfsMountOptions
-
Typed helper for the
mount_optionsblock ofaws_datasync_location_nfs(derived from provider schema). - DatasyncLocationNfsOnPremConfig
-
Typed helper for the
on_prem_configblock ofaws_datasync_location_nfs(derived from provider schema). - DatasyncLocationS3Config
-
Typed helper for the
s3_configblock ofaws_datasync_location_s3(derived from provider schema). - DatasyncLocationSmbMountOptions
-
Typed helper for the
mount_optionsblock ofaws_datasync_location_smb(derived from provider schema). - DatasyncTaskExcludes
-
Typed helper for the
excludesblock ofaws_datasync_task(derived from provider schema). - DatasyncTaskIncludes
-
Typed helper for the
includesblock ofaws_datasync_task(derived from provider schema). - DatasyncTaskOptions
-
Typed helper for the
optionsblock ofaws_datasync_task(derived from provider schema). - DatasyncTaskReportConfig
-
Typed helper for the
task_report_configblock ofaws_datasync_task(derived from provider schema). - DatasyncTaskReportOverrides
-
Typed helper for the
task_report_config.report_overridesblock ofaws_datasync_task(derived from provider schema). - DatasyncTaskS3Destination
-
Typed helper for the
task_report_config.s3_destinationblock ofaws_datasync_task(derived from provider schema). - DatasyncTaskSchedule
-
Typed helper for the
scheduleblock ofaws_datasync_task(derived from provider schema).
Enums
- DatasyncLocationAzureBlobAccessTier
-
Datasync Location Azure Blob Access enum for
access_tier. - DatasyncLocationAzureBlobAuthenticationType
-
Datasync Location Azure Blob Authentication enum for
authentication_type. - DatasyncLocationAzureBlobType
-
Datasync Location Azure Blob enum for
blob_type. - DatasyncLocationEfsInTransitEncryption
-
Datasync Location Efs In Transit enum for
in_transit_encryption. - DatasyncLocationFsxOntapFileSystemNfsVersion
-
version— derived from the provider schema description. - DatasyncLocationFsxOntapFileSystemSmbVersion
-
version— derived from the provider schema description. - DatasyncLocationFsxOpenzfsFileSystemVersion
-
version— derived from the provider schema description. - DatasyncLocationHdfsAuthenticationType
-
Datasync Location Hdfs Authentication enum for
authentication_type. - DatasyncLocationHdfsDataTransferProtection
-
data_transfer_protection— derived from the provider schema description. - DatasyncLocationHdfsRpcProtection
-
rpc_protection— derived from the provider schema description. - DatasyncLocationNfsVersion
-
version— derived from the provider schema description. - DatasyncLocationObjectStorageServerProtocol
-
Datasync Location Object Storage Server enum for
server_protocol. - DatasyncLocationS3StorageClass
-
Datasync Location S3 Storage enum for
s3_storage_class. - DatasyncLocationSmbVersion
-
version— derived from the provider schema description. - DatasyncTaskAtime
-
atime— derived from the provider schema description. - DatasyncTaskDeletedOverride
-
deleted_override— derived from the provider schema description. - DatasyncTaskFilterType
-
filter_type— derived from the provider schema description. - DatasyncTaskGid
-
gid— derived from the provider schema description. - DatasyncTaskLogLevel
-
log_level— derived from the provider schema description. - DatasyncTaskMode
-
Datasync Task enum for
task_mode. - DatasyncTaskMtime
-
mtime— derived from the provider schema description. - DatasyncTaskObjectTags
-
object_tags— derived from the provider schema description. - DatasyncTaskOutputType
-
output_type— derived from the provider schema description. - DatasyncTaskOverwriteMode
-
overwrite_mode— derived from the provider schema description. - DatasyncTaskPosixPermissions
-
posix_permissions— derived from the provider schema description. - DatasyncTaskPreserveDeletedFiles
-
preserve_deleted_files— derived from the provider schema description. - DatasyncTaskPreserveDevices
-
preserve_devices— derived from the provider schema description. - DatasyncTaskQueueing
-
task_queueing— derived from the provider schema description. - DatasyncTaskReportLevel
-
report_level— derived from the provider schema description. - DatasyncTaskS3ObjectVersioning
-
s3_object_versioning— derived from the provider schema description. - DatasyncTaskSecurityDescriptorCopyFlags
-
security_descriptor_copy_flags— derived from the provider schema description. - DatasyncTaskSkippedOverride
-
skipped_override— derived from the provider schema description. - DatasyncTaskStatus
-
status— derived from the provider schema description. - DatasyncTaskTransferMode
-
transfer_mode— derived from the provider schema description. - DatasyncTaskTransferredOverride
-
transferred_override— derived from the provider schema description. - DatasyncTaskUid
-
uid— derived from the provider schema description. - DatasyncTaskVerifiedOverride
-
verified_override— derived from the provider schema description. - DatasyncTaskVerifyMode
-
verify_mode— derived from the provider schema description.