db library
AWS RDS DB instances, snapshots, and option and parameter groups.
Classes
- AwsDbClusterSnapshot
-
Factory wrapper for
aws_db_cluster_snapshot. - AwsDbEventSubscription
-
Factory wrapper for
aws_db_event_subscription. - AwsDbInstance
-
Factory wrapper for
aws_db_instance. - AwsDbInstanceAutomatedBackupsReplication
-
Factory wrapper for
aws_db_instance_automated_backups_replication. - AwsDbInstanceRoleAssociation
-
Factory wrapper for
aws_db_instance_role_association. - AwsDbOptionGroup
-
Factory wrapper for
aws_db_option_group. - AwsDbParameterGroup
-
Factory wrapper for
aws_db_parameter_group. - AwsDbProxy
-
Factory wrapper for
aws_db_proxy. - AwsDbProxyDefaultTargetGroup
-
Factory wrapper for
aws_db_proxy_default_target_group. - AwsDbProxyEndpoint
-
Factory wrapper for
aws_db_proxy_endpoint. - AwsDbProxyTarget
-
Factory wrapper for
aws_db_proxy_target. - AwsDbSnapshot
-
Factory wrapper for
aws_db_snapshot. - AwsDbSnapshotCopy
-
Factory wrapper for
aws_db_snapshot_copy. - AwsDbSubnetGroup
-
Factory wrapper for
aws_db_subnet_group. - DbEventSubscriptionName
-
At most one of
name,name_prefixonaws_db_event_subscription: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DbEventSubscriptionNameChoice
-
The DbEventSubscriptionName.name choice: sets
name. - DbEventSubscriptionNamePrefix
-
The DbEventSubscriptionName.namePrefix choice: sets
name_prefix. - DbInstanceBlueGreenUpdate
-
Typed helper for the
blue_green_updateblock ofaws_db_instance(derived from provider schema). - DbInstanceIdentifier
-
At most one of
identifier,identifier_prefixonaws_db_instance: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DbInstanceIdentifierChoice
-
The DbInstanceIdentifier.identifier choice: sets
identifier. - DbInstanceIdentifierPrefix
-
The DbInstanceIdentifier.identifierPrefix choice: sets
identifier_prefix. - DbInstanceManageMasterUserPassword
-
The DbInstancePassword.manageMasterUserPassword choice: sets
manage_master_user_password. - DbInstancePassword
-
At most one of
manage_master_user_password,password,password_woonaws_db_instance: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DbInstancePasswordChoice
-
The DbInstancePassword.password choice: sets
password. - DbInstancePasswordWo
-
The DbInstancePassword.passwordWo choice: sets
password_wo. - DbInstanceRestoreToPointInTime
-
Typed helper for the
restore_to_point_in_timeblock ofaws_db_instance(derived from provider schema). - DbInstanceS3Import
-
Typed helper for the
s3_importblock ofaws_db_instance(derived from provider schema). - DbInstanceTarget
-
At most one of
restore_time,use_latest_restorable_timeon therestore_to_point_in_timeblock ofaws_db_instance: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DbInstanceTargetRestoreTime
-
The DbInstanceTarget.restoreTime choice: sets
restore_time. - DbInstanceTargetUseLatestRestorableTime
-
The DbInstanceTarget.useLatestRestorableTime choice: sets
use_latest_restorable_time. - DbOptionGroupName
-
At most one of
name,name_prefixonaws_db_option_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DbOptionGroupNameChoice
-
The DbOptionGroupName.name choice: sets
name. - DbOptionGroupNamePrefix
-
The DbOptionGroupName.namePrefix choice: sets
name_prefix. - DbOptionGroupOption
-
Typed helper for the
optionblock ofaws_db_option_group(derived from provider schema). - DbOptionGroupOptionSettings
-
Typed helper for the
option.option_settingsblock ofaws_db_option_group(derived from provider schema). - DbParameterGroupName
-
At most one of
name,name_prefixonaws_db_parameter_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DbParameterGroupNameChoice
-
The DbParameterGroupName.name choice: sets
name. - DbParameterGroupNamePrefix
-
The DbParameterGroupName.namePrefix choice: sets
name_prefix. - DbParameterGroupParameter
-
Typed helper for the
parameterblock ofaws_db_parameter_group(derived from provider schema). - DbProxyAuth
-
Typed helper for the
authblock ofaws_db_proxy(derived from provider schema). - DbProxyDefaultTargetGroupConnectionPoolConfig
-
Typed helper for the
connection_pool_configblock ofaws_db_proxy_default_target_group(derived from provider schema). - DbProxyTargetDatabase
-
Exactly one of
db_cluster_identifier,db_instance_identifieronaws_db_proxy_target: the provider rejects none and more than one, so each variant sets one of them. - DbProxyTargetDatabaseDbClusterIdentifier
-
The DbProxyTargetDatabase.dbClusterIdentifier choice: sets
db_cluster_identifier. - DbProxyTargetDatabaseDbInstanceIdentifier
-
The DbProxyTargetDatabase.dbInstanceIdentifier choice: sets
db_instance_identifier. - DbSubnetGroupName
-
At most one of
name,name_prefixonaws_db_subnet_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DbSubnetGroupNameChoice
-
The DbSubnetGroupName.name choice: sets
name. - DbSubnetGroupNamePrefix
-
The DbSubnetGroupName.namePrefix choice: sets
name_prefix.
Enums
- DbEventSubscriptionSourceType
-
Db Event Subscription Source enum for
source_type. - DbInstanceBackupTarget
-
Db Instance Backup enum for
backup_target. - DbInstanceDatabaseInsightsMode
-
Db Instance Database Insights enum for
database_insights_mode. - DbInstanceEnabledCloudwatchLogsExports
-
Db Instance Enabled Cloudwatch Logs enum for
enabled_cloudwatch_logs_exports. - DbInstanceEngineLifecycleSupport
-
Db Instance Engine Lifecycle enum for
engine_lifecycle_support. - DbInstanceNetworkType
-
Db Instance Network enum for
network_type. - DbInstanceReplicaMode
-
Db Instance Replica enum for
replica_mode. - DbParameterGroupApplyMethod
-
apply_method— derived from the provider schema description. - DbProxyAuthScheme
-
auth_scheme— derived from the provider schema description. - DbProxyClientPasswordAuthType
-
client_password_auth_type— derived from the provider schema description. - DbProxyDefaultAuthScheme
-
Db Proxy Default Auth enum for
default_auth_scheme. - DbProxyDefaultTargetGroupSessionPinningFilters
-
session_pinning_filters— derived from the provider schema description. - DbProxyEndpointNetworkType
-
Db Proxy Endpoint Network enum for
endpoint_network_type. - DbProxyEndpointTargetRole
-
Db Proxy Endpoint Target enum for
target_role. - DbProxyEngineFamily
-
Db Proxy Engine enum for
engine_family. - DbProxyIamAuth
-
iam_auth— derived from the provider schema description. - DbProxyTargetConnectionNetworkType
-
Db Proxy Target Connection Network enum for
target_connection_network_type.