docdb library
AWS DocumentDB.
Classes
- AwsDocdbCluster
-
Factory wrapper for
aws_docdb_cluster. - AwsDocdbClusterInstance
-
Factory wrapper for
aws_docdb_cluster_instance. - AwsDocdbClusterParameterGroup
-
Factory wrapper for
aws_docdb_cluster_parameter_group. - AwsDocdbClusterSnapshot
-
Factory wrapper for
aws_docdb_cluster_snapshot. - AwsDocdbEventSubscription
-
Factory wrapper for
aws_docdb_event_subscription. - AwsDocdbGlobalCluster
-
Factory wrapper for
aws_docdb_global_cluster. - AwsDocdbSubnetGroup
-
Factory wrapper for
aws_docdb_subnet_group. - DocdbClusterIdentifier
-
At most one of
cluster_identifier,cluster_identifier_prefixonaws_docdb_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DocdbClusterIdentifierChoice
-
The DocdbClusterIdentifier.clusterIdentifier choice: sets
cluster_identifier. - DocdbClusterIdentifierPrefix
-
The DocdbClusterIdentifier.clusterIdentifierPrefix choice: sets
cluster_identifier_prefix. - DocdbClusterInstanceIdentifier
-
At most one of
identifier,identifier_prefixonaws_docdb_cluster_instance: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DocdbClusterInstanceIdentifierChoice
-
The DocdbClusterInstanceIdentifier.identifier choice: sets
identifier. - DocdbClusterInstanceIdentifierPrefix
-
The DocdbClusterInstanceIdentifier.identifierPrefix choice: sets
identifier_prefix. - DocdbClusterMasterPassword
-
At most one of
manage_master_user_password,master_password,master_password_woonaws_docdb_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DocdbClusterMasterPasswordChoice
-
The DocdbClusterMasterPassword.masterPassword choice: sets
master_password. - DocdbClusterMasterPasswordManageMasterUserPassword
-
The DocdbClusterMasterPassword.manageMasterUserPassword choice: sets
manage_master_user_password. - DocdbClusterMasterPasswordWo
-
The DocdbClusterMasterPassword.masterPasswordWo choice: sets
master_password_wo. - DocdbClusterParameterGroupName
-
At most one of
name,name_prefixonaws_docdb_cluster_parameter_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DocdbClusterParameterGroupNameChoice
-
The DocdbClusterParameterGroupName.name choice: sets
name. - DocdbClusterParameterGroupNamePrefix
-
The DocdbClusterParameterGroupName.namePrefix choice: sets
name_prefix. - DocdbClusterParameterGroupParameter
-
Typed helper for the
parameterblock ofaws_docdb_cluster_parameter_group(derived from provider schema). - DocdbClusterRestoreSource
-
At most one of
restore_to_point_in_time,snapshot_identifieronaws_docdb_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DocdbClusterRestoreSourceRestoreToPointInTime
-
The DocdbClusterRestoreSource.restoreToPointInTime choice: sets
restore_to_point_in_time. - DocdbClusterRestoreSourceSnapshotIdentifier
-
The DocdbClusterRestoreSource.snapshotIdentifier choice: sets
snapshot_identifier. - DocdbClusterRestoreToPointInTime
-
Typed helper for the
restore_to_point_in_timeblock ofaws_docdb_cluster(derived from provider schema). - DocdbClusterServerlessV2ScalingConfiguration
-
Typed helper for the
serverless_v2_scaling_configurationblock ofaws_docdb_cluster(derived from provider schema). - DocdbClusterTarget
-
At most one of
restore_to_time,use_latest_restorable_timeon therestore_to_point_in_timeblock ofaws_docdb_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DocdbClusterTargetRestoreToTime
-
The DocdbClusterTarget.restoreToTime choice: sets
restore_to_time. - DocdbClusterTargetUseLatestRestorableTime
-
The DocdbClusterTarget.useLatestRestorableTime choice: sets
use_latest_restorable_time. - DocdbEventSubscriptionName
-
At most one of
name,name_prefixonaws_docdb_event_subscription: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DocdbEventSubscriptionNameChoice
-
The DocdbEventSubscriptionName.name choice: sets
name. - DocdbEventSubscriptionNamePrefix
-
The DocdbEventSubscriptionName.namePrefix choice: sets
name_prefix. - DocdbGlobalClusterSource
-
Exactly one of
engine,source_db_cluster_identifieronaws_docdb_global_cluster: the provider rejects none and more than one, so each variant sets one of them. - DocdbGlobalClusterSourceDbClusterIdentifier
-
The DocdbGlobalClusterSource.sourceDbClusterIdentifier choice: sets
source_db_cluster_identifier. - DocdbGlobalClusterSourceEngine
-
The DocdbGlobalClusterSource.engine choice: sets
engine. - DocdbSubnetGroupName
-
At most one of
name,name_prefixonaws_docdb_subnet_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DocdbSubnetGroupNameChoice
-
The DocdbSubnetGroupName.name choice: sets
name. - DocdbSubnetGroupNamePrefix
-
The DocdbSubnetGroupName.namePrefix choice: sets
name_prefix.
Enums
- DocdbClusterEnabledCloudwatchLogsExports
-
Docdb Cluster Enabled Cloudwatch Logs enum for
enabled_cloudwatch_logs_exports. - DocdbClusterEngine
-
Docdb Cluster enum for
engine. - DocdbClusterInstanceEngine
-
Docdb Cluster Instance enum for
engine. - DocdbClusterNetworkType
-
Docdb Cluster Network enum for
network_type. - DocdbClusterParameterGroupApplyMethod
-
apply_method— derived from the provider schema description. - DocdbClusterRestoreType
-
restore_type— derived from the provider schema description. - DocdbClusterStorageType
-
Docdb Cluster Storage enum for
storage_type. - DocdbGlobalClusterEngine
-
Docdb Global Cluster enum for
engine.