dynamodb library
AWS DynamoDB.
Classes
- AwsDynamodbContributorInsights
-
Factory wrapper for
aws_dynamodb_contributor_insights. - AwsDynamodbGlobalSecondaryIndex
-
Factory wrapper for
aws_dynamodb_global_secondary_index. - AwsDynamodbGlobalTable
-
Factory wrapper for
aws_dynamodb_global_table. - AwsDynamodbKinesisStreamingDestination
-
Factory wrapper for
aws_dynamodb_kinesis_streaming_destination. - AwsDynamodbResourcePolicy
-
Factory wrapper for
aws_dynamodb_resource_policy. - AwsDynamodbTable
-
Factory wrapper for
aws_dynamodb_table. - AwsDynamodbTableExport
-
Factory wrapper for
aws_dynamodb_table_export. - AwsDynamodbTableItem
-
Factory wrapper for
aws_dynamodb_table_item. - AwsDynamodbTableReplica
-
Factory wrapper for
aws_dynamodb_table_replica. - AwsDynamodbTag
-
Factory wrapper for
aws_dynamodb_tag. - DynamodbGlobalSecondaryIndexKeySchema
-
Typed helper for the
key_schemablock ofaws_dynamodb_global_secondary_index(derived from provider schema). - DynamodbGlobalSecondaryIndexOnDemandThroughput
-
Typed helper for the
on_demand_throughputblock ofaws_dynamodb_global_secondary_index(derived from provider schema). - DynamodbGlobalSecondaryIndexProjection
-
Typed helper for the
projectionblock ofaws_dynamodb_global_secondary_index(derived from provider schema). - DynamodbGlobalSecondaryIndexProvisionedThroughput
-
Typed helper for the
provisioned_throughputblock ofaws_dynamodb_global_secondary_index(derived from provider schema). - DynamodbGlobalTableReplica
-
Typed helper for the
replicablock ofaws_dynamodb_global_table(derived from provider schema). - DynamodbTableAttribute
-
Typed helper for the
attributeblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableCsv
-
Typed helper for the
import_table.input_format_options.csvblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableExportIncrementalExportSpecification
-
Typed helper for the
incremental_export_specificationblock ofaws_dynamodb_table_export(derived from provider schema). - DynamodbTableGlobalSecondaryIndex
-
Typed helper for the
global_secondary_indexblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableGlobalTableWitness
-
Typed helper for the
global_table_witnessblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableImportTable
-
Typed helper for the
import_tableblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableInputFormatOptions
-
Typed helper for the
import_table.input_format_optionsblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableKeySchema
-
Typed helper for the
global_secondary_index.key_schemablock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableLocalSecondaryIndex
-
Typed helper for the
local_secondary_indexblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableOnDemandThroughput
-
Typed helper for the
on_demand_throughputblock ofaws_dynamodb_table(derived from provider schema). Shared by every block of this shape in the resource. - DynamodbTablePointInTimeRecovery
-
Typed helper for the
point_in_time_recoveryblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableReplica
-
Typed helper for the
replicablock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableS3BucketSource
-
Typed helper for the
import_table.s3_bucket_sourceblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableServerSideEncryption
-
Typed helper for the
server_side_encryptionblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableSource
-
At most one of
import_table,restore_backup_arn,restore_source_name,restore_source_table_arnonaws_dynamodb_table: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - DynamodbTableSourceImportTable
-
The DynamodbTableSource.importTable choice: sets
import_table. - DynamodbTableSourceRestoreBackupArn
-
The DynamodbTableSource.restoreBackupArn choice: sets
restore_backup_arn. - DynamodbTableSourceRestoreSourceName
-
The DynamodbTableSource.restoreSourceName choice: sets
restore_source_name. - DynamodbTableSourceRestoreSourceTableArn
-
The DynamodbTableSource.restoreSourceTableArn choice: sets
restore_source_table_arn. - DynamodbTableTtl
-
Typed helper for the
ttlblock ofaws_dynamodb_table(derived from provider schema). - DynamodbTableWarmThroughput
-
Typed helper for the
warm_throughputblock ofaws_dynamodb_table(derived from provider schema). Shared by every block of this shape in the resource.
Enums
- DynamodbContributorInsightsMode
-
Dynamodb Contributor Insights enum for
mode. - DynamodbGlobalSecondaryIndexAttributeType
-
attribute_type— derived from the provider schema description. - DynamodbGlobalSecondaryIndexKeyType
-
key_type— derived from the provider schema description. - DynamodbGlobalSecondaryIndexProjectionType
-
projection_type— derived from the provider schema description. - DynamodbKinesisStreamingDestinationApproximateCreationDateTimePrecision
-
Dynamodb Kinesis Streaming Destination Approximate Creation Date Time enum for
approximate_creation_date_time_precision. - DynamodbTableBillingMode
-
Dynamodb Table Billing enum for
billing_mode. - DynamodbTableClass
-
Dynamodb Table enum for
table_class. - DynamodbTableConsistencyMode
-
consistency_mode— derived from the provider schema description. - DynamodbTableExportFormat
-
Dynamodb Table Export enum for
export_format. - DynamodbTableExportS3SseAlgorithm
-
Dynamodb Table Export S3 Sse enum for
s3_sse_algorithm. - DynamodbTableExportType
-
Dynamodb Table Export enum for
export_type. - DynamodbTableExportViewType
-
export_view_type— derived from the provider schema description. - DynamodbTableInputCompressionType
-
input_compression_type— derived from the provider schema description. - DynamodbTableInputFormat
-
input_format— derived from the provider schema description. - DynamodbTableKeyType
-
key_type— derived from the provider schema description. - DynamodbTableProjectionType
-
projection_type— derived from the provider schema description. - DynamodbTableReplicaTableClassOverride
-
Dynamodb Table Replica Table Class enum for
table_class_override. - DynamodbTableStreamViewType
-
Dynamodb Table Stream View enum for
stream_view_type. - DynamodbTableType
-
type— derived from the provider schema description.