elasticache library
AWS ElastiCache.
Classes
- AwsElasticacheCluster
-
Factory wrapper for
aws_elasticache_cluster. - AwsElasticacheGlobalReplicationGroup
-
Factory wrapper for
aws_elasticache_global_replication_group. - AwsElasticacheParameterGroup
-
Factory wrapper for
aws_elasticache_parameter_group. - AwsElasticacheReplicationGroup
-
Factory wrapper for
aws_elasticache_replication_group. - AwsElasticacheReservedCacheNode
-
Factory wrapper for
aws_elasticache_reserved_cache_node. - AwsElasticacheServerlessCache
-
Factory wrapper for
aws_elasticache_serverless_cache. - AwsElasticacheSubnetGroup
-
Factory wrapper for
aws_elasticache_subnet_group. - AwsElasticacheUser
-
Factory wrapper for
aws_elasticache_user. - AwsElasticacheUserGroup
-
Factory wrapper for
aws_elasticache_user_group. - AwsElasticacheUserGroupAssociation
-
Factory wrapper for
aws_elasticache_user_group_association. - ElasticacheClusterLogDeliveryConfiguration
-
Typed helper for the
log_delivery_configurationblock ofaws_elasticache_cluster(derived from provider schema). - ElasticacheClusterSource
-
Exactly one of
engine,replication_group_idonaws_elasticache_cluster: the provider rejects none and more than one, so each variant sets one of them. - ElasticacheClusterSourceEngine
-
The ElasticacheClusterSource.engine choice: sets
engine. - ElasticacheClusterSourceReplicationGroupId
-
The ElasticacheClusterSource.replicationGroupId choice: sets
replication_group_id. - ElasticacheParameterGroupParameter
-
Typed helper for the
parameterblock ofaws_elasticache_parameter_group(derived from provider schema). - ElasticacheReplicationGroupAuth
-
At most one of
auth_token,auth_token_wo,user_group_idsonaws_elasticache_replication_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - ElasticacheReplicationGroupAuthToken
-
The ElasticacheReplicationGroupAuth.authToken choice: sets
auth_token. - ElasticacheReplicationGroupAuthTokenWo
-
The ElasticacheReplicationGroupAuth.authTokenWo choice: sets
auth_token_wo. - ElasticacheReplicationGroupAuthUserGroupIds
-
The ElasticacheReplicationGroupAuth.userGroupIds choice: sets
user_group_ids. - ElasticacheReplicationGroupLogDeliveryConfiguration
-
Typed helper for the
log_delivery_configurationblock ofaws_elasticache_replication_group(derived from provider schema). - ElasticacheReplicationGroupNodeGroupConfiguration
-
Typed helper for the
node_group_configurationblock ofaws_elasticache_replication_group(derived from provider schema). - ElasticacheReplicationGroupTopology
-
At most one of
node_group_configuration,preferred_cache_cluster_azsonaws_elasticache_replication_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - ElasticacheReplicationGroupTopologyNodeGroupConfiguration
-
The ElasticacheReplicationGroupTopology.nodeGroupConfiguration choice: sets
node_group_configuration. - ElasticacheReplicationGroupTopologyPreferredCacheClusterAzs
-
The ElasticacheReplicationGroupTopology.preferredCacheClusterAzs choice: sets
preferred_cache_cluster_azs. - ElasticacheServerlessCacheDataStorage
-
Typed helper for the
cache_usage_limits.data_storageblock ofaws_elasticache_serverless_cache(derived from provider schema). - ElasticacheServerlessCacheEcpuPerSecond
-
Typed helper for the
cache_usage_limits.ecpu_per_secondblock ofaws_elasticache_serverless_cache(derived from provider schema). - ElasticacheServerlessCacheUsageLimits
-
Typed helper for the
cache_usage_limitsblock ofaws_elasticache_serverless_cache(derived from provider schema). - ElasticacheUserAuthenticationMode
-
Typed helper for the
authentication_modeblock ofaws_elasticache_user(derived from provider schema).
Enums
- ElasticacheClusterAzMode
-
Elasticache Cluster Az enum for
az_mode. - ElasticacheClusterDestinationType
-
destination_type— derived from the provider schema description. - ElasticacheClusterEngine
-
Elasticache Cluster enum for
engine. - ElasticacheClusterIpDiscovery
-
Elasticache Cluster Ip enum for
ip_discovery. - ElasticacheClusterLogFormat
-
log_format— derived from the provider schema description. - ElasticacheClusterLogType
-
log_type— derived from the provider schema description. - ElasticacheClusterNetworkType
-
Elasticache Cluster Network enum for
network_type. - ElasticacheClusterOutpostMode
-
Elasticache Cluster Outpost enum for
outpost_mode. - ElasticacheGlobalReplicationGroupEngine
-
Elasticache Global Replication Group enum for
engine. - ElasticacheReplicationGroupAuthTokenUpdateStrategy
-
Elasticache Replication Group Auth Token Update enum for
auth_token_update_strategy. - ElasticacheReplicationGroupClusterMode
-
Elasticache Replication Group Cluster enum for
cluster_mode. - ElasticacheReplicationGroupDestinationType
-
destination_type— derived from the provider schema description. - ElasticacheReplicationGroupDurability
-
Elasticache Replication Group enum for
durability. - ElasticacheReplicationGroupEngine
-
Elasticache Replication Group enum for
engine. - ElasticacheReplicationGroupIpDiscovery
-
Elasticache Replication Group Ip enum for
ip_discovery. - ElasticacheReplicationGroupLogFormat
-
log_format— derived from the provider schema description. - ElasticacheReplicationGroupLogType
-
log_type— derived from the provider schema description. - ElasticacheReplicationGroupNetworkType
-
Elasticache Replication Group Network enum for
network_type. - ElasticacheReplicationGroupTransitEncryptionMode
-
Elasticache Replication Group Transit Encryption enum for
transit_encryption_mode. - ElasticacheServerlessCacheNetworkType
-
Elasticache Serverless Cache Network enum for
network_type. - ElasticacheServerlessCacheUnit
-
unit— derived from the provider schema description. - ElasticacheUserEngine
-
Elasticache User enum for
engine. - ElasticacheUserGroupEngine
-
Elasticache User Group enum for
engine. - ElasticacheUserType
-
type— derived from the provider schema description.