evidently library
AWS CloudWatch Evidently.
Classes
- AwsEvidentlyFeature
-
Factory wrapper for
aws_evidently_feature. - AwsEvidentlyLaunch
-
Factory wrapper for
aws_evidently_launch. - AwsEvidentlyProject
-
Factory wrapper for
aws_evidently_project. - AwsEvidentlySegment
-
Factory wrapper for
aws_evidently_segment. - EvidentlyFeatureValue
-
Typed helper for the
variations.valueblock ofaws_evidently_feature(derived from provider schema). - EvidentlyFeatureVariations
-
Typed helper for the
variationsblock ofaws_evidently_feature(derived from provider schema). - EvidentlyLaunchGroups
-
Typed helper for the
groupsblock ofaws_evidently_launch(derived from provider schema). - EvidentlyLaunchMetricDefinition
-
Typed helper for the
metric_monitors.metric_definitionblock ofaws_evidently_launch(derived from provider schema). - EvidentlyLaunchMetricMonitors
-
Typed helper for the
metric_monitorsblock ofaws_evidently_launch(derived from provider schema). - EvidentlyLaunchScheduledSplitsConfig
-
Typed helper for the
scheduled_splits_configblock ofaws_evidently_launch(derived from provider schema). - EvidentlyLaunchSegmentOverrides
-
Typed helper for the
scheduled_splits_config.steps.segment_overridesblock ofaws_evidently_launch(derived from provider schema). - EvidentlyLaunchSteps
-
Typed helper for the
scheduled_splits_config.stepsblock ofaws_evidently_launch(derived from provider schema). - EvidentlyProjectCloudwatchLogs
-
Typed helper for the
data_delivery.cloudwatch_logsblock ofaws_evidently_project(derived from provider schema). - EvidentlyProjectDataDelivery
-
At most one of
cloudwatch_logs,s3_destinationon thedata_deliveryblock ofaws_evidently_project: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - EvidentlyProjectDataDeliveryCloudwatchLogs
-
The EvidentlyProjectDataDelivery.cloudwatchLogs choice: sets
cloudwatch_logs. - EvidentlyProjectDataDeliveryS3Destination
-
The EvidentlyProjectDataDelivery.s3Destination choice: sets
s3_destination. - EvidentlyProjectS3Destination
-
Typed helper for the
data_delivery.s3_destinationblock ofaws_evidently_project(derived from provider schema).
Enums
- EvidentlyFeatureEvaluationStrategy
-
Evidently Feature Evaluation enum for
evaluation_strategy.