fsx library
AWS FSx.
Classes
- AwsFsxBackup
-
Factory wrapper for
aws_fsx_backup. - AwsFsxDataRepositoryAssociation
-
Factory wrapper for
aws_fsx_data_repository_association. - AwsFsxFileCache
-
Factory wrapper for
aws_fsx_file_cache. - AwsFsxLustreFileSystem
-
Factory wrapper for
aws_fsx_lustre_file_system. - AwsFsxOntapFileSystem
-
Factory wrapper for
aws_fsx_ontap_file_system. - AwsFsxOntapStorageVirtualMachine
-
Factory wrapper for
aws_fsx_ontap_storage_virtual_machine. - AwsFsxOntapVolume
-
Factory wrapper for
aws_fsx_ontap_volume. - AwsFsxOpenzfsFileSystem
-
Factory wrapper for
aws_fsx_openzfs_file_system. - AwsFsxOpenzfsSnapshot
-
Factory wrapper for
aws_fsx_openzfs_snapshot. - AwsFsxOpenzfsVolume
-
Factory wrapper for
aws_fsx_openzfs_volume. - AwsFsxS3AccessPointAttachment
-
Factory wrapper for
aws_fsx_s3_access_point_attachment. - AwsFsxWindowsFileSystem
-
Factory wrapper for
aws_fsx_windows_file_system. - FsxDataRepositoryAssociationAutoExportPolicy
-
Typed helper for the
s3.auto_export_policyblock ofaws_fsx_data_repository_association(derived from provider schema). - FsxDataRepositoryAssociationAutoImportPolicy
-
Typed helper for the
s3.auto_import_policyblock ofaws_fsx_data_repository_association(derived from provider schema). - FsxDataRepositoryAssociationS3
-
Typed helper for the
s3block ofaws_fsx_data_repository_association(derived from provider schema). - FsxFileCacheDataRepositoryAssociation
-
Typed helper for the
data_repository_associationblock ofaws_fsx_file_cache(derived from provider schema). - FsxFileCacheLustreConfiguration
-
Typed helper for the
lustre_configurationblock ofaws_fsx_file_cache(derived from provider schema). - FsxFileCacheMetadataConfiguration
-
Typed helper for the
lustre_configuration.metadata_configurationblock ofaws_fsx_file_cache(derived from provider schema). - FsxFileCacheNfs
-
Typed helper for the
data_repository_association.nfsblock ofaws_fsx_file_cache(derived from provider schema). - FsxLustreFileSystemDataReadCacheConfiguration
-
Typed helper for the
data_read_cache_configurationblock ofaws_fsx_lustre_file_system(derived from provider schema). - FsxLustreFileSystemLogConfiguration
-
Typed helper for the
log_configurationblock ofaws_fsx_lustre_file_system(derived from provider schema). - FsxLustreFileSystemMetadataConfiguration
-
Typed helper for the
metadata_configurationblock ofaws_fsx_lustre_file_system(derived from provider schema). - FsxLustreFileSystemRootSquashConfiguration
-
Typed helper for the
root_squash_configurationblock ofaws_fsx_lustre_file_system(derived from provider schema). - FsxOntapFileSystemDiskIopsConfiguration
-
Typed helper for the
disk_iops_configurationblock ofaws_fsx_ontap_file_system(derived from provider schema). - FsxOntapFileSystemThroughputCapacity
-
Exactly one of
throughput_capacity,throughput_capacity_per_ha_paironaws_fsx_ontap_file_system: the provider rejects none and more than one, so each variant sets one of them. - FsxOntapFileSystemThroughputCapacityChoice
-
The FsxOntapFileSystemThroughputCapacity.throughputCapacity choice: sets
throughput_capacity. - FsxOntapFileSystemThroughputCapacityPerHaPair
-
The FsxOntapFileSystemThroughputCapacity.throughputCapacityPerHaPair choice: sets
throughput_capacity_per_ha_pair. - FsxOntapStorageVirtualMachineActiveDirectoryConfiguration
-
Typed helper for the
active_directory_configurationblock ofaws_fsx_ontap_storage_virtual_machine(derived from provider schema). - FsxOntapStorageVirtualMachineSelfManagedActiveDirectoryConfiguration
-
Typed helper for the
active_directory_configuration.self_managed_active_directory_configurationblock ofaws_fsx_ontap_storage_virtual_machine(derived from provider schema). - FsxOntapVolumeAggregateConfiguration
-
Typed helper for the
aggregate_configurationblock ofaws_fsx_ontap_volume(derived from provider schema). - FsxOntapVolumeAutocommitPeriod
-
Typed helper for the
snaplock_configuration.autocommit_periodblock ofaws_fsx_ontap_volume(derived from provider schema). - FsxOntapVolumeDefaultRetention
-
Typed helper for the
snaplock_configuration.retention_period.default_retentionblock ofaws_fsx_ontap_volume(derived from provider schema). - FsxOntapVolumeMaximumRetention
-
Typed helper for the
snaplock_configuration.retention_period.maximum_retentionblock ofaws_fsx_ontap_volume(derived from provider schema). - FsxOntapVolumeMinimumRetention
-
Typed helper for the
snaplock_configuration.retention_period.minimum_retentionblock ofaws_fsx_ontap_volume(derived from provider schema). - FsxOntapVolumeRetentionPeriod
-
Typed helper for the
snaplock_configuration.retention_periodblock ofaws_fsx_ontap_volume(derived from provider schema). - FsxOntapVolumeSize
-
Exactly one of
size_in_bytes,size_in_megabytesonaws_fsx_ontap_volume: the provider rejects none and more than one, so each variant sets one of them. - FsxOntapVolumeSizeInBytes
-
The FsxOntapVolumeSize.sizeInBytes choice: sets
size_in_bytes. - FsxOntapVolumeSizeInMegabytes
-
The FsxOntapVolumeSize.sizeInMegabytes choice: sets
size_in_megabytes. - FsxOntapVolumeSnaplockConfiguration
-
Typed helper for the
snaplock_configurationblock ofaws_fsx_ontap_volume(derived from provider schema). - FsxOntapVolumeTieringPolicy
-
Typed helper for the
tiering_policyblock ofaws_fsx_ontap_volume(derived from provider schema). - FsxOpenzfsFileSystemClientConfigurations
-
Typed helper for the
root_volume_configuration.nfs_exports.client_configurationsblock ofaws_fsx_openzfs_file_system(derived from provider schema). - FsxOpenzfsFileSystemDiskIopsConfiguration
-
Typed helper for the
disk_iops_configurationblock ofaws_fsx_openzfs_file_system(derived from provider schema). - FsxOpenzfsFileSystemNfsExports
-
Typed helper for the
root_volume_configuration.nfs_exportsblock ofaws_fsx_openzfs_file_system(derived from provider schema). - FsxOpenzfsFileSystemReadCacheConfiguration
-
Typed helper for the
read_cache_configurationblock ofaws_fsx_openzfs_file_system(derived from provider schema). - FsxOpenzfsFileSystemRootVolumeConfiguration
-
Typed helper for the
root_volume_configurationblock ofaws_fsx_openzfs_file_system(derived from provider schema). - FsxOpenzfsFileSystemUserAndGroupQuotas
-
Typed helper for the
root_volume_configuration.user_and_group_quotasblock ofaws_fsx_openzfs_file_system(derived from provider schema). - FsxOpenzfsVolumeClientConfigurations
-
Typed helper for the
nfs_exports.client_configurationsblock ofaws_fsx_openzfs_volume(derived from provider schema). - FsxOpenzfsVolumeNfsExports
-
Typed helper for the
nfs_exportsblock ofaws_fsx_openzfs_volume(derived from provider schema). - FsxOpenzfsVolumeOriginSnapshot
-
Typed helper for the
origin_snapshotblock ofaws_fsx_openzfs_volume(derived from provider schema). - FsxOpenzfsVolumeUserAndGroupQuotas
-
Typed helper for the
user_and_group_quotasblock ofaws_fsx_openzfs_volume(derived from provider schema). - FsxS3AccessPointAttachmentFileSystemIdentity
-
Typed helper for the
openzfs_configuration.file_system_identityblock ofaws_fsx_s3_access_point_attachment(derived from provider schema). - FsxS3AccessPointAttachmentOpenzfsConfiguration
-
Typed helper for the
openzfs_configurationblock ofaws_fsx_s3_access_point_attachment(derived from provider schema). - FsxS3AccessPointAttachmentPosixUser
-
Typed helper for the
openzfs_configuration.file_system_identity.posix_userblock ofaws_fsx_s3_access_point_attachment(derived from provider schema). - FsxS3AccessPointAttachmentS3AccessPoint
-
Typed helper for the
s3_access_pointblock ofaws_fsx_s3_access_point_attachment(derived from provider schema). - FsxS3AccessPointAttachmentVpcConfiguration
-
Typed helper for the
s3_access_point.vpc_configurationblock ofaws_fsx_s3_access_point_attachment(derived from provider schema). - FsxWindowsFileSystemActiveDirectory
-
At most one of
active_directory_id,self_managed_active_directoryonaws_fsx_windows_file_system: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - FsxWindowsFileSystemActiveDirectoryId
-
The FsxWindowsFileSystemActiveDirectory.activeDirectoryId choice: sets
active_directory_id. - FsxWindowsFileSystemAuditLogConfiguration
-
Typed helper for the
audit_log_configurationblock ofaws_fsx_windows_file_system(derived from provider schema). - FsxWindowsFileSystemDiskIopsConfiguration
-
Typed helper for the
disk_iops_configurationblock ofaws_fsx_windows_file_system(derived from provider schema). - FsxWindowsFileSystemSelfManagedActiveDirectory
-
Typed helper for the
self_managed_active_directoryblock ofaws_fsx_windows_file_system(derived from provider schema). - FsxWindowsFileSystemSelfManagedActiveDirectoryChoice
-
The FsxWindowsFileSystemActiveDirectory.selfManagedActiveDirectory choice: sets
self_managed_active_directory.
Enums
- FsxDataRepositoryAssociationEvents
-
events— derived from the provider schema description. - FsxFileCacheDeploymentType
-
deployment_type— derived from the provider schema description. - FsxFileCacheType
-
Fsx File Cache enum for
file_cache_type. - FsxFileCacheVersion
-
version— derived from the provider schema description. - FsxLustreFileSystemAutoImportPolicy
-
Fsx Lustre File System Auto Import enum for
auto_import_policy. - FsxLustreFileSystemDataCompressionType
-
Fsx Lustre File System Data Compression enum for
data_compression_type. - FsxLustreFileSystemDeploymentType
-
Fsx Lustre File System Deployment enum for
deployment_type. - FsxLustreFileSystemDriveCacheType
-
Fsx Lustre File System Drive Cache enum for
drive_cache_type. - FsxLustreFileSystemLevel
-
level— derived from the provider schema description. - FsxLustreFileSystemMode
-
mode— derived from the provider schema description. - FsxLustreFileSystemSizingMode
-
sizing_mode— derived from the provider schema description. - FsxLustreFileSystemStorageType
-
Fsx Lustre File System Storage enum for
storage_type. - FsxOntapFileSystemDeploymentType
-
Fsx Ontap File System Deployment enum for
deployment_type. - FsxOntapFileSystemMode
-
mode— derived from the provider schema description. - FsxOntapFileSystemNetworkType
-
Fsx Ontap File System Network enum for
network_type. - FsxOntapFileSystemStorageType
-
Fsx Ontap File System Storage enum for
storage_type. - FsxOntapStorageVirtualMachineRootVolumeSecurityStyle
-
Fsx Ontap Storage Virtual Machine Root Volume Security enum for
root_volume_security_style. - FsxOntapVolumeAutocommitPeriodType
-
type— derived from the provider schema description. - FsxOntapVolumeDefaultRetentionType
-
type— derived from the provider schema description. - FsxOntapVolumeOntapVolumeType
-
Fsx Ontap Volume Ontap Volume enum for
ontap_volume_type. - FsxOntapVolumePrivilegedDelete
-
privileged_delete— derived from the provider schema description. - FsxOntapVolumeSecurityStyle
-
Fsx Ontap Volume Security enum for
security_style. - FsxOntapVolumeSnaplockType
-
snaplock_type— derived from the provider schema description. - FsxOntapVolumeStyle
-
Fsx Ontap Volume enum for
volume_style. - FsxOntapVolumeTieringPolicyName
-
name— derived from the provider schema description. - FsxOntapVolumeType
-
Fsx Ontap Volume enum for
volume_type. - FsxOpenzfsFileSystemDataCompressionType
-
data_compression_type— derived from the provider schema description. - FsxOpenzfsFileSystemDeleteOptions
-
Fsx Openzfs File System Delete enum for
delete_options. - FsxOpenzfsFileSystemDeploymentType
-
Fsx Openzfs File System Deployment enum for
deployment_type. - FsxOpenzfsFileSystemMode
-
mode— derived from the provider schema description. - FsxOpenzfsFileSystemNetworkType
-
Fsx Openzfs File System Network enum for
network_type. - FsxOpenzfsFileSystemSizingMode
-
sizing_mode— derived from the provider schema description. - FsxOpenzfsFileSystemStorageType
-
Fsx Openzfs File System Storage enum for
storage_type. - FsxOpenzfsFileSystemType
-
type— derived from the provider schema description. - FsxOpenzfsVolumeCopyStrategy
-
copy_strategy— derived from the provider schema description. - FsxOpenzfsVolumeDataCompressionType
-
Fsx Openzfs Volume Data Compression enum for
data_compression_type. - FsxOpenzfsVolumeDeleteVolumeOptions
-
Fsx Openzfs Volume Delete Volume enum for
delete_volume_options. - FsxOpenzfsVolumeType
-
Fsx Openzfs Volume enum for
volume_type. - FsxOpenzfsVolumeUserAndGroupQuotasType
-
type— derived from the provider schema description. - FsxS3AccessPointAttachmentFileSystemIdentityType
-
type— derived from the provider schema description. - FsxS3AccessPointAttachmentType
-
Fsx S3 Access Point Attachment enum for
type. - FsxWindowsFileSystemDeploymentType
-
Fsx Windows File System Deployment enum for
deployment_type. - FsxWindowsFileSystemFileAccessAuditLogLevel
-
file_access_audit_log_level— derived from the provider schema description. -
file_share_access_audit_log_level— derived from the provider schema description. - FsxWindowsFileSystemMode
-
mode— derived from the provider schema description. - FsxWindowsFileSystemNetworkType
-
Fsx Windows File System Network enum for
network_type. - FsxWindowsFileSystemStorageType
-
Fsx Windows File System Storage enum for
storage_type.