gamelift library
AWS GameLift.
Classes
- AwsGameliftAlias
-
Factory wrapper for
aws_gamelift_alias. - AwsGameliftBuild
-
Factory wrapper for
aws_gamelift_build. - AwsGameliftFleet
-
Factory wrapper for
aws_gamelift_fleet. - AwsGameliftGameServerGroup
-
Factory wrapper for
aws_gamelift_game_server_group. - AwsGameliftGameSessionQueue
-
Factory wrapper for
aws_gamelift_game_session_queue. - AwsGameliftScript
-
Factory wrapper for
aws_gamelift_script. - GameliftAliasRoutingStrategy
-
Typed helper for the
routing_strategyblock ofaws_gamelift_alias(derived from provider schema). - GameliftBuildStorageLocation
-
Typed helper for the
storage_locationblock ofaws_gamelift_build(derived from provider schema). - GameliftFleetArtifact
-
Exactly one of
build_id,script_idonaws_gamelift_fleet: the provider rejects none and more than one, so each variant sets one of them. - GameliftFleetArtifactBuildId
-
The GameliftFleetArtifact.buildId choice: sets
build_id. - GameliftFleetArtifactScriptId
-
The GameliftFleetArtifact.scriptId choice: sets
script_id. - GameliftFleetCertificateConfiguration
-
Typed helper for the
certificate_configurationblock ofaws_gamelift_fleet(derived from provider schema). - GameliftFleetEc2InboundPermission
-
Typed helper for the
ec2_inbound_permissionblock ofaws_gamelift_fleet(derived from provider schema). - GameliftFleetResourceCreationLimitPolicy
-
Typed helper for the
resource_creation_limit_policyblock ofaws_gamelift_fleet(derived from provider schema). - GameliftFleetRuntimeConfiguration
-
Typed helper for the
runtime_configurationblock ofaws_gamelift_fleet(derived from provider schema). - GameliftFleetServerProcess
-
Typed helper for the
runtime_configuration.server_processblock ofaws_gamelift_fleet(derived from provider schema). - GameliftGameServerGroupAutoScalingPolicy
-
Typed helper for the
auto_scaling_policyblock ofaws_gamelift_game_server_group(derived from provider schema). - GameliftGameServerGroupIdentifier
-
At most one of
id,nameon thelaunch_templateblock ofaws_gamelift_game_server_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - GameliftGameServerGroupIdentifierId
-
The GameliftGameServerGroupIdentifier.id choice: sets
id. - GameliftGameServerGroupIdentifierName
-
The GameliftGameServerGroupIdentifier.name choice: sets
name. - GameliftGameServerGroupInstanceDefinition
-
Typed helper for the
instance_definitionblock ofaws_gamelift_game_server_group(derived from provider schema). - GameliftGameServerGroupLaunchTemplate
-
Typed helper for the
launch_templateblock ofaws_gamelift_game_server_group(derived from provider schema). - GameliftGameServerGroupTargetTrackingConfiguration
-
Typed helper for the
auto_scaling_policy.target_tracking_configurationblock ofaws_gamelift_game_server_group(derived from provider schema). - GameliftGameSessionQueuePlayerLatencyPolicy
-
Typed helper for the
player_latency_policyblock ofaws_gamelift_game_session_queue(derived from provider schema). - GameliftScriptCode
-
Exactly one of
storage_location,zip_fileonaws_gamelift_script: the provider rejects none and more than one, so each variant sets one of them. - GameliftScriptCodeStorageLocation
-
The GameliftScriptCode.storageLocation choice: sets
storage_location. - GameliftScriptCodeZipFile
-
The GameliftScriptCode.zipFile choice: sets
zip_file. - GameliftScriptStorageLocation
-
Typed helper for the
storage_locationblock ofaws_gamelift_script(derived from provider schema).
Enums
- GameliftAliasType
-
type— derived from the provider schema description. - GameliftBuildOperatingSystem
-
Gamelift Build Operating enum for
operating_system. - GameliftFleetCertificateType
-
certificate_type— derived from the provider schema description. - GameliftFleetEc2InstanceType
-
Gamelift Fleet Ec2 Instance enum for
ec2_instance_type. - GameliftFleetNewGameSessionProtectionPolicy
-
Gamelift Fleet New Game Session Protection enum for
new_game_session_protection_policy. - GameliftFleetProtocol
-
protocol— derived from the provider schema description. - GameliftFleetType
-
Gamelift Fleet enum for
fleet_type. - GameliftGameServerGroupBalancingStrategy
-
Gamelift Game Server Group Balancing enum for
balancing_strategy. - GameliftGameServerGroupGameServerProtectionPolicy
-
Gamelift Game Server Group Game Server Protection enum for
game_server_protection_policy. - GameliftGameServerGroupInstanceType
-
instance_type— derived from the provider schema description.