iam library
AWS IAM.
Classes
- AwsIamAccessKey
-
Factory wrapper for
aws_iam_access_key. - AwsIamAccountAlias
-
Factory wrapper for
aws_iam_account_alias. - AwsIamAccountPasswordPolicy
-
Factory wrapper for
aws_iam_account_password_policy. - AwsIamGroup
-
Factory wrapper for
aws_iam_group. - AwsIamGroupMembership
-
Factory wrapper for
aws_iam_group_membership. - AwsIamGroupPoliciesExclusive
-
Factory wrapper for
aws_iam_group_policies_exclusive. - AwsIamGroupPolicy
-
Factory wrapper for
aws_iam_group_policy. - AwsIamGroupPolicyAttachment
-
Factory wrapper for
aws_iam_group_policy_attachment. - AwsIamGroupPolicyAttachmentsExclusive
-
Factory wrapper for
aws_iam_group_policy_attachments_exclusive. - AwsIamInstanceProfile
-
Factory wrapper for
aws_iam_instance_profile. - AwsIamOpenidConnectProvider
-
Factory wrapper for
aws_iam_openid_connect_provider. - AwsIamOrganizationsFeatures
-
Factory wrapper for
aws_iam_organizations_features. - AwsIamOutboundWebIdentityFederation
-
Factory wrapper for
aws_iam_outbound_web_identity_federation. - AwsIamPolicy
-
Factory wrapper for
aws_iam_policy. - AwsIamPolicyAttachment
-
Factory wrapper for
aws_iam_policy_attachment. - AwsIamRole
-
Factory wrapper for
aws_iam_role. - AwsIamRolePoliciesExclusive
-
Factory wrapper for
aws_iam_role_policies_exclusive. - AwsIamRolePolicy
-
Factory wrapper for
aws_iam_role_policy. - AwsIamRolePolicyAttachment
-
Factory wrapper for
aws_iam_role_policy_attachment. - AwsIamRolePolicyAttachmentsExclusive
-
Factory wrapper for
aws_iam_role_policy_attachments_exclusive. - AwsIamSamlProvider
-
Factory wrapper for
aws_iam_saml_provider. - AwsIamSecurityTokenServicePreferences
-
Factory wrapper for
aws_iam_security_token_service_preferences. - AwsIamServerCertificate
-
Factory wrapper for
aws_iam_server_certificate. - AwsIamServiceLinkedRole
-
Factory wrapper for
aws_iam_service_linked_role. - AwsIamServiceSpecificCredential
-
Factory wrapper for
aws_iam_service_specific_credential. - AwsIamSigningCertificate
-
Factory wrapper for
aws_iam_signing_certificate. - AwsIamUser
-
Factory wrapper for
aws_iam_user. - AwsIamUserGroupMembership
-
Factory wrapper for
aws_iam_user_group_membership. - AwsIamUserLoginProfile
-
Factory wrapper for
aws_iam_user_login_profile. - AwsIamUserPoliciesExclusive
-
Factory wrapper for
aws_iam_user_policies_exclusive. - AwsIamUserPolicy
-
Factory wrapper for
aws_iam_user_policy. - AwsIamUserPolicyAttachment
-
Factory wrapper for
aws_iam_user_policy_attachment. - AwsIamUserPolicyAttachmentsExclusive
-
Factory wrapper for
aws_iam_user_policy_attachments_exclusive. - AwsIamUserSshKey
-
Factory wrapper for
aws_iam_user_ssh_key. - AwsIamVirtualMfaDevice
-
Factory wrapper for
aws_iam_virtual_mfa_device. - IamGroupPolicyName
-
At most one of
name,name_prefixonaws_iam_group_policy: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - IamGroupPolicyNameChoice
-
The IamGroupPolicyName.name choice: sets
name. - IamGroupPolicyNamePrefix
-
The IamGroupPolicyName.namePrefix choice: sets
name_prefix. - IamInstanceProfileName
-
At most one of
name,name_prefixonaws_iam_instance_profile: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - IamInstanceProfileNameChoice
-
The IamInstanceProfileName.name choice: sets
name. - IamInstanceProfileNamePrefix
-
The IamInstanceProfileName.namePrefix choice: sets
name_prefix. - IamPolicyName
-
At most one of
name,name_prefixonaws_iam_policy: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - IamPolicyNameChoice
-
The IamPolicyName.name choice: sets
name. - IamPolicyNamePrefix
-
The IamPolicyName.namePrefix choice: sets
name_prefix. - IamRoleInlinePolicy
-
Typed helper for the
inline_policyblock ofaws_iam_role(derived from provider schema). - IamRoleName
-
At most one of
name,name_prefixonaws_iam_role: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - IamRoleNameChoice
-
The IamRoleName.name choice: sets
name. - IamRoleNamePrefix
-
The IamRoleName.namePrefix choice: sets
name_prefix. - IamRolePolicyName
-
At most one of
name,name_prefixonaws_iam_role_policy: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - IamRolePolicyNameChoice
-
The IamRolePolicyName.name choice: sets
name. - IamRolePolicyNamePrefix
-
The IamRolePolicyName.namePrefix choice: sets
name_prefix. - IamServerCertificateName
-
At most one of
name,name_prefixonaws_iam_server_certificate: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - IamServerCertificateNameChoice
-
The IamServerCertificateName.name choice: sets
name. - IamServerCertificateNamePrefix
-
The IamServerCertificateName.namePrefix choice: sets
name_prefix. - IamUserPolicyName
-
At most one of
name,name_prefixonaws_iam_user_policy: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - IamUserPolicyNameChoice
-
The IamUserPolicyName.name choice: sets
name. - IamUserPolicyNamePrefix
-
The IamUserPolicyName.namePrefix choice: sets
name_prefix.
Enums
- IamAccessKeyStatus
-
Iam Access Key enum for
status. - IamOrganizationsFeaturesEnabledFeatures
-
Iam Organizations Features Enabled enum for
enabled_features. - IamSecurityTokenServicePreferencesGlobalEndpointTokenVersion
-
Iam Security Token Service Preferences Global Endpoint Token enum for
global_endpoint_token_version. - IamServiceSpecificCredentialStatus
-
Iam Service Specific Credential enum for
status. - IamSigningCertificateStatus
-
Iam Signing Certificate enum for
status. - IamUserSshKeyEncoding
-
Iam User Ssh Key enum for
encoding.