imagebuilder library
AWS EC2 Image Builder.
Classes
- AwsImagebuilderComponent
-
Factory wrapper for
aws_imagebuilder_component. - AwsImagebuilderContainerRecipe
-
Factory wrapper for
aws_imagebuilder_container_recipe. - AwsImagebuilderDistributionConfiguration
-
Factory wrapper for
aws_imagebuilder_distribution_configuration. - AwsImagebuilderImage
-
Factory wrapper for
aws_imagebuilder_image. - AwsImagebuilderImagePipeline
-
Factory wrapper for
aws_imagebuilder_image_pipeline. - AwsImagebuilderImageRecipe
-
Factory wrapper for
aws_imagebuilder_image_recipe. - AwsImagebuilderInfrastructureConfiguration
-
Factory wrapper for
aws_imagebuilder_infrastructure_configuration. - AwsImagebuilderLifecyclePolicy
-
Factory wrapper for
aws_imagebuilder_lifecycle_policy. - AwsImagebuilderWorkflow
-
Factory wrapper for
aws_imagebuilder_workflow. - ImagebuilderComponentDocument
-
Exactly one of
data,urionaws_imagebuilder_component: the provider rejects none and more than one, so each variant sets one of them. - ImagebuilderComponentDocumentData
-
The ImagebuilderComponentDocument.data choice: sets
data. - ImagebuilderComponentDocumentUri
-
The ImagebuilderComponentDocument.uri choice: sets
uri. - ImagebuilderContainerRecipeBlockDeviceMapping
-
Typed helper for the
instance_configuration.block_device_mappingblock ofaws_imagebuilder_container_recipe(derived from provider schema). - ImagebuilderContainerRecipeComponent
-
Typed helper for the
componentblock ofaws_imagebuilder_container_recipe(derived from provider schema). - ImagebuilderContainerRecipeDockerfileTemplate
-
Exactly one of
dockerfile_template_data,dockerfile_template_urionaws_imagebuilder_container_recipe: the provider rejects none and more than one, so each variant sets one of them. - ImagebuilderContainerRecipeDockerfileTemplateData
-
The ImagebuilderContainerRecipeDockerfileTemplate.dockerfileTemplateData choice: sets
dockerfile_template_data. - ImagebuilderContainerRecipeDockerfileTemplateUri
-
The ImagebuilderContainerRecipeDockerfileTemplate.dockerfileTemplateUri choice: sets
dockerfile_template_uri. - ImagebuilderContainerRecipeEbs
-
Typed helper for the
instance_configuration.block_device_mapping.ebsblock ofaws_imagebuilder_container_recipe(derived from provider schema). - ImagebuilderContainerRecipeInstanceConfiguration
-
Typed helper for the
instance_configurationblock ofaws_imagebuilder_container_recipe(derived from provider schema). - ImagebuilderContainerRecipeParameter
-
Typed helper for the
component.parameterblock ofaws_imagebuilder_container_recipe(derived from provider schema). - ImagebuilderContainerRecipeTargetRepository
-
Typed helper for the
target_repositoryblock ofaws_imagebuilder_container_recipe(derived from provider schema). - ImagebuilderDistributionConfigurationAmiDistributionConfiguration
-
Typed helper for the
distribution.ami_distribution_configurationblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderDistributionConfigurationContainerDistributionConfiguration
-
Typed helper for the
distribution.container_distribution_configurationblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderDistributionConfigurationDistribution
-
Typed helper for the
distributionblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderDistributionConfigurationFastLaunchConfiguration
-
Typed helper for the
distribution.fast_launch_configurationblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderDistributionConfigurationLaunchPermission
-
Typed helper for the
distribution.ami_distribution_configuration.launch_permissionblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderDistributionConfigurationLaunchTemplate
-
Typed helper for the
distribution.fast_launch_configuration.launch_templateblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderDistributionConfigurationLaunchTemplateConfiguration
-
Typed helper for the
distribution.launch_template_configurationblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderDistributionConfigurationS3ExportConfiguration
-
Typed helper for the
distribution.s3_export_configurationblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderDistributionConfigurationSnapshotConfiguration
-
Typed helper for the
distribution.fast_launch_configuration.snapshot_configurationblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderDistributionConfigurationSsmParameterConfiguration
-
Typed helper for the
distribution.ssm_parameter_configurationblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderDistributionConfigurationTargetRepository
-
Typed helper for the
distribution.container_distribution_configuration.target_repositoryblock ofaws_imagebuilder_distribution_configuration(derived from provider schema). - ImagebuilderImageContainerRecipeArn
-
The ImagebuilderImageRecipeArn.containerRecipeArn choice: sets
container_recipe_arn. - ImagebuilderImageEcrConfiguration
-
Typed helper for the
image_scanning_configuration.ecr_configurationblock ofaws_imagebuilder_image(derived from provider schema). - ImagebuilderImageLoggingConfiguration
-
Typed helper for the
logging_configurationblock ofaws_imagebuilder_image(derived from provider schema). - ImagebuilderImageParameter
-
Typed helper for the
workflow.parameterblock ofaws_imagebuilder_image(derived from provider schema). - ImagebuilderImagePipelineContainerRecipeArn
-
The ImagebuilderImagePipelineRecipeArn.containerRecipeArn choice: sets
container_recipe_arn. - ImagebuilderImagePipelineEcrConfiguration
-
Typed helper for the
image_scanning_configuration.ecr_configurationblock ofaws_imagebuilder_image_pipeline(derived from provider schema). - ImagebuilderImagePipelineImageRecipeArn
-
The ImagebuilderImagePipelineRecipeArn.imageRecipeArn choice: sets
image_recipe_arn. - ImagebuilderImagePipelineImageScanningConfiguration
-
Typed helper for the
image_scanning_configurationblock ofaws_imagebuilder_image_pipeline(derived from provider schema). - ImagebuilderImagePipelineImageTestsConfiguration
-
Typed helper for the
image_tests_configurationblock ofaws_imagebuilder_image_pipeline(derived from provider schema). - ImagebuilderImagePipelineLoggingConfiguration
-
Typed helper for the
logging_configurationblock ofaws_imagebuilder_image_pipeline(derived from provider schema). - ImagebuilderImagePipelineParameter
-
Typed helper for the
workflow.parameterblock ofaws_imagebuilder_image_pipeline(derived from provider schema). - ImagebuilderImagePipelineRecipeArn
-
Exactly one of
container_recipe_arn,image_recipe_arnonaws_imagebuilder_image_pipeline: the provider rejects none and more than one, so each variant sets one of them. - ImagebuilderImagePipelineSchedule
-
Typed helper for the
scheduleblock ofaws_imagebuilder_image_pipeline(derived from provider schema). - ImagebuilderImagePipelineWorkflow
-
Typed helper for the
workflowblock ofaws_imagebuilder_image_pipeline(derived from provider schema). - ImagebuilderImageRecipeArn
-
Exactly one of
container_recipe_arn,image_recipe_arnonaws_imagebuilder_image: the provider rejects none and more than one, so each variant sets one of them. - ImagebuilderImageRecipeArnChoice
-
The ImagebuilderImageRecipeArn.imageRecipeArn choice: sets
image_recipe_arn. - ImagebuilderImageRecipeBlockDeviceMapping
-
Typed helper for the
block_device_mappingblock ofaws_imagebuilder_image_recipe(derived from provider schema). - ImagebuilderImageRecipeComponent
-
Typed helper for the
componentblock ofaws_imagebuilder_image_recipe(derived from provider schema). - ImagebuilderImageRecipeEbs
-
Typed helper for the
block_device_mapping.ebsblock ofaws_imagebuilder_image_recipe(derived from provider schema). - ImagebuilderImageRecipeParameter
-
Typed helper for the
component.parameterblock ofaws_imagebuilder_image_recipe(derived from provider schema). - ImagebuilderImageRecipeSystemsManagerAgent
-
Typed helper for the
systems_manager_agentblock ofaws_imagebuilder_image_recipe(derived from provider schema). - ImagebuilderImageScanningConfiguration
-
Typed helper for the
image_scanning_configurationblock ofaws_imagebuilder_image(derived from provider schema). - ImagebuilderImageTestsConfiguration
-
Typed helper for the
image_tests_configurationblock ofaws_imagebuilder_image(derived from provider schema). - ImagebuilderImageWorkflow
-
Typed helper for the
workflowblock ofaws_imagebuilder_image(derived from provider schema). - ImagebuilderInfrastructureConfigurationHost
-
At most one of
host_id,host_resource_group_arnon theplacementblock ofaws_imagebuilder_infrastructure_configuration: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - ImagebuilderInfrastructureConfigurationHostId
-
The ImagebuilderInfrastructureConfigurationHost.hostId choice: sets
host_id. - ImagebuilderInfrastructureConfigurationHostResourceGroupArn
-
The ImagebuilderInfrastructureConfigurationHost.hostResourceGroupArn choice: sets
host_resource_group_arn. - ImagebuilderInfrastructureConfigurationInstanceMetadataOptions
-
Typed helper for the
instance_metadata_optionsblock ofaws_imagebuilder_infrastructure_configuration(derived from provider schema). - ImagebuilderInfrastructureConfigurationLogging
-
Typed helper for the
loggingblock ofaws_imagebuilder_infrastructure_configuration(derived from provider schema). - ImagebuilderInfrastructureConfigurationPlacement
-
Typed helper for the
placementblock ofaws_imagebuilder_infrastructure_configuration(derived from provider schema). - ImagebuilderInfrastructureConfigurationS3Logs
-
Typed helper for the
logging.s3_logsblock ofaws_imagebuilder_infrastructure_configuration(derived from provider schema). - ImagebuilderLifecyclePolicyAction
-
Typed helper for the
policy_detail.actionblock ofaws_imagebuilder_lifecycle_policy(derived from provider schema). - ImagebuilderLifecyclePolicyAmis
-
Typed helper for the
policy_detail.exclusion_rules.amisblock ofaws_imagebuilder_lifecycle_policy(derived from provider schema). - ImagebuilderLifecyclePolicyDetail
-
Typed helper for the
policy_detailblock ofaws_imagebuilder_lifecycle_policy(derived from provider schema). - ImagebuilderLifecyclePolicyExclusionRules
-
Typed helper for the
policy_detail.exclusion_rulesblock ofaws_imagebuilder_lifecycle_policy(derived from provider schema). - ImagebuilderLifecyclePolicyFilter
-
Typed helper for the
policy_detail.filterblock ofaws_imagebuilder_lifecycle_policy(derived from provider schema). - ImagebuilderLifecyclePolicyIncludeResources
-
Typed helper for the
policy_detail.action.include_resourcesblock ofaws_imagebuilder_lifecycle_policy(derived from provider schema). - ImagebuilderLifecyclePolicyLastLaunched
-
Typed helper for the
policy_detail.exclusion_rules.amis.last_launchedblock ofaws_imagebuilder_lifecycle_policy(derived from provider schema). - ImagebuilderLifecyclePolicyRecipe
-
Typed helper for the
resource_selection.recipeblock ofaws_imagebuilder_lifecycle_policy(derived from provider schema). - ImagebuilderLifecyclePolicyResourceSelection
-
Typed helper for the
resource_selectionblock ofaws_imagebuilder_lifecycle_policy(derived from provider schema). - ImagebuilderWorkflowDocument
-
Exactly one of
data,urionaws_imagebuilder_workflow: the provider rejects none and more than one, so each variant sets one of them. - ImagebuilderWorkflowDocumentData
-
The ImagebuilderWorkflowDocument.data choice: sets
data. - ImagebuilderWorkflowDocumentUri
-
The ImagebuilderWorkflowDocument.uri choice: sets
uri.
Enums
- ImagebuilderComponentPlatform
-
Imagebuilder Component enum for
platform. - ImagebuilderContainerRecipeContainerType
-
Imagebuilder Container Recipe Container enum for
container_type. - ImagebuilderContainerRecipePlatformOverride
-
Imagebuilder Container Recipe Platform enum for
platform_override. - ImagebuilderContainerRecipeService
-
service— derived from the provider schema description. - ImagebuilderContainerRecipeVolumeType
-
volume_type— derived from the provider schema description. - ImagebuilderDistributionConfigurationDataType
-
data_type— derived from the provider schema description. - ImagebuilderDistributionConfigurationDiskImageFormat
-
disk_image_format— derived from the provider schema description. - ImagebuilderDistributionConfigurationService
-
service— derived from the provider schema description. - ImagebuilderImageOnFailure
-
on_failure— derived from the provider schema description. - ImagebuilderImagePipelineExecutionStartCondition
-
pipeline_execution_start_condition— derived from the provider schema description. - ImagebuilderImagePipelineOnFailure
-
on_failure— derived from the provider schema description. - ImagebuilderImagePipelineStatus
-
Imagebuilder Image Pipeline enum for
status. - ImagebuilderImageRecipeVolumeType
-
volume_type— derived from the provider schema description. - ImagebuilderInfrastructureConfigurationHttpTokens
-
http_tokens— derived from the provider schema description. - ImagebuilderInfrastructureConfigurationTenancy
-
tenancy— derived from the provider schema description. - ImagebuilderLifecyclePolicyActionType
-
type— derived from the provider schema description. - ImagebuilderLifecyclePolicyFilterType
-
type— derived from the provider schema description. - ImagebuilderLifecyclePolicyResourceType
-
Imagebuilder Lifecycle Policy Resource enum for
resource_type. - ImagebuilderLifecyclePolicyUnit
-
unit— derived from the provider schema description. - ImagebuilderWorkflowType
-
Imagebuilder Workflow enum for
type.