kendra library
AWS Kendra.
Classes
- AwsKendraDataSource
-
Factory wrapper for
aws_kendra_data_source. - AwsKendraExperience
-
Factory wrapper for
aws_kendra_experience. - AwsKendraFaq
-
Factory wrapper for
aws_kendra_faq. - AwsKendraIndex
-
Factory wrapper for
aws_kendra_index. - AwsKendraQuerySuggestionsBlockList
-
Factory wrapper for
aws_kendra_query_suggestions_block_list. - AwsKendraThesaurus
-
Factory wrapper for
aws_kendra_thesaurus. - KendraDataSourceAccessControlListConfiguration
-
Typed helper for the
configuration.s3_configuration.access_control_list_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceAuthenticationConfiguration
-
Typed helper for the
configuration.web_crawler_configuration.authentication_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceBasicAuthentication
-
Typed helper for the
configuration.web_crawler_configuration.authentication_configuration.basic_authenticationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceCondition
-
Typed helper for the
custom_document_enrichment_configuration.inline_configurations.conditionblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceConditionOnValue
-
Typed helper for the
custom_document_enrichment_configuration.inline_configurations.condition.condition_on_valueblock ofaws_kendra_data_source(derived from provider schema). Shared by every block of this shape in the resource. - KendraDataSourceConfiguration
-
Typed helper for the
configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceCustomDocumentEnrichmentConfiguration
-
Typed helper for the
custom_document_enrichment_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceDocumentsMetadataConfiguration
-
Typed helper for the
configuration.s3_configuration.documents_metadata_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceInlineConfigurations
-
Typed helper for the
custom_document_enrichment_configuration.inline_configurationsblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceInvocationCondition
-
Typed helper for the
custom_document_enrichment_configuration.post_extraction_hook_configuration.invocation_conditionblock ofaws_kendra_data_source(derived from provider schema). Shared by every block of this shape in the resource. - KendraDataSourcePostExtractionHookConfiguration
-
Typed helper for the
custom_document_enrichment_configuration.post_extraction_hook_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourcePreExtractionHookConfiguration
-
Typed helper for the
custom_document_enrichment_configuration.pre_extraction_hook_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceProxyConfiguration
-
Typed helper for the
configuration.web_crawler_configuration.proxy_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceS3Configuration
-
Typed helper for the
configuration.s3_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceSeedUrlConfiguration
-
Typed helper for the
configuration.web_crawler_configuration.urls.seed_url_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceSiteMapsConfiguration
-
Typed helper for the
configuration.web_crawler_configuration.urls.site_maps_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceTarget
-
Typed helper for the
custom_document_enrichment_configuration.inline_configurations.targetblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceTargetDocumentAttributeValue
-
Typed helper for the
custom_document_enrichment_configuration.inline_configurations.target.target_document_attribute_valueblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceTemplateConfiguration
-
Typed helper for the
configuration.template_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceUrls
-
Typed helper for the
configuration.web_crawler_configuration.urlsblock ofaws_kendra_data_source(derived from provider schema). - KendraDataSourceWebCrawlerConfiguration
-
Typed helper for the
configuration.web_crawler_configurationblock ofaws_kendra_data_source(derived from provider schema). - KendraExperienceConfiguration
-
Typed helper for the
configurationblock ofaws_kendra_experience(derived from provider schema). - KendraExperienceContentSourceConfiguration
-
Typed helper for the
configuration.content_source_configurationblock ofaws_kendra_experience(derived from provider schema). - KendraExperienceUserIdentityConfiguration
-
Typed helper for the
configuration.user_identity_configurationblock ofaws_kendra_experience(derived from provider schema). - KendraFaqS3Path
-
Typed helper for the
s3_pathblock ofaws_kendra_faq(derived from provider schema). - KendraIndexCapacityUnits
-
Typed helper for the
capacity_unitsblock ofaws_kendra_index(derived from provider schema). - KendraIndexDocumentMetadataConfigurationUpdates
-
Typed helper for the
document_metadata_configuration_updatesblock ofaws_kendra_index(derived from provider schema). - KendraIndexJsonTokenTypeConfiguration
-
Typed helper for the
user_token_configurations.json_token_type_configurationblock ofaws_kendra_index(derived from provider schema). - KendraIndexJwtTokenTypeConfiguration
-
Typed helper for the
user_token_configurations.jwt_token_type_configurationblock ofaws_kendra_index(derived from provider schema). - KendraIndexRelevance
-
Typed helper for the
document_metadata_configuration_updates.relevanceblock ofaws_kendra_index(derived from provider schema). - KendraIndexSearch
-
Typed helper for the
document_metadata_configuration_updates.searchblock ofaws_kendra_index(derived from provider schema). - KendraIndexServerSideEncryptionConfiguration
-
Typed helper for the
server_side_encryption_configurationblock ofaws_kendra_index(derived from provider schema). - KendraIndexUserGroupResolutionConfiguration
-
Typed helper for the
user_group_resolution_configurationblock ofaws_kendra_index(derived from provider schema). - KendraIndexUserTokenConfigurations
-
Typed helper for the
user_token_configurationsblock ofaws_kendra_index(derived from provider schema). - KendraQuerySuggestionsBlockListSourceS3Path
-
Typed helper for the
source_s3_pathblock ofaws_kendra_query_suggestions_block_list(derived from provider schema). - KendraThesaurusSourceS3Path
-
Typed helper for the
source_s3_pathblock ofaws_kendra_thesaurus(derived from provider schema).
Enums
- KendraDataSourceType
-
Kendra Data Source enum for
type. - KendraDataSourceWebCrawlerMode
-
web_crawler_mode— derived from the provider schema description. - KendraFaqFileFormat
-
Kendra Faq File enum for
file_format. - KendraIndexEdition
-
Kendra Index enum for
edition. - KendraIndexKeyLocation
-
key_location— derived from the provider schema description. - KendraIndexRankOrder
-
rank_order— derived from the provider schema description. - KendraIndexType
-
type— derived from the provider schema description. - KendraIndexUserContextPolicy
-
Kendra Index User Context enum for
user_context_policy. - KendraIndexUserGroupResolutionMode
-
user_group_resolution_mode— derived from the provider schema description.