kms library
AWS Key Management Service (KMS).
Classes
- AwsKmsAlias
-
Factory wrapper for
aws_kms_alias. - AwsKmsCiphertext
-
Factory wrapper for
aws_kms_ciphertext. - AwsKmsCustomKeyStore
-
Factory wrapper for
aws_kms_custom_key_store. - AwsKmsExternalKey
-
Factory wrapper for
aws_kms_external_key. - AwsKmsGrant
-
Factory wrapper for
aws_kms_grant. - AwsKmsKey
-
Factory wrapper for
aws_kms_key. - AwsKmsKeyPolicy
-
Factory wrapper for
aws_kms_key_policy. - AwsKmsReplicaExternalKey
-
Factory wrapper for
aws_kms_replica_external_key. - AwsKmsReplicaKey
-
Factory wrapper for
aws_kms_replica_key. - KmsAliasName
-
At most one of
name,name_prefixonaws_kms_alias: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - KmsAliasNameChoice
-
The KmsAliasName.name choice: sets
name. - KmsAliasNamePrefix
-
The KmsAliasName.namePrefix choice: sets
name_prefix. - KmsCiphertextPlaintext
-
Exactly one of
plaintext,plaintext_woonaws_kms_ciphertext: the provider rejects none and more than one, so each variant sets one of them. - KmsCiphertextPlaintextChoice
-
The KmsCiphertextPlaintext.plaintext choice: sets
plaintext. - KmsCiphertextPlaintextWo
-
The KmsCiphertextPlaintext.plaintextWo choice: sets
plaintext_wo. - KmsCustomKeyStoreXksProxyAuthenticationCredential
-
Typed helper for the
xks_proxy_authentication_credentialblock ofaws_kms_custom_key_store(derived from provider schema). - KmsGrantConstraints
-
Typed helper for the
constraintsblock ofaws_kms_grant(derived from provider schema).
Enums
- KmsCustomKeyStoreType
-
Kms Custom Key Store enum for
custom_key_store_type. - KmsCustomKeyStoreXksProxyConnectivity
-
Kms Custom Key Store Xks Proxy enum for
xks_proxy_connectivity. - KmsExternalKeySpec
-
Kms External Key enum for
key_spec. - KmsExternalKeyUsage
-
Kms External Key enum for
key_usage. - KmsGrantOperations
-
Kms Grant enum for
operations. - KmsKeyCustomerMasterKeySpec
-
Kms Key Customer Master Key enum for
customer_master_key_spec. - KmsKeyUsage
-
Kms Key enum for
key_usage.