lexv2models library
AWS Lex V2.
Classes
- AwsLexv2modelsBot
-
Factory wrapper for
aws_lexv2models_bot. - AwsLexv2modelsBotLocale
-
Factory wrapper for
aws_lexv2models_bot_locale. - AwsLexv2modelsBotVersion
-
Factory wrapper for
aws_lexv2models_bot_version. - AwsLexv2modelsIntent
-
Factory wrapper for
aws_lexv2models_intent. - AwsLexv2modelsSlot
-
Factory wrapper for
aws_lexv2models_slot. - AwsLexv2modelsSlotType
-
Factory wrapper for
aws_lexv2models_slot_type. - Lexv2modelsBotDataPrivacy
-
Typed helper for the
data_privacyblock ofaws_lexv2models_bot(derived from provider schema). - Lexv2modelsBotLocaleVoiceSettings
-
Typed helper for the
voice_settingsblock ofaws_lexv2models_bot_locale(derived from provider schema). - Lexv2modelsBotMembers
-
Typed helper for the
membersblock ofaws_lexv2models_bot(derived from provider schema). - Lexv2modelsIntent
-
Typed helper for the
closing_setting.next_step.intentblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentAllowedInputTypes
-
Typed helper for the
confirmation_setting.prompt_specification.prompt_attempts_specification.allowed_input_typesblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentAudioAndDtmfInputSpecification
-
Typed helper for the
confirmation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specificationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentAudioSpecification
-
Typed helper for the
confirmation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specification.audio_specificationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentBedrockKnowledgeStoreConfiguration
-
Typed helper for the
qna_intent_configuration.data_source_configuration.bedrock_knowledge_store_configurationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentBedrockKnowledgeStoreConfigurationExactResponseFields
-
Typed helper for the
qna_intent_configuration.data_source_configuration.bedrock_knowledge_store_configuration.exact_response_fieldsblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentBedrockModelConfiguration
-
Typed helper for the
qna_intent_configuration.bedrock_model_configurationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentButton
-
Typed helper for the
closing_setting.closing_response.message_group.message.image_response_card.buttonblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentClosingResponse
-
Typed helper for the
closing_setting.closing_responseblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentClosingSetting
-
Typed helper for the
closing_settingblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentCodeHook
-
Typed helper for the
confirmation_setting.code_hookblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentCondition
-
Typed helper for the
closing_setting.conditional.conditional_branch.conditionblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentConditional
-
Typed helper for the
closing_setting.conditionalblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentConditionalBranch
-
Typed helper for the
closing_setting.conditional.conditional_branchblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentConfirmationConditional
-
Typed helper for the
confirmation_setting.confirmation_conditionalblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentConfirmationNextStep
-
Typed helper for the
confirmation_setting.confirmation_next_stepblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentConfirmationResponse
-
Typed helper for the
confirmation_setting.confirmation_responseblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentConfirmationSetting
-
Typed helper for the
confirmation_settingblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentCustomPayload
-
Typed helper for the
closing_setting.closing_response.message_group.message.custom_payloadblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentDataSourceConfiguration
-
Typed helper for the
qna_intent_configuration.data_source_configurationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentDataSourceConfigurationKendraConfiguration
-
Typed helper for the
qna_intent_configuration.data_source_configuration.kendra_configurationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentDeclinationConditional
-
Typed helper for the
confirmation_setting.declination_conditionalblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentDeclinationNextStep
-
Typed helper for the
confirmation_setting.declination_next_stepblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentDeclinationResponse
-
Typed helper for the
confirmation_setting.declination_responseblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentDefaultBranch
-
Typed helper for the
closing_setting.conditional.default_branchblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentDialogAction
-
Typed helper for the
closing_setting.next_step.dialog_actionblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentDialogCodeHook
-
Typed helper for the
dialog_code_hookblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentDtmfSpecification
-
Typed helper for the
confirmation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specification.dtmf_specificationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentElicitationCodeHook
-
Typed helper for the
confirmation_setting.elicitation_code_hookblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentFailureConditional
-
Typed helper for the
confirmation_setting.failure_conditionalblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentFailureNextStep
-
Typed helper for the
confirmation_setting.failure_next_stepblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentFailureResponse
-
Typed helper for the
confirmation_setting.failure_responseblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentFulfillmentCodeHook
-
Typed helper for the
fulfillment_code_hookblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentFulfillmentUpdatesSpecification
-
Typed helper for the
fulfillment_code_hook.fulfillment_updates_specificationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentGuardrail
-
Typed helper for the
qna_intent_configuration.bedrock_model_configuration.guardrailblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentImageResponseCard
-
Typed helper for the
closing_setting.closing_response.message_group.message.image_response_cardblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentInitialResponse
-
Typed helper for the
initial_response_setting.initial_responseblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentInitialResponseSetting
-
Typed helper for the
initial_response_settingblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentInputContext
-
Typed helper for the
input_contextblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentKendraConfiguration
-
Typed helper for the
kendra_configurationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentMessage
-
Typed helper for the
closing_setting.closing_response.message_group.messageblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentMessageGroup
-
Typed helper for the
closing_setting.closing_response.message_groupblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentNextStep
-
Typed helper for the
closing_setting.next_stepblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentOpensearchConfiguration
-
Typed helper for the
qna_intent_configuration.data_source_configuration.opensearch_configurationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentOpensearchConfigurationExactResponseFields
-
Typed helper for the
qna_intent_configuration.data_source_configuration.opensearch_configuration.exact_response_fieldsblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentOutputContext
-
Typed helper for the
output_contextblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentPlainTextMessage
-
Typed helper for the
closing_setting.closing_response.message_group.message.plain_text_messageblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentPostCodeHookSpecification
-
Typed helper for the
confirmation_setting.code_hook.post_code_hook_specificationblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentPostFulfillmentStatusSpecification
-
Typed helper for the
fulfillment_code_hook.post_fulfillment_status_specificationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentPromptAttemptsSpecification
-
Typed helper for the
confirmation_setting.prompt_specification.prompt_attempts_specificationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentPromptSpecification
-
Typed helper for the
confirmation_setting.prompt_specificationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentQnaIntentConfiguration
-
Typed helper for the
qna_intent_configurationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentResponse
-
Typed helper for the
closing_setting.conditional.conditional_branch.responseblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentSampleUtterance
-
Typed helper for the
sample_utteranceblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentSlot
-
Typed helper for the
closing_setting.next_step.intent.slotblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentSlotPriority
-
Typed helper for the
slot_priorityblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentSsmlMessage
-
Typed helper for the
closing_setting.closing_response.message_group.message.ssml_messageblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentStartResponse
-
Typed helper for the
fulfillment_code_hook.fulfillment_updates_specification.start_responseblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentSuccessConditional
-
Typed helper for the
fulfillment_code_hook.post_fulfillment_status_specification.success_conditionalblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentSuccessNextStep
-
Typed helper for the
fulfillment_code_hook.post_fulfillment_status_specification.success_next_stepblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentSuccessResponse
-
Typed helper for the
fulfillment_code_hook.post_fulfillment_status_specification.success_responseblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentTextInputSpecification
-
Typed helper for the
confirmation_setting.prompt_specification.prompt_attempts_specification.text_input_specificationblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentTimeoutConditional
-
Typed helper for the
fulfillment_code_hook.post_fulfillment_status_specification.timeout_conditionalblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentTimeoutNextStep
-
Typed helper for the
fulfillment_code_hook.post_fulfillment_status_specification.timeout_next_stepblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentTimeoutResponse
-
Typed helper for the
fulfillment_code_hook.post_fulfillment_status_specification.timeout_responseblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentUpdateResponse
-
Typed helper for the
fulfillment_code_hook.fulfillment_updates_specification.update_responseblock ofaws_lexv2models_intent(derived from provider schema). - Lexv2modelsIntentValue
-
Typed helper for the
closing_setting.next_step.intent.slot.valueblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsIntentVariation
-
Typed helper for the
closing_setting.closing_response.message_group.variationblock ofaws_lexv2models_intent(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotAllowedInputTypes
-
Typed helper for the
value_elicitation_setting.prompt_specification.prompt_attempts_specification.allowed_input_typesblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotAudioAndDtmfInputSpecification
-
Typed helper for the
value_elicitation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specificationblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotAudioSpecification
-
Typed helper for the
value_elicitation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specification.audio_specificationblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotButton
-
Typed helper for the
value_elicitation_setting.prompt_specification.message_group.message.image_response_card.buttonblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotContinueResponse
-
Typed helper for the
value_elicitation_setting.wait_and_continue_specification.continue_responseblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotCustomPayload
-
Typed helper for the
value_elicitation_setting.prompt_specification.message_group.message.custom_payloadblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotDefaultValueList
-
Typed helper for the
value_elicitation_setting.default_value_specification.default_value_listblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotDefaultValueSpecification
-
Typed helper for the
value_elicitation_setting.default_value_specificationblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotDtmfSpecification
-
Typed helper for the
value_elicitation_setting.prompt_specification.prompt_attempts_specification.audio_and_dtmf_input_specification.dtmf_specificationblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotImageResponseCard
-
Typed helper for the
value_elicitation_setting.prompt_specification.message_group.message.image_response_cardblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotMessage
-
Typed helper for the
value_elicitation_setting.prompt_specification.message_group.messageblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotMessageGroup
-
Typed helper for the
value_elicitation_setting.prompt_specification.message_groupblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotMultipleValuesSetting
-
Typed helper for the
multiple_values_settingblock ofaws_lexv2models_slot(derived from provider schema). - Lexv2modelsSlotObfuscationSetting
-
Typed helper for the
obfuscation_settingblock ofaws_lexv2models_slot(derived from provider schema). - Lexv2modelsSlotPlainTextMessage
-
Typed helper for the
value_elicitation_setting.prompt_specification.message_group.message.plain_text_messageblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotPromptAttemptsSpecification
-
Typed helper for the
value_elicitation_setting.prompt_specification.prompt_attempts_specificationblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotPromptSpecification
-
Typed helper for the
value_elicitation_setting.prompt_specificationblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotResolutionSetting
-
Typed helper for the
value_elicitation_setting.slot_resolution_settingblock ofaws_lexv2models_slot(derived from provider schema). - Lexv2modelsSlotSampleUtterance
-
Typed helper for the
value_elicitation_setting.sample_utteranceblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotSpecification
-
Typed helper for the
sub_slot_setting.slot_specificationblock ofaws_lexv2models_slot(derived from provider schema). - Lexv2modelsSlotSpecificationValueElicitationSetting
-
Typed helper for the
sub_slot_setting.slot_specification.value_elicitation_settingblock ofaws_lexv2models_slot(derived from provider schema). - Lexv2modelsSlotSsmlMessage
-
Typed helper for the
value_elicitation_setting.prompt_specification.message_group.message.ssml_messageblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotStillWaitingResponse
-
Typed helper for the
value_elicitation_setting.wait_and_continue_specification.still_waiting_responseblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotSubSlotSetting
-
Typed helper for the
sub_slot_settingblock ofaws_lexv2models_slot(derived from provider schema). - Lexv2modelsSlotTextInputSpecification
-
Typed helper for the
value_elicitation_setting.prompt_specification.prompt_attempts_specification.text_input_specificationblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotTypeAdvancedRecognitionSetting
-
Typed helper for the
value_selection_setting.advanced_recognition_settingblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotTypeCompositeSlotTypeSetting
-
Typed helper for the
composite_slot_type_settingblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotTypeExternalSourceSetting
-
Typed helper for the
external_source_settingblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotTypeGrammarSlotTypeSetting
-
Typed helper for the
external_source_setting.grammar_slot_type_settingblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotTypeRegexFilter
-
Typed helper for the
value_selection_setting.regex_filterblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotTypeSampleValue
-
Typed helper for the
slot_type_values.sample_valueblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotTypeSource
-
Typed helper for the
external_source_setting.grammar_slot_type_setting.sourceblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotTypeSubSlots
-
Typed helper for the
composite_slot_type_setting.sub_slotsblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotTypeSynonyms
-
Typed helper for the
slot_type_values.synonymsblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotTypeValues
-
Typed helper for the
slot_type_valuesblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotTypeValueSelectionSetting
-
Typed helper for the
value_selection_settingblock ofaws_lexv2models_slot_type(derived from provider schema). - Lexv2modelsSlotValueElicitationSetting
-
Typed helper for the
value_elicitation_settingblock ofaws_lexv2models_slot(derived from provider schema). - Lexv2modelsSlotVariation
-
Typed helper for the
value_elicitation_setting.prompt_specification.message_group.variationblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotWaitAndContinueSpecification
-
Typed helper for the
value_elicitation_setting.wait_and_continue_specificationblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource. - Lexv2modelsSlotWaitingResponse
-
Typed helper for the
value_elicitation_setting.wait_and_continue_specification.waiting_responseblock ofaws_lexv2models_slot(derived from provider schema). Shared by every block of this shape in the resource.
Enums
- Lexv2modelsBotLocaleEngine
-
engine— derived from the provider schema description. - Lexv2modelsBotType
-
Lexv2models Bot enum for
type. - Lexv2modelsSlotTypeAudioRecognitionStrategy
-
audio_recognition_strategy— derived from the provider schema description. - Lexv2modelsSlotTypeResolutionStrategy
-
resolution_strategy— derived from the provider schema description.