lightsail library
AWS Lightsail.
Classes
- AwsLightsailBucket
-
Factory wrapper for
aws_lightsail_bucket. - AwsLightsailBucketAccessKey
-
Factory wrapper for
aws_lightsail_bucket_access_key. - AwsLightsailBucketResourceAccess
-
Factory wrapper for
aws_lightsail_bucket_resource_access. - AwsLightsailCertificate
-
Factory wrapper for
aws_lightsail_certificate. - AwsLightsailContainerService
-
Factory wrapper for
aws_lightsail_container_service. - AwsLightsailContainerServiceDeploymentVersion
-
Factory wrapper for
aws_lightsail_container_service_deployment_version. - AwsLightsailDatabase
-
Factory wrapper for
aws_lightsail_database. - AwsLightsailDisk
-
Factory wrapper for
aws_lightsail_disk. - AwsLightsailDiskAttachment
-
Factory wrapper for
aws_lightsail_disk_attachment. - AwsLightsailDistribution
-
Factory wrapper for
aws_lightsail_distribution. - AwsLightsailDomain
-
Factory wrapper for
aws_lightsail_domain. - AwsLightsailDomainEntry
-
Factory wrapper for
aws_lightsail_domain_entry. - AwsLightsailInstance
-
Factory wrapper for
aws_lightsail_instance. - AwsLightsailInstancePublicPorts
-
Factory wrapper for
aws_lightsail_instance_public_ports. - AwsLightsailKeyPair
-
Factory wrapper for
aws_lightsail_key_pair. - AwsLightsailLb
-
Factory wrapper for
aws_lightsail_lb. - AwsLightsailLbAttachment
-
Factory wrapper for
aws_lightsail_lb_attachment. - AwsLightsailLbCertificate
-
Factory wrapper for
aws_lightsail_lb_certificate. - AwsLightsailLbCertificateAttachment
-
Factory wrapper for
aws_lightsail_lb_certificate_attachment. - AwsLightsailLbHttpsRedirectionPolicy
-
Factory wrapper for
aws_lightsail_lb_https_redirection_policy. - AwsLightsailLbStickinessPolicy
-
Factory wrapper for
aws_lightsail_lb_stickiness_policy. - AwsLightsailStaticIp
-
Factory wrapper for
aws_lightsail_static_ip. - AwsLightsailStaticIpAttachment
-
Factory wrapper for
aws_lightsail_static_ip_attachment. - LightsailContainerServiceCertificate
-
Typed helper for the
public_domain_names.certificateblock ofaws_lightsail_container_service(derived from provider schema). - LightsailContainerServiceDeploymentVersionContainer
-
Typed helper for the
containerblock ofaws_lightsail_container_service_deployment_version(derived from provider schema). - LightsailContainerServiceDeploymentVersionHealthCheck
-
Typed helper for the
public_endpoint.health_checkblock ofaws_lightsail_container_service_deployment_version(derived from provider schema). - LightsailContainerServiceDeploymentVersionPublicEndpoint
-
Typed helper for the
public_endpointblock ofaws_lightsail_container_service_deployment_version(derived from provider schema). - LightsailContainerServiceEcrImagePullerRole
-
Typed helper for the
private_registry_access.ecr_image_puller_roleblock ofaws_lightsail_container_service(derived from provider schema). - LightsailContainerServicePrivateRegistryAccess
-
Typed helper for the
private_registry_accessblock ofaws_lightsail_container_service(derived from provider schema). - LightsailContainerServicePublicDomainNames
-
Typed helper for the
public_domain_namesblock ofaws_lightsail_container_service(derived from provider schema). - LightsailDistributionCacheBehavior
-
Typed helper for the
cache_behaviorblock ofaws_lightsail_distribution(derived from provider schema). - LightsailDistributionCacheBehaviorSettings
-
Typed helper for the
cache_behavior_settingsblock ofaws_lightsail_distribution(derived from provider schema). - LightsailDistributionDefaultCacheBehavior
-
Typed helper for the
default_cache_behaviorblock ofaws_lightsail_distribution(derived from provider schema). - LightsailDistributionForwardedCookies
-
Typed helper for the
cache_behavior_settings.forwarded_cookiesblock ofaws_lightsail_distribution(derived from provider schema). - LightsailDistributionForwardedHeaders
-
Typed helper for the
cache_behavior_settings.forwarded_headersblock ofaws_lightsail_distribution(derived from provider schema). - LightsailDistributionForwardedQueryStrings
-
Typed helper for the
cache_behavior_settings.forwarded_query_stringsblock ofaws_lightsail_distribution(derived from provider schema). - LightsailDistributionOrigin
-
Typed helper for the
originblock ofaws_lightsail_distribution(derived from provider schema). - LightsailInstanceAddOn
-
Typed helper for the
add_onblock ofaws_lightsail_instance(derived from provider schema). - LightsailInstancePublicPortsPortInfo
-
Typed helper for the
port_infoblock ofaws_lightsail_instance_public_ports(derived from provider schema). - LightsailKeyPairName
-
At most one of
name,name_prefixonaws_lightsail_key_pair: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - LightsailKeyPairNameChoice
-
The LightsailKeyPairName.name choice: sets
name. - LightsailKeyPairNamePrefix
-
The LightsailKeyPairName.namePrefix choice: sets
name_prefix.
Enums
- LightsailDistributionOption
-
option— derived from the provider schema description. - LightsailDomainEntryType
-
Lightsail Domain Entry enum for
type. - LightsailInstanceStatus
-
status— derived from the provider schema description. - LightsailLbIpAddressType
-
Lightsail Lb Ip Address enum for
ip_address_type.