mailmanager library
AWS SES Mail Manager.
Classes
- AwsMailmanagerArchive
-
Factory wrapper for
aws_mailmanager_archive. - AwsMailmanagerIngressPoint
-
Factory wrapper for
aws_mailmanager_ingress_point. - AwsMailmanagerRelay
-
Factory wrapper for
aws_mailmanager_relay. - AwsMailmanagerRuleSet
-
Factory wrapper for
aws_mailmanager_rule_set. - AwsMailmanagerTrafficPolicy
-
Factory wrapper for
aws_mailmanager_traffic_policy. - MailmanagerArchiveRetention
-
Typed helper for the
retentionblock ofaws_mailmanager_archive(derived from provider schema). - MailmanagerIngressPointConfiguration
-
Typed helper for the
ingress_point_configurationblock ofaws_mailmanager_ingress_point(derived from provider schema). - MailmanagerIngressPointNetworkConfiguration
-
Typed helper for the
network_configurationblock ofaws_mailmanager_ingress_point(derived from provider schema). - MailmanagerIngressPointPrivateNetworkConfiguration
-
Typed helper for the
network_configuration.private_network_configurationblock ofaws_mailmanager_ingress_point(derived from provider schema). - MailmanagerIngressPointPublicNetworkConfiguration
-
Typed helper for the
network_configuration.public_network_configurationblock ofaws_mailmanager_ingress_point(derived from provider schema). - MailmanagerIngressPointTlsAuthConfiguration
-
Typed helper for the
ingress_point_configuration.tls_auth_configurationblock ofaws_mailmanager_ingress_point(derived from provider schema). - MailmanagerIngressPointTrustStore
-
Typed helper for the
ingress_point_configuration.tls_auth_configuration.trust_storeblock ofaws_mailmanager_ingress_point(derived from provider schema). - MailmanagerRelayAuthentication
-
Exactly one of
no_authentication,secret_arnon theauthenticationblock ofaws_mailmanager_relay: the provider rejects none and more than one, so each variant sets one of them. - MailmanagerRelayAuthenticationSecretArn
-
The MailmanagerRelayAuthentication.secretArn choice: sets
secret_arn. - MailmanagerRelayNoAuthentication
-
Typed helper for the
authentication.no_authenticationblock ofaws_mailmanager_relay(derived from provider schema). - MailmanagerRelayNoAuthenticationChoice
-
The MailmanagerRelayAuthentication.noAuthentication choice: sets
no_authentication. - MailmanagerRuleSetAction
-
Typed helper for the
rule.actionblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetAddHeader
-
Typed helper for the
rule.action.add_headerblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetAnalysis
-
Typed helper for the
rule.condition.boolean_expression.evaluate.analysisblock ofaws_mailmanager_rule_set(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerRuleSetArchive
-
Typed helper for the
rule.action.archiveblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetBooleanExpression
-
Typed helper for the
rule.condition.boolean_expressionblock ofaws_mailmanager_rule_set(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerRuleSetBooleanExpressionEvaluate
-
Exactly one of
analysis,attribute,is_in_address_liston therule.condition.boolean_expression.evaluateblock ofaws_mailmanager_rule_set: the provider rejects none and more than one, so each variant sets one of them. - MailmanagerRuleSetBooleanExpressionEvaluateAnalysis
-
The MailmanagerRuleSetBooleanExpressionEvaluate.analysis choice: sets
analysis. - MailmanagerRuleSetBooleanExpressionEvaluateAttribute
-
The MailmanagerRuleSetBooleanExpressionEvaluate.attribute choice: sets
attribute. - MailmanagerRuleSetBooleanExpressionEvaluateIsInAddressList
-
The MailmanagerRuleSetBooleanExpressionEvaluate.isInAddressList choice: sets
is_in_address_list. - MailmanagerRuleSetBounce
-
Typed helper for the
rule.action.bounceblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetCondition
-
Typed helper for the
rule.conditionblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetDeliverToMailbox
-
Typed helper for the
rule.action.deliver_to_mailboxblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetDeliverToQBusiness
-
Typed helper for the
rule.action.deliver_to_q_businessblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetDmarcExpression
-
Typed helper for the
rule.condition.dmarc_expressionblock ofaws_mailmanager_rule_set(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerRuleSetDrop
-
Typed helper for the
rule.action.dropblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetInvokeLambda
-
Typed helper for the
rule.action.invoke_lambdablock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetIpExpression
-
Typed helper for the
rule.condition.ip_expressionblock ofaws_mailmanager_rule_set(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerRuleSetIpExpressionEvaluate
-
Typed helper for the
rule.condition.ip_expression.evaluateblock ofaws_mailmanager_rule_set(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerRuleSetIsInAddressList
-
Typed helper for the
rule.condition.boolean_expression.evaluate.is_in_address_listblock ofaws_mailmanager_rule_set(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerRuleSetNumberExpression
-
Typed helper for the
rule.condition.number_expressionblock ofaws_mailmanager_rule_set(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerRuleSetNumberExpressionEvaluate
-
Typed helper for the
rule.condition.number_expression.evaluateblock ofaws_mailmanager_rule_set(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerRuleSetPublishToSns
-
Typed helper for the
rule.action.publish_to_snsblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetRelay
-
Typed helper for the
rule.action.relayblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetReplaceRecipient
-
Typed helper for the
rule.action.replace_recipientblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetRule
-
Typed helper for the
ruleblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetSend
-
Typed helper for the
rule.action.sendblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetStringExpression
-
Typed helper for the
rule.condition.string_expressionblock ofaws_mailmanager_rule_set(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerRuleSetStringExpressionEvaluate
-
Exactly one of
analysis,attribute,client_certificate_attribute,mime_header_attributeon therule.condition.string_expression.evaluateblock ofaws_mailmanager_rule_set: the provider rejects none and more than one, so each variant sets one of them. - MailmanagerRuleSetStringExpressionEvaluateAnalysis
-
The MailmanagerRuleSetStringExpressionEvaluate.analysis choice: sets
analysis. - MailmanagerRuleSetStringExpressionEvaluateAttribute
-
The MailmanagerRuleSetStringExpressionEvaluate.attribute choice: sets
attribute. - MailmanagerRuleSetStringExpressionEvaluateClientCertificateAttribute
-
The MailmanagerRuleSetStringExpressionEvaluate.clientCertificateAttribute choice: sets
client_certificate_attribute. - MailmanagerRuleSetStringExpressionEvaluateMimeHeaderAttribute
-
The MailmanagerRuleSetStringExpressionEvaluate.mimeHeaderAttribute choice: sets
mime_header_attribute. - MailmanagerRuleSetUnless
-
Typed helper for the
rule.unlessblock ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerRuleSetVerdictExpression
-
Typed helper for the
rule.condition.verdict_expressionblock ofaws_mailmanager_rule_set(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerRuleSetVerdictExpressionEvaluate
-
Exactly one of
analysis,attributeon therule.condition.verdict_expression.evaluateblock ofaws_mailmanager_rule_set: the provider rejects none and more than one, so each variant sets one of them. - MailmanagerRuleSetVerdictExpressionEvaluateAnalysis
-
The MailmanagerRuleSetVerdictExpressionEvaluate.analysis choice: sets
analysis. - MailmanagerRuleSetVerdictExpressionEvaluateAttribute
-
The MailmanagerRuleSetVerdictExpressionEvaluate.attribute choice: sets
attribute. - MailmanagerRuleSetWriteToS3
-
Typed helper for the
rule.action.write_to_s3block ofaws_mailmanager_rule_set(derived from provider schema). - MailmanagerTrafficPolicyAnalysis
-
Typed helper for the
policy_statement.condition.boolean_expression.evaluate.analysisblock ofaws_mailmanager_traffic_policy(derived from provider schema). Shared by every block of this shape in the resource. - MailmanagerTrafficPolicyBooleanExpression
-
Typed helper for the
policy_statement.condition.boolean_expressionblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyBooleanExpressionEvaluate
-
Typed helper for the
policy_statement.condition.boolean_expression.evaluateblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyCondition
-
Typed helper for the
policy_statement.conditionblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyIpExpression
-
Typed helper for the
policy_statement.condition.ip_expressionblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyIpExpressionEvaluate
-
Typed helper for the
policy_statement.condition.ip_expression.evaluateblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyIpv6Expression
-
Typed helper for the
policy_statement.condition.ipv6_expressionblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyIpv6ExpressionEvaluate
-
Typed helper for the
policy_statement.condition.ipv6_expression.evaluateblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyIsInAddressList
-
Typed helper for the
policy_statement.condition.boolean_expression.evaluate.is_in_address_listblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyStatement
-
Typed helper for the
policy_statementblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyStringExpression
-
Typed helper for the
policy_statement.condition.string_expressionblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyStringExpressionEvaluate
-
Exactly one of
analysis,attributeon thepolicy_statement.condition.string_expression.evaluateblock ofaws_mailmanager_traffic_policy: the provider rejects none and more than one, so each variant sets one of them. - MailmanagerTrafficPolicyStringExpressionEvaluateAnalysis
-
The MailmanagerTrafficPolicyStringExpressionEvaluate.analysis choice: sets
analysis. - MailmanagerTrafficPolicyStringExpressionEvaluateAttribute
-
The MailmanagerTrafficPolicyStringExpressionEvaluate.attribute choice: sets
attribute. - MailmanagerTrafficPolicyTlsExpression
-
Typed helper for the
policy_statement.condition.tls_expressionblock ofaws_mailmanager_traffic_policy(derived from provider schema). - MailmanagerTrafficPolicyTlsExpressionEvaluate
-
Typed helper for the
policy_statement.condition.tls_expression.evaluateblock ofaws_mailmanager_traffic_policy(derived from provider schema).
Enums
- MailmanagerArchiveRetentionPeriod
-
retention_period— derived from the provider schema description. - MailmanagerIngressPointIpType
-
ip_type— derived from the provider schema description. - MailmanagerIngressPointStatusToUpdate
-
Mailmanager Ingress Point Status To enum for
status_to_update. - MailmanagerIngressPointTlsPolicy
-
Mailmanager Ingress Point Tls enum for
tls_policy. - MailmanagerIngressPointType
-
Mailmanager Ingress Point enum for
type. - MailmanagerRuleSetActionFailurePolicy
-
action_failure_policy— derived from the provider schema description. - MailmanagerRuleSetBooleanExpressionAttribute
-
attribute— derived from the provider schema description. - MailmanagerRuleSetBooleanExpressionOperator
-
operator— derived from the provider schema description. - MailmanagerRuleSetClientCertificateAttribute
-
client_certificate_attribute— derived from the provider schema description. - MailmanagerRuleSetDmarcExpressionOperator
-
operator— derived from the provider schema description. - MailmanagerRuleSetDmarcExpressionValues
-
values— derived from the provider schema description. - MailmanagerRuleSetEncoding
-
encoding— derived from the provider schema description. - MailmanagerRuleSetInvocationType
-
invocation_type— derived from the provider schema description. - MailmanagerRuleSetIpExpressionAttribute
-
attribute— derived from the provider schema description. - MailmanagerRuleSetIpExpressionOperator
-
operator— derived from the provider schema description. - MailmanagerRuleSetIsInAddressListAttribute
-
attribute— derived from the provider schema description. - MailmanagerRuleSetMailFrom
-
mail_from— derived from the provider schema description. - MailmanagerRuleSetNumberExpressionAttribute
-
attribute— derived from the provider schema description. - MailmanagerRuleSetNumberExpressionOperator
-
operator— derived from the provider schema description. - MailmanagerRuleSetPayloadType
-
payload_type— derived from the provider schema description. - MailmanagerRuleSetStringExpressionAttribute
-
attribute— derived from the provider schema description. - MailmanagerRuleSetStringExpressionOperator
-
operator— derived from the provider schema description. - MailmanagerRuleSetVerdictExpressionAttribute
-
attribute— derived from the provider schema description. - MailmanagerRuleSetVerdictExpressionValues
-
values— derived from the provider schema description. - MailmanagerTrafficPolicyAction
-
action— derived from the provider schema description. - MailmanagerTrafficPolicyBooleanExpressionOperator
-
operator— derived from the provider schema description. - MailmanagerTrafficPolicyDefaultAction
-
Mailmanager Traffic Policy Default enum for
default_action. - MailmanagerTrafficPolicyIpExpressionAttribute
-
attribute— derived from the provider schema description. - MailmanagerTrafficPolicyIpExpressionOperator
-
operator— derived from the provider schema description. - MailmanagerTrafficPolicyIpv6ExpressionAttribute
-
attribute— derived from the provider schema description. - MailmanagerTrafficPolicyStringExpressionAttribute
-
attribute— derived from the provider schema description. - MailmanagerTrafficPolicyStringExpressionOperator
-
operator— derived from the provider schema description. - MailmanagerTrafficPolicyTlsExpressionAttribute
-
attribute— derived from the provider schema description. - MailmanagerTrafficPolicyTlsExpressionOperator
-
operator— derived from the provider schema description. - MailmanagerTrafficPolicyValue
-
value— derived from the provider schema description.