medialive library
AWS Elemental MediaLive.
Classes
- AwsMedialiveChannel
-
Factory wrapper for
aws_medialive_channel. - AwsMedialiveInput
-
Factory wrapper for
aws_medialive_input. - AwsMedialiveInputSecurityGroup
-
Factory wrapper for
aws_medialive_input_security_group. - AwsMedialiveMultiplex
-
Factory wrapper for
aws_medialive_multiplex. - AwsMedialiveMultiplexProgram
-
Factory wrapper for
aws_medialive_multiplex_program. - MedialiveChannelAacSettings
-
Typed helper for the
encoder_settings.audio_descriptions.codec_settings.aac_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAc3Settings
-
Typed helper for the
encoder_settings.audio_descriptions.codec_settings.ac3_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAncillarySourceSettings
-
Typed helper for the
input_attachments.input_settings.caption_selector.selector_settings.ancillary_source_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelArchiveCdnSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.archive_group_settings.archive_cdn_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelArchiveGroupSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.archive_group_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelArchiveOutputSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.archive_output_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelArchiveOutputSettingsContainerSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.archive_output_settings.container_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelArchiveS3Settings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.archive_group_settings.archive_cdn_settings.archive_s3_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAribDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.arib_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAribSourceSettings
-
Typed helper for the
input_attachments.input_settings.caption_selector.selector_settings.arib_source_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioDescriptions
-
Typed helper for the
encoder_settings.audio_descriptionsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioDescriptionsCodecSettings
-
Typed helper for the
encoder_settings.audio_descriptions.codec_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioHlsRenditionSelection
-
Typed helper for the
input_attachments.input_settings.audio_selector.selector_settings.audio_hls_rendition_selectionblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioLanguageSelection
-
Typed helper for the
input_attachments.input_settings.audio_selector.selector_settings.audio_language_selectionblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioNormalizationSettings
-
Typed helper for the
encoder_settings.audio_descriptions.audio_normalization_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioOnlyHlsSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.hls_output_settings.hls_settings.audio_only_hls_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioOnlyImage
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.hls_output_settings.hls_settings.audio_only_hls_settings.audio_only_imageblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioPidSelection
-
Typed helper for the
input_attachments.input_settings.audio_selector.selector_settings.audio_pid_selectionblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioSelector
-
Typed helper for the
input_attachments.input_settings.audio_selectorblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioSelectorSettings
-
Typed helper for the
input_attachments.input_settings.audio_selector.selector_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioSilenceSettings
-
Typed helper for the
input_attachments.automatic_input_failover_settings.failover_condition.failover_condition_settings.audio_silence_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioTrackSelection
-
Typed helper for the
input_attachments.input_settings.audio_selector.selector_settings.audio_track_selectionblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAudioWatermarkSettings
-
Typed helper for the
encoder_settings.audio_descriptions.audio_watermark_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAutomaticInputFailoverSettings
-
Typed helper for the
input_attachments.automatic_input_failover_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAvailBlanking
-
Typed helper for the
encoder_settings.avail_blankingblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelAvailBlankingImage
-
Typed helper for the
encoder_settings.avail_blanking.avail_blanking_imageblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelBurnInDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.burn_in_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelCaptionDescriptions
-
Typed helper for the
encoder_settings.caption_descriptionsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelCaptionLanguageMappings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settings.caption_language_mappingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelCaptionSelector
-
Typed helper for the
input_attachments.input_settings.caption_selectorblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelCaptionSelectorSettings
-
Typed helper for the
input_attachments.input_settings.caption_selector.selector_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelCdiInputSpecification
-
Typed helper for the
cdi_input_specificationblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelColorSpacePassthroughSettings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h265_settings.color_space_settings.color_space_passthrough_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelColorSpaceSettings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h265_settings.color_space_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelDestination
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.archive_group_settings.destinationblock ofaws_medialive_channel(derived from provider schema). Shared by every block of this shape in the resource. - MedialiveChannelDestinations
-
Typed helper for the
destinationsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelDolbyEDecode
-
Typed helper for the
input_attachments.input_settings.audio_selector.selector_settings.audio_track_selection.dolby_e_decodeblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelDolbyVision81Settings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h265_settings.color_space_settings.dolby_vision81_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelDvbNitSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.archive_output_settings.container_settings.m2ts_settings.dvb_nit_settingsblock ofaws_medialive_channel(derived from provider schema). Shared by every block of this shape in the resource. - MedialiveChannelDvbSdtSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.archive_output_settings.container_settings.m2ts_settings.dvb_sdt_settingsblock ofaws_medialive_channel(derived from provider schema). Shared by every block of this shape in the resource. - MedialiveChannelDvbSubDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.dvb_sub_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelDvbSubSourceSettings
-
Typed helper for the
input_attachments.input_settings.caption_selector.selector_settings.dvb_sub_source_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelDvbTdtSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.archive_output_settings.container_settings.m2ts_settings.dvb_tdt_settingsblock ofaws_medialive_channel(derived from provider schema). Shared by every block of this shape in the resource. - MedialiveChannelEac3AtmosSettings
-
Typed helper for the
encoder_settings.audio_descriptions.codec_settings.eac3_atmos_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelEac3Settings
-
Typed helper for the
encoder_settings.audio_descriptions.codec_settings.eac3_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelEbuTtDDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.ebu_tt_d_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelEmbeddedDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.embedded_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelEmbeddedPlusScte20DestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.embedded_plus_scte20_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelEmbeddedSourceSettings
-
Typed helper for the
input_attachments.input_settings.caption_selector.selector_settings.embedded_source_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelEncoderSettings
-
Typed helper for the
encoder_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelFailoverCondition
-
Typed helper for the
input_attachments.automatic_input_failover_settings.failover_conditionblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelFailoverConditionSettings
-
Typed helper for the
input_attachments.automatic_input_failover_settings.failover_condition.failover_condition_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelFecOutputSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.udp_output_settings.fec_output_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelFilterSettings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h264_settings.filter_settingsblock ofaws_medialive_channel(derived from provider schema). Shared by every block of this shape in the resource. - MedialiveChannelFmp4HlsSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.hls_output_settings.hls_settings.fmp4_hls_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelFont
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.burn_in_destination_settings.fontblock ofaws_medialive_channel(derived from provider schema). Shared by every block of this shape in the resource. - MedialiveChannelFrameCaptureCdnSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.frame_capture_group_settings.frame_capture_cdn_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelFrameCaptureGroupSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.frame_capture_group_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelFrameCaptureHlsSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.hls_output_settings.hls_settings.frame_capture_hls_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelFrameCaptureOutputSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.frame_capture_output_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelFrameCaptureS3Settings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.frame_capture_group_settings.frame_capture_cdn_settings.frame_capture_s3_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelFrameCaptureSettings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.frame_capture_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelGlobalConfiguration
-
Typed helper for the
encoder_settings.global_configurationblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelH264Settings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h264_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelH265Settings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h265_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHdr10Settings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h265_settings.color_space_settings.hdr10_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHlsAkamaiSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settings.hls_cdn_settings.hls_akamai_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHlsBasicPutSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settings.hls_cdn_settings.hls_basic_put_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHlsCdnSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settings.hls_cdn_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHlsGroupSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHlsInputSettings
-
Typed helper for the
input_attachments.input_settings.network_input_settings.hls_input_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHlsMediaStoreSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settings.hls_cdn_settings.hls_media_store_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHlsOutputSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.hls_output_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHlsS3Settings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settings.hls_cdn_settings.hls_s3_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHlsSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.hls_output_settings.hls_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHlsWebdavSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settings.hls_cdn_settings.hls_webdav_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelHtmlMotionGraphicsSettings
-
Typed helper for the
encoder_settings.motion_graphics_configuration.motion_graphics_settings.html_motion_graphics_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelInputAttachments
-
Typed helper for the
input_attachmentsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelInputChannelLevels
-
Typed helper for the
encoder_settings.audio_descriptions.remix_settings.channel_mappings.input_channel_levelsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelInputLossBehavior
-
Typed helper for the
encoder_settings.global_configuration.input_loss_behaviorblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelInputLossImageSlate
-
Typed helper for the
encoder_settings.global_configuration.input_loss_behavior.input_loss_image_slateblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelInputLossSettings
-
Typed helper for the
input_attachments.automatic_input_failover_settings.failover_condition.failover_condition_settings.input_loss_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelInputSettings
-
Typed helper for the
input_attachments.input_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelInputSpecification
-
Typed helper for the
input_specificationblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelKeyProviderServer
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settings.key_provider_settings.static_key_settings.key_provider_serverblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelKeyProviderSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settings.key_provider_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelM2tsSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.archive_output_settings.container_settings.m2ts_settingsblock ofaws_medialive_channel(derived from provider schema). Shared by every block of this shape in the resource. - MedialiveChannelM3u8Settings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.hls_output_settings.hls_settings.standard_hls_settings.m3u8_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMaintenance
-
Typed helper for the
maintenanceblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMappings
-
Typed helper for the
encoder_settings.audio_descriptions.remix_settings.channel_mappingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMediaPackageGroupSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.media_package_group_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMediaPackageOutputSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.media_package_output_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMediaPackageSettings
-
Typed helper for the
destinations.media_package_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMotionGraphicsConfiguration
-
Typed helper for the
encoder_settings.motion_graphics_configurationblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMotionGraphicsSettings
-
Typed helper for the
encoder_settings.motion_graphics_configuration.motion_graphics_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMp2Settings
-
Typed helper for the
encoder_settings.audio_descriptions.codec_settings.mp2_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMsSmoothGroupSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.ms_smooth_group_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMsSmoothOutputSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.ms_smooth_output_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMultiplexGroupSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.multiplex_group_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMultiplexOutputSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.multiplex_output_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelMultiplexSettings
-
Typed helper for the
destinations.multiplex_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelNetworkInputSettings
-
Typed helper for the
input_attachments.input_settings.network_input_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelNielsenCbetSettings
-
Typed helper for the
encoder_settings.audio_descriptions.audio_watermark_settings.nielsen_watermarks_settings.nielsen_cbet_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelNielsenConfiguration
-
Typed helper for the
encoder_settings.nielsen_configurationblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelNielsenNaesIiNwSettings
-
Typed helper for the
encoder_settings.audio_descriptions.audio_watermark_settings.nielsen_watermarks_settings.nielsen_naes_ii_nw_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelNielsenWatermarksSettings
-
Typed helper for the
encoder_settings.audio_descriptions.audio_watermark_settings.nielsen_watermarks_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelOutputGroups
-
Typed helper for the
encoder_settings.output_groupsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelOutputGroupSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelOutputRectangle
-
Typed helper for the
input_attachments.input_settings.caption_selector.selector_settings.teletext_source_settings.output_rectangleblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelOutputs
-
Typed helper for the
encoder_settings.output_groups.outputsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelOutputSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelPassThroughSettings
-
Typed helper for the
encoder_settings.audio_descriptions.codec_settings.pass_through_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelRawSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.archive_output_settings.container_settings.raw_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelRec601Settings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h265_settings.color_space_settings.rec601_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelRec709Settings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h265_settings.color_space_settings.rec709_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelRemixSettings
-
Typed helper for the
encoder_settings.audio_descriptions.remix_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelRtmpCaptionInfoDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.rtmp_caption_info_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelRtmpGroupSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.rtmp_group_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelRtmpOutputSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.rtmp_output_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelScte20PlusEmbeddedDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.scte20_plus_embedded_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelScte20SourceSettings
-
Typed helper for the
input_attachments.input_settings.caption_selector.selector_settings.scte20_source_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelScte27DestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.scte27_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelScte27SourceSettings
-
Typed helper for the
input_attachments.input_settings.caption_selector.selector_settings.scte27_source_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelSettings
-
Typed helper for the
destinations.settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelSmpteTtDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.smpte_tt_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelStandardHlsSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.hls_output_settings.hls_settings.standard_hls_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelStaticKeySettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.hls_group_settings.key_provider_settings.static_key_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelTeletextDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.teletext_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelTeletextSourceSettings
-
Typed helper for the
input_attachments.input_settings.caption_selector.selector_settings.teletext_source_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelTemporalFilterSettings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h264_settings.filter_settings.temporal_filter_settingsblock ofaws_medialive_channel(derived from provider schema). Shared by every block of this shape in the resource. - MedialiveChannelTimecodeBurninSettings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settings.h265_settings.timecode_burnin_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelTimecodeConfig
-
Typed helper for the
encoder_settings.timecode_configblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelTracks
-
Typed helper for the
input_attachments.input_settings.audio_selector.selector_settings.audio_track_selection.tracksblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelTtmlDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.ttml_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelUdpGroupSettings
-
Typed helper for the
encoder_settings.output_groups.output_group_settings.udp_group_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelUdpOutputSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.udp_output_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelUdpOutputSettingsContainerSettings
-
Typed helper for the
encoder_settings.output_groups.outputs.output_settings.udp_output_settings.container_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelVideoBlackSettings
-
Typed helper for the
input_attachments.automatic_input_failover_settings.failover_condition.failover_condition_settings.video_black_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelVideoDescriptions
-
Typed helper for the
encoder_settings.video_descriptionsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelVideoDescriptionsCodecSettings
-
Typed helper for the
encoder_settings.video_descriptions.codec_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelVideoSelector
-
Typed helper for the
input_attachments.input_settings.video_selectorblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelVpc
-
Typed helper for the
vpcblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelWavSettings
-
Typed helper for the
encoder_settings.audio_descriptions.codec_settings.wav_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveChannelWebvttDestinationSettings
-
Typed helper for the
encoder_settings.caption_descriptions.destination_settings.webvtt_destination_settingsblock ofaws_medialive_channel(derived from provider schema). - MedialiveInputDestinations
-
Typed helper for the
destinationsblock ofaws_medialive_input(derived from provider schema). - MedialiveInputDevices
-
Typed helper for the
input_devicesblock ofaws_medialive_input(derived from provider schema). - MedialiveInputMediaConnectFlows
-
Typed helper for the
media_connect_flowsblock ofaws_medialive_input(derived from provider schema). - MedialiveInputSecurityGroupWhitelistRules
-
Typed helper for the
whitelist_rulesblock ofaws_medialive_input_security_group(derived from provider schema). - MedialiveInputSources
-
Typed helper for the
sourcesblock ofaws_medialive_input(derived from provider schema). - MedialiveInputVpc
-
Typed helper for the
vpcblock ofaws_medialive_input(derived from provider schema). - MedialiveMultiplexProgramServiceDescriptor
-
Typed helper for the
multiplex_program_settings.service_descriptorblock ofaws_medialive_multiplex_program(derived from provider schema). - MedialiveMultiplexProgramSettings
-
Typed helper for the
multiplex_program_settingsblock ofaws_medialive_multiplex_program(derived from provider schema). - MedialiveMultiplexProgramStatmuxSettings
-
Typed helper for the
multiplex_program_settings.video_settings.statmux_settingsblock ofaws_medialive_multiplex_program(derived from provider schema). - MedialiveMultiplexProgramVideoSettings
-
Typed helper for the
multiplex_program_settings.video_settingsblock ofaws_medialive_multiplex_program(derived from provider schema). - MedialiveMultiplexSettings
-
Typed helper for the
multiplex_settingsblock ofaws_medialive_multiplex(derived from provider schema).
Enums
- MedialiveChannelClass
-
Medialive Channel enum for
channel_class. - MedialiveChannelCodec
-
codec— derived from the provider schema description. - MedialiveChannelColorSpace
-
color_space— derived from the provider schema description. - MedialiveChannelColorSpaceUsage
-
color_space_usage— derived from the provider schema description. - MedialiveChannelConvert608To708
-
convert_608_to_708— derived from the provider schema description. - MedialiveChannelDeblockFilter
-
deblock_filter— derived from the provider schema description. - MedialiveChannelDenoiseFilter
-
denoise_filter— derived from the provider schema description. - MedialiveChannelInputFilter
-
input_filter— derived from the provider schema description. - MedialiveChannelInputPreference
-
input_preference— derived from the provider schema description. - MedialiveChannelInputResolution
-
input_resolution— derived from the provider schema description. - MedialiveChannelLanguageSelectionPolicy
-
language_selection_policy— derived from the provider schema description. - MedialiveChannelLogLevel
-
Medialive Channel Log enum for
log_level. - MedialiveChannelMaintenanceDay
-
maintenance_day— derived from the provider schema description. - MedialiveChannelMaximumBitrate
-
maximum_bitrate— derived from the provider schema description. - MedialiveChannelOcrLanguage
-
ocr_language— derived from the provider schema description. - MedialiveChannelProgramSelection
-
program_selection— derived from the provider schema description. - MedialiveChannelResolution
-
resolution— derived from the provider schema description. - MedialiveChannelScte20Detection
-
scte20_detection— derived from the provider schema description. - MedialiveChannelScte35Source
-
scte35_source— derived from the provider schema description. - MedialiveChannelServerValidation
-
server_validation— derived from the provider schema description. - MedialiveChannelSmpte2038DataPreference
-
smpte2038_data_preference— derived from the provider schema description. - MedialiveChannelSourceEndBehavior
-
source_end_behavior— derived from the provider schema description. - MedialiveInputType
-
Medialive Input enum for
type.