memorydb library
AWS MemoryDB.
Classes
- AwsMemorydbAcl
-
Factory wrapper for
aws_memorydb_acl. - AwsMemorydbCluster
-
Factory wrapper for
aws_memorydb_cluster. - AwsMemorydbMultiRegionCluster
-
Factory wrapper for
aws_memorydb_multi_region_cluster. - AwsMemorydbParameterGroup
-
Factory wrapper for
aws_memorydb_parameter_group. - AwsMemorydbSnapshot
-
Factory wrapper for
aws_memorydb_snapshot. - AwsMemorydbSubnetGroup
-
Factory wrapper for
aws_memorydb_subnet_group. - AwsMemorydbUser
-
Factory wrapper for
aws_memorydb_user. - MemorydbAclName
-
At most one of
name,name_prefixonaws_memorydb_acl: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - MemorydbAclNameChoice
-
The MemorydbAclName.name choice: sets
name. - MemorydbAclNamePrefix
-
The MemorydbAclName.namePrefix choice: sets
name_prefix. - MemorydbClusterName
-
At most one of
name,name_prefixonaws_memorydb_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - MemorydbClusterNameChoice
-
The MemorydbClusterName.name choice: sets
name. - MemorydbClusterNamePrefix
-
The MemorydbClusterName.namePrefix choice: sets
name_prefix. - MemorydbClusterSnapshot
-
At most one of
snapshot_arns,snapshot_nameonaws_memorydb_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - MemorydbClusterSnapshotArns
-
The MemorydbClusterSnapshot.snapshotArns choice: sets
snapshot_arns. - MemorydbClusterSnapshotName
-
The MemorydbClusterSnapshot.snapshotName choice: sets
snapshot_name. - MemorydbParameterGroupName
-
At most one of
name,name_prefixonaws_memorydb_parameter_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - MemorydbParameterGroupNameChoice
-
The MemorydbParameterGroupName.name choice: sets
name. - MemorydbParameterGroupNamePrefix
-
The MemorydbParameterGroupName.namePrefix choice: sets
name_prefix. - MemorydbParameterGroupParameter
-
Typed helper for the
parameterblock ofaws_memorydb_parameter_group(derived from provider schema). - MemorydbSnapshotName
-
At most one of
name,name_prefixonaws_memorydb_snapshot: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - MemorydbSnapshotNameChoice
-
The MemorydbSnapshotName.name choice: sets
name. - MemorydbSnapshotNamePrefix
-
The MemorydbSnapshotName.namePrefix choice: sets
name_prefix. - MemorydbSubnetGroupName
-
At most one of
name,name_prefixonaws_memorydb_subnet_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - MemorydbSubnetGroupNameChoice
-
The MemorydbSubnetGroupName.name choice: sets
name. - MemorydbSubnetGroupNamePrefix
-
The MemorydbSubnetGroupName.namePrefix choice: sets
name_prefix. - MemorydbUserAuthenticationMode
-
Typed helper for the
authentication_modeblock ofaws_memorydb_user(derived from provider schema).
Enums
- MemorydbClusterEngine
-
Memorydb Cluster enum for
engine. - MemorydbClusterIpDiscovery
-
Memorydb Cluster Ip enum for
ip_discovery. - MemorydbClusterNetworkType
-
Memorydb Cluster Network enum for
network_type. - MemorydbMultiRegionClusterEngine
-
Memorydb Multi Region Cluster enum for
engine. - MemorydbMultiRegionClusterUpdateStrategy
-
Memorydb Multi Region Cluster Update enum for
update_strategy. - MemorydbUserType
-
type— derived from the provider schema description.