msk library
AWS Managed Streaming for Apache Kafka (MSK).
Classes
- AwsMskChannel
-
Factory wrapper for
aws_msk_channel. - AwsMskCluster
-
Factory wrapper for
aws_msk_cluster. - AwsMskClusterPolicy
-
Factory wrapper for
aws_msk_cluster_policy. - AwsMskConfiguration
-
Factory wrapper for
aws_msk_configuration. - AwsMskReplicator
-
Factory wrapper for
aws_msk_replicator. - AwsMskScramSecretAssociation
-
Factory wrapper for
aws_msk_scram_secret_association. - AwsMskServerlessCluster
-
Factory wrapper for
aws_msk_serverless_cluster. - AwsMskSingleScramSecretAssociation
-
Factory wrapper for
aws_msk_single_scram_secret_association. - AwsMskTopic
-
Factory wrapper for
aws_msk_topic. - AwsMskVpcConnection
-
Factory wrapper for
aws_msk_vpc_connection. - MskChannelCatalog
-
Typed helper for the
iceberg_destination.catalogblock ofaws_msk_channel(derived from provider schema). - MskChannelCloudwatchLogs
-
Typed helper for the
logging_info.cloudwatch_logsblock ofaws_msk_channel(derived from provider schema). - MskChannelDeadLetterQueueS3
-
Typed helper for the
iceberg_destination.dead_letter_queue_s3block ofaws_msk_channel(derived from provider schema). Shared by every block of this shape in the resource. - MskChannelDestination
-
Exactly one of
iceberg_destination,s3_destinationonaws_msk_channel: the provider rejects none and more than one, so each variant sets one of them. - MskChannelDestinationTable
-
Typed helper for the
iceberg_destination.destination_tableblock ofaws_msk_channel(derived from provider schema). - MskChannelEncryptionConfiguration
-
Typed helper for the
encryption_configurationblock ofaws_msk_channel(derived from provider schema). - MskChannelFirehose
-
Typed helper for the
logging_info.firehoseblock ofaws_msk_channel(derived from provider schema). - MskChannelIcebergDestination
-
Typed helper for the
iceberg_destinationblock ofaws_msk_channel(derived from provider schema). - MskChannelIcebergDestinationChoice
-
The MskChannelDestination.icebergDestination choice: sets
iceberg_destination. - MskChannelLoggingInfo
-
Typed helper for the
logging_infoblock ofaws_msk_channel(derived from provider schema). - MskChannelPartitionSpec
-
Typed helper for the
iceberg_destination.destination_table.partition_specblock ofaws_msk_channel(derived from provider schema). - MskChannelRecordConverter
-
Typed helper for the
topic_configuration.record_converterblock ofaws_msk_channel(derived from provider schema). - MskChannelRecordSchema
-
Typed helper for the
topic_configuration.record_schemablock ofaws_msk_channel(derived from provider schema). - MskChannelS3
-
Typed helper for the
logging_info.s3block ofaws_msk_channel(derived from provider schema). - MskChannelS3Destination
-
Typed helper for the
s3_destinationblock ofaws_msk_channel(derived from provider schema). - MskChannelS3DestinationChoice
-
The MskChannelDestination.s3Destination choice: sets
s3_destination. - MskChannelSchemaEvolution
-
Typed helper for the
iceberg_destination.schema_evolutionblock ofaws_msk_channel(derived from provider schema). - MskChannelSource
-
Typed helper for the
iceberg_destination.destination_table.partition_spec.sourceblock ofaws_msk_channel(derived from provider schema). - MskChannelStorage
-
Typed helper for the
s3_destination.storageblock ofaws_msk_channel(derived from provider schema). - MskChannelTableCreation
-
Typed helper for the
iceberg_destination.table_creationblock ofaws_msk_channel(derived from provider schema). - MskChannelTopicConfiguration
-
Typed helper for the
topic_configurationblock ofaws_msk_channel(derived from provider schema). - MskClusterBrokerLogs
-
Typed helper for the
logging_info.broker_logsblock ofaws_msk_cluster(derived from provider schema). - MskClusterBrokerNodeGroupInfo
-
Typed helper for the
broker_node_group_infoblock ofaws_msk_cluster(derived from provider schema). - MskClusterClientAuthentication
-
Typed helper for the
client_authenticationblock ofaws_msk_cluster(derived from provider schema). - MskClusterCloudwatchLogs
-
Typed helper for the
logging_info.broker_logs.cloudwatch_logsblock ofaws_msk_cluster(derived from provider schema). - MskClusterConfigurationInfo
-
Typed helper for the
configuration_infoblock ofaws_msk_cluster(derived from provider schema). - MskClusterConnectivityInfo
-
Typed helper for the
broker_node_group_info.connectivity_infoblock ofaws_msk_cluster(derived from provider schema). - MskClusterEbsStorageInfo
-
Typed helper for the
broker_node_group_info.storage_info.ebs_storage_infoblock ofaws_msk_cluster(derived from provider schema). - MskClusterEncryptionInfo
-
Typed helper for the
encryption_infoblock ofaws_msk_cluster(derived from provider schema). - MskClusterEncryptionInTransit
-
Typed helper for the
encryption_info.encryption_in_transitblock ofaws_msk_cluster(derived from provider schema). - MskClusterFirehose
-
Typed helper for the
logging_info.broker_logs.firehoseblock ofaws_msk_cluster(derived from provider schema). - MskClusterJmxExporter
-
Typed helper for the
open_monitoring.prometheus.jmx_exporterblock ofaws_msk_cluster(derived from provider schema). - MskClusterLoggingInfo
-
Typed helper for the
logging_infoblock ofaws_msk_cluster(derived from provider schema). - MskClusterNodeExporter
-
Typed helper for the
open_monitoring.prometheus.node_exporterblock ofaws_msk_cluster(derived from provider schema). - MskClusterOpenMonitoring
-
Typed helper for the
open_monitoringblock ofaws_msk_cluster(derived from provider schema). - MskClusterPrometheus
-
Typed helper for the
open_monitoring.prometheusblock ofaws_msk_cluster(derived from provider schema). - MskClusterProvisionedThroughput
-
Typed helper for the
broker_node_group_info.storage_info.ebs_storage_info.provisioned_throughputblock ofaws_msk_cluster(derived from provider schema). - MskClusterPublicAccess
-
Typed helper for the
broker_node_group_info.connectivity_info.public_accessblock ofaws_msk_cluster(derived from provider schema). - MskClusterRebalancing
-
Typed helper for the
rebalancingblock ofaws_msk_cluster(derived from provider schema). - MskClusterS3
-
Typed helper for the
logging_info.broker_logs.s3block ofaws_msk_cluster(derived from provider schema). - MskClusterSasl
-
Typed helper for the
client_authentication.saslblock ofaws_msk_cluster(derived from provider schema). Shared by every block of this shape in the resource. - MskClusterStorageInfo
-
Typed helper for the
broker_node_group_info.storage_infoblock ofaws_msk_cluster(derived from provider schema). - MskClusterTls
-
Typed helper for the
client_authentication.tlsblock ofaws_msk_cluster(derived from provider schema). - MskClusterVpcConnectivity
-
Typed helper for the
broker_node_group_info.connectivity_info.vpc_connectivityblock ofaws_msk_cluster(derived from provider schema). - MskClusterVpcConnectivityClientAuthentication
-
Typed helper for the
broker_node_group_info.connectivity_info.vpc_connectivity.client_authenticationblock ofaws_msk_cluster(derived from provider schema). - MskReplicatorAmazonMskCluster
-
Typed helper for the
kafka_cluster.amazon_msk_clusterblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorApacheKafkaCluster
-
Typed helper for the
kafka_cluster.apache_kafka_clusterblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorClientAuthentication
-
Typed helper for the
kafka_cluster.client_authenticationblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorCloudwatchLogs
-
Typed helper for the
log_delivery.replicator_log_delivery.cloudwatch_logsblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorConsumerGroupReplication
-
Typed helper for the
replication_info_list.consumer_group_replicationblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorEncryptionInTransit
-
Typed helper for the
kafka_cluster.encryption_in_transitblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorFirehose
-
Typed helper for the
log_delivery.replicator_log_delivery.firehoseblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorKafkaCluster
-
Typed helper for the
kafka_clusterblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorLogDelivery
-
Typed helper for the
log_deliveryblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorMtls
-
Typed helper for the
kafka_cluster.client_authentication.mtlsblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorReplicationInfoList
-
Typed helper for the
replication_info_listblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorReplicatorLogDelivery
-
Typed helper for the
log_delivery.replicator_log_deliveryblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorS3
-
Typed helper for the
log_delivery.replicator_log_delivery.s3block ofaws_msk_replicator(derived from provider schema). - MskReplicatorSaslScram
-
Typed helper for the
kafka_cluster.client_authentication.sasl_scramblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorSourceKafkaCluster
-
Exactly one of
source_kafka_cluster_arn,source_kafka_cluster_idon thereplication_info_listblock ofaws_msk_replicator: the provider rejects none and more than one, so each variant sets one of them. - MskReplicatorSourceKafkaClusterArn
-
The MskReplicatorSourceKafkaCluster.sourceKafkaClusterArn choice: sets
source_kafka_cluster_arn. - MskReplicatorSourceKafkaClusterId
-
The MskReplicatorSourceKafkaCluster.sourceKafkaClusterId choice: sets
source_kafka_cluster_id. - MskReplicatorStartingPosition
-
Typed helper for the
replication_info_list.topic_replication.starting_positionblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorTargetKafkaCluster
-
Exactly one of
target_kafka_cluster_arn,target_kafka_cluster_idon thereplication_info_listblock ofaws_msk_replicator: the provider rejects none and more than one, so each variant sets one of them. - MskReplicatorTargetKafkaClusterArn
-
The MskReplicatorTargetKafkaCluster.targetKafkaClusterArn choice: sets
target_kafka_cluster_arn. - MskReplicatorTargetKafkaClusterId
-
The MskReplicatorTargetKafkaCluster.targetKafkaClusterId choice: sets
target_kafka_cluster_id. - MskReplicatorTopicNameConfiguration
-
Typed helper for the
replication_info_list.topic_replication.topic_name_configurationblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorTopicReplication
-
Typed helper for the
replication_info_list.topic_replicationblock ofaws_msk_replicator(derived from provider schema). - MskReplicatorVpcConfig
-
Typed helper for the
kafka_cluster.vpc_configblock ofaws_msk_replicator(derived from provider schema). - MskServerlessClusterClientAuthentication
-
Typed helper for the
client_authenticationblock ofaws_msk_serverless_cluster(derived from provider schema). - MskServerlessClusterIam
-
Typed helper for the
client_authentication.sasl.iamblock ofaws_msk_serverless_cluster(derived from provider schema). - MskServerlessClusterSasl
-
Typed helper for the
client_authentication.saslblock ofaws_msk_serverless_cluster(derived from provider schema). - MskServerlessClusterVpcConfig
-
Typed helper for the
vpc_configblock ofaws_msk_serverless_cluster(derived from provider schema).
Enums
- MskChannelCompressionType
-
compression_type— derived from the provider schema description. - MskChannelPartitionStrategy
-
partition_strategy— derived from the provider schema description. - MskChannelStorageClass
-
storage_class— derived from the provider schema description. - MskChannelStorageCompressionType
-
compression_type— derived from the provider schema description. - MskChannelValueConverter
-
value_converter— derived from the provider schema description. - MskClusterAzDistribution
-
az_distribution— derived from the provider schema description. - MskClusterClientBroker
-
client_broker— derived from the provider schema description. - MskClusterEnhancedMonitoring
-
Msk Cluster Enhanced enum for
enhanced_monitoring. - MskClusterNetworkType
-
network_type— derived from the provider schema description. - MskClusterStatus
-
status— derived from the provider schema description. - MskClusterStorageMode
-
Msk Cluster Storage enum for
storage_mode. - MskClusterType
-
type— derived from the provider schema description. - MskReplicatorConsumerGroupOffsetSyncMode
-
consumer_group_offset_sync_mode— derived from the provider schema description. - MskReplicatorMechanism
-
mechanism— derived from the provider schema description. - MskReplicatorStartingPositionType
-
type— derived from the provider schema description. - MskReplicatorTopicNameConfigurationType
-
type— derived from the provider schema description.