neptune library
AWS Neptune.
Classes
- AwsNeptuneCluster
-
Factory wrapper for
aws_neptune_cluster. - AwsNeptuneClusterEndpoint
-
Factory wrapper for
aws_neptune_cluster_endpoint. - AwsNeptuneClusterInstance
-
Factory wrapper for
aws_neptune_cluster_instance. - AwsNeptuneClusterParameterGroup
-
Factory wrapper for
aws_neptune_cluster_parameter_group. - AwsNeptuneClusterSnapshot
-
Factory wrapper for
aws_neptune_cluster_snapshot. - AwsNeptuneEventSubscription
-
Factory wrapper for
aws_neptune_event_subscription. - AwsNeptuneGlobalCluster
-
Factory wrapper for
aws_neptune_global_cluster. - AwsNeptuneParameterGroup
-
Factory wrapper for
aws_neptune_parameter_group. - AwsNeptuneSubnetGroup
-
Factory wrapper for
aws_neptune_subnet_group. - NeptuneClusterIdentifier
-
At most one of
cluster_identifier,cluster_identifier_prefixonaws_neptune_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - NeptuneClusterIdentifierChoice
-
The NeptuneClusterIdentifier.clusterIdentifier choice: sets
cluster_identifier. - NeptuneClusterIdentifierPrefix
-
The NeptuneClusterIdentifier.clusterIdentifierPrefix choice: sets
cluster_identifier_prefix. - NeptuneClusterInstanceIdentifier
-
At most one of
identifier,identifier_prefixonaws_neptune_cluster_instance: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - NeptuneClusterInstanceIdentifierChoice
-
The NeptuneClusterInstanceIdentifier.identifier choice: sets
identifier. - NeptuneClusterInstanceIdentifierPrefix
-
The NeptuneClusterInstanceIdentifier.identifierPrefix choice: sets
identifier_prefix. - NeptuneClusterParameterGroupName
-
At most one of
name,name_prefixonaws_neptune_cluster_parameter_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - NeptuneClusterParameterGroupNameChoice
-
The NeptuneClusterParameterGroupName.name choice: sets
name. - NeptuneClusterParameterGroupNamePrefix
-
The NeptuneClusterParameterGroupName.namePrefix choice: sets
name_prefix. - NeptuneClusterParameterGroupParameter
-
Typed helper for the
parameterblock ofaws_neptune_cluster_parameter_group(derived from provider schema). - NeptuneClusterServerlessV2ScalingConfiguration
-
Typed helper for the
serverless_v2_scaling_configurationblock ofaws_neptune_cluster(derived from provider schema). - NeptuneEventSubscriptionName
-
At most one of
name,name_prefixonaws_neptune_event_subscription: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - NeptuneEventSubscriptionNameChoice
-
The NeptuneEventSubscriptionName.name choice: sets
name. - NeptuneEventSubscriptionNamePrefix
-
The NeptuneEventSubscriptionName.namePrefix choice: sets
name_prefix. - NeptuneGlobalClusterSource
-
Exactly one of
engine,source_db_cluster_identifieronaws_neptune_global_cluster: the provider rejects none and more than one, so each variant sets one of them. - NeptuneGlobalClusterSourceDbClusterIdentifier
-
The NeptuneGlobalClusterSource.sourceDbClusterIdentifier choice: sets
source_db_cluster_identifier. - NeptuneGlobalClusterSourceEngine
-
The NeptuneGlobalClusterSource.engine choice: sets
engine. - NeptuneParameterGroupName
-
At most one of
name,name_prefixonaws_neptune_parameter_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - NeptuneParameterGroupNameChoice
-
The NeptuneParameterGroupName.name choice: sets
name. - NeptuneParameterGroupNamePrefix
-
The NeptuneParameterGroupName.namePrefix choice: sets
name_prefix. - NeptuneParameterGroupParameter
-
Typed helper for the
parameterblock ofaws_neptune_parameter_group(derived from provider schema). - NeptuneSubnetGroupName
-
At most one of
name,name_prefixonaws_neptune_subnet_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - NeptuneSubnetGroupNameChoice
-
The NeptuneSubnetGroupName.name choice: sets
name. - NeptuneSubnetGroupNamePrefix
-
The NeptuneSubnetGroupName.namePrefix choice: sets
name_prefix.
Enums
- NeptuneClusterEnableCloudwatchLogsExports
-
Neptune Cluster Enable Cloudwatch Logs enum for
enable_cloudwatch_logs_exports. - NeptuneClusterEndpointType
-
Neptune Cluster Endpoint enum for
endpoint_type. - NeptuneClusterEngine
-
Neptune Cluster enum for
engine. - NeptuneClusterInstanceEngine
-
Neptune Cluster Instance enum for
engine. - NeptuneClusterParameterGroupApplyMethod
-
apply_method— derived from the provider schema description. - NeptuneClusterStorageType
-
Neptune Cluster Storage enum for
storage_type. - NeptuneGlobalClusterEngine
-
Neptune Global Cluster enum for
engine. - NeptuneParameterGroupApplyMethod
-
apply_method— derived from the provider schema description.