pipes library
AWS EventBridge Pipes.
Classes
- AwsPipesPipe
-
Factory wrapper for
aws_pipes_pipe. - PipesPipeActivemqBrokerParameters
-
Typed helper for the
source_parameters.activemq_broker_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeActivemqBrokerParametersCredentials
-
Typed helper for the
source_parameters.activemq_broker_parameters.credentialsblock ofaws_pipes_pipe(derived from provider schema). Shared by every block of this shape in the resource. - PipesPipeArrayProperties
-
Typed helper for the
target_parameters.batch_job_parameters.array_propertiesblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeAwsVpcConfiguration
-
Typed helper for the
target_parameters.ecs_task_parameters.network_configuration.aws_vpc_configurationblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeBatchJobParameters
-
Typed helper for the
target_parameters.batch_job_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeCapacityProviderStrategy
-
Typed helper for the
target_parameters.ecs_task_parameters.capacity_provider_strategyblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeCloudwatchLogsLogDestination
-
Typed helper for the
log_configuration.cloudwatch_logs_log_destinationblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeCloudwatchLogsParameters
-
Typed helper for the
target_parameters.cloudwatch_logs_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeContainerOverride
-
Typed helper for the
target_parameters.ecs_task_parameters.overrides.container_overrideblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeContainerOverrideResourceRequirement
-
Typed helper for the
target_parameters.ecs_task_parameters.overrides.container_override.resource_requirementblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeContainerOverrides
-
Typed helper for the
target_parameters.batch_job_parameters.container_overridesblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeDeadLetterConfig
-
Typed helper for the
source_parameters.dynamodb_stream_parameters.dead_letter_configblock ofaws_pipes_pipe(derived from provider schema). Shared by every block of this shape in the resource. - PipesPipeDependsOn
-
Typed helper for the
target_parameters.batch_job_parameters.depends_onblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeDynamodbStreamParameters
-
Typed helper for the
source_parameters.dynamodb_stream_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeEcsTaskParameters
-
Typed helper for the
target_parameters.ecs_task_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeEnrichmentParameters
-
Typed helper for the
enrichment_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeEnvironment
-
Typed helper for the
target_parameters.batch_job_parameters.container_overrides.environmentblock ofaws_pipes_pipe(derived from provider schema). Shared by every block of this shape in the resource. - PipesPipeEnvironmentFile
-
Typed helper for the
target_parameters.ecs_task_parameters.overrides.container_override.environment_fileblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeEphemeralStorage
-
Typed helper for the
target_parameters.ecs_task_parameters.overrides.ephemeral_storageblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeEventbridgeEventBusParameters
-
Typed helper for the
target_parameters.eventbridge_event_bus_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeFilter
-
Typed helper for the
source_parameters.filter_criteria.filterblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeFilterCriteria
-
Typed helper for the
source_parameters.filter_criteriablock ofaws_pipes_pipe(derived from provider schema). - PipesPipeFirehoseLogDestination
-
Typed helper for the
log_configuration.firehose_log_destinationblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeHttpParameters
-
Typed helper for the
enrichment_parameters.http_parametersblock ofaws_pipes_pipe(derived from provider schema). Shared by every block of this shape in the resource. - PipesPipeInferenceAcceleratorOverride
-
Typed helper for the
target_parameters.ecs_task_parameters.overrides.inference_accelerator_overrideblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeLambdaFunctionParameters
-
Typed helper for the
target_parameters.lambda_function_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeLogConfiguration
-
Typed helper for the
log_configurationblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeManagedStreamingKafkaParameters
-
Typed helper for the
source_parameters.managed_streaming_kafka_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeManagedStreamingKafkaParametersCredentials
-
Typed helper for the
source_parameters.managed_streaming_kafka_parameters.credentialsblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeName
-
At most one of
name,name_prefixonaws_pipes_pipe: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - PipesPipeNameChoice
-
The PipesPipeName.name choice: sets
name. - PipesPipeNamePrefix
-
The PipesPipeName.namePrefix choice: sets
name_prefix. - PipesPipeNetworkConfiguration
-
Typed helper for the
target_parameters.ecs_task_parameters.network_configurationblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeOverrides
-
Typed helper for the
target_parameters.ecs_task_parameters.overridesblock ofaws_pipes_pipe(derived from provider schema). - PipesPipePipelineParameter
-
Typed helper for the
target_parameters.sagemaker_pipeline_parameters.pipeline_parameterblock ofaws_pipes_pipe(derived from provider schema). - PipesPipePlacementConstraint
-
Typed helper for the
target_parameters.ecs_task_parameters.placement_constraintblock ofaws_pipes_pipe(derived from provider schema). - PipesPipePlacementStrategy
-
Typed helper for the
target_parameters.ecs_task_parameters.placement_strategyblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeRabbitmqBrokerParameters
-
Typed helper for the
source_parameters.rabbitmq_broker_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeRedshiftDataParameters
-
Typed helper for the
target_parameters.redshift_data_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeResourceRequirement
-
Typed helper for the
target_parameters.batch_job_parameters.container_overrides.resource_requirementblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeRetryStrategy
-
Typed helper for the
target_parameters.batch_job_parameters.retry_strategyblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeS3LogDestination
-
Typed helper for the
log_configuration.s3_log_destinationblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeSagemakerPipelineParameters
-
Typed helper for the
target_parameters.sagemaker_pipeline_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeSelfManagedKafkaParameters
-
Typed helper for the
source_parameters.self_managed_kafka_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeSelfManagedKafkaParametersCredentials
-
Typed helper for the
source_parameters.self_managed_kafka_parameters.credentialsblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeSourceParameters
-
Typed helper for the
source_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeSourceParametersKinesisStreamParameters
-
Typed helper for the
source_parameters.kinesis_stream_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeSourceParametersService
-
At most one of
activemq_broker_parameters,dynamodb_stream_parameters,kinesis_stream_parameters,managed_streaming_kafka_parameters,rabbitmq_broker_parameters,self_managed_kafka_parameters,sqs_queue_parameterson thesource_parametersblock ofaws_pipes_pipe: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - PipesPipeSourceParametersServiceActivemqBrokerParameters
-
The PipesPipeSourceParametersService.activemqBrokerParameters choice: sets
activemq_broker_parameters. - PipesPipeSourceParametersServiceDynamodbStreamParameters
-
The PipesPipeSourceParametersService.dynamodbStreamParameters choice: sets
dynamodb_stream_parameters. - PipesPipeSourceParametersServiceKinesisStreamParameters
-
The PipesPipeSourceParametersService.kinesisStreamParameters choice: sets
kinesis_stream_parameters. - PipesPipeSourceParametersServiceManagedStreamingKafkaParameters
-
The PipesPipeSourceParametersService.managedStreamingKafkaParameters choice: sets
managed_streaming_kafka_parameters. - PipesPipeSourceParametersServiceRabbitmqBrokerParameters
-
The PipesPipeSourceParametersService.rabbitmqBrokerParameters choice: sets
rabbitmq_broker_parameters. - PipesPipeSourceParametersServiceSelfManagedKafkaParameters
-
The PipesPipeSourceParametersService.selfManagedKafkaParameters choice: sets
self_managed_kafka_parameters. - PipesPipeSourceParametersServiceSqsQueueParameters
-
The PipesPipeSourceParametersService.sqsQueueParameters choice: sets
sqs_queue_parameters. - PipesPipeSourceParametersSqsQueueParameters
-
Typed helper for the
source_parameters.sqs_queue_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeStepFunctionStateMachineParameters
-
Typed helper for the
target_parameters.step_function_state_machine_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeTargetParameters
-
Typed helper for the
target_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeTargetParametersKinesisStreamParameters
-
Typed helper for the
target_parameters.kinesis_stream_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeTargetParametersService
-
At most one of
batch_job_parameters,cloudwatch_logs_parameters,ecs_task_parameters,eventbridge_event_bus_parameters,http_parameters,kinesis_stream_parameters,lambda_function_parameters,redshift_data_parameters,sagemaker_pipeline_parameters,sqs_queue_parameters,step_function_state_machine_parameterson thetarget_parametersblock ofaws_pipes_pipe: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - PipesPipeTargetParametersServiceBatchJobParameters
-
The PipesPipeTargetParametersService.batchJobParameters choice: sets
batch_job_parameters. - PipesPipeTargetParametersServiceCloudwatchLogsParameters
-
The PipesPipeTargetParametersService.cloudwatchLogsParameters choice: sets
cloudwatch_logs_parameters. - PipesPipeTargetParametersServiceEcsTaskParameters
-
The PipesPipeTargetParametersService.ecsTaskParameters choice: sets
ecs_task_parameters. - PipesPipeTargetParametersServiceEventbridgeEventBusParameters
-
The PipesPipeTargetParametersService.eventbridgeEventBusParameters choice: sets
eventbridge_event_bus_parameters. - PipesPipeTargetParametersServiceHttpParameters
-
The PipesPipeTargetParametersService.httpParameters choice: sets
http_parameters. - PipesPipeTargetParametersServiceKinesisStreamParameters
-
The PipesPipeTargetParametersService.kinesisStreamParameters choice: sets
kinesis_stream_parameters. - PipesPipeTargetParametersServiceLambdaFunctionParameters
-
The PipesPipeTargetParametersService.lambdaFunctionParameters choice: sets
lambda_function_parameters. - PipesPipeTargetParametersServiceRedshiftDataParameters
-
The PipesPipeTargetParametersService.redshiftDataParameters choice: sets
redshift_data_parameters. - PipesPipeTargetParametersServiceSagemakerPipelineParameters
-
The PipesPipeTargetParametersService.sagemakerPipelineParameters choice: sets
sagemaker_pipeline_parameters. - PipesPipeTargetParametersServiceSqsQueueParameters
-
The PipesPipeTargetParametersService.sqsQueueParameters choice: sets
sqs_queue_parameters. - PipesPipeTargetParametersServiceStepFunctionStateMachineParameters
-
The PipesPipeTargetParametersService.stepFunctionStateMachineParameters choice: sets
step_function_state_machine_parameters. - PipesPipeTargetParametersSqsQueueParameters
-
Typed helper for the
target_parameters.sqs_queue_parametersblock ofaws_pipes_pipe(derived from provider schema). - PipesPipeVpc
-
Typed helper for the
source_parameters.self_managed_kafka_parameters.vpcblock ofaws_pipes_pipe(derived from provider schema).
Enums
- PipesPipeAssignPublicIp
-
assign_public_ip— derived from the provider schema description. - PipesPipeContainerOverrideType
-
type— derived from the provider schema description. - PipesPipeDependsOnType
-
type— derived from the provider schema description. - PipesPipeDesiredState
-
Pipes Pipe Desired enum for
desired_state. - PipesPipeDynamodbStreamParametersStartingPosition
-
starting_position— derived from the provider schema description. - PipesPipeEnvironmentFileType
-
type— derived from the provider schema description. - PipesPipeIncludeExecutionData
-
include_execution_data— derived from the provider schema description. - PipesPipeInvocationType
-
invocation_type— derived from the provider schema description. - PipesPipeKinesisStreamParametersStartingPosition
-
starting_position— derived from the provider schema description. - PipesPipeLaunchType
-
launch_type— derived from the provider schema description. - PipesPipeLevel
-
level— derived from the provider schema description. - PipesPipeOnPartialBatchItemFailure
-
on_partial_batch_item_failure— derived from the provider schema description. - PipesPipeOutputFormat
-
output_format— derived from the provider schema description. - PipesPipePlacementConstraintType
-
type— derived from the provider schema description. - PipesPipePlacementStrategyType
-
type— derived from the provider schema description. - PipesPipePropagateTags
-
propagate_tags— derived from the provider schema description. - PipesPipeResourceRequirementType
-
type— derived from the provider schema description.