rbin library
AWS Recycle Bin.
Classes
- AwsRbinRule
-
Factory wrapper for
aws_rbin_rule. - RbinRuleExcludeResourceTags
-
Typed helper for the
exclude_resource_tagsblock ofaws_rbin_rule(derived from provider schema). - RbinRuleLockConfiguration
-
Typed helper for the
lock_configurationblock ofaws_rbin_rule(derived from provider schema). - RbinRuleResourceTags
-
Typed helper for the
resource_tagsblock ofaws_rbin_rule(derived from provider schema). - RbinRuleRetentionPeriod
-
Typed helper for the
retention_periodblock ofaws_rbin_rule(derived from provider schema). - RbinRuleTagFilter
-
At most one of
exclude_resource_tags,resource_tagsonaws_rbin_rule: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RbinRuleTagFilterExcludeResourceTags
-
The RbinRuleTagFilter.excludeResourceTags choice: sets
exclude_resource_tags. - RbinRuleTagFilterResourceTags
-
The RbinRuleTagFilter.resourceTags choice: sets
resource_tags. - RbinRuleUnlockDelay
-
Typed helper for the
lock_configuration.unlock_delayblock ofaws_rbin_rule(derived from provider schema).
Enums
- RbinRuleResourceType
-
Rbin Rule Resource enum for
resource_type. - RbinRuleRetentionPeriodUnit
-
retention_period_unit— derived from the provider schema description. - RbinRuleUnlockDelayUnit
-
unlock_delay_unit— derived from the provider schema description.