rds library
AWS RDS clusters, proxies, and Aurora.
Classes
- AwsRdsCertificate
-
Factory wrapper for
aws_rds_certificate. - AwsRdsCluster
-
Factory wrapper for
aws_rds_cluster. - AwsRdsClusterActivityStream
-
Factory wrapper for
aws_rds_cluster_activity_stream. - AwsRdsClusterEndpoint
-
Factory wrapper for
aws_rds_cluster_endpoint. - AwsRdsClusterInstance
-
Factory wrapper for
aws_rds_cluster_instance. - AwsRdsClusterParameterGroup
-
Factory wrapper for
aws_rds_cluster_parameter_group. - AwsRdsClusterRoleAssociation
-
Factory wrapper for
aws_rds_cluster_role_association. - AwsRdsClusterSnapshotCopy
-
Factory wrapper for
aws_rds_cluster_snapshot_copy. - AwsRdsCustomDbEngineVersion
-
Factory wrapper for
aws_rds_custom_db_engine_version. - AwsRdsExportTask
-
Factory wrapper for
aws_rds_export_task. - AwsRdsGlobalCluster
-
Factory wrapper for
aws_rds_global_cluster. - AwsRdsInstanceState
-
Factory wrapper for
aws_rds_instance_state. - AwsRdsIntegration
-
Factory wrapper for
aws_rds_integration. - AwsRdsReservedInstance
-
Factory wrapper for
aws_rds_reserved_instance. - AwsRdsShardGroup
-
Factory wrapper for
aws_rds_shard_group. - RdsClusterEndpointExcludedMembers
-
The RdsClusterEndpointMembers.excludedMembers choice: sets
excluded_members. - RdsClusterEndpointMembers
-
At most one of
excluded_members,static_membersonaws_rds_cluster_endpoint: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RdsClusterEndpointStaticMembers
-
The RdsClusterEndpointMembers.staticMembers choice: sets
static_members. - RdsClusterIdentifier
-
At most one of
cluster_identifier,cluster_identifier_prefixonaws_rds_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RdsClusterIdentifierChoice
-
The RdsClusterIdentifier.clusterIdentifier choice: sets
cluster_identifier. - RdsClusterIdentifierPrefix
-
The RdsClusterIdentifier.clusterIdentifierPrefix choice: sets
cluster_identifier_prefix. - RdsClusterInstanceIdentifier
-
At most one of
identifier,identifier_prefixonaws_rds_cluster_instance: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RdsClusterInstanceIdentifierChoice
-
The RdsClusterInstanceIdentifier.identifier choice: sets
identifier. - RdsClusterInstanceIdentifierPrefix
-
The RdsClusterInstanceIdentifier.identifierPrefix choice: sets
identifier_prefix. - RdsClusterMasterPassword
-
At most one of
manage_master_user_password,master_password,master_password_woonaws_rds_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RdsClusterMasterPasswordChoice
-
The RdsClusterMasterPassword.masterPassword choice: sets
master_password. - RdsClusterMasterPasswordManageMasterUserPassword
-
The RdsClusterMasterPassword.manageMasterUserPassword choice: sets
manage_master_user_password. - RdsClusterMasterPasswordWo
-
The RdsClusterMasterPassword.masterPasswordWo choice: sets
master_password_wo. - RdsClusterParameterGroupName
-
At most one of
name,name_prefixonaws_rds_cluster_parameter_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RdsClusterParameterGroupNameChoice
-
The RdsClusterParameterGroupName.name choice: sets
name. - RdsClusterParameterGroupNamePrefix
-
The RdsClusterParameterGroupName.namePrefix choice: sets
name_prefix. - RdsClusterParameterGroupParameter
-
Typed helper for the
parameterblock ofaws_rds_cluster_parameter_group(derived from provider schema). - RdsClusterRestoreToPointInTime
-
Typed helper for the
restore_to_point_in_timeblock ofaws_rds_cluster(derived from provider schema). - RdsClusterS3Import
-
Typed helper for the
s3_importblock ofaws_rds_cluster(derived from provider schema). - RdsClusterScalingConfiguration
-
Typed helper for the
scaling_configurationblock ofaws_rds_cluster(derived from provider schema). - RdsClusterServerlessv2ScalingConfiguration
-
Typed helper for the
serverlessv2_scaling_configurationblock ofaws_rds_cluster(derived from provider schema). - RdsClusterSourceCluster
-
Exactly one of
source_cluster_identifier,source_cluster_resource_idon therestore_to_point_in_timeblock ofaws_rds_cluster: the provider rejects none and more than one, so each variant sets one of them. - RdsClusterSourceClusterIdentifier
-
The RdsClusterSourceCluster.sourceClusterIdentifier choice: sets
source_cluster_identifier. - RdsClusterSourceClusterResourceId
-
The RdsClusterSourceCluster.sourceClusterResourceId choice: sets
source_cluster_resource_id. - RdsClusterTarget
-
Exactly one of
restore_to_time,use_latest_restorable_timeon therestore_to_point_in_timeblock ofaws_rds_cluster: the provider rejects none and more than one, so each variant sets one of them. - RdsClusterTargetRestoreToTime
-
The RdsClusterTarget.restoreToTime choice: sets
restore_to_time. - RdsClusterTargetUseLatestRestorableTime
-
The RdsClusterTarget.useLatestRestorableTime choice: sets
use_latest_restorable_time. - RdsCustomDbEngineVersionManifest
-
At most one of
filename,manifestonaws_rds_custom_db_engine_version: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RdsCustomDbEngineVersionManifestChoice
-
The RdsCustomDbEngineVersionManifest.manifest choice: sets
manifest. - RdsCustomDbEngineVersionManifestFilename
-
The RdsCustomDbEngineVersionManifest.filename choice: sets
filename.
Enums
- RdsClusterActivityStreamMode
-
Rds Cluster Activity Stream enum for
mode. - RdsClusterDatabaseInsightsMode
-
Rds Cluster Database Insights enum for
database_insights_mode. - RdsClusterEnabledCloudwatchLogsExports
-
Rds Cluster Enabled Cloudwatch Logs enum for
enabled_cloudwatch_logs_exports. - RdsClusterEndpointCustomEndpointType
-
Rds Cluster Endpoint Custom Endpoint enum for
custom_endpoint_type. - RdsClusterEngineLifecycleSupport
-
Rds Cluster Engine Lifecycle enum for
engine_lifecycle_support. - RdsClusterEngineMode
-
Rds Cluster Engine enum for
engine_mode. - RdsClusterNetworkType
-
Rds Cluster Network enum for
network_type. - RdsClusterParameterGroupApplyMethod
-
apply_method— derived from the provider schema description. - RdsClusterRestoreType
-
restore_type— derived from the provider schema description. - RdsClusterScalabilityType
-
Rds Cluster Scalability enum for
cluster_scalability_type. - RdsClusterTimeoutAction
-
timeout_action— derived from the provider schema description. - RdsCustomDbEngineVersionStatus
-
Rds Custom Db Engine Version enum for
status. - RdsGlobalClusterEngine
-
Rds Global Cluster enum for
engine. - RdsGlobalClusterEngineLifecycleSupport
-
Rds Global Cluster Engine Lifecycle enum for
engine_lifecycle_support. - RdsInstanceState
-
Rds Instance enum for
state.