redshift library
AWS Redshift.
Classes
- AwsRedshiftAuthenticationProfile
-
Factory wrapper for
aws_redshift_authentication_profile. - AwsRedshiftCluster
-
Factory wrapper for
aws_redshift_cluster. - AwsRedshiftClusterIamRoles
-
Factory wrapper for
aws_redshift_cluster_iam_roles. - AwsRedshiftClusterSnapshot
-
Factory wrapper for
aws_redshift_cluster_snapshot. -
Factory wrapper for
aws_redshift_data_share_authorization. -
Factory wrapper for
aws_redshift_data_share_consumer_association. - AwsRedshiftEndpointAccess
-
Factory wrapper for
aws_redshift_endpoint_access. - AwsRedshiftEndpointAuthorization
-
Factory wrapper for
aws_redshift_endpoint_authorization. - AwsRedshiftEventSubscription
-
Factory wrapper for
aws_redshift_event_subscription. - AwsRedshiftHsmClientCertificate
-
Factory wrapper for
aws_redshift_hsm_client_certificate. - AwsRedshiftHsmConfiguration
-
Factory wrapper for
aws_redshift_hsm_configuration. - AwsRedshiftIdcApplication
-
Factory wrapper for
aws_redshift_idc_application. - AwsRedshiftIntegration
-
Factory wrapper for
aws_redshift_integration. - AwsRedshiftLogging
-
Factory wrapper for
aws_redshift_logging. - AwsRedshiftNamespaceRegistration
-
Factory wrapper for
aws_redshift_namespace_registration. - AwsRedshiftParameterGroup
-
Factory wrapper for
aws_redshift_parameter_group. - AwsRedshiftPartner
-
Factory wrapper for
aws_redshift_partner. - AwsRedshiftResourcePolicy
-
Factory wrapper for
aws_redshift_resource_policy. - AwsRedshiftScheduledAction
-
Factory wrapper for
aws_redshift_scheduled_action. - AwsRedshiftSnapshotCopy
-
Factory wrapper for
aws_redshift_snapshot_copy. - AwsRedshiftSnapshotCopyGrant
-
Factory wrapper for
aws_redshift_snapshot_copy_grant. - AwsRedshiftSnapshotSchedule
-
Factory wrapper for
aws_redshift_snapshot_schedule. - AwsRedshiftSnapshotScheduleAssociation
-
Factory wrapper for
aws_redshift_snapshot_schedule_association. - AwsRedshiftSubnetGroup
-
Factory wrapper for
aws_redshift_subnet_group. - AwsRedshiftUsageLimit
-
Factory wrapper for
aws_redshift_usage_limit. - RedshiftClusterManageMasterPassword
-
The RedshiftClusterMasterPassword.manageMasterPassword choice: sets
manage_master_password. - RedshiftClusterMasterPassword
-
At most one of
manage_master_password,master_password,master_password_woonaws_redshift_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RedshiftClusterMasterPasswordChoice
-
The RedshiftClusterMasterPassword.masterPassword choice: sets
master_password. - RedshiftClusterMasterPasswordWo
-
The RedshiftClusterMasterPassword.masterPasswordWo choice: sets
master_password_wo. - RedshiftClusterSnapshot
-
At most one of
snapshot_arn,snapshot_identifieronaws_redshift_cluster: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RedshiftClusterSnapshotArn
-
The RedshiftClusterSnapshot.snapshotArn choice: sets
snapshot_arn. - RedshiftClusterSnapshotIdentifier
-
The RedshiftClusterSnapshot.snapshotIdentifier choice: sets
snapshot_identifier. -
Exactly one of
associate_entire_account,consumer_arn,consumer_regiononaws_redshift_data_share_consumer_association: the provider rejects none and more than one, so each variant sets one of them. -
The RedshiftDataShareConsumerAssociationConsumer.consumerArn choice: sets
consumer_arn. -
The RedshiftDataShareConsumerAssociationConsumer.associateEntireAccount choice: sets
associate_entire_account. -
The RedshiftDataShareConsumerAssociationConsumer.consumerRegion choice: sets
consumer_region. - RedshiftIdcApplicationAuthorizedTokenIssuer
-
Typed helper for the
authorized_token_issuerblock ofaws_redshift_idc_application(derived from provider schema). - RedshiftIdcApplicationConnect
-
Typed helper for the
service_integration.redshift.connectblock ofaws_redshift_idc_application(derived from provider schema). - RedshiftIdcApplicationLakeFormation
-
Typed helper for the
service_integration.lake_formationblock ofaws_redshift_idc_application(derived from provider schema). - RedshiftIdcApplicationLakeFormationQuery
-
Typed helper for the
service_integration.lake_formation.lake_formation_queryblock ofaws_redshift_idc_application(derived from provider schema). - RedshiftIdcApplicationReadWriteAccess
-
Typed helper for the
service_integration.s3_access_grants.read_write_accessblock ofaws_redshift_idc_application(derived from provider schema). - RedshiftIdcApplicationRedshift
-
Typed helper for the
service_integration.redshiftblock ofaws_redshift_idc_application(derived from provider schema). - RedshiftIdcApplicationS3AccessGrants
-
Typed helper for the
service_integration.s3_access_grantsblock ofaws_redshift_idc_application(derived from provider schema). - RedshiftIdcApplicationServiceIntegration
-
Typed helper for the
service_integrationblock ofaws_redshift_idc_application(derived from provider schema). - RedshiftParameterGroupParameter
-
Typed helper for the
parameterblock ofaws_redshift_parameter_group(derived from provider schema). - RedshiftScheduledActionPauseCluster
-
Typed helper for the
target_action.pause_clusterblock ofaws_redshift_scheduled_action(derived from provider schema). - RedshiftScheduledActionResizeCluster
-
Typed helper for the
target_action.resize_clusterblock ofaws_redshift_scheduled_action(derived from provider schema). - RedshiftScheduledActionResumeCluster
-
Typed helper for the
target_action.resume_clusterblock ofaws_redshift_scheduled_action(derived from provider schema). - RedshiftScheduledActionTargetAction
-
Exactly one of
pause_cluster,resize_cluster,resume_clusteron thetarget_actionblock ofaws_redshift_scheduled_action: the provider rejects none and more than one, so each variant sets one of them. - RedshiftScheduledActionTargetActionPauseCluster
-
The RedshiftScheduledActionTargetAction.pauseCluster choice: sets
pause_cluster. - RedshiftScheduledActionTargetActionResizeCluster
-
The RedshiftScheduledActionTargetAction.resizeCluster choice: sets
resize_cluster. - RedshiftScheduledActionTargetActionResumeCluster
-
The RedshiftScheduledActionTargetAction.resumeCluster choice: sets
resume_cluster. - RedshiftSnapshotScheduleIdentifier
-
At most one of
identifier,identifier_prefixonaws_redshift_snapshot_schedule: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RedshiftSnapshotScheduleIdentifierChoice
-
The RedshiftSnapshotScheduleIdentifier.identifier choice: sets
identifier. - RedshiftSnapshotScheduleIdentifierPrefix
-
The RedshiftSnapshotScheduleIdentifier.identifierPrefix choice: sets
identifier_prefix.
Enums
- RedshiftClusterAquaConfigurationStatus
-
Redshift Cluster Aqua Configuration enum for
aqua_configuration_status. - RedshiftEventSubscriptionEventCategories
-
Redshift Event Subscription Event enum for
event_categories. - RedshiftEventSubscriptionSeverity
-
Redshift Event Subscription enum for
severity. - RedshiftEventSubscriptionSourceType
-
Redshift Event Subscription Source enum for
source_type. - RedshiftIdcApplicationAuthorization
-
authorization— derived from the provider schema description. - RedshiftIdcApplicationType
-
Redshift Idc Application enum for
application_type. - RedshiftLoggingLogDestinationType
-
Redshift Logging Log Destination enum for
log_destination_type. - RedshiftLoggingLogExports
-
Redshift Logging Log enum for
log_exports. - RedshiftUsageLimitBreachAction
-
Redshift Usage Limit Breach enum for
breach_action. - RedshiftUsageLimitFeatureType
-
Redshift Usage Limit Feature enum for
feature_type. - RedshiftUsageLimitPeriod
-
Redshift Usage Limit enum for
period. - RedshiftUsageLimitType
-
Redshift Usage Limit enum for
limit_type.