rekognition library
AWS Rekognition.
Classes
- AwsRekognitionCollection
-
Factory wrapper for
aws_rekognition_collection. - AwsRekognitionProject
-
Factory wrapper for
aws_rekognition_project. - AwsRekognitionStreamProcessor
-
Factory wrapper for
aws_rekognition_stream_processor. - RekognitionStreamProcessorBoundingBox
-
Typed helper for the
regions_of_interest.bounding_boxblock ofaws_rekognition_stream_processor(derived from provider schema). - RekognitionStreamProcessorConnectedHome
-
Typed helper for the
settings.connected_homeblock ofaws_rekognition_stream_processor(derived from provider schema). - RekognitionStreamProcessorDataSharingPreference
-
Typed helper for the
data_sharing_preferenceblock ofaws_rekognition_stream_processor(derived from provider schema). - RekognitionStreamProcessorFaceSearch
-
Typed helper for the
settings.face_searchblock ofaws_rekognition_stream_processor(derived from provider schema). - RekognitionStreamProcessorInput
-
Typed helper for the
inputblock ofaws_rekognition_stream_processor(derived from provider schema). - RekognitionStreamProcessorKinesisDataStream
-
Typed helper for the
output.kinesis_data_streamblock ofaws_rekognition_stream_processor(derived from provider schema). - RekognitionStreamProcessorKinesisVideoStream
-
Typed helper for the
input.kinesis_video_streamblock ofaws_rekognition_stream_processor(derived from provider schema). - RekognitionStreamProcessorNotificationChannel
-
Typed helper for the
notification_channelblock ofaws_rekognition_stream_processor(derived from provider schema). - RekognitionStreamProcessorOutput
-
At most one of
kinesis_data_stream,s3_destinationon theoutputblock ofaws_rekognition_stream_processor: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RekognitionStreamProcessorOutputKinesisDataStream
-
The RekognitionStreamProcessorOutput.kinesisDataStream choice: sets
kinesis_data_stream. - RekognitionStreamProcessorOutputS3Destination
-
The RekognitionStreamProcessorOutput.s3Destination choice: sets
s3_destination. - RekognitionStreamProcessorPolygon
-
Typed helper for the
regions_of_interest.polygonblock ofaws_rekognition_stream_processor(derived from provider schema). - RekognitionStreamProcessorRegionsOfInterest
-
At most one of
bounding_box,polygonon theregions_of_interestblock ofaws_rekognition_stream_processor: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RekognitionStreamProcessorRegionsOfInterestBoundingBox
-
The RekognitionStreamProcessorRegionsOfInterest.boundingBox choice: sets
bounding_box. - RekognitionStreamProcessorRegionsOfInterestPolygon
-
The RekognitionStreamProcessorRegionsOfInterest.polygon choice: sets
polygon. - RekognitionStreamProcessorS3Destination
-
Typed helper for the
output.s3_destinationblock ofaws_rekognition_stream_processor(derived from provider schema). - RekognitionStreamProcessorSettings
-
At most one of
connected_home,face_searchon thesettingsblock ofaws_rekognition_stream_processor: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - RekognitionStreamProcessorSettingsConnectedHome
-
The RekognitionStreamProcessorSettings.connectedHome choice: sets
connected_home. - RekognitionStreamProcessorSettingsFaceSearch
-
The RekognitionStreamProcessorSettings.faceSearch choice: sets
face_search.
Enums
- RekognitionProjectAutoUpdate
-
Rekognition Project Auto enum for
auto_update. - RekognitionProjectFeature
-
Rekognition Project enum for
feature. - RekognitionStreamProcessorLabels
-
labels— derived from the provider schema description.