route53 library
AWS Route 53.
Classes
- AwsRoute53CidrCollection
-
Factory wrapper for
aws_route53_cidr_collection. - AwsRoute53CidrLocation
-
Factory wrapper for
aws_route53_cidr_location. - AwsRoute53DelegationSet
-
Factory wrapper for
aws_route53_delegation_set. - AwsRoute53HealthCheck
-
Factory wrapper for
aws_route53_health_check. - AwsRoute53HostedZoneDnssec
-
Factory wrapper for
aws_route53_hosted_zone_dnssec. - AwsRoute53KeySigningKey
-
Factory wrapper for
aws_route53_key_signing_key. - AwsRoute53QueryLog
-
Factory wrapper for
aws_route53_query_log. - AwsRoute53Record
-
Factory wrapper for
aws_route53_record. - AwsRoute53RecordsExclusive
-
Factory wrapper for
aws_route53_records_exclusive. - AwsRoute53ResolverConfig
-
Factory wrapper for
aws_route53_resolver_config. - AwsRoute53ResolverDnssecConfig
-
Factory wrapper for
aws_route53_resolver_dnssec_config. - AwsRoute53ResolverEndpoint
-
Factory wrapper for
aws_route53_resolver_endpoint. - AwsRoute53ResolverFirewallConfig
-
Factory wrapper for
aws_route53_resolver_firewall_config. - AwsRoute53ResolverFirewallDomainList
-
Factory wrapper for
aws_route53_resolver_firewall_domain_list. - AwsRoute53ResolverFirewallRule
-
Factory wrapper for
aws_route53_resolver_firewall_rule. - AwsRoute53ResolverFirewallRuleGroup
-
Factory wrapper for
aws_route53_resolver_firewall_rule_group. - AwsRoute53ResolverFirewallRuleGroupAssociation
-
Factory wrapper for
aws_route53_resolver_firewall_rule_group_association. - AwsRoute53ResolverQueryLogConfig
-
Factory wrapper for
aws_route53_resolver_query_log_config. - AwsRoute53ResolverQueryLogConfigAssociation
-
Factory wrapper for
aws_route53_resolver_query_log_config_association. - AwsRoute53ResolverRule
-
Factory wrapper for
aws_route53_resolver_rule. - AwsRoute53ResolverRuleAssociation
-
Factory wrapper for
aws_route53_resolver_rule_association. - AwsRoute53TrafficPolicy
-
Factory wrapper for
aws_route53_traffic_policy. - AwsRoute53TrafficPolicyInstance
-
Factory wrapper for
aws_route53_traffic_policy_instance. - AwsRoute53VpcAssociationAuthorization
-
Factory wrapper for
aws_route53_vpc_association_authorization. - AwsRoute53Zone
-
Factory wrapper for
aws_route53_zone. - AwsRoute53ZoneAssociation
-
Factory wrapper for
aws_route53_zone_association. - Route53RecordAlias
-
Typed helper for the
aliasblock ofaws_route53_record(derived from provider schema). - Route53RecordCidrRoutingPolicy
-
Typed helper for the
cidr_routing_policyblock ofaws_route53_record(derived from provider schema). - Route53RecordCidrRoutingPolicyChoice
-
The Route53RecordRoutingPolicy.cidrRoutingPolicy choice: sets
cidr_routing_policy. - Route53RecordCoordinates
-
Typed helper for the
geoproximity_routing_policy.coordinatesblock ofaws_route53_record(derived from provider schema). - Route53RecordFailoverRoutingPolicy
-
Typed helper for the
failover_routing_policyblock ofaws_route53_record(derived from provider schema). - Route53RecordFailoverRoutingPolicyChoice
-
The Route53RecordRoutingPolicy.failoverRoutingPolicy choice: sets
failover_routing_policy. - Route53RecordGeolocationRoutingPolicy
-
Typed helper for the
geolocation_routing_policyblock ofaws_route53_record(derived from provider schema). - Route53RecordGeolocationRoutingPolicyChoice
-
The Route53RecordRoutingPolicy.geolocationRoutingPolicy choice: sets
geolocation_routing_policy. - Route53RecordGeoproximityRoutingPolicy
-
Typed helper for the
geoproximity_routing_policyblock ofaws_route53_record(derived from provider schema). - Route53RecordGeoproximityRoutingPolicyChoice
-
The Route53RecordRoutingPolicy.geoproximityRoutingPolicy choice: sets
geoproximity_routing_policy. - Route53RecordLatencyRoutingPolicy
-
Typed helper for the
latency_routing_policyblock ofaws_route53_record(derived from provider schema). - Route53RecordLatencyRoutingPolicyChoice
-
The Route53RecordRoutingPolicy.latencyRoutingPolicy choice: sets
latency_routing_policy. - Route53RecordMultivalueAnswerRoutingPolicy
-
The Route53RecordRoutingPolicy.multivalueAnswerRoutingPolicy choice: sets
multivalue_answer_routing_policy. - Route53RecordRoutingPolicy
-
At most one of
cidr_routing_policy,failover_routing_policy,geolocation_routing_policy,geoproximity_routing_policy,latency_routing_policy,multivalue_answer_routing_policy,weighted_routing_policyonaws_route53_record: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - Route53RecordsExclusiveAliasTarget
-
Typed helper for the
resource_record_set.alias_targetblock ofaws_route53_records_exclusive(derived from provider schema). - Route53RecordsExclusiveCidrRoutingConfig
-
Typed helper for the
resource_record_set.cidr_routing_configblock ofaws_route53_records_exclusive(derived from provider schema). - Route53RecordsExclusiveCoordinates
-
Typed helper for the
resource_record_set.geoproximity_location.coordinatesblock ofaws_route53_records_exclusive(derived from provider schema). - Route53RecordsExclusiveGeolocation
-
Typed helper for the
resource_record_set.geolocationblock ofaws_route53_records_exclusive(derived from provider schema). - Route53RecordsExclusiveGeoproximityLocation
-
Typed helper for the
resource_record_set.geoproximity_locationblock ofaws_route53_records_exclusive(derived from provider schema). - Route53RecordsExclusiveResourceRecords
-
Typed helper for the
resource_record_set.resource_recordsblock ofaws_route53_records_exclusive(derived from provider schema). - Route53RecordsExclusiveResourceRecordSet
-
Typed helper for the
resource_record_setblock ofaws_route53_records_exclusive(derived from provider schema). - Route53RecordTarget
-
Exactly one of
alias,recordsonaws_route53_record: the provider rejects none and more than one, so each variant sets one of them. - Route53RecordTargetAlias
-
The Route53RecordTarget.alias choice: sets
alias. - Route53RecordTargetRecords
-
The Route53RecordTarget.records choice: sets
records. - Route53RecordWeightedRoutingPolicy
-
Typed helper for the
weighted_routing_policyblock ofaws_route53_record(derived from provider schema). - Route53RecordWeightedRoutingPolicyChoice
-
The Route53RecordRoutingPolicy.weightedRoutingPolicy choice: sets
weighted_routing_policy. - Route53ResolverEndpointIpAddress
-
Typed helper for the
ip_addressblock ofaws_route53_resolver_endpoint(derived from provider schema). - Route53ResolverRuleTargetIp
-
Typed helper for the
target_ipblock ofaws_route53_resolver_rule(derived from provider schema). - Route53ZoneVisibility
-
At most one of
delegation_set_id,vpconaws_route53_zone: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - Route53ZoneVisibilityDelegationSetId
-
The Route53ZoneVisibility.delegationSetId choice: sets
delegation_set_id. - Route53ZoneVisibilityVpc
-
The Route53ZoneVisibility.vpc choice: sets
vpc. - Route53ZoneVpc
-
Typed helper for the
vpcblock ofaws_route53_zone(derived from provider schema).
Enums
- Route53HealthCheckCloudwatchAlarmRegion
-
Route53 Health Check Cloudwatch Alarm enum for
cloudwatch_alarm_region. - Route53HealthCheckInsufficientDataHealthStatus
-
Route53 Health Check Insufficient Data Health enum for
insufficient_data_health_status. - Route53HealthCheckRegions
-
Route53 Health Check enum for
regions. - Route53HealthCheckType
-
Route53 Health Check enum for
type. - Route53HostedZoneDnssecSigningStatus
-
Route53 Hosted Zone Dnssec Signing enum for
signing_status. - Route53KeySigningKeyStatus
-
Route53 Key Signing Key enum for
status. - Route53RecordFailoverRoutingPolicyType
-
type— derived from the provider schema description. - Route53RecordRegion
-
region— derived from the provider schema description. - Route53RecordsExclusiveFailover
-
failover— derived from the provider schema description. - Route53RecordsExclusiveRegion
-
region— derived from the provider schema description. - Route53RecordsExclusiveType
-
type— derived from the provider schema description. - Route53RecordType
-
Route53 Record enum for
type. - Route53ResolverConfigAutodefinedReverseFlag
-
Route53 Resolver Config Autodefined Reverse enum for
autodefined_reverse_flag. - Route53ResolverEndpointDirection
-
Route53 Resolver Endpoint enum for
direction. - Route53ResolverEndpointProtocols
-
Route53 Resolver Endpoint enum for
protocols. - Route53ResolverEndpointType
-
Route53 Resolver Endpoint enum for
resolver_endpoint_type. - Route53ResolverFirewallConfigFirewallFailOpen
-
Route53 Resolver Firewall Config Firewall Fail enum for
firewall_fail_open. - Route53ResolverFirewallRuleAction
-
Route53 Resolver Firewall Rule enum for
action. - Route53ResolverFirewallRuleBlockOverrideDnsType
-
Route53 Resolver Firewall Rule Block Override Dns enum for
block_override_dns_type. - Route53ResolverFirewallRuleBlockResponse
-
Route53 Resolver Firewall Rule Block enum for
block_response. - Route53ResolverFirewallRuleConfidenceThreshold
-
Route53 Resolver Firewall Rule Confidence enum for
confidence_threshold. - Route53ResolverFirewallRuleDnsThreatProtection
-
Route53 Resolver Firewall Rule Dns Threat enum for
dns_threat_protection. - Route53ResolverFirewallRuleFirewallDomainRedirectionAction
-
Route53 Resolver Firewall Rule Firewall Domain Redirection enum for
firewall_domain_redirection_action. - Route53ResolverFirewallRuleGroupAssociationMutationProtection
-
Route53 Resolver Firewall Rule Group Association Mutation enum for
mutation_protection. - Route53ResolverRuleProtocol
-
protocol— derived from the provider schema description. - Route53ResolverRuleType
-
Route53 Resolver Rule enum for
rule_type. - Route53VpcAssociationAuthorizationVpcRegion
-
Route53 Vpc Association Authorization Vpc enum for
vpc_region. - Route53ZoneAssociationVpcRegion
-
Route53 Zone Association Vpc enum for
vpc_region.