s3 library
AWS S3.
Classes
- AwsS3AccessPoint
-
Factory wrapper for
aws_s3_access_point. - AwsS3AccountPublicAccessBlock
-
Factory wrapper for
aws_s3_account_public_access_block. - AwsS3Bucket
-
Factory wrapper for
aws_s3_bucket. - AwsS3BucketAbac
-
Factory wrapper for
aws_s3_bucket_abac. - AwsS3BucketAccelerateConfiguration
-
Factory wrapper for
aws_s3_bucket_accelerate_configuration. - AwsS3BucketAcl
-
Factory wrapper for
aws_s3_bucket_acl. - AwsS3BucketAnalyticsConfiguration
-
Factory wrapper for
aws_s3_bucket_analytics_configuration. - AwsS3BucketCorsConfiguration
-
Factory wrapper for
aws_s3_bucket_cors_configuration. - AwsS3BucketIntelligentTieringConfiguration
-
Factory wrapper for
aws_s3_bucket_intelligent_tiering_configuration. - AwsS3BucketInventory
-
Factory wrapper for
aws_s3_bucket_inventory. - AwsS3BucketLifecycleConfiguration
-
Factory wrapper for
aws_s3_bucket_lifecycle_configuration. - AwsS3BucketLogging
-
Factory wrapper for
aws_s3_bucket_logging. - AwsS3BucketMetadataConfiguration
-
Factory wrapper for
aws_s3_bucket_metadata_configuration. - AwsS3BucketMetric
-
Factory wrapper for
aws_s3_bucket_metric. - AwsS3BucketNotification
-
Factory wrapper for
aws_s3_bucket_notification. - AwsS3BucketObject
-
Factory wrapper for
aws_s3_bucket_object. - AwsS3BucketObjectLockConfiguration
-
Factory wrapper for
aws_s3_bucket_object_lock_configuration. - AwsS3BucketOwnershipControls
-
Factory wrapper for
aws_s3_bucket_ownership_controls. - AwsS3BucketPolicy
-
Factory wrapper for
aws_s3_bucket_policy. - AwsS3BucketPublicAccessBlock
-
Factory wrapper for
aws_s3_bucket_public_access_block. - AwsS3BucketReplicationConfiguration
-
Factory wrapper for
aws_s3_bucket_replication_configuration. - AwsS3BucketRequestPaymentConfiguration
-
Factory wrapper for
aws_s3_bucket_request_payment_configuration. - AwsS3BucketServerSideEncryptionConfiguration
-
Factory wrapper for
aws_s3_bucket_server_side_encryption_configuration. - AwsS3BucketVersioning
-
Factory wrapper for
aws_s3_bucket_versioning. - AwsS3BucketWebsiteConfiguration
-
Factory wrapper for
aws_s3_bucket_website_configuration. - AwsS3DirectoryBucket
-
Factory wrapper for
aws_s3_directory_bucket. - AwsS3Object
-
Factory wrapper for
aws_s3_object. - AwsS3ObjectCopy
-
Factory wrapper for
aws_s3_object_copy. - S3AccessPointPublicAccessBlockConfiguration
-
Typed helper for the
public_access_block_configurationblock ofaws_s3_access_point(derived from provider schema). - S3AccessPointVpcConfiguration
-
Typed helper for the
vpc_configurationblock ofaws_s3_access_point(derived from provider schema). - S3BucketAbacStatus
-
Typed helper for the
abac_statusblock ofaws_s3_bucket_abac(derived from provider schema). - S3BucketAccess
-
At most one of
acl,grantonaws_s3_bucket: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - S3BucketAccessAcl
-
The S3BucketAccess.acl choice: sets
acl. - S3BucketAccessControlTranslation
-
Typed helper for the
replication_configuration.rules.destination.access_control_translationblock ofaws_s3_bucket(derived from provider schema). - S3BucketAccessGrant
-
The S3BucketAccess.grant choice: sets
grant. - S3BucketAclAccessControlPolicy
-
Typed helper for the
access_control_policyblock ofaws_s3_bucket_acl(derived from provider schema). - S3BucketAclAccessControlPolicyChoice
-
The S3BucketAclPolicy.accessControlPolicy choice: sets
access_control_policy. - S3BucketAclGrant
-
Typed helper for the
access_control_policy.grantblock ofaws_s3_bucket_acl(derived from provider schema). - S3BucketAclGrantee
-
Typed helper for the
access_control_policy.grant.granteeblock ofaws_s3_bucket_acl(derived from provider schema). - S3BucketAclOwner
-
Typed helper for the
access_control_policy.ownerblock ofaws_s3_bucket_acl(derived from provider schema). - S3BucketAclPolicy
-
Exactly one of
access_control_policy,aclonaws_s3_bucket_acl: the provider rejects none and more than one, so each variant sets one of them. - S3BucketAclPolicyAcl
-
The S3BucketAclPolicy.acl choice: sets
acl. - S3BucketAnalyticsConfigurationDataExport
-
Typed helper for the
storage_class_analysis.data_exportblock ofaws_s3_bucket_analytics_configuration(derived from provider schema). - S3BucketAnalyticsConfigurationDestination
-
Typed helper for the
storage_class_analysis.data_export.destinationblock ofaws_s3_bucket_analytics_configuration(derived from provider schema). - S3BucketAnalyticsConfigurationFilter
-
Typed helper for the
filterblock ofaws_s3_bucket_analytics_configuration(derived from provider schema). - S3BucketAnalyticsConfigurationS3BucketDestination
-
Typed helper for the
storage_class_analysis.data_export.destination.s3_bucket_destinationblock ofaws_s3_bucket_analytics_configuration(derived from provider schema). - S3BucketAnalyticsConfigurationStorageClassAnalysis
-
Typed helper for the
storage_class_analysisblock ofaws_s3_bucket_analytics_configuration(derived from provider schema). - S3BucketCorsConfigurationCorsRule
-
Typed helper for the
cors_ruleblock ofaws_s3_bucket_cors_configuration(derived from provider schema). - S3BucketCorsRule
-
Typed helper for the
cors_ruleblock ofaws_s3_bucket(derived from provider schema). - S3BucketDestination
-
Typed helper for the
replication_configuration.rules.destinationblock ofaws_s3_bucket(derived from provider schema). - S3BucketExpiration
-
Typed helper for the
lifecycle_rule.expirationblock ofaws_s3_bucket(derived from provider schema). - S3BucketFilter
-
Typed helper for the
replication_configuration.rules.filterblock ofaws_s3_bucket(derived from provider schema). - S3BucketGrant
-
Typed helper for the
grantblock ofaws_s3_bucket(derived from provider schema). - S3BucketIntelligentTieringConfigurationFilter
-
Typed helper for the
filterblock ofaws_s3_bucket_intelligent_tiering_configuration(derived from provider schema). - S3BucketIntelligentTieringConfigurationTiering
-
Typed helper for the
tieringblock ofaws_s3_bucket_intelligent_tiering_configuration(derived from provider schema). - S3BucketInventoryDestination
-
Typed helper for the
destinationblock ofaws_s3_bucket_inventory(derived from provider schema). - S3BucketInventoryDestinationBucket
-
Typed helper for the
destination.bucketblock ofaws_s3_bucket_inventory(derived from provider schema). - S3BucketInventoryEncryption
-
At most one of
sse_kms,sse_s3on thedestination.bucket.encryptionblock ofaws_s3_bucket_inventory: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - S3BucketInventoryEncryptionSseKms
-
The S3BucketInventoryEncryption.sseKms choice: sets
sse_kms. - S3BucketInventoryEncryptionSseS3
-
The S3BucketInventoryEncryption.sseS3 choice: sets
sse_s3. - S3BucketInventoryFilter
-
Typed helper for the
filterblock ofaws_s3_bucket_inventory(derived from provider schema). - S3BucketInventorySchedule
-
Typed helper for the
scheduleblock ofaws_s3_bucket_inventory(derived from provider schema). - S3BucketInventorySseKms
-
Typed helper for the
destination.bucket.encryption.sse_kmsblock ofaws_s3_bucket_inventory(derived from provider schema). - S3BucketInventorySseS3
-
Typed helper for the
destination.bucket.encryption.sse_s3block ofaws_s3_bucket_inventory(derived from provider schema). - S3BucketLifecycleConfigurationAbortIncompleteMultipartUpload
-
Typed helper for the
rule.abort_incomplete_multipart_uploadblock ofaws_s3_bucket_lifecycle_configuration(derived from provider schema). - S3BucketLifecycleConfigurationAnd
-
Typed helper for the
rule.filter.andblock ofaws_s3_bucket_lifecycle_configuration(derived from provider schema). - S3BucketLifecycleConfigurationExpiration
-
Typed helper for the
rule.expirationblock ofaws_s3_bucket_lifecycle_configuration(derived from provider schema). - S3BucketLifecycleConfigurationFilter
-
Typed helper for the
rule.filterblock ofaws_s3_bucket_lifecycle_configuration(derived from provider schema). - S3BucketLifecycleConfigurationNoncurrentVersionExpiration
-
Typed helper for the
rule.noncurrent_version_expirationblock ofaws_s3_bucket_lifecycle_configuration(derived from provider schema). - S3BucketLifecycleConfigurationNoncurrentVersionTransition
-
Typed helper for the
rule.noncurrent_version_transitionblock ofaws_s3_bucket_lifecycle_configuration(derived from provider schema). - S3BucketLifecycleConfigurationRule
-
Typed helper for the
ruleblock ofaws_s3_bucket_lifecycle_configuration(derived from provider schema). - S3BucketLifecycleConfigurationTag
-
Typed helper for the
rule.filter.tagblock ofaws_s3_bucket_lifecycle_configuration(derived from provider schema). - S3BucketLifecycleConfigurationTransition
-
Typed helper for the
rule.transitionblock ofaws_s3_bucket_lifecycle_configuration(derived from provider schema). - S3BucketLifecycleRule
-
Typed helper for the
lifecycle_ruleblock ofaws_s3_bucket(derived from provider schema). - S3BucketLogging
-
Typed helper for the
loggingblock ofaws_s3_bucket(derived from provider schema). - S3BucketLoggingGrantee
-
Typed helper for the
target_grant.granteeblock ofaws_s3_bucket_logging(derived from provider schema). - S3BucketLoggingPartitionedPrefix
-
Typed helper for the
target_object_key_format.partitioned_prefixblock ofaws_s3_bucket_logging(derived from provider schema). - S3BucketLoggingSimplePrefix
-
Typed helper for the
target_object_key_format.simple_prefixblock ofaws_s3_bucket_logging(derived from provider schema). - S3BucketLoggingTargetGrant
-
Typed helper for the
target_grantblock ofaws_s3_bucket_logging(derived from provider schema). - S3BucketLoggingTargetObjectKeyFormat
-
Exactly one of
partitioned_prefix,simple_prefixon thetarget_object_key_formatblock ofaws_s3_bucket_logging: the provider rejects none and more than one, so each variant sets one of them. - S3BucketLoggingTargetObjectKeyFormatPartitionedPrefix
-
The S3BucketLoggingTargetObjectKeyFormat.partitionedPrefix choice: sets
partitioned_prefix. - S3BucketLoggingTargetObjectKeyFormatSimplePrefix
-
The S3BucketLoggingTargetObjectKeyFormat.simplePrefix choice: sets
simple_prefix. - S3BucketMetadataConfiguration
-
Typed helper for the
metadata_configurationblock ofaws_s3_bucket_metadata_configuration(derived from provider schema). - S3BucketMetadataConfigurationEncryptionConfiguration
-
Typed helper for the
metadata_configuration.inventory_table_configuration.encryption_configurationblock ofaws_s3_bucket_metadata_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3BucketMetadataConfigurationInventoryTableConfiguration
-
Typed helper for the
metadata_configuration.inventory_table_configurationblock ofaws_s3_bucket_metadata_configuration(derived from provider schema). - S3BucketMetadataConfigurationJournalTableConfiguration
-
Typed helper for the
metadata_configuration.journal_table_configurationblock ofaws_s3_bucket_metadata_configuration(derived from provider schema). - S3BucketMetadataConfigurationRecordExpiration
-
Typed helper for the
metadata_configuration.journal_table_configuration.record_expirationblock ofaws_s3_bucket_metadata_configuration(derived from provider schema). - S3BucketMetricFilter
-
Typed helper for the
filterblock ofaws_s3_bucket_metric(derived from provider schema). - S3BucketMetrics
-
Typed helper for the
replication_configuration.rules.destination.metricsblock ofaws_s3_bucket(derived from provider schema). - S3BucketMode
-
Exactly one of
index_document,redirect_all_requests_toon thewebsiteblock ofaws_s3_bucket: the provider rejects none and more than one, so each variant sets one of them. - S3BucketModeIndexDocument
-
The S3BucketMode.indexDocument choice: sets
index_document. - S3BucketModeRedirectAllRequestsTo
-
The S3BucketMode.redirectAllRequestsTo choice: sets
redirect_all_requests_to. - S3BucketName
-
At most one of
bucket,bucket_prefixonaws_s3_bucket: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - S3BucketNameBucket
-
The S3BucketName.bucket choice: sets
bucket. - S3BucketNameBucketPrefix
-
The S3BucketName.bucketPrefix choice: sets
bucket_prefix. - S3BucketNoncurrentVersionExpiration
-
Typed helper for the
lifecycle_rule.noncurrent_version_expirationblock ofaws_s3_bucket(derived from provider schema). - S3BucketNoncurrentVersionTransition
-
Typed helper for the
lifecycle_rule.noncurrent_version_transitionblock ofaws_s3_bucket(derived from provider schema). - S3BucketNotificationLambdaFunction
-
Typed helper for the
lambda_functionblock ofaws_s3_bucket_notification(derived from provider schema). - S3BucketNotificationQueue
-
Typed helper for the
queueblock ofaws_s3_bucket_notification(derived from provider schema). - S3BucketNotificationTopic
-
Typed helper for the
topicblock ofaws_s3_bucket_notification(derived from provider schema). - S3BucketObjectBody
-
At most one of
content,content_base64,sourceonaws_s3_bucket_object: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - S3BucketObjectBodyContent
-
The S3BucketObjectBody.content choice: sets
content. - S3BucketObjectBodyContentBase64
-
The S3BucketObjectBody.contentBase64 choice: sets
content_base64. - S3BucketObjectBodySource
-
The S3BucketObjectBody.source choice: sets
source. - S3BucketObjectIntegrity
-
At most one of
etag,kms_key_idonaws_s3_bucket_object: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - S3BucketObjectIntegrityEtag
-
The S3BucketObjectIntegrity.etag choice: sets
etag. - S3BucketObjectIntegrityKmsKeyId
-
The S3BucketObjectIntegrity.kmsKeyId choice: sets
kms_key_id. - S3BucketObjectLockConfigurationDefaultRetention
-
Typed helper for the
rule.default_retentionblock ofaws_s3_bucket_object_lock_configuration(derived from provider schema). - S3BucketObjectLockConfigurationPeriod
-
At most one of
days,yearson therule.default_retentionblock ofaws_s3_bucket_object_lock_configuration: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - S3BucketObjectLockConfigurationPeriodDays
-
The S3BucketObjectLockConfigurationPeriod.days choice: sets
days. - S3BucketObjectLockConfigurationPeriodYears
-
The S3BucketObjectLockConfigurationPeriod.years choice: sets
years. - S3BucketObjectLockConfigurationRule
-
Typed helper for the
ruleblock ofaws_s3_bucket_object_lock_configuration(derived from provider schema). - S3BucketOwnershipControlsRule
-
Typed helper for the
ruleblock ofaws_s3_bucket_ownership_controls(derived from provider schema). - S3BucketReplicationConfiguration
-
Typed helper for the
replication_configurationblock ofaws_s3_bucket(derived from provider schema). - S3BucketReplicationConfigurationAccessControlTranslation
-
Typed helper for the
rule.destination.access_control_translationblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationAnd
-
Typed helper for the
rule.filter.andblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationDeleteMarkerReplication
-
Typed helper for the
rule.delete_marker_replicationblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationDestination
-
Typed helper for the
rule.destinationblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationEncryptionConfiguration
-
Typed helper for the
rule.destination.encryption_configurationblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationEventThreshold
-
Typed helper for the
rule.destination.metrics.event_thresholdblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationExistingObjectReplication
-
Typed helper for the
rule.existing_object_replicationblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationFilter
-
Typed helper for the
rule.filterblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationMetrics
-
Typed helper for the
rule.destination.metricsblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationReplicaModifications
-
Typed helper for the
rule.source_selection_criteria.replica_modificationsblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationReplicationTime
-
Typed helper for the
rule.destination.replication_timeblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationRule
-
Typed helper for the
ruleblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationSourceSelectionCriteria
-
Typed helper for the
rule.source_selection_criteriablock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationSseKmsEncryptedObjects
-
Typed helper for the
rule.source_selection_criteria.sse_kms_encrypted_objectsblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationTag
-
Typed helper for the
rule.filter.tagblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationConfigurationTime
-
Typed helper for the
rule.destination.replication_time.timeblock ofaws_s3_bucket_replication_configuration(derived from provider schema). - S3BucketReplicationTime
-
Typed helper for the
replication_configuration.rules.destination.replication_timeblock ofaws_s3_bucket(derived from provider schema). - S3BucketRules
-
Typed helper for the
replication_configuration.rulesblock ofaws_s3_bucket(derived from provider schema). - S3BucketServerSideEncryptionConfigurationApplyServerSideEncryptionByDefault
-
Typed helper for the
rule.apply_server_side_encryption_by_defaultblock ofaws_s3_bucket_server_side_encryption_configuration(derived from provider schema). - S3BucketServerSideEncryptionConfigurationRule
-
Typed helper for the
ruleblock ofaws_s3_bucket_server_side_encryption_configuration(derived from provider schema). - S3BucketSourceSelectionCriteria
-
Typed helper for the
replication_configuration.rules.source_selection_criteriablock ofaws_s3_bucket(derived from provider schema). - S3BucketSseKmsEncryptedObjects
-
Typed helper for the
replication_configuration.rules.source_selection_criteria.sse_kms_encrypted_objectsblock ofaws_s3_bucket(derived from provider schema). - S3BucketTransition
-
Typed helper for the
lifecycle_rule.transitionblock ofaws_s3_bucket(derived from provider schema). - S3BucketVersioning
-
Typed helper for the
versioningblock ofaws_s3_bucket(derived from provider schema). - S3BucketVersioningConfiguration
-
Typed helper for the
versioning_configurationblock ofaws_s3_bucket_versioning(derived from provider schema). - S3BucketWebsite
-
Typed helper for the
websiteblock ofaws_s3_bucket(derived from provider schema). - S3BucketWebsiteConfigurationCondition
-
Typed helper for the
routing_rule.conditionblock ofaws_s3_bucket_website_configuration(derived from provider schema). - S3BucketWebsiteConfigurationErrorDocument
-
Typed helper for the
error_documentblock ofaws_s3_bucket_website_configuration(derived from provider schema). - S3BucketWebsiteConfigurationIndexDocument
-
Typed helper for the
index_documentblock ofaws_s3_bucket_website_configuration(derived from provider schema). - S3BucketWebsiteConfigurationRedirect
-
Typed helper for the
routing_rule.redirectblock ofaws_s3_bucket_website_configuration(derived from provider schema). - S3BucketWebsiteConfigurationRedirectAllRequestsTo
-
Typed helper for the
redirect_all_requests_toblock ofaws_s3_bucket_website_configuration(derived from provider schema). - S3BucketWebsiteConfigurationRoutingRule
-
Typed helper for the
routing_ruleblock ofaws_s3_bucket_website_configuration(derived from provider schema). - S3DirectoryBucketLocation
-
Typed helper for the
locationblock ofaws_s3_directory_bucket(derived from provider schema). - S3ObjectBody
-
At most one of
content,content_base64,sourceonaws_s3_object: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - S3ObjectBodyContent
-
The S3ObjectBody.content choice: sets
content. - S3ObjectBodyContentBase64
-
The S3ObjectBody.contentBase64 choice: sets
content_base64. - S3ObjectBodySource
-
The S3ObjectBody.source choice: sets
source. - S3ObjectCopyAccess
-
At most one of
acl,grantonaws_s3_object_copy: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - S3ObjectCopyAccessAcl
-
The S3ObjectCopyAccess.acl choice: sets
acl. - S3ObjectCopyAccessGrant
-
The S3ObjectCopyAccess.grant choice: sets
grant. - S3ObjectCopyDefaultTags
-
Typed helper for the
override_provider.default_tagsblock ofaws_s3_object_copy(derived from provider schema). - S3ObjectCopyGrant
-
Typed helper for the
grantblock ofaws_s3_object_copy(derived from provider schema). - S3ObjectCopyOverrideProvider
-
Typed helper for the
override_providerblock ofaws_s3_object_copy(derived from provider schema). - S3ObjectDefaultTags
-
Typed helper for the
override_provider.default_tagsblock ofaws_s3_object(derived from provider schema). - S3ObjectIntegrity
-
At most one of
etag,kms_key_idonaws_s3_object: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - S3ObjectIntegrityEtag
-
The S3ObjectIntegrity.etag choice: sets
etag. - S3ObjectIntegrityKmsKeyId
-
The S3ObjectIntegrity.kmsKeyId choice: sets
kms_key_id. - S3ObjectOverrideProvider
-
Typed helper for the
override_providerblock ofaws_s3_object(derived from provider schema).
Enums
- S3BucketAccelerateConfigurationStatus
-
S3 Bucket Accelerate Configuration enum for
status. - S3BucketAccelerationStatus
-
S3 Bucket Acceleration enum for
acceleration_status. - S3BucketAclPermission
-
permission— derived from the provider schema description. - S3BucketAclType
-
type— derived from the provider schema description. - S3BucketAnalyticsConfigurationFormat
-
format— derived from the provider schema description. - S3BucketAnalyticsConfigurationOutputSchemaVersion
-
output_schema_version— derived from the provider schema description. - S3BucketDeleteMarkerReplicationStatus
-
delete_marker_replication_status— derived from the provider schema description. - S3BucketDestinationStorageClass
-
storage_class— derived from the provider schema description. - S3BucketIntelligentTieringConfigurationAccessTier
-
access_tier— derived from the provider schema description. - S3BucketIntelligentTieringConfigurationStatus
-
S3 Bucket Intelligent Tiering Configuration enum for
status. - S3BucketInventoryFormat
-
format— derived from the provider schema description. - S3BucketInventoryFrequency
-
frequency— derived from the provider schema description. - S3BucketInventoryIncludedObjectVersions
-
S3 Bucket Inventory Included Object enum for
included_object_versions. - S3BucketInventoryOptionalFields
-
S3 Bucket Inventory Optional enum for
optional_fields. - S3BucketLifecycleConfigurationStatus
-
status— derived from the provider schema description. - S3BucketLifecycleConfigurationStorageClass
-
storage_class— derived from the provider schema description. - S3BucketLifecycleConfigurationTransitionDefaultMinimumObjectSize
-
S3 Bucket Lifecycle Configuration Transition Default Minimum Object enum for
transition_default_minimum_object_size. - S3BucketLoggingPartitionDateSource
-
partition_date_source— derived from the provider schema description. - S3BucketLoggingPermission
-
permission— derived from the provider schema description. - S3BucketLoggingType
-
type— derived from the provider schema description. - S3BucketMetadataConfigurationExpiration
-
expiration— derived from the provider schema description. - S3BucketMetadataConfigurationSseAlgorithm
-
sse_algorithm— derived from the provider schema description. - S3BucketMetadataConfigurationState
-
configuration_state— derived from the provider schema description. - S3BucketNamespace
-
S3 Bucket enum for
bucket_namespace. - S3BucketObjectAcl
-
S3 Bucket Object enum for
acl. - S3BucketObjectLockConfigurationMode
-
mode— derived from the provider schema description. - S3BucketObjectLockConfigurationObjectLockEnabled
-
S3 Bucket Object Lock Configuration Object Lock enum for
object_lock_enabled. - S3BucketObjectLockLegalHoldStatus
-
S3 Bucket Object Lock Legal Hold enum for
object_lock_legal_hold_status. - S3BucketObjectLockMode
-
S3 Bucket Object Lock enum for
object_lock_mode. - S3BucketObjectServerSideEncryption
-
S3 Bucket Object Server Side enum for
server_side_encryption. - S3BucketObjectStorageClass
-
S3 Bucket Object Storage enum for
storage_class. - S3BucketOwner
-
owner— derived from the provider schema description. - S3BucketOwnershipControlsObjectOwnership
-
object_ownership— derived from the provider schema description. - S3BucketPermissions
-
permissions— derived from the provider schema description. - S3BucketReplicationConfigurationOwner
-
owner— derived from the provider schema description. - S3BucketReplicationConfigurationStatus
-
status— derived from the provider schema description. - S3BucketReplicationConfigurationStorageClass
-
storage_class— derived from the provider schema description. - S3BucketRequestPayer
-
S3 Bucket Request enum for
request_payer. - S3BucketRequestPaymentConfigurationPayer
-
S3 Bucket Request Payment Configuration enum for
payer. - S3BucketServerSideEncryptionConfigurationBlockedEncryptionTypes
-
blocked_encryption_types— derived from the provider schema description. - S3BucketServerSideEncryptionConfigurationSseAlgorithm
-
sse_algorithm— derived from the provider schema description. - S3BucketStatus
-
status— derived from the provider schema description. - S3BucketStorageClass
-
storage_class— derived from the provider schema description. - S3BucketType
-
type— derived from the provider schema description. - S3BucketVersioningMfaDelete
-
mfa_delete— derived from the provider schema description. - S3BucketWebsiteConfigurationProtocol
-
protocol— derived from the provider schema description. - S3ObjectAcl
-
S3 Object enum for
acl. - S3ObjectChecksumAlgorithm
-
S3 Object Checksum enum for
checksum_algorithm. - S3ObjectCopyAcl
-
S3 Object Copy enum for
acl. - S3ObjectCopyChecksumAlgorithm
-
S3 Object Copy Checksum enum for
checksum_algorithm. - S3ObjectCopyMetadataDirective
-
S3 Object Copy Metadata enum for
metadata_directive. - S3ObjectCopyObjectLockLegalHoldStatus
-
S3 Object Copy Object Lock Legal Hold enum for
object_lock_legal_hold_status. - S3ObjectCopyObjectLockMode
-
S3 Object Copy Object Lock enum for
object_lock_mode. - S3ObjectCopyPermissions
-
permissions— derived from the provider schema description. - S3ObjectCopyRequestPayer
-
S3 Object Copy Request enum for
request_payer. - S3ObjectCopyServerSideEncryption
-
S3 Object Copy Server Side enum for
server_side_encryption. - S3ObjectCopyStorageClass
-
S3 Object Copy Storage enum for
storage_class. - S3ObjectCopyTaggingDirective
-
S3 Object Copy Tagging enum for
tagging_directive. - S3ObjectCopyType
-
type— derived from the provider schema description. - S3ObjectLockLegalHoldStatus
-
S3 Object Lock Legal Hold enum for
object_lock_legal_hold_status. - S3ObjectLockMode
-
S3 Object Lock enum for
object_lock_mode. - S3ObjectServerSideEncryption
-
S3 Object Server Side enum for
server_side_encryption. - S3ObjectStorageClass
-
S3 Object Storage enum for
storage_class.