s3control library
AWS S3 Control (account-level S3).
Classes
- AwsS3controlAccessGrant
-
Factory wrapper for
aws_s3control_access_grant. - AwsS3controlAccessGrantsInstance
-
Factory wrapper for
aws_s3control_access_grants_instance. - AwsS3controlAccessGrantsInstanceResourcePolicy
-
Factory wrapper for
aws_s3control_access_grants_instance_resource_policy. - AwsS3controlAccessGrantsLocation
-
Factory wrapper for
aws_s3control_access_grants_location. - AwsS3controlAccessPointPolicy
-
Factory wrapper for
aws_s3control_access_point_policy. - AwsS3controlBucket
-
Factory wrapper for
aws_s3control_bucket. - AwsS3controlBucketLifecycleConfiguration
-
Factory wrapper for
aws_s3control_bucket_lifecycle_configuration. - AwsS3controlBucketPolicy
-
Factory wrapper for
aws_s3control_bucket_policy. - AwsS3controlDirectoryBucketAccessPointScope
-
Factory wrapper for
aws_s3control_directory_bucket_access_point_scope. - AwsS3controlMultiRegionAccessPoint
-
Factory wrapper for
aws_s3control_multi_region_access_point. - AwsS3controlMultiRegionAccessPointPolicy
-
Factory wrapper for
aws_s3control_multi_region_access_point_policy. - AwsS3controlMultiRegionAccessPointRoutes
-
Factory wrapper for
aws_s3control_multi_region_access_point_routes. - AwsS3controlObjectLambdaAccessPoint
-
Factory wrapper for
aws_s3control_object_lambda_access_point. - AwsS3controlObjectLambdaAccessPointPolicy
-
Factory wrapper for
aws_s3control_object_lambda_access_point_policy. - AwsS3controlStorageLensConfiguration
-
Factory wrapper for
aws_s3control_storage_lens_configuration. - S3controlAccessGrantAccessGrantsLocationConfiguration
-
Typed helper for the
access_grants_location_configurationblock ofaws_s3control_access_grant(derived from provider schema). - S3controlAccessGrantGrantee
-
Typed helper for the
granteeblock ofaws_s3control_access_grant(derived from provider schema). - S3controlBucketLifecycleConfigurationAbortIncompleteMultipartUpload
-
Typed helper for the
rule.abort_incomplete_multipart_uploadblock ofaws_s3control_bucket_lifecycle_configuration(derived from provider schema). - S3controlBucketLifecycleConfigurationExpiration
-
Typed helper for the
rule.expirationblock ofaws_s3control_bucket_lifecycle_configuration(derived from provider schema). - S3controlBucketLifecycleConfigurationFilter
-
Typed helper for the
rule.filterblock ofaws_s3control_bucket_lifecycle_configuration(derived from provider schema). - S3controlBucketLifecycleConfigurationRule
-
Typed helper for the
ruleblock ofaws_s3control_bucket_lifecycle_configuration(derived from provider schema). - S3controlDirectoryBucketAccessPointScope
-
Typed helper for the
scopeblock ofaws_s3control_directory_bucket_access_point_scope(derived from provider schema). - S3controlMultiRegionAccessPointDetails
-
Typed helper for the
detailsblock ofaws_s3control_multi_region_access_point(derived from provider schema). - S3controlMultiRegionAccessPointDetailsRegion
-
Typed helper for the
details.regionblock ofaws_s3control_multi_region_access_point(derived from provider schema). - S3controlMultiRegionAccessPointPolicyDetails
-
Typed helper for the
detailsblock ofaws_s3control_multi_region_access_point_policy(derived from provider schema). - S3controlMultiRegionAccessPointPublicAccessBlock
-
Typed helper for the
details.public_access_blockblock ofaws_s3control_multi_region_access_point(derived from provider schema). - S3controlMultiRegionAccessPointRoutesRoute
-
Typed helper for the
routeblock ofaws_s3control_multi_region_access_point_routes(derived from provider schema). - S3controlObjectLambdaAccessPointAwsLambda
-
Typed helper for the
configuration.transformation_configuration.content_transformation.aws_lambdablock ofaws_s3control_object_lambda_access_point(derived from provider schema). - S3controlObjectLambdaAccessPointConfiguration
-
Typed helper for the
configurationblock ofaws_s3control_object_lambda_access_point(derived from provider schema). - S3controlObjectLambdaAccessPointContentTransformation
-
Typed helper for the
configuration.transformation_configuration.content_transformationblock ofaws_s3control_object_lambda_access_point(derived from provider schema). - S3controlObjectLambdaAccessPointTransformationConfiguration
-
Typed helper for the
configuration.transformation_configurationblock ofaws_s3control_object_lambda_access_point(derived from provider schema). - S3controlStorageLensConfiguration
-
Typed helper for the
storage_lens_configurationblock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationAccountLevel
-
Typed helper for the
storage_lens_configuration.account_levelblock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationActivityMetrics
-
Typed helper for the
storage_lens_configuration.account_level.activity_metricsblock ofaws_s3control_storage_lens_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3controlStorageLensConfigurationAdvancedCostOptimizationMetrics
-
Typed helper for the
storage_lens_configuration.account_level.advanced_cost_optimization_metricsblock ofaws_s3control_storage_lens_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3controlStorageLensConfigurationAdvancedDataProtectionMetrics
-
Typed helper for the
storage_lens_configuration.account_level.advanced_data_protection_metricsblock ofaws_s3control_storage_lens_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3controlStorageLensConfigurationAdvancedPerformanceMetrics
-
Typed helper for the
storage_lens_configuration.account_level.advanced_performance_metricsblock ofaws_s3control_storage_lens_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3controlStorageLensConfigurationAwsOrg
-
Typed helper for the
storage_lens_configuration.aws_orgblock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationBucketLevel
-
Typed helper for the
storage_lens_configuration.account_level.bucket_levelblock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationCloudWatchMetrics
-
Typed helper for the
storage_lens_configuration.data_export.cloud_watch_metricsblock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationDataExport
-
Typed helper for the
storage_lens_configuration.data_exportblock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationDetailedStatusCodeMetrics
-
Typed helper for the
storage_lens_configuration.account_level.detailed_status_code_metricsblock ofaws_s3control_storage_lens_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3controlStorageLensConfigurationEncryption
-
Typed helper for the
storage_lens_configuration.data_export.s3_bucket_destination.encryptionblock ofaws_s3control_storage_lens_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3controlStorageLensConfigurationExclude
-
Typed helper for the
storage_lens_configuration.excludeblock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationExpandedPrefixesDataExport
-
Typed helper for the
storage_lens_configuration.expanded_prefixes_data_exportblock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationInclude
-
Typed helper for the
storage_lens_configuration.includeblock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationPrefixLevel
-
Typed helper for the
storage_lens_configuration.account_level.bucket_level.prefix_levelblock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationS3BucketDestination
-
Typed helper for the
storage_lens_configuration.data_export.s3_bucket_destinationblock ofaws_s3control_storage_lens_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3controlStorageLensConfigurationSelectionCriteria
-
Typed helper for the
storage_lens_configuration.account_level.bucket_level.prefix_level.storage_metrics.selection_criteriablock ofaws_s3control_storage_lens_configuration(derived from provider schema). - S3controlStorageLensConfigurationSseKms
-
Typed helper for the
storage_lens_configuration.data_export.s3_bucket_destination.encryption.sse_kmsblock ofaws_s3control_storage_lens_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3controlStorageLensConfigurationSseS3
-
Typed helper for the
storage_lens_configuration.data_export.s3_bucket_destination.encryption.sse_s3block ofaws_s3control_storage_lens_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3controlStorageLensConfigurationStorageLensTableDestination
-
Typed helper for the
storage_lens_configuration.data_export.storage_lens_table_destinationblock ofaws_s3control_storage_lens_configuration(derived from provider schema). Shared by every block of this shape in the resource. - S3controlStorageLensConfigurationStorageMetrics
-
Typed helper for the
storage_lens_configuration.account_level.bucket_level.prefix_level.storage_metricsblock ofaws_s3control_storage_lens_configuration(derived from provider schema).
Enums
- S3controlAccessGrantGranteeType
-
grantee_type— derived from the provider schema description. - S3controlAccessGrantPermission
-
S3control Access Grant enum for
permission. - S3controlAccessGrantS3PrefixType
-
S3control Access Grant S3 Prefix enum for
s3_prefix_type. - S3controlDirectoryBucketAccessPointScopePermissions
-
permissions— derived from the provider schema description. - S3controlObjectLambdaAccessPointActions
-
actions— derived from the provider schema description. - S3controlObjectLambdaAccessPointAllowedFeatures
-
allowed_features— derived from the provider schema description.