securityhub library
AWS Security Hub.
Classes
- AwsSecurityhubAccount
-
Factory wrapper for
aws_securityhub_account. - AwsSecurityhubAccountV2
-
Factory wrapper for
aws_securityhub_account_v2. - AwsSecurityhubActionTarget
-
Factory wrapper for
aws_securityhub_action_target. - AwsSecurityhubAggregatorV2
-
Factory wrapper for
aws_securityhub_aggregator_v2. - AwsSecurityhubAutomationRule
-
Factory wrapper for
aws_securityhub_automation_rule. - AwsSecurityhubAutomationRuleV2
-
Factory wrapper for
aws_securityhub_automation_rule_v2. - AwsSecurityhubConfigurationPolicy
-
Factory wrapper for
aws_securityhub_configuration_policy. - AwsSecurityhubConfigurationPolicyAssociation
-
Factory wrapper for
aws_securityhub_configuration_policy_association. - AwsSecurityhubConnectorV2
-
Factory wrapper for
aws_securityhub_connector_v2. - AwsSecurityhubFeatureV2
-
Factory wrapper for
aws_securityhub_feature_v2. - AwsSecurityhubFindingAggregator
-
Factory wrapper for
aws_securityhub_finding_aggregator. - AwsSecurityhubInsight
-
Factory wrapper for
aws_securityhub_insight. - AwsSecurityhubInviteAccepter
-
Factory wrapper for
aws_securityhub_invite_accepter. - AwsSecurityhubMember
-
Factory wrapper for
aws_securityhub_member. - AwsSecurityhubOrganizationAdminAccount
-
Factory wrapper for
aws_securityhub_organization_admin_account. - AwsSecurityhubOrganizationConfiguration
-
Factory wrapper for
aws_securityhub_organization_configuration. - AwsSecurityhubProductSubscription
-
Factory wrapper for
aws_securityhub_product_subscription. - AwsSecurityhubStandardsControl
-
Factory wrapper for
aws_securityhub_standards_control. - AwsSecurityhubStandardsControlAssociation
-
Factory wrapper for
aws_securityhub_standards_control_association. - AwsSecurityhubStandardsSubscription
-
Factory wrapper for
aws_securityhub_standards_subscription. - SecurityhubAutomationRuleActions
-
Typed helper for the
actionsblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleAwsAccountId
-
Typed helper for the
criteria.aws_account_idblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleAwsAccountName
-
Typed helper for the
criteria.aws_account_nameblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleCompanyName
-
Typed helper for the
criteria.company_nameblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleComplianceAssociatedStandardsId
-
Typed helper for the
criteria.compliance_associated_standards_idblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleComplianceSecurityControlId
-
Typed helper for the
criteria.compliance_security_control_idblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleComplianceStatus
-
Typed helper for the
criteria.compliance_statusblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleConfidence
-
Typed helper for the
criteria.confidenceblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleCreatedAt
-
Typed helper for the
criteria.created_atblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleCriteria
-
Typed helper for the
criteriablock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleCriteriaDescription
-
Typed helper for the
criteria.descriptionblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleCriteriaId
-
Typed helper for the
criteria.idblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleCriteriaType
-
Typed helper for the
criteria.typeblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleCriticality
-
Typed helper for the
criteria.criticalityblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleDateRange
-
Typed helper for the
criteria.created_at.date_rangeblock ofaws_securityhub_automation_rule(derived from provider schema). Shared by every block of this shape in the resource. - SecurityhubAutomationRuleFindingFieldsUpdate
-
Typed helper for the
actions.finding_fields_updateblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleFirstObservedAt
-
Typed helper for the
criteria.first_observed_atblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleGeneratorId
-
Typed helper for the
criteria.generator_idblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleLastObservedAt
-
Typed helper for the
criteria.last_observed_atblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleNote
-
Typed helper for the
actions.finding_fields_update.noteblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleNoteText
-
Typed helper for the
criteria.note_textblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleNoteUpdatedAt
-
Typed helper for the
criteria.note_updated_atblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleNoteUpdatedBy
-
Typed helper for the
criteria.note_updated_byblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleProductArn
-
Typed helper for the
criteria.product_arnblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleProductName
-
Typed helper for the
criteria.product_nameblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleRecordState
-
Typed helper for the
criteria.record_stateblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleRelatedFindings
-
Typed helper for the
actions.finding_fields_update.related_findingsblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleRelatedFindingsId
-
Typed helper for the
criteria.related_findings_idblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleRelatedFindingsProductArn
-
Typed helper for the
criteria.related_findings_product_arnblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleResourceApplicationArn
-
Typed helper for the
criteria.resource_application_arnblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleResourceApplicationName
-
Typed helper for the
criteria.resource_application_nameblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleResourceDetailsOther
-
Typed helper for the
criteria.resource_details_otherblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleResourceId
-
Typed helper for the
criteria.resource_idblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleResourcePartition
-
Typed helper for the
criteria.resource_partitionblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleResourceRegion
-
Typed helper for the
criteria.resource_regionblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleResourceTags
-
Typed helper for the
criteria.resource_tagsblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleResourceType
-
Typed helper for the
criteria.resource_typeblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleSeverity
-
Typed helper for the
actions.finding_fields_update.severityblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleSeverityLabel
-
Typed helper for the
criteria.severity_labelblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleSourceUrl
-
Typed helper for the
criteria.source_urlblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleTitle
-
Typed helper for the
criteria.titleblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleUpdatedAt
-
Typed helper for the
criteria.updated_atblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleUserDefinedFields
-
Typed helper for the
criteria.user_defined_fieldsblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleV2Action
-
Typed helper for the
actionblock ofaws_securityhub_automation_rule_v2(derived from provider schema). - SecurityhubAutomationRuleV2Criteria
-
Typed helper for the
criteriablock ofaws_securityhub_automation_rule_v2(derived from provider schema). - SecurityhubAutomationRuleV2ExternalIntegrationConfiguration
-
Typed helper for the
action.external_integration_configurationblock ofaws_securityhub_automation_rule_v2(derived from provider schema). - SecurityhubAutomationRuleV2FindingFieldsUpdate
-
Typed helper for the
action.finding_fields_updateblock ofaws_securityhub_automation_rule_v2(derived from provider schema). - SecurityhubAutomationRuleVerificationState
-
Typed helper for the
criteria.verification_stateblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleWorkflow
-
Typed helper for the
actions.finding_fields_update.workflowblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubAutomationRuleWorkflowStatus
-
Typed helper for the
criteria.workflow_statusblock ofaws_securityhub_automation_rule(derived from provider schema). - SecurityhubConfigurationPolicy
-
Typed helper for the
configuration_policyblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicyBool
-
Typed helper for the
configuration_policy.security_controls_configuration.security_control_custom_parameter.parameter.boolblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicyControlIdentifiers
-
At most one of
disabled_control_identifiers,enabled_control_identifierson theconfiguration_policy.security_controls_configurationblock ofaws_securityhub_configuration_policy: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - SecurityhubConfigurationPolicyDisabledControlIdentifiers
-
The SecurityhubConfigurationPolicyControlIdentifiers.disabledControlIdentifiers choice: sets
disabled_control_identifiers. - SecurityhubConfigurationPolicyDouble
-
Typed helper for the
configuration_policy.security_controls_configuration.security_control_custom_parameter.parameter.doubleblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicyEnabledControlIdentifiers
-
The SecurityhubConfigurationPolicyControlIdentifiers.enabledControlIdentifiers choice: sets
enabled_control_identifiers. - SecurityhubConfigurationPolicyEnum
-
Typed helper for the
configuration_policy.security_controls_configuration.security_control_custom_parameter.parameter.enumblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicyEnumList
-
Typed helper for the
configuration_policy.security_controls_configuration.security_control_custom_parameter.parameter.enum_listblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicyInt
-
Typed helper for the
configuration_policy.security_controls_configuration.security_control_custom_parameter.parameter.intblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicyIntList
-
Typed helper for the
configuration_policy.security_controls_configuration.security_control_custom_parameter.parameter.int_listblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicyParameter
-
Typed helper for the
configuration_policy.security_controls_configuration.security_control_custom_parameter.parameterblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicySecurityControlCustomParameter
-
Typed helper for the
configuration_policy.security_controls_configuration.security_control_custom_parameterblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicySecurityControlsConfiguration
-
Typed helper for the
configuration_policy.security_controls_configurationblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicyString
-
Typed helper for the
configuration_policy.security_controls_configuration.security_control_custom_parameter.parameter.stringblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConfigurationPolicyStringList
-
Typed helper for the
configuration_policy.security_controls_configuration.security_control_custom_parameter.parameter.string_listblock ofaws_securityhub_configuration_policy(derived from provider schema). - SecurityhubConnectorV2ConnectorProvider
-
Exactly one of
jira_cloud,service_nowon theconnector_providerblock ofaws_securityhub_connector_v2: the provider rejects none and more than one, so each variant sets one of them. - SecurityhubConnectorV2ConnectorProviderJiraCloud
-
The SecurityhubConnectorV2ConnectorProvider.jiraCloud choice: sets
jira_cloud. - SecurityhubConnectorV2ConnectorProviderServiceNow
-
The SecurityhubConnectorV2ConnectorProvider.serviceNow choice: sets
service_now. - SecurityhubConnectorV2JiraCloud
-
Typed helper for the
connector_provider.jira_cloudblock ofaws_securityhub_connector_v2(derived from provider schema). - SecurityhubConnectorV2ServiceNow
-
Typed helper for the
connector_provider.service_nowblock ofaws_securityhub_connector_v2(derived from provider schema). - SecurityhubInsightAwsAccountId
-
Typed helper for the
filters.aws_account_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightAwsAccountName
-
Typed helper for the
filters.aws_account_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightCompanyName
-
Typed helper for the
filters.company_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightComplianceAssociatedStandardsId
-
Typed helper for the
filters.compliance_associated_standards_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightComplianceSecurityControlId
-
Typed helper for the
filters.compliance_security_control_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightComplianceSecurityControlParametersName
-
Typed helper for the
filters.compliance_security_control_parameters_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightComplianceSecurityControlParametersValue
-
Typed helper for the
filters.compliance_security_control_parameters_valueblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightComplianceStatus
-
Typed helper for the
filters.compliance_statusblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightConfidence
-
Typed helper for the
filters.confidenceblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightCreatedAt
-
Typed helper for the
filters.created_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightCriticality
-
Typed helper for the
filters.criticalityblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightDateRange
-
Typed helper for the
filters.created_at.date_rangeblock ofaws_securityhub_insight(derived from provider schema). Shared by every block of this shape in the resource. - SecurityhubInsightDescription
-
Typed helper for the
filters.descriptionblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightFilters
-
Typed helper for the
filtersblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightFiltersId
-
Typed helper for the
filters.idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightFindingProviderFieldsConfidence
-
Typed helper for the
filters.finding_provider_fields_confidenceblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightFindingProviderFieldsCriticality
-
Typed helper for the
filters.finding_provider_fields_criticalityblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightFindingProviderFieldsRelatedFindingsId
-
Typed helper for the
filters.finding_provider_fields_related_findings_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightFindingProviderFieldsRelatedFindingsProductArn
-
Typed helper for the
filters.finding_provider_fields_related_findings_product_arnblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightFindingProviderFieldsSeverityLabel
-
Typed helper for the
filters.finding_provider_fields_severity_labelblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightFindingProviderFieldsSeverityOriginal
-
Typed helper for the
filters.finding_provider_fields_severity_originalblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightFindingProviderFieldsTypes
-
Typed helper for the
filters.finding_provider_fields_typesblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightFirstObservedAt
-
Typed helper for the
filters.first_observed_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightGeneratorId
-
Typed helper for the
filters.generator_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightKeyword
-
Typed helper for the
filters.keywordblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightLastObservedAt
-
Typed helper for the
filters.last_observed_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightMalwareName
-
Typed helper for the
filters.malware_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightMalwarePath
-
Typed helper for the
filters.malware_pathblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightMalwareState
-
Typed helper for the
filters.malware_stateblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightMalwareType
-
Typed helper for the
filters.malware_typeblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkDestinationDomain
-
Typed helper for the
filters.network_destination_domainblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkDestinationIpv4
-
Typed helper for the
filters.network_destination_ipv4block ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkDestinationIpv6
-
Typed helper for the
filters.network_destination_ipv6block ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkDestinationPort
-
Typed helper for the
filters.network_destination_portblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkDirection
-
Typed helper for the
filters.network_directionblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkProtocol
-
Typed helper for the
filters.network_protocolblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkSourceDomain
-
Typed helper for the
filters.network_source_domainblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkSourceIpv4
-
Typed helper for the
filters.network_source_ipv4block ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkSourceIpv6
-
Typed helper for the
filters.network_source_ipv6block ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkSourceMac
-
Typed helper for the
filters.network_source_macblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNetworkSourcePort
-
Typed helper for the
filters.network_source_portblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNoteText
-
Typed helper for the
filters.note_textblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNoteUpdatedAt
-
Typed helper for the
filters.note_updated_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightNoteUpdatedBy
-
Typed helper for the
filters.note_updated_byblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightProcessLaunchedAt
-
Typed helper for the
filters.process_launched_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightProcessName
-
Typed helper for the
filters.process_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightProcessParentPid
-
Typed helper for the
filters.process_parent_pidblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightProcessPath
-
Typed helper for the
filters.process_pathblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightProcessPid
-
Typed helper for the
filters.process_pidblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightProcessTerminatedAt
-
Typed helper for the
filters.process_terminated_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightProductArn
-
Typed helper for the
filters.product_arnblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightProductFields
-
Typed helper for the
filters.product_fieldsblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightProductName
-
Typed helper for the
filters.product_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightRecommendationText
-
Typed helper for the
filters.recommendation_textblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightRecordState
-
Typed helper for the
filters.record_stateblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightRelatedFindingsId
-
Typed helper for the
filters.related_findings_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightRelatedFindingsProductArn
-
Typed helper for the
filters.related_findings_product_arnblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsEc2InstanceIamInstanceProfileArn
-
Typed helper for the
filters.resource_aws_ec2_instance_iam_instance_profile_arnblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsEc2InstanceImageId
-
Typed helper for the
filters.resource_aws_ec2_instance_image_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsEc2InstanceIpv4Addresses
-
Typed helper for the
filters.resource_aws_ec2_instance_ipv4_addressesblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsEc2InstanceIpv6Addresses
-
Typed helper for the
filters.resource_aws_ec2_instance_ipv6_addressesblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsEc2InstanceKeyName
-
Typed helper for the
filters.resource_aws_ec2_instance_key_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsEc2InstanceLaunchedAt
-
Typed helper for the
filters.resource_aws_ec2_instance_launched_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsEc2InstanceSubnetId
-
Typed helper for the
filters.resource_aws_ec2_instance_subnet_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsEc2InstanceType
-
Typed helper for the
filters.resource_aws_ec2_instance_typeblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsEc2InstanceVpcId
-
Typed helper for the
filters.resource_aws_ec2_instance_vpc_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsIamAccessKeyCreatedAt
-
Typed helper for the
filters.resource_aws_iam_access_key_created_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsIamAccessKeyStatus
-
Typed helper for the
filters.resource_aws_iam_access_key_statusblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsIamAccessKeyUserName
-
Typed helper for the
filters.resource_aws_iam_access_key_user_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsS3BucketOwnerId
-
Typed helper for the
filters.resource_aws_s3_bucket_owner_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceAwsS3BucketOwnerName
-
Typed helper for the
filters.resource_aws_s3_bucket_owner_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceContainerImageId
-
Typed helper for the
filters.resource_container_image_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceContainerImageName
-
Typed helper for the
filters.resource_container_image_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceContainerLaunchedAt
-
Typed helper for the
filters.resource_container_launched_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceContainerName
-
Typed helper for the
filters.resource_container_nameblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceDetailsOther
-
Typed helper for the
filters.resource_details_otherblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceId
-
Typed helper for the
filters.resource_idblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourcePartition
-
Typed helper for the
filters.resource_partitionblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceRegion
-
Typed helper for the
filters.resource_regionblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceTags
-
Typed helper for the
filters.resource_tagsblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightResourceType
-
Typed helper for the
filters.resource_typeblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightSeverityLabel
-
Typed helper for the
filters.severity_labelblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightSourceUrl
-
Typed helper for the
filters.source_urlblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightThreatIntelIndicatorCategory
-
Typed helper for the
filters.threat_intel_indicator_categoryblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightThreatIntelIndicatorLastObservedAt
-
Typed helper for the
filters.threat_intel_indicator_last_observed_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightThreatIntelIndicatorSource
-
Typed helper for the
filters.threat_intel_indicator_sourceblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightThreatIntelIndicatorSourceUrl
-
Typed helper for the
filters.threat_intel_indicator_source_urlblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightThreatIntelIndicatorType
-
Typed helper for the
filters.threat_intel_indicator_typeblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightThreatIntelIndicatorValue
-
Typed helper for the
filters.threat_intel_indicator_valueblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightTitle
-
Typed helper for the
filters.titleblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightType
-
Typed helper for the
filters.typeblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightUpdatedAt
-
Typed helper for the
filters.updated_atblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightUserDefinedValues
-
Typed helper for the
filters.user_defined_valuesblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightVerificationState
-
Typed helper for the
filters.verification_stateblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubInsightWorkflowStatus
-
Typed helper for the
filters.workflow_statusblock ofaws_securityhub_insight(derived from provider schema). - SecurityhubOrganizationConfiguration
-
Typed helper for the
organization_configurationblock ofaws_securityhub_organization_configuration(derived from provider schema).
Enums
- SecurityhubAccountControlFindingGenerator
-
Securityhub Account Control Finding enum for
control_finding_generator. - SecurityhubAutomationRuleActionsType
-
type— derived from the provider schema description. - SecurityhubAutomationRuleAwsAccountIdComparison
-
comparison— derived from the provider schema description. - SecurityhubAutomationRuleFindingFieldsUpdateStatus
-
status— derived from the provider schema description. - SecurityhubAutomationRuleFindingFieldsUpdateVerificationState
-
verification_state— derived from the provider schema description. - SecurityhubAutomationRuleLabel
-
label— derived from the provider schema description. - SecurityhubAutomationRuleResourceDetailsOtherComparison
-
comparison— derived from the provider schema description. - SecurityhubAutomationRuleStatus
-
Securityhub Automation Rule enum for
rule_status. - SecurityhubAutomationRuleUnit
-
unit— derived from the provider schema description. - SecurityhubAutomationRuleV2RuleStatus
-
Securityhub Automation Rule V2 Rule enum for
rule_status. - SecurityhubAutomationRuleV2Type
-
type— derived from the provider schema description. - SecurityhubFeatureV2FeatureName
-
Securityhub Feature V2 Feature enum for
feature_name. - SecurityhubFeatureV2FeatureStatus
-
Securityhub Feature V2 Feature enum for
feature_status. - SecurityhubFindingAggregatorLinkingMode
-
Securityhub Finding Aggregator Linking enum for
linking_mode. - SecurityhubOrganizationConfigurationAutoEnableStandards
-
Securityhub Organization Configuration Auto Enable enum for
auto_enable_standards. - SecurityhubOrganizationConfigurationType
-
configuration_type— derived from the provider schema description. - SecurityhubStandardsControlAssociationStatus
-
Securityhub Standards Control Association enum for
association_status. - SecurityhubStandardsControlStatus
-
Securityhub Standards Control enum for
control_status.