ses library
AWS SES (V1).
Classes
- AwsSesActiveReceiptRuleSet
-
Factory wrapper for
aws_ses_active_receipt_rule_set. - AwsSesConfigurationSet
-
Factory wrapper for
aws_ses_configuration_set. - AwsSesDomainDkim
-
Factory wrapper for
aws_ses_domain_dkim. - AwsSesDomainIdentity
-
Factory wrapper for
aws_ses_domain_identity. - AwsSesDomainIdentityVerification
-
Factory wrapper for
aws_ses_domain_identity_verification. - AwsSesDomainMailFrom
-
Factory wrapper for
aws_ses_domain_mail_from. - AwsSesEmailIdentity
-
Factory wrapper for
aws_ses_email_identity. - AwsSesEventDestination
-
Factory wrapper for
aws_ses_event_destination. - AwsSesIdentityNotificationTopic
-
Factory wrapper for
aws_ses_identity_notification_topic. - AwsSesIdentityPolicy
-
Factory wrapper for
aws_ses_identity_policy. - AwsSesReceiptFilter
-
Factory wrapper for
aws_ses_receipt_filter. - AwsSesReceiptRule
-
Factory wrapper for
aws_ses_receipt_rule. - AwsSesReceiptRuleSet
-
Factory wrapper for
aws_ses_receipt_rule_set. - AwsSesTemplate
-
Factory wrapper for
aws_ses_template. - SesConfigurationSetDeliveryOptions
-
Typed helper for the
delivery_optionsblock ofaws_ses_configuration_set(derived from provider schema). - SesConfigurationSetTrackingOptions
-
Typed helper for the
tracking_optionsblock ofaws_ses_configuration_set(derived from provider schema). - SesEventDestinationCloudwatchDestination
-
Typed helper for the
cloudwatch_destinationblock ofaws_ses_event_destination(derived from provider schema). - SesEventDestinationKinesisDestination
-
Typed helper for the
kinesis_destinationblock ofaws_ses_event_destination(derived from provider schema). - SesEventDestinationSnsDestination
-
Typed helper for the
sns_destinationblock ofaws_ses_event_destination(derived from provider schema). - SesEventDestinationTarget
-
At most one of
cloudwatch_destination,kinesis_destination,sns_destinationonaws_ses_event_destination: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - SesEventDestinationTargetCloudwatchDestination
-
The SesEventDestinationTarget.cloudwatchDestination choice: sets
cloudwatch_destination. - SesEventDestinationTargetKinesisDestination
-
The SesEventDestinationTarget.kinesisDestination choice: sets
kinesis_destination. - SesEventDestinationTargetSnsDestination
-
The SesEventDestinationTarget.snsDestination choice: sets
sns_destination. - SesReceiptRuleAddHeaderAction
-
Typed helper for the
add_header_actionblock ofaws_ses_receipt_rule(derived from provider schema). - SesReceiptRuleBounceAction
-
Typed helper for the
bounce_actionblock ofaws_ses_receipt_rule(derived from provider schema). - SesReceiptRuleLambdaAction
-
Typed helper for the
lambda_actionblock ofaws_ses_receipt_rule(derived from provider schema). - SesReceiptRuleS3Action
-
Typed helper for the
s3_actionblock ofaws_ses_receipt_rule(derived from provider schema). - SesReceiptRuleSnsAction
-
Typed helper for the
sns_actionblock ofaws_ses_receipt_rule(derived from provider schema). - SesReceiptRuleStopAction
-
Typed helper for the
stop_actionblock ofaws_ses_receipt_rule(derived from provider schema). - SesReceiptRuleWorkmailAction
-
Typed helper for the
workmail_actionblock ofaws_ses_receipt_rule(derived from provider schema).
Enums
- SesConfigurationSetTlsPolicy
-
tls_policy— derived from the provider schema description. - SesDomainMailFromBehaviorOnMxFailure
-
Ses Domain Mail From Behavior On Mx enum for
behavior_on_mx_failure. - SesEventDestinationMatchingTypes
-
Ses Event Destination Matching enum for
matching_types. - SesEventDestinationValueSource
-
value_source— derived from the provider schema description. - SesIdentityNotificationTopicNotificationType
-
Ses Identity Notification Topic Notification enum for
notification_type. - SesReceiptFilterPolicy
-
Ses Receipt Filter enum for
policy. - SesReceiptRuleEncoding
-
encoding— derived from the provider schema description. - SesReceiptRuleInvocationType
-
invocation_type— derived from the provider schema description. - SesReceiptRuleScope
-
scope— derived from the provider schema description. - SesReceiptRuleTlsPolicy
-
Ses Receipt Rule Tls enum for
tls_policy.