sesv2 library
AWS SES.
Classes
- AwsSesv2AccountSuppressionAttributes
-
Factory wrapper for
aws_sesv2_account_suppression_attributes. - AwsSesv2AccountVdmAttributes
-
Factory wrapper for
aws_sesv2_account_vdm_attributes. - AwsSesv2ConfigurationSet
-
Factory wrapper for
aws_sesv2_configuration_set. - AwsSesv2ConfigurationSetEventDestination
-
Factory wrapper for
aws_sesv2_configuration_set_event_destination. - AwsSesv2ContactList
-
Factory wrapper for
aws_sesv2_contact_list. - AwsSesv2DedicatedIpAssignment
-
Factory wrapper for
aws_sesv2_dedicated_ip_assignment. - AwsSesv2DedicatedIpPool
-
Factory wrapper for
aws_sesv2_dedicated_ip_pool. - AwsSesv2EmailIdentity
-
Factory wrapper for
aws_sesv2_email_identity. - AwsSesv2EmailIdentityFeedbackAttributes
-
Factory wrapper for
aws_sesv2_email_identity_feedback_attributes. - AwsSesv2EmailIdentityMailFromAttributes
-
Factory wrapper for
aws_sesv2_email_identity_mail_from_attributes. - AwsSesv2EmailIdentityPolicy
-
Factory wrapper for
aws_sesv2_email_identity_policy. - AwsSesv2MultiRegionEndpoint
-
Factory wrapper for
aws_sesv2_multi_region_endpoint. - AwsSesv2Tenant
-
Factory wrapper for
aws_sesv2_tenant. - AwsSesv2TenantResourceAssociation
-
Factory wrapper for
aws_sesv2_tenant_resource_association. - Sesv2AccountVdmAttributesDashboardAttributes
-
Typed helper for the
dashboard_attributesblock ofaws_sesv2_account_vdm_attributes(derived from provider schema). - Sesv2AccountVdmAttributesGuardianAttributes
-
Typed helper for the
guardian_attributesblock ofaws_sesv2_account_vdm_attributes(derived from provider schema). - Sesv2ConfigurationSetDashboardOptions
-
Typed helper for the
vdm_options.dashboard_optionsblock ofaws_sesv2_configuration_set(derived from provider schema). - Sesv2ConfigurationSetDeliveryOptions
-
Typed helper for the
delivery_optionsblock ofaws_sesv2_configuration_set(derived from provider schema). - Sesv2ConfigurationSetEventDestination
-
Typed helper for the
event_destinationblock ofaws_sesv2_configuration_set_event_destination(derived from provider schema). - Sesv2ConfigurationSetEventDestinationCloudWatchDestination
-
Typed helper for the
event_destination.cloud_watch_destinationblock ofaws_sesv2_configuration_set_event_destination(derived from provider schema). - Sesv2ConfigurationSetEventDestinationDimensionConfiguration
-
Typed helper for the
event_destination.cloud_watch_destination.dimension_configurationblock ofaws_sesv2_configuration_set_event_destination(derived from provider schema). - Sesv2ConfigurationSetEventDestinationEventBridgeDestination
-
Typed helper for the
event_destination.event_bridge_destinationblock ofaws_sesv2_configuration_set_event_destination(derived from provider schema). - Sesv2ConfigurationSetEventDestinationKinesisFirehoseDestination
-
Typed helper for the
event_destination.kinesis_firehose_destinationblock ofaws_sesv2_configuration_set_event_destination(derived from provider schema). - Sesv2ConfigurationSetEventDestinationPinpointDestination
-
Typed helper for the
event_destination.pinpoint_destinationblock ofaws_sesv2_configuration_set_event_destination(derived from provider schema). - Sesv2ConfigurationSetEventDestinationSnsDestination
-
Typed helper for the
event_destination.sns_destinationblock ofaws_sesv2_configuration_set_event_destination(derived from provider schema). - Sesv2ConfigurationSetEventDestinationTarget
-
Exactly one of
cloud_watch_destination,event_bridge_destination,kinesis_firehose_destination,pinpoint_destination,sns_destinationon theevent_destinationblock ofaws_sesv2_configuration_set_event_destination: the provider rejects none and more than one, so each variant sets one of them. - Sesv2ConfigurationSetEventDestinationTargetCloudWatchDestination
-
The Sesv2ConfigurationSetEventDestinationTarget.cloudWatchDestination choice: sets
cloud_watch_destination. - Sesv2ConfigurationSetEventDestinationTargetEventBridgeDestination
-
The Sesv2ConfigurationSetEventDestinationTarget.eventBridgeDestination choice: sets
event_bridge_destination. - Sesv2ConfigurationSetEventDestinationTargetKinesisFirehoseDestination
-
The Sesv2ConfigurationSetEventDestinationTarget.kinesisFirehoseDestination choice: sets
kinesis_firehose_destination. - Sesv2ConfigurationSetEventDestinationTargetPinpointDestination
-
The Sesv2ConfigurationSetEventDestinationTarget.pinpointDestination choice: sets
pinpoint_destination. - Sesv2ConfigurationSetEventDestinationTargetSnsDestination
-
The Sesv2ConfigurationSetEventDestinationTarget.snsDestination choice: sets
sns_destination. - Sesv2ConfigurationSetGuardianOptions
-
Typed helper for the
vdm_options.guardian_optionsblock ofaws_sesv2_configuration_set(derived from provider schema). - Sesv2ConfigurationSetReputationOptions
-
Typed helper for the
reputation_optionsblock ofaws_sesv2_configuration_set(derived from provider schema). - Sesv2ConfigurationSetSendingOptions
-
Typed helper for the
sending_optionsblock ofaws_sesv2_configuration_set(derived from provider schema). - Sesv2ConfigurationSetSuppressionOptions
-
Typed helper for the
suppression_optionsblock ofaws_sesv2_configuration_set(derived from provider schema). - Sesv2ConfigurationSetTrackingOptions
-
Typed helper for the
tracking_optionsblock ofaws_sesv2_configuration_set(derived from provider schema). - Sesv2ConfigurationSetVdmOptions
-
Typed helper for the
vdm_optionsblock ofaws_sesv2_configuration_set(derived from provider schema). - Sesv2ContactListTopic
-
Typed helper for the
topicblock ofaws_sesv2_contact_list(derived from provider schema). - Sesv2EmailIdentityDkimSigningAttributes
-
Typed helper for the
dkim_signing_attributesblock ofaws_sesv2_email_identity(derived from provider schema). - Sesv2MultiRegionEndpointDetails
-
Typed helper for the
detailsblock ofaws_sesv2_multi_region_endpoint(derived from provider schema). - Sesv2MultiRegionEndpointRoutesDetails
-
Typed helper for the
details.routes_detailsblock ofaws_sesv2_multi_region_endpoint(derived from provider schema).
Enums
- Sesv2AccountSuppressionAttributesSuppressedReasons
-
Sesv2 Account Suppression Attributes Suppressed enum for
suppressed_reasons. - Sesv2AccountVdmAttributesEngagementMetrics
-
engagement_metrics— derived from the provider schema description. -
optimized_shared_delivery— derived from the provider schema description. - Sesv2AccountVdmAttributesVdmEnabled
-
Sesv2 Account Vdm Attributes Vdm enum for
vdm_enabled. - Sesv2ConfigurationSetEngagementMetrics
-
engagement_metrics— derived from the provider schema description. - Sesv2ConfigurationSetEventDestinationDimensionValueSource
-
dimension_value_source— derived from the provider schema description. - Sesv2ConfigurationSetEventDestinationMatchingEventTypes
-
matching_event_types— derived from the provider schema description. - Sesv2ConfigurationSetHttpsPolicy
-
https_policy— derived from the provider schema description. -
optimized_shared_delivery— derived from the provider schema description. - Sesv2ConfigurationSetSuppressedReasons
-
suppressed_reasons— derived from the provider schema description. - Sesv2ConfigurationSetTlsPolicy
-
tls_policy— derived from the provider schema description. - Sesv2ContactListDefaultSubscriptionStatus
-
default_subscription_status— derived from the provider schema description. - Sesv2DedicatedIpPoolScalingMode
-
Sesv2 Dedicated Ip Pool Scaling enum for
scaling_mode. - Sesv2EmailIdentityMailFromAttributesBehaviorOnMxFailure
-
Sesv2 Email Identity Mail From Attributes Behavior On Mx enum for
behavior_on_mx_failure. - Sesv2EmailIdentityNextSigningKeyLength
-
next_signing_key_length— derived from the provider schema description.