shield library
AWS Shield.
Classes
- AwsShieldApplicationLayerAutomaticResponse
-
Factory wrapper for
aws_shield_application_layer_automatic_response. - AwsShieldDrtAccessLogBucketAssociation
-
Factory wrapper for
aws_shield_drt_access_log_bucket_association. - AwsShieldDrtAccessRoleArnAssociation
-
Factory wrapper for
aws_shield_drt_access_role_arn_association. - AwsShieldProactiveEngagement
-
Factory wrapper for
aws_shield_proactive_engagement. - AwsShieldProtection
-
Factory wrapper for
aws_shield_protection. - AwsShieldProtectionGroup
-
Factory wrapper for
aws_shield_protection_group. - AwsShieldProtectionHealthCheckAssociation
-
Factory wrapper for
aws_shield_protection_health_check_association. - AwsShieldSubscription
-
Factory wrapper for
aws_shield_subscription. - ShieldProactiveEngagementEmergencyContact
-
Typed helper for the
emergency_contactblock ofaws_shield_proactive_engagement(derived from provider schema). - ShieldProtectionGroupScope
-
At most one of
members,resource_typeonaws_shield_protection_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - ShieldProtectionGroupScopeMembers
-
The ShieldProtectionGroupScope.members choice: sets
members. - ShieldProtectionGroupScopeResourceType
-
The ShieldProtectionGroupScope.resourceType choice: sets
resource_type.
Enums
- ShieldApplicationLayerAutomaticResponseAction
-
Shield Application Layer Automatic Response enum for
action. - ShieldProtectionGroupAggregation
-
Shield Protection Group enum for
aggregation. - ShieldProtectionGroupPattern
-
Shield Protection Group enum for
pattern. - ShieldProtectionGroupResourceType
-
Shield Protection Group Resource enum for
resource_type. - ShieldSubscriptionAutoRenew
-
Shield Subscription Auto enum for
auto_renew.