ssm library
AWS Systems Manager.
Classes
- AwsSsmActivation
-
Factory wrapper for
aws_ssm_activation. - AwsSsmAssociation
-
Factory wrapper for
aws_ssm_association. - AwsSsmDefaultPatchBaseline
-
Factory wrapper for
aws_ssm_default_patch_baseline. - AwsSsmDocument
-
Factory wrapper for
aws_ssm_document. - AwsSsmMaintenanceWindow
-
Factory wrapper for
aws_ssm_maintenance_window. - AwsSsmMaintenanceWindowTarget
-
Factory wrapper for
aws_ssm_maintenance_window_target. - AwsSsmMaintenanceWindowTask
-
Factory wrapper for
aws_ssm_maintenance_window_task. - AwsSsmParameter
-
Factory wrapper for
aws_ssm_parameter. - AwsSsmPatchBaseline
-
Factory wrapper for
aws_ssm_patch_baseline. - AwsSsmPatchGroup
-
Factory wrapper for
aws_ssm_patch_group. - AwsSsmResourceDataSync
-
Factory wrapper for
aws_ssm_resource_data_sync. - AwsSsmServiceSetting
-
Factory wrapper for
aws_ssm_service_setting. - SsmAssociationOutputLocation
-
Typed helper for the
output_locationblock ofaws_ssm_association(derived from provider schema). - SsmAssociationTargets
-
Typed helper for the
targetsblock ofaws_ssm_association(derived from provider schema). - SsmDocumentAttachmentsSource
-
Typed helper for the
attachments_sourceblock ofaws_ssm_document(derived from provider schema). - SsmMaintenanceWindowTargetTargets
-
Typed helper for the
targetsblock ofaws_ssm_maintenance_window_target(derived from provider schema). - SsmMaintenanceWindowTaskAutomationParameters
-
Typed helper for the
task_invocation_parameters.automation_parametersblock ofaws_ssm_maintenance_window_task(derived from provider schema). - SsmMaintenanceWindowTaskCloudwatchConfig
-
Typed helper for the
task_invocation_parameters.run_command_parameters.cloudwatch_configblock ofaws_ssm_maintenance_window_task(derived from provider schema). - SsmMaintenanceWindowTaskInvocationParameters
-
Typed helper for the
task_invocation_parametersblock ofaws_ssm_maintenance_window_task(derived from provider schema). - SsmMaintenanceWindowTaskLambdaParameters
-
Typed helper for the
task_invocation_parameters.lambda_parametersblock ofaws_ssm_maintenance_window_task(derived from provider schema). - SsmMaintenanceWindowTaskNotificationConfig
-
Typed helper for the
task_invocation_parameters.run_command_parameters.notification_configblock ofaws_ssm_maintenance_window_task(derived from provider schema). - SsmMaintenanceWindowTaskParameter
-
Typed helper for the
task_invocation_parameters.automation_parameters.parameterblock ofaws_ssm_maintenance_window_task(derived from provider schema). Shared by every block of this shape in the resource. - SsmMaintenanceWindowTaskRunCommandParameters
-
Typed helper for the
task_invocation_parameters.run_command_parametersblock ofaws_ssm_maintenance_window_task(derived from provider schema). - SsmMaintenanceWindowTaskStepFunctionsParameters
-
Typed helper for the
task_invocation_parameters.step_functions_parametersblock ofaws_ssm_maintenance_window_task(derived from provider schema). - SsmMaintenanceWindowTaskTargets
-
Typed helper for the
targetsblock ofaws_ssm_maintenance_window_task(derived from provider schema). - SsmParameterInsecureValue
-
The SsmParameterValue.insecureValue choice: sets
insecure_value. - SsmParameterValue
-
Exactly one of
insecure_value,value,value_woonaws_ssm_parameter: the provider rejects none and more than one, so each variant sets one of them. - SsmParameterValueChoice
-
The SsmParameterValue.value choice: sets
value. - SsmParameterValueWo
-
The SsmParameterValue.valueWo choice: sets
value_wo. - SsmPatchBaselineApprovalRule
-
Typed helper for the
approval_ruleblock ofaws_ssm_patch_baseline(derived from provider schema). - SsmPatchBaselineGlobalFilter
-
Typed helper for the
global_filterblock ofaws_ssm_patch_baseline(derived from provider schema). - SsmPatchBaselinePatchFilter
-
Typed helper for the
approval_rule.patch_filterblock ofaws_ssm_patch_baseline(derived from provider schema). - SsmPatchBaselineSource
-
Typed helper for the
sourceblock ofaws_ssm_patch_baseline(derived from provider schema). - SsmResourceDataSyncDestinationDataSharing
-
Typed helper for the
s3_destination.destination_data_sharingblock ofaws_ssm_resource_data_sync(derived from provider schema). - SsmResourceDataSyncS3Destination
-
Typed helper for the
s3_destinationblock ofaws_ssm_resource_data_sync(derived from provider schema).
Enums
- SsmAssociationComplianceSeverity
-
Ssm Association Compliance enum for
compliance_severity. - SsmAssociationSyncCompliance
-
Ssm Association Sync enum for
sync_compliance. - SsmDefaultPatchBaselineOperatingSystem
-
Ssm Default Patch Baseline Operating enum for
operating_system. - SsmDocumentFormat
-
Ssm Document enum for
document_format. - SsmDocumentKey
-
key— derived from the provider schema description. - SsmDocumentType
-
Ssm Document enum for
document_type. - SsmMaintenanceWindowTargetResourceType
-
Ssm Maintenance Window Target Resource enum for
resource_type. - SsmMaintenanceWindowTaskCutoffBehavior
-
Ssm Maintenance Window Task Cutoff enum for
cutoff_behavior. - SsmMaintenanceWindowTaskDocumentHashType
-
document_hash_type— derived from the provider schema description. - SsmMaintenanceWindowTaskNotificationEvents
-
notification_events— derived from the provider schema description. - SsmMaintenanceWindowTaskNotificationType
-
notification_type— derived from the provider schema description. - SsmMaintenanceWindowTaskType
-
Ssm Maintenance Window Task enum for
task_type. - SsmParameterDataType
-
Ssm Parameter Data enum for
data_type. - SsmParameterTier
-
Ssm Parameter enum for
tier. - SsmParameterType
-
Ssm Parameter enum for
type. - SsmPatchBaselineApprovedPatchesComplianceLevel
-
Ssm Patch Baseline Approved Patches Compliance enum for
approved_patches_compliance_level. - SsmPatchBaselineAvailableSecurityUpdatesComplianceStatus
-
Ssm Patch Baseline Available Security Updates Compliance enum for
available_security_updates_compliance_status. - SsmPatchBaselineComplianceLevel
-
compliance_level— derived from the provider schema description. - SsmPatchBaselineKey
-
key— derived from the provider schema description. - SsmPatchBaselineOperatingSystem
-
Ssm Patch Baseline Operating enum for
operating_system. - SsmPatchBaselineRejectedPatchesAction
-
Ssm Patch Baseline Rejected Patches enum for
rejected_patches_action. - SsmResourceDataSyncDestinationDataSharingType
-
destination_data_sharing_type— derived from the provider schema description. - SsmResourceDataSyncFormat
-
sync_format— derived from the provider schema description.