storagegateway library
AWS Storage Gateway.
Classes
- AwsStoragegatewayCache
-
Factory wrapper for
aws_storagegateway_cache. - AwsStoragegatewayCachedIscsiVolume
-
Factory wrapper for
aws_storagegateway_cached_iscsi_volume. - AwsStoragegatewayFileSystemAssociation
-
Factory wrapper for
aws_storagegateway_file_system_association. - AwsStoragegatewayGateway
-
Factory wrapper for
aws_storagegateway_gateway. -
Factory wrapper for
aws_storagegateway_nfs_file_share. -
Factory wrapper for
aws_storagegateway_smb_file_share. - AwsStoragegatewayStoredIscsiVolume
-
Factory wrapper for
aws_storagegateway_stored_iscsi_volume. - AwsStoragegatewayTapePool
-
Factory wrapper for
aws_storagegateway_tape_pool. - AwsStoragegatewayUploadBuffer
-
Factory wrapper for
aws_storagegateway_upload_buffer. - AwsStoragegatewayWorkingStorage
-
Factory wrapper for
aws_storagegateway_working_storage. - StoragegatewayFileSystemAssociationCacheAttributes
-
Typed helper for the
cache_attributesblock ofaws_storagegateway_file_system_association(derived from provider schema). - StoragegatewayGatewayActivation
-
Exactly one of
activation_key,gateway_ip_addressonaws_storagegateway_gateway: the provider rejects none and more than one, so each variant sets one of them. - StoragegatewayGatewayActivationGatewayIpAddress
-
The StoragegatewayGatewayActivation.gatewayIpAddress choice: sets
gateway_ip_address. - StoragegatewayGatewayActivationKey
-
The StoragegatewayGatewayActivation.activationKey choice: sets
activation_key. - StoragegatewayGatewayMaintenanceStartTime
-
Typed helper for the
maintenance_start_timeblock ofaws_storagegateway_gateway(derived from provider schema). - StoragegatewayGatewaySmbActiveDirectorySettings
-
Typed helper for the
smb_active_directory_settingsblock ofaws_storagegateway_gateway(derived from provider schema). -
Typed helper for the
cache_attributesblock ofaws_storagegateway_nfs_file_share(derived from provider schema). -
Typed helper for the
nfs_file_share_defaultsblock ofaws_storagegateway_nfs_file_share(derived from provider schema). -
Typed helper for the
cache_attributesblock ofaws_storagegateway_smb_file_share(derived from provider schema). - StoragegatewayUploadBufferDisk
-
Exactly one of
disk_id,disk_pathonaws_storagegateway_upload_buffer: the provider rejects none and more than one, so each variant sets one of them. - StoragegatewayUploadBufferDiskId
-
The StoragegatewayUploadBufferDisk.diskId choice: sets
disk_id. - StoragegatewayUploadBufferDiskPath
-
The StoragegatewayUploadBufferDisk.diskPath choice: sets
disk_path.
Enums
- StoragegatewayGatewayMediumChangerType
-
Storagegateway Gateway Medium Changer enum for
medium_changer_type. - StoragegatewayGatewaySmbSecurityStrategy
-
Storagegateway Gateway Smb Security enum for
smb_security_strategy. - StoragegatewayGatewayTapeDriveType
-
Storagegateway Gateway Tape Drive enum for
tape_drive_type. - StoragegatewayGatewayType
-
Storagegateway Gateway enum for
gateway_type. -
Storagegateway Nfs File Share Default Storage enum for
default_storage_class. -
Storagegateway Nfs File Share Object enum for
object_acl. -
Storagegateway Nfs File Share enum for
squash. -
Storagegateway Smb File Share enum for
authentication. -
Storagegateway Smb File Share Case enum for
case_sensitivity. -
Storagegateway Smb File Share Default Storage enum for
default_storage_class. -
Storagegateway Smb File Share Object enum for
object_acl. - StoragegatewayTapePoolRetentionLockType
-
Storagegateway Tape Pool Retention Lock enum for
retention_lock_type. - StoragegatewayTapePoolStorageClass
-
Storagegateway Tape Pool Storage enum for
storage_class.