AppflowFlowRedshift class final
Typed helper for the destination_flow_config.destination_connector_properties.redshift block of
aws_appflow_flow (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AppflowFlowRedshift({TfArg<
String> ? bucketPrefix, required TfArg<String> intermediateBucketName, required TfArg<String> object, AppflowFlowErrorHandlingConfig? errorHandlingConfig}) -
const
Properties
-
bucketPrefix
→ TfArg<
String> ? -
final
- errorHandlingConfig → AppflowFlowErrorHandlingConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
intermediateBucketName
→ TfArg<
String> -
final
-
object
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited