AppmeshRouteHttp2RouteMatch class final
Typed helper for the spec.http2_route.match block of
aws_appmesh_route (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
AppmeshRouteHttp2RouteMatch({TfArg<
String> ? method, TfArg<num> ? port, TfArg<String> ? prefix, TfArg<String> ? scheme, List<AppmeshRouteHeader> ? header, AppmeshRoutePath? path, List<AppmeshRouteQueryParameter> ? queryParameter}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
header
→ List<
AppmeshRouteHeader> ? -
final
-
method
→ TfArg<
String> ? -
final
- path → AppmeshRoutePath?
-
final
-
port
→ TfArg<
num> ? -
final
-
prefix
→ TfArg<
String> ? -
final
-
queryParameter
→ List<
AppmeshRouteQueryParameter> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scheme
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited