AppmeshVirtualNodePerRequest class final
Typed helper for the spec.listener.timeout.grpc.per_request block of
aws_appmesh_virtual_node (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
AppmeshVirtualNodePerRequest({required AppmeshVirtualNodeUnit unit, required TfArg<
num> value}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unit → AppmeshVirtualNodeUnit
-
final
-
value
→ TfArg<
num> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited