AppmeshVirtualNodeSpec class final
Typed helper for the spec block of
aws_appmesh_virtual_node (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AppmeshVirtualNodeSpec({List<
AppmeshVirtualNodeBackend> ? backend, AppmeshVirtualNodeBackendDefaults? backendDefaults, List<AppmeshVirtualNodeListener> ? listener, AppmeshVirtualNodeLogging? logging, AppmeshVirtualNodeServiceDiscovery? serviceDiscovery}) -
const
Properties
-
backend
→ List<
AppmeshVirtualNodeBackend> ? -
final
- backendDefaults → AppmeshVirtualNodeBackendDefaults?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
listener
→ List<
AppmeshVirtualNodeListener> ? -
final
- logging → AppmeshVirtualNodeLogging?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceDiscovery → AppmeshVirtualNodeServiceDiscovery?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited