AppmeshVirtualServiceProviderVirtualNode class final
The AppmeshVirtualServiceProvider.virtualNode choice: sets virtual_node.
- Inheritance
-
- Object
- AppmeshVirtualServiceProvider
- AppmeshVirtualServiceProviderVirtualNode
Constructors
- AppmeshVirtualServiceProviderVirtualNode(AppmeshVirtualServiceVirtualNode virtualNode)
-
const
Properties
- blockKey → String
-
The Terraform argument this choice sets.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- virtualNode → AppmeshVirtualServiceVirtualNode
-
final
Methods
-
encode(
) → Map< String, Object?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited