AppsyncChannelNamespaceOnSubscribe class final
Typed helper for the handler_configs.on_subscribe block of
aws_appsync_channel_namespace (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AppsyncChannelNamespaceOnSubscribe({required AppsyncChannelNamespaceBehavior behavior, List<
AppsyncChannelNamespaceIntegration> ? integration}) -
const
Properties
- behavior → AppsyncChannelNamespaceBehavior
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
integration
→ List<
AppsyncChannelNamespaceIntegration> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited