AppsyncDatasourceDynamodbConfig class final
Typed helper for the dynamodb_config block of
aws_appsync_datasource (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
AppsyncDatasourceDynamodbConfig({TfArg<
String> ? region, required TfArg<String> tableName, TfArg<bool> ? useCallerCredentials, TfArg<bool> ? versioned, AppsyncDatasourceDeltaSyncConfig? deltaSyncConfig}) -
const
Properties
- deltaSyncConfig → AppsyncDatasourceDeltaSyncConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
region
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tableName
→ TfArg<
String> -
final
-
useCallerCredentials
→ TfArg<
bool> ? -
final
-
versioned
→ TfArg<
bool> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited