ArcregionswitchPlanParallelConfigStep class final
Typed helper for the workflow.step.parallel_config.step block of
aws_arcregionswitch_plan (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ArcregionswitchPlanParallelConfigStep({TfArg<
String> ? description, required TfArg<ArcregionswitchPlanExecutionBlockType> executionBlockType, required TfArg<String> name, List<ArcregionswitchPlanArcRoutingControlConfig> ? arcRoutingControlConfig, List<ArcregionswitchPlanAuroraProvisionedScalingConfig> ? auroraProvisionedScalingConfig, List<ArcregionswitchPlanAuroraServerlessScalingConfig> ? auroraServerlessScalingConfig, List<ArcregionswitchPlanCustomActionLambdaConfig> ? customActionLambdaConfig, List<ArcregionswitchPlanDocumentDbConfig> ? documentDbConfig, List<ArcregionswitchPlanEc2AsgCapacityIncreaseConfig> ? ec2AsgCapacityIncreaseConfig, List<ArcregionswitchPlanEcsCapacityIncreaseConfig> ? ecsCapacityIncreaseConfig, List<ArcregionswitchPlanEksResourceScalingConfig> ? eksResourceScalingConfig, List<ArcregionswitchPlanExecutionApprovalConfig> ? executionApprovalConfig, List<ArcregionswitchPlanGlobalAuroraConfig> ? globalAuroraConfig, List<ArcregionswitchPlanLambdaEventSourceMappingConfig> ? lambdaEventSourceMappingConfig, List<ArcregionswitchPlanNeptuneGlobalDatabaseConfig> ? neptuneGlobalDatabaseConfig, List<ArcregionswitchPlanRdsCreateCrossRegionReadReplicaConfig> ? rdsCreateCrossRegionReadReplicaConfig, List<ArcregionswitchPlanRdsPromoteReadReplicaConfig> ? rdsPromoteReadReplicaConfig, List<ArcregionswitchPlanRegionSwitchPlanConfig> ? regionSwitchPlanConfig, List<ArcregionswitchPlanRoute53HealthCheckConfig> ? route53HealthCheckConfig}) -
const
Properties
-
arcRoutingControlConfig
→ List<
ArcregionswitchPlanArcRoutingControlConfig> ? -
final
-
auroraProvisionedScalingConfig
→ List<
ArcregionswitchPlanAuroraProvisionedScalingConfig> ? -
final
-
auroraServerlessScalingConfig
→ List<
ArcregionswitchPlanAuroraServerlessScalingConfig> ? -
final
-
customActionLambdaConfig
→ List<
ArcregionswitchPlanCustomActionLambdaConfig> ? -
final
-
description
→ TfArg<
String> ? -
final
-
documentDbConfig
→ List<
ArcregionswitchPlanDocumentDbConfig> ? -
final
-
ec2AsgCapacityIncreaseConfig
→ List<
ArcregionswitchPlanEc2AsgCapacityIncreaseConfig> ? -
final
-
ecsCapacityIncreaseConfig
→ List<
ArcregionswitchPlanEcsCapacityIncreaseConfig> ? -
final
-
eksResourceScalingConfig
→ List<
ArcregionswitchPlanEksResourceScalingConfig> ? -
final
-
executionApprovalConfig
→ List<
ArcregionswitchPlanExecutionApprovalConfig> ? -
final
-
executionBlockType
→ TfArg<
ArcregionswitchPlanExecutionBlockType> -
final
-
globalAuroraConfig
→ List<
ArcregionswitchPlanGlobalAuroraConfig> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lambdaEventSourceMappingConfig
→ List<
ArcregionswitchPlanLambdaEventSourceMappingConfig> ? -
final
-
name
→ TfArg<
String> -
final
-
neptuneGlobalDatabaseConfig
→ List<
ArcregionswitchPlanNeptuneGlobalDatabaseConfig> ? -
final
-
rdsCreateCrossRegionReadReplicaConfig
→ List<
ArcregionswitchPlanRdsCreateCrossRegionReadReplicaConfig> ? -
final
-
rdsPromoteReadReplicaConfig
→ List<
ArcregionswitchPlanRdsPromoteReadReplicaConfig> ? -
final
-
regionSwitchPlanConfig
→ List<
ArcregionswitchPlanRegionSwitchPlanConfig> ? -
final
-
route53HealthCheckConfig
→ List<
ArcregionswitchPlanRoute53HealthCheckConfig> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited