BedrockModelInvocationJobS3InputDataConfig class final
Typed helper for the input_data_config.s3_input_data_config block of
aws_bedrock_model_invocation_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BedrockModelInvocationJobS3InputDataConfig({TfArg<
String> ? s3BucketOwner, TfArg<BedrockModelInvocationJobS3InputFormat> ? s3InputFormat, required TfArg<String> s3Uri}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
s3BucketOwner
→ TfArg<
String> ? -
final
-
s3InputFormat
→ TfArg<
BedrockModelInvocationJobS3InputFormat> ? -
final
-
s3Uri
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited