BedrockModelInvocationLoggingConfigurationCloudwatchConfig class final
Typed helper for the logging_config.cloudwatch_config block of
aws_bedrock_model_invocation_logging_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BedrockModelInvocationLoggingConfigurationCloudwatchConfig({required RefTo<
AwsCloudwatchLogGroup> logGroupName, required RefTo<AwsIamRole> roleArn, List<BedrockModelInvocationLoggingConfigurationLargeDataDeliveryS3Config> ? largeDataDeliveryS3Config}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
largeDataDeliveryS3Config
→ List<
BedrockModelInvocationLoggingConfigurationLargeDataDeliveryS3Config> ? -
final
-
logGroupName
→ RefTo<
AwsCloudwatchLogGroup> -
final
-
roleArn
→ RefTo<
AwsIamRole> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited