BedrockModelInvocationLoggingConfigurationS3Config class final
Typed helper for the logging_config.s3_config block of
aws_bedrock_model_invocation_logging_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BedrockModelInvocationLoggingConfigurationS3Config({required RefTo<
AwsS3Bucket> bucketName, TfArg<String> ? keyPrefix}) -
const
Properties
-
bucketName
→ RefTo<
AwsS3Bucket> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keyPrefix
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited