BedrockagentKnowledgeBaseBedrockEmbeddingModelConfiguration class final
Typed helper for the knowledge_base_configuration.managed_knowledge_base_configuration.embedding_model_configuration.bedrock_embedding_model_configuration block of
aws_bedrockagent_knowledge_base (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
BedrockagentKnowledgeBaseBedrockEmbeddingModelConfiguration({TfArg<
num> ? dimensions, BedrockagentKnowledgeBaseEmbeddingDataType? embeddingDataType, List<BedrockagentKnowledgeBaseAudio> ? audio, List<BedrockagentKnowledgeBaseVideo> ? video}) -
const
Properties
-
audio
→ List<
BedrockagentKnowledgeBaseAudio> ? -
final
-
dimensions
→ TfArg<
num> ? -
final
- embeddingDataType → BedrockagentKnowledgeBaseEmbeddingDataType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
video
→ List<
BedrockagentKnowledgeBaseVideo> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited