BedrockagentKnowledgeBaseRedshiftConfiguration class final
Typed helper for the knowledge_base_configuration.sql_knowledge_base_configuration.redshift_configuration block of
aws_bedrockagent_knowledge_base (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BedrockagentKnowledgeBaseRedshiftConfiguration({List<
BedrockagentKnowledgeBaseQueryEngineConfiguration> ? queryEngineConfiguration, List<BedrockagentKnowledgeBaseQueryGenerationConfiguration> ? queryGenerationConfiguration, List<BedrockagentKnowledgeBaseRedshiftConfigurationStorageConfiguration> ? storageConfiguration}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
queryEngineConfiguration
→ List<
BedrockagentKnowledgeBaseQueryEngineConfiguration> ? -
final
-
queryGenerationConfiguration
→ List<
BedrockagentKnowledgeBaseQueryGenerationConfiguration> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storageConfiguration
→ List<
BedrockagentKnowledgeBaseRedshiftConfigurationStorageConfiguration> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited