BedrockagentcoreMemoryStrategyMetadataSchema class final
Typed helper for the memory_record_schema.metadata_schema block of
aws_bedrockagentcore_memory_strategy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BedrockagentcoreMemoryStrategyMetadataSchema({TfArg<
BedrockagentcoreMemoryStrategyExtractionType> ? extractionType, required TfArg<String> key, TfArg<BedrockagentcoreMemoryStrategyMetadataSchemaType> ? type, List<BedrockagentcoreMemoryStrategyExtractionConfig> ? extractionConfig}) -
const
Properties
-
extractionConfig
→ List<
BedrockagentcoreMemoryStrategyExtractionConfig> ? -
final
-
extractionType
→ TfArg<
BedrockagentcoreMemoryStrategyExtractionType> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
key
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
→ TfArg<
BedrockagentcoreMemoryStrategyMetadataSchemaType> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited