BillingViewDataFilterExpression class final
Typed helper for the data_filter_expression block of
aws_billing_view (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
BillingViewDataFilterExpression({List<
BillingViewDimensions> ? dimensions, List<BillingViewDataFilterExpressionTags> ? tags, List<BillingViewTimeRange> ? timeRange}) -
const
Properties
-
dimensions
→ List<
BillingViewDimensions> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
-
timeRange
→ List<
BillingViewTimeRange> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited