CloudformationStackSetInstanceOperationPreferences class final
Typed helper for the operation_preferences block of
aws_cloudformation_stack_set_instance (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudformationStackSetInstanceOperationPreferences({CloudformationStackSetInstanceConcurrencyMode? concurrencyMode, CloudformationStackSetInstanceFailureTolerance? failureTolerance, CloudformationStackSetInstanceMaxConcurrent? maxConcurrent, CloudformationStackSetInstanceRegionConcurrencyType? regionConcurrencyType, TfArg<
List< ? regionOrder})String> > -
const
Properties
- concurrencyMode → CloudformationStackSetInstanceConcurrencyMode?
-
final
- failureTolerance → CloudformationStackSetInstanceFailureTolerance?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrent → CloudformationStackSetInstanceMaxConcurrent?
-
final
- regionConcurrencyType → CloudformationStackSetInstanceRegionConcurrencyType?
-
final
-
regionOrder
→ TfArg<
List< ?String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited