CloudfrontFieldLevelEncryptionProfileItems class final
Typed helper for the encryption_entities.items block of
aws_cloudfront_field_level_encryption_profile (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudfrontFieldLevelEncryptionProfileItems({required TfArg<
String> providerId, required TfArg<String> publicKeyId, required CloudfrontFieldLevelEncryptionProfileFieldPatterns fieldPatterns}) -
const
Properties
- fieldPatterns → CloudfrontFieldLevelEncryptionProfileFieldPatterns
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
providerId
→ TfArg<
String> -
final
-
publicKeyId
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited