CloudfrontMultitenantDistributionOriginMtlsConfig class final
Typed helper for the origin.custom_origin_config.origin_mtls_config block of
aws_cloudfront_multitenant_distribution (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudfrontMultitenantDistributionOriginMtlsConfig({required TfArg<
String> clientCertificateArn}) -
const
Properties
-
clientCertificateArn
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited