CloudfrontMultitenantDistributionOriginShield class final
Typed helper for the origin.origin_shield block of
aws_cloudfront_multitenant_distribution (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudfrontMultitenantDistributionOriginShield({required TfArg<
bool> enabled, TfArg<String> ? originShieldRegion}) -
const
Properties
-
enabled
→ TfArg<
bool> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
originShieldRegion
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited