CloudwatchEventTargetBatchTarget class final
Typed helper for the batch_target block of
aws_cloudwatch_event_target (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudwatchEventTargetBatchTarget({TfArg<
num> ? arraySize, TfArg<num> ? jobAttempts, required TfArg<String> jobDefinition, required TfArg<String> jobName}) -
const
Properties
-
arraySize
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
jobAttempts
→ TfArg<
num> ? -
final
-
jobDefinition
→ TfArg<
String> -
final
-
jobName
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited