CloudwatchEventTargetCapacityProviderStrategy class final
Typed helper for the ecs_target.capacity_provider_strategy block of
aws_cloudwatch_event_target (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CloudwatchEventTargetCapacityProviderStrategy({TfArg<
num> ? base, required TfArg<String> capacityProvider, TfArg<num> ? weight}) -
const
Properties
-
base
→ TfArg<
num> ? -
final
-
capacityProvider
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
weight
→ TfArg<
num> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited