CodebuildProjectBuildBatchConfig class final
Typed helper for the build_batch_config block of
aws_codebuild_project (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CodebuildProjectBuildBatchConfig({TfArg<
bool> ? combineArtifacts, required RefTo<AwsIamRole> serviceRole, TfArg<num> ? timeoutInMins, CodebuildProjectRestrictions? restrictions}) -
const
Properties
-
combineArtifacts
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- restrictions → CodebuildProjectRestrictions?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serviceRole
→ RefTo<
AwsIamRole> -
final
-
timeoutInMins
→ TfArg<
num> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited