CodebuildProjectFileSystemLocations class final
Typed helper for the file_system_locations block of
aws_codebuild_project (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CodebuildProjectFileSystemLocations({TfArg<
String> ? identifier, TfArg<String> ? location, TfArg<String> ? mountOptions, TfArg<String> ? mountPoint, CodebuildProjectFileSystemLocationsType? type}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
identifier
→ TfArg<
String> ? -
final
-
location
→ TfArg<
String> ? -
final
-
mountOptions
→ TfArg<
String> ? -
final
-
mountPoint
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → CodebuildProjectFileSystemLocationsType?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited