CodebuildProjectRegistryCredential class final
Typed helper for the environment.registry_credential block of
aws_codebuild_project (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CodebuildProjectRegistryCredential({required TfArg<
String> credential, required CodebuildProjectCredentialProvider credentialProvider}) -
const
Properties
-
credential
→ TfArg<
String> -
final
- credentialProvider → CodebuildProjectCredentialProvider
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited