CodedeployDeploymentGroupTriggerConfiguration class final
Typed helper for the trigger_configuration block of
aws_codedeploy_deployment_group (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CodedeployDeploymentGroupTriggerConfiguration({required List<
TfArg< triggerEvents, required TfArg<CodedeployDeploymentGroupTriggerEvents> >String> triggerName, required TfArg<String> triggerTargetArn}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
triggerEvents
→ List<
TfArg< CodedeployDeploymentGroupTriggerEvents> > -
final
-
triggerName
→ TfArg<
String> -
final
-
triggerTargetArn
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited