ComprehendDocumentClassifierInputDataConfig class final
Typed helper for the input_data_config block of
aws_comprehend_document_classifier (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ComprehendDocumentClassifierInputDataConfig({ComprehendDocumentClassifierDataFormat? dataFormat, ComprehendDocumentClassifierLabelDelimiter? labelDelimiter, required ComprehendDocumentClassifierSource source, TfArg<
String> ? testS3Uri}) -
const
Properties
- dataFormat → ComprehendDocumentClassifierDataFormat?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelDelimiter → ComprehendDocumentClassifierLabelDelimiter?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → ComprehendDocumentClassifierSource
-
final
-
testS3Uri
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited