ConfigConfigRuleSourceDetail class final
Typed helper for the source.source_detail block of
aws_config_config_rule (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ConfigConfigRuleSourceDetail({TfArg<
ConfigConfigRuleEventSource> ? eventSource, TfArg<ConfigConfigRuleSourceDetailMaximumExecutionFrequency> ? maximumExecutionFrequency, TfArg<ConfigConfigRuleMessageType> ? messageType}) -
const
Properties
-
eventSource
→ TfArg<
ConfigConfigRuleEventSource> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maximumExecutionFrequency
→ TfArg<
ConfigConfigRuleSourceDetailMaximumExecutionFrequency> ? -
final
-
messageType
→ TfArg<
ConfigConfigRuleMessageType> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited