ConfigOrganizationConformancePackInputParameter class final
Typed helper for the input_parameter block of
aws_config_organization_conformance_pack (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ConfigOrganizationConformancePackInputParameter({required TfArg<
String> parameterName, required TfArg<String> parameterValue}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parameterName
→ TfArg<
String> -
final
-
parameterValue
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited