ConnectInstanceStorageConfigS3Config class final
Typed helper for the storage_config.s3_config block of
aws_connect_instance_storage_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ConnectInstanceStorageConfigS3Config({required RefTo<
AwsS3Bucket> bucketName, required TfArg<String> bucketPrefix, ConnectInstanceStorageConfigEncryptionConfig? encryptionConfig}) -
const
Properties
-
bucketName
→ RefTo<
AwsS3Bucket> -
final
-
bucketPrefix
→ TfArg<
String> -
final
- encryptionConfig → ConnectInstanceStorageConfigEncryptionConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited