ConnectQuickConnectConfig class final
Typed helper for the quick_connect_config block of
aws_connect_quick_connect (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ConnectQuickConnectConfig({required ConnectQuickConnectType quickConnectType, List<
ConnectQuickConnectPhoneConfig> ? phoneConfig, List<ConnectQuickConnectQueueConfig> ? queueConfig, List<ConnectQuickConnectUserConfig> ? userConfig}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
phoneConfig
→ List<
ConnectQuickConnectPhoneConfig> ? -
final
-
queueConfig
→ List<
ConnectQuickConnectQueueConfig> ? -
final
- quickConnectType → ConnectQuickConnectType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userConfig
→ List<
ConnectQuickConnectUserConfig> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited