ConnectVocabularyLanguageCode extension type
Connect Vocabulary Language enum for language_code.
Constructors
-
ConnectVocabularyLanguageCode.arg(TfArg<
String> arg) -
const
- ConnectVocabularyLanguageCode.expression(String template)
- ConnectVocabularyLanguageCode.variable(String name)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- arAe → const ConnectVocabularyLanguageCode
- caEs → const ConnectVocabularyLanguageCode
- daDk → const ConnectVocabularyLanguageCode
- deCh → const ConnectVocabularyLanguageCode
- deDe → const ConnectVocabularyLanguageCode
- enAb → const ConnectVocabularyLanguageCode
- enAu → const ConnectVocabularyLanguageCode
- enGb → const ConnectVocabularyLanguageCode
- enIe → const ConnectVocabularyLanguageCode
- enIn → const ConnectVocabularyLanguageCode
- enNz → const ConnectVocabularyLanguageCode
- enUs → const ConnectVocabularyLanguageCode
- enWl → const ConnectVocabularyLanguageCode
- enZa → const ConnectVocabularyLanguageCode
- esEs → const ConnectVocabularyLanguageCode
- esUs → const ConnectVocabularyLanguageCode
- fiFi → const ConnectVocabularyLanguageCode
- frCa → const ConnectVocabularyLanguageCode
- frFr → const ConnectVocabularyLanguageCode
- hiIn → const ConnectVocabularyLanguageCode
- idId → const ConnectVocabularyLanguageCode
- itIt → const ConnectVocabularyLanguageCode
- jaJp → const ConnectVocabularyLanguageCode
- koKr → const ConnectVocabularyLanguageCode
- msMy → const ConnectVocabularyLanguageCode
- nlNl → const ConnectVocabularyLanguageCode
- noNo → const ConnectVocabularyLanguageCode
- plPl → const ConnectVocabularyLanguageCode
- ptBr → const ConnectVocabularyLanguageCode
- ptPt → const ConnectVocabularyLanguageCode
- svSe → const ConnectVocabularyLanguageCode
- tlPh → const ConnectVocabularyLanguageCode
-
values
→ const List<
ConnectVocabularyLanguageCode> - zhCn → const ConnectVocabularyLanguageCode