DlmLifecyclePolicyScripts class final
Typed helper for the policy_details.schedule.create_rule.scripts block of
aws_dlm_lifecycle_policy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DlmLifecyclePolicyScripts({TfArg<
bool> ? executeOperationOnScriptFailure, required TfArg<String> executionHandler, TfArg<DlmLifecyclePolicyExecutionHandlerService> ? executionHandlerService, TfArg<num> ? executionTimeout, TfArg<num> ? maximumRetryCount, List<TfArg< ? stages})DlmLifecyclePolicyStages> > -
const
Properties
-
executeOperationOnScriptFailure
→ TfArg<
bool> ? -
final
-
executionHandler
→ TfArg<
String> -
final
-
executionHandlerService
→ TfArg<
DlmLifecyclePolicyExecutionHandlerService> ? -
final
-
executionTimeout
→ TfArg<
num> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maximumRetryCount
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stages
→ List<
TfArg< ?DlmLifecyclePolicyStages> > -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited