DmsReplicationConfigComputeConfig class final
Typed helper for the compute_config block of
aws_dms_replication_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DmsReplicationConfigComputeConfig({TfArg<
String> ? availabilityZone, TfArg<String> ? dnsNameServers, RefTo<AwsKmsKey> ? kmsKeyId, TfArg<num> ? maxCapacityUnits, TfArg<num> ? minCapacityUnits, TfArg<bool> ? multiAz, TfArg<String> ? preferredMaintenanceWindow, required TfArg<String> replicationSubnetGroupId, TfArg<List< ? vpcSecurityGroupIds})RefTo< >AwsSecurityGroup> > -
const
Properties
-
availabilityZone
→ TfArg<
String> ? -
final
-
dnsNameServers
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeyId
→ RefTo<
AwsKmsKey> ? -
final
-
maxCapacityUnits
→ TfArg<
num> ? -
final
-
minCapacityUnits
→ TfArg<
num> ? -
final
-
multiAz
→ TfArg<
bool> ? -
final
-
preferredMaintenanceWindow
→ TfArg<
String> ? -
final
-
replicationSubnetGroupId
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
vpcSecurityGroupIds
→ TfArg<
List< ?RefTo< >AwsSecurityGroup> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited