DynamodbTableS3BucketSource class final
Typed helper for the import_table.s3_bucket_source block of
aws_dynamodb_table (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
DynamodbTableS3BucketSource({required RefTo<
AwsS3Bucket> bucket, TfArg<String> ? bucketOwner, TfArg<String> ? keyPrefix}) -
const
Properties
-
bucket
→ RefTo<
AwsS3Bucket> -
final
-
bucketOwner
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keyPrefix
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited