EcsDaemonTaskDefinitionLogConfiguration class final
Typed helper for the container_definition.log_configuration block of
aws_ecs_daemon_task_definition (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
EcsDaemonTaskDefinitionLogConfiguration({required TfArg<
EcsDaemonTaskDefinitionLogDriver> logDriver, TfArg<Map< ? options, List<String, String> >EcsDaemonTaskDefinitionSecretOption> ? secretOption}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logDriver
→ TfArg<
EcsDaemonTaskDefinitionLogDriver> -
final
-
options
→ TfArg<
Map< ?String, String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretOption
→ List<
EcsDaemonTaskDefinitionSecretOption> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited