EcsServiceDeploymentConfiguration class final
Typed helper for the deployment_configuration block of
aws_ecs_service (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
EcsServiceDeploymentConfiguration({TfArg<
String> ? bakeTimeInMinutes, EcsServiceStrategy? strategy, EcsServiceCanaryConfiguration? canaryConfiguration, List<EcsServiceLifecycleHook> ? lifecycleHook, EcsServiceLinearConfiguration? linearConfiguration}) -
const
Properties
-
bakeTimeInMinutes
→ TfArg<
String> ? -
final
- canaryConfiguration → EcsServiceCanaryConfiguration?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lifecycleHook
→ List<
EcsServiceLifecycleHook> ? -
final
- linearConfiguration → EcsServiceLinearConfiguration?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strategy → EcsServiceStrategy?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited