EcsTaskDefinitionS3filesVolumeConfiguration class final
Typed helper for the volume.s3files_volume_configuration block of
aws_ecs_task_definition (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
accessPointArn
→ TfArg<
String> ? -
final
-
fileSystemArn
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rootDirectory
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transitEncryptionPort
→ TfArg<
num> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited