ElasticacheReplicationGroupLogDeliveryConfiguration class final
Typed helper for the log_delivery_configuration block of
aws_elasticache_replication_group (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ElasticacheReplicationGroupLogDeliveryConfiguration({required TfArg<
String> destination, required TfArg<ElasticacheReplicationGroupDestinationType> destinationType, required TfArg<ElasticacheReplicationGroupLogFormat> logFormat, required TfArg<ElasticacheReplicationGroupLogType> logType}) -
const
Properties
-
destination
→ TfArg<
String> -
final
-
destinationType
→ TfArg<
ElasticacheReplicationGroupDestinationType> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logFormat
→ TfArg<
ElasticacheReplicationGroupLogFormat> -
final
-
logType
→ TfArg<
ElasticacheReplicationGroupLogType> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited