ElastictranscoderPresetAudioCodecOptions class final
Typed helper for the audio_codec_options block of
aws_elastictranscoder_preset (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- ElastictranscoderPresetAudioCodecOptions({ElastictranscoderPresetBitDepth? bitDepth, ElastictranscoderPresetBitOrder? bitOrder, ElastictranscoderPresetProfile? profile, ElastictranscoderPresetSigned? signed})
-
const
Properties
- bitDepth → ElastictranscoderPresetBitDepth?
-
final
- bitOrder → ElastictranscoderPresetBitOrder?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- profile → ElastictranscoderPresetProfile?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signed → ElastictranscoderPresetSigned?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited