FlowLogDestinationOptions class final
Typed helper for the destination_options block of
aws_flow_log (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
FlowLogDestinationOptions({FlowLogFileFormat? fileFormat, TfArg<
bool> ? hiveCompatiblePartitions, TfArg<bool> ? perHourPartition}) -
const
Properties
- fileFormat → FlowLogFileFormat?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hiveCompatiblePartitions
→ TfArg<
bool> ? -
final
-
perHourPartition
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited