FsxWindowsFileSystemSelfManagedActiveDirectory class final
Typed helper for the self_managed_active_directory block of
aws_fsx_windows_file_system (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
FsxWindowsFileSystemSelfManagedActiveDirectory({required TfArg<
List< dnsIps, TfArg<String> >String> ? domainJoinServiceAccountSecret, required TfArg<String> domainName, TfArg<String> ? fileSystemAdministratorsGroup, TfArg<String> ? organizationalUnitDistinguishedName, TfArg<String> ? password, TfArg<String> ? passwordWo, TfArg<num> ? passwordWoVersion, TfArg<String> ? username}) -
const
Properties
-
dnsIps
→ TfArg<
List< String> > -
final
-
domainJoinServiceAccountSecret
→ TfArg<
String> ? -
final
-
domainName
→ TfArg<
String> -
final
-
fileSystemAdministratorsGroup
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
organizationalUnitDistinguishedName
→ TfArg<
String> ? -
final
-
password
→ TfArg<
String> ? -
final
-
passwordWo
→ TfArg<
String> ? -
final
-
passwordWoVersion
→ TfArg<
num> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
username
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited