IdentitystoreUserAddresses class final
Typed helper for the addresses block of
aws_identitystore_user (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
country
→ TfArg<
String> ? -
final
-
formatted
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locality
→ TfArg<
String> ? -
final
-
postalCode
→ TfArg<
String> ? -
final
-
primary
→ TfArg<
bool> ? -
final
-
region
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
streetAddress
→ TfArg<
String> ? -
final
-
type
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited