ImagebuilderContainerRecipeBlockDeviceMapping class final
Typed helper for the instance_configuration.block_device_mapping block of
aws_imagebuilder_container_recipe (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ImagebuilderContainerRecipeBlockDeviceMapping({TfArg<
String> ? deviceName, TfArg<bool> ? noDevice, TfArg<String> ? virtualName, ImagebuilderContainerRecipeEbs? ebs}) -
const
Properties
-
deviceName
→ TfArg<
String> ? -
final
- ebs → ImagebuilderContainerRecipeEbs?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
noDevice
→ TfArg<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
virtualName
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited