IotTopicRuleErrorAction class final
Typed helper for the error_action block of
aws_iot_topic_rule (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- IotTopicRuleErrorAction({IotTopicRuleCloudwatchAlarm? cloudwatchAlarm, IotTopicRuleCloudwatchLogs? cloudwatchLogs, IotTopicRuleCloudwatchMetric? cloudwatchMetric, IotTopicRuleDynamodb? dynamodb, IotTopicRuleDynamodbv2? dynamodbv2, IotTopicRuleElasticsearch? elasticsearch, IotTopicRuleFirehose? firehose, IotTopicRuleHttp? http, IotTopicRuleIotAnalytics? iotAnalytics, IotTopicRuleIotEvents? iotEvents, IotTopicRuleKafka? kafka, IotTopicRuleKinesis? kinesis, IotTopicRuleLambda? lambda, IotTopicRuleRepublish? republish, IotTopicRuleS3? s3, IotTopicRuleSns? sns, IotTopicRuleSqs? sqs, IotTopicRuleStepFunctions? stepFunctions, IotTopicRuleTimestream? timestream})
-
const
Properties
- cloudwatchAlarm → IotTopicRuleCloudwatchAlarm?
-
final
- cloudwatchLogs → IotTopicRuleCloudwatchLogs?
-
final
- cloudwatchMetric → IotTopicRuleCloudwatchMetric?
-
final
- dynamodb → IotTopicRuleDynamodb?
-
final
- dynamodbv2 → IotTopicRuleDynamodbv2?
-
final
- elasticsearch → IotTopicRuleElasticsearch?
-
final
- firehose → IotTopicRuleFirehose?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- http → IotTopicRuleHttp?
-
final
- iotAnalytics → IotTopicRuleIotAnalytics?
-
final
- iotEvents → IotTopicRuleIotEvents?
-
final
- kafka → IotTopicRuleKafka?
-
final
- kinesis → IotTopicRuleKinesis?
-
final
- lambda → IotTopicRuleLambda?
-
final
- republish → IotTopicRuleRepublish?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s3 → IotTopicRuleS3?
-
final
- sns → IotTopicRuleSns?
-
final
- sqs → IotTopicRuleSqs?
-
final
- stepFunctions → IotTopicRuleStepFunctions?
-
final
- timestream → IotTopicRuleTimestream?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited