KendraDataSourceInvocationCondition class final
Typed helper for the custom_document_enrichment_configuration.post_extraction_hook_configuration.invocation_condition block of
aws_kendra_data_source (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
KendraDataSourceInvocationCondition({required TfArg<
String> conditionDocumentAttributeKey, required TfArg<String> operator, KendraDataSourceConditionOnValue? conditionOnValue}) -
const
Properties
-
conditionDocumentAttributeKey
→ TfArg<
String> -
final
- conditionOnValue → KendraDataSourceConditionOnValue?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
operator
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited