KendraDataSourcePreExtractionHookConfiguration class final
Typed helper for the custom_document_enrichment_configuration.pre_extraction_hook_configuration block of
aws_kendra_data_source (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
KendraDataSourcePreExtractionHookConfiguration({required RefTo<
AwsLambdaFunction> lambdaArn, required RefTo<AwsS3Bucket> s3Bucket, KendraDataSourceInvocationCondition? invocationCondition}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- invocationCondition → KendraDataSourceInvocationCondition?
-
final
-
lambdaArn
→ RefTo<
AwsLambdaFunction> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
s3Bucket
→ RefTo<
AwsS3Bucket> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited