KeyspacesTableSchemaDefinition class final
Typed helper for the schema_definition block of
aws_keyspaces_table (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
KeyspacesTableSchemaDefinition({List<
KeyspacesTableClusteringKey> ? clusteringKey, required List<KeyspacesTableColumn> column, required List<KeyspacesTablePartitionKey> partitionKey, List<KeyspacesTableStaticColumn> ? staticColumn}) -
const
Properties
-
clusteringKey
→ List<
KeyspacesTableClusteringKey> ? -
final
-
column
→ List<
KeyspacesTableColumn> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
partitionKey
→ List<
KeyspacesTablePartitionKey> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
staticColumn
→ List<
KeyspacesTableStaticColumn> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited