KinesisAnalyticsApplicationInputsSchema class final
Typed helper for the inputs.schema block of
aws_kinesis_analytics_application (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
KinesisAnalyticsApplicationInputsSchema({TfArg<
String> ? recordEncoding, required List<KinesisAnalyticsApplicationRecordColumns> recordColumns, required KinesisAnalyticsApplicationRecordFormat recordFormat}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
recordColumns
→ List<
KinesisAnalyticsApplicationRecordColumns> -
final
-
recordEncoding
→ TfArg<
String> ? -
final
- recordFormat → KinesisAnalyticsApplicationRecordFormat
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited