LambdaFunctionEventInvokeConfigDestinationConfig class final
Typed helper for the destination_config block of
aws_lambda_function_event_invoke_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- LambdaFunctionEventInvokeConfigDestinationConfig({LambdaFunctionEventInvokeConfigOnFailure? onFailure, LambdaFunctionEventInvokeConfigOnSuccess? onSuccess})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onFailure → LambdaFunctionEventInvokeConfigOnFailure?
-
final
- onSuccess → LambdaFunctionEventInvokeConfigOnSuccess?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited