LexIntentRejectionStatement class final
Typed helper for the rejection_statement block of
aws_lex_intent (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
LexIntentRejectionStatement({TfArg<
String> ? responseCard, required List<LexIntentMessage> message}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
message
→ List<
LexIntentMessage> -
final
-
responseCard
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited