Lexv2modelsIntentAllowedInputTypes class final
Typed helper for the confirmation_setting.prompt_specification.prompt_attempts_specification.allowed_input_types block of
aws_lexv2models_intent (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsIntentAllowedInputTypes({required TfArg<
bool> allowAudioInput, required TfArg<bool> allowDtmfInput}) -
const
Properties
-
allowAudioInput
→ TfArg<
bool> -
final
-
allowDtmfInput
→ TfArg<
bool> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited