Lexv2modelsIntentClosingSetting class final
Typed helper for the closing_setting block of
aws_lexv2models_intent (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsIntentClosingSetting({TfArg<
bool> ? active, List<Lexv2modelsIntentClosingResponse> ? closingResponse, List<Lexv2modelsIntentConditional> ? conditional, List<Lexv2modelsIntentNextStep> ? nextStep}) -
const
Properties
-
active
→ TfArg<
bool> ? -
final
-
closingResponse
→ List<
Lexv2modelsIntentClosingResponse> ? -
final
-
conditional
→ List<
Lexv2modelsIntentConditional> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nextStep
→ List<
Lexv2modelsIntentNextStep> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited