Lexv2modelsIntentConfirmationConditional class final
Typed helper for the confirmation_setting.confirmation_conditional block of
aws_lexv2models_intent (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsIntentConfirmationConditional({required TfArg<
bool> active, List<Lexv2modelsIntentConditionalBranch> ? conditionalBranch, List<Lexv2modelsIntentDefaultBranch> ? defaultBranch}) -
const
Properties
-
active
→ TfArg<
bool> -
final
-
conditionalBranch
→ List<
Lexv2modelsIntentConditionalBranch> ? -
final
-
defaultBranch
→ List<
Lexv2modelsIntentDefaultBranch> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited