Lexv2modelsIntentMessage class final
Typed helper for the closing_setting.closing_response.message_group.message block of
aws_lexv2models_intent (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsIntentMessage({List<
Lexv2modelsIntentCustomPayload> ? customPayload, List<Lexv2modelsIntentImageResponseCard> ? imageResponseCard, List<Lexv2modelsIntentPlainTextMessage> ? plainTextMessage, List<Lexv2modelsIntentSsmlMessage> ? ssmlMessage}) -
const
Properties
-
customPayload
→ List<
Lexv2modelsIntentCustomPayload> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imageResponseCard
→ List<
Lexv2modelsIntentImageResponseCard> ? -
final
-
plainTextMessage
→ List<
Lexv2modelsIntentPlainTextMessage> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
ssmlMessage
→ List<
Lexv2modelsIntentSsmlMessage> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited