Lexv2modelsIntentPostCodeHookSpecification class final
Typed helper for the confirmation_setting.code_hook.post_code_hook_specification block of
aws_lexv2models_intent (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsIntentPostCodeHookSpecification({List<
Lexv2modelsIntentFailureConditional> ? failureConditional, List<Lexv2modelsIntentFailureNextStep> ? failureNextStep, List<Lexv2modelsIntentFailureResponse> ? failureResponse, List<Lexv2modelsIntentSuccessConditional> ? successConditional, List<Lexv2modelsIntentSuccessNextStep> ? successNextStep, List<Lexv2modelsIntentSuccessResponse> ? successResponse, List<Lexv2modelsIntentTimeoutConditional> ? timeoutConditional, List<Lexv2modelsIntentTimeoutNextStep> ? timeoutNextStep, List<Lexv2modelsIntentTimeoutResponse> ? timeoutResponse}) -
const
Properties
-
failureConditional
→ List<
Lexv2modelsIntentFailureConditional> ? -
final
-
failureNextStep
→ List<
Lexv2modelsIntentFailureNextStep> ? -
final
-
failureResponse
→ List<
Lexv2modelsIntentFailureResponse> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
successConditional
→ List<
Lexv2modelsIntentSuccessConditional> ? -
final
-
successNextStep
→ List<
Lexv2modelsIntentSuccessNextStep> ? -
final
-
successResponse
→ List<
Lexv2modelsIntentSuccessResponse> ? -
final
-
timeoutConditional
→ List<
Lexv2modelsIntentTimeoutConditional> ? -
final
-
timeoutNextStep
→ List<
Lexv2modelsIntentTimeoutNextStep> ? -
final
-
timeoutResponse
→ List<
Lexv2modelsIntentTimeoutResponse> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited