Lexv2modelsIntentPromptAttemptsSpecification class final
Typed helper for the confirmation_setting.prompt_specification.prompt_attempts_specification block of
aws_lexv2models_intent (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsIntentPromptAttemptsSpecification({TfArg<
bool> ? allowInterrupt, required TfArg<String> mapBlockKey, List<Lexv2modelsIntentAllowedInputTypes> ? allowedInputTypes, List<Lexv2modelsIntentAudioAndDtmfInputSpecification> ? audioAndDtmfInputSpecification, List<Lexv2modelsIntentTextInputSpecification> ? textInputSpecification}) -
const
Properties
-
allowedInputTypes
→ List<
Lexv2modelsIntentAllowedInputTypes> ? -
final
-
allowInterrupt
→ TfArg<
bool> ? -
final
-
audioAndDtmfInputSpecification
→ List<
Lexv2modelsIntentAudioAndDtmfInputSpecification> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mapBlockKey
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
textInputSpecification
→ List<
Lexv2modelsIntentTextInputSpecification> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited