Lexv2modelsSlotTypeSource class final
Typed helper for the external_source_setting.grammar_slot_type_setting.source block of
aws_lexv2models_slot_type (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Lexv2modelsSlotTypeSource({required RefTo<
AwsKmsKey> kmsKeyArn, required RefTo<AwsS3Bucket> s3BucketName, required TfArg<String> s3ObjectKey}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeyArn
→ RefTo<
AwsKmsKey> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
s3BucketName
→ RefTo<
AwsS3Bucket> -
final
-
s3ObjectKey
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited