Macie2ClassificationJobBucketDefinitionsChoice class final
The Macie2ClassificationJobBucket.bucketDefinitions choice: sets bucket_definitions.
- Inheritance
-
- Object
- Macie2ClassificationJobBucket
- Macie2ClassificationJobBucketDefinitionsChoice
Constructors
-
Macie2ClassificationJobBucketDefinitionsChoice(List<
Macie2ClassificationJobBucketDefinitions> bucketDefinitions) -
const
Properties
-
bucketDefinitions
→ List<
Macie2ClassificationJobBucketDefinitions> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited