Macie2ClassificationJobSimpleCriterion class final
Typed helper for the s3_job_definition.bucket_criteria.excludes.and.simple_criterion block of
aws_macie2_classification_job (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
Macie2ClassificationJobSimpleCriterion({Macie2ClassificationJobComparator? comparator, TfArg<
String> ? key, TfArg<List< ? values})String> > -
const
Properties
- comparator → Macie2ClassificationJobComparator?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
key
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ TfArg<
List< ?String> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited