MailmanagerRuleSetRule class final
Typed helper for the rule block of
aws_mailmanager_rule_set (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
MailmanagerRuleSetRule({TfArg<
String> ? name, List<MailmanagerRuleSetAction> ? action, List<MailmanagerRuleSetCondition> ? condition, List<MailmanagerRuleSetUnless> ? unless}) -
const
Properties
-
action
→ List<
MailmanagerRuleSetAction> ? -
final
-
condition
→ List<
MailmanagerRuleSetCondition> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unless
→ List<
MailmanagerRuleSetUnless> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited