MedialiveChannelFrameCaptureSettings class final
Typed helper for the encoder_settings.video_descriptions.codec_settings.frame_capture_settings block of
aws_medialive_channel (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
MedialiveChannelFrameCaptureSettings({TfArg<
num> ? captureInterval, TfArg<String> ? captureIntervalUnits}) -
const
Properties
-
captureInterval
→ TfArg<
num> ? -
final
-
captureIntervalUnits
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited