MskClusterClientAuthentication class final
Typed helper for the client_authentication block of
aws_msk_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
MskClusterClientAuthentication({TfArg<
bool> ? unauthenticated, MskClusterSasl? sasl, MskClusterTls? tls}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sasl → MskClusterSasl?
-
final
- tls → MskClusterTls?
-
final
-
unauthenticated
→ TfArg<
bool> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited