MskReplicatorTopicReplication class final
Typed helper for the replication_info_list.topic_replication block of
aws_msk_replicator (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
MskReplicatorTopicReplication({TfArg<
bool> ? copyAccessControlListsForTopics, TfArg<bool> ? copyTopicConfigurations, TfArg<bool> ? detectAndCopyNewTopics, TfArg<List< ? topicsToExclude, required TfArg<String> >List< topicsToReplicate, MskReplicatorStartingPosition? startingPosition, MskReplicatorTopicNameConfiguration? topicNameConfiguration})String> > -
const
Properties
-
copyAccessControlListsForTopics
→ TfArg<
bool> ? -
final
-
copyTopicConfigurations
→ TfArg<
bool> ? -
final
-
detectAndCopyNewTopics
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startingPosition → MskReplicatorStartingPosition?
-
final
- topicNameConfiguration → MskReplicatorTopicNameConfiguration?
-
final
-
topicsToExclude
→ TfArg<
List< ?String> > -
final
-
topicsToReplicate
→ TfArg<
List< String> > -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited