NetworkInterfaceIpv6AddressCount class final
The NetworkInterfaceIpv6Address.ipv6AddressCount choice: sets ipv6_address_count.
- Inheritance
-
- Object
- NetworkInterfaceIpv6Address
- NetworkInterfaceIpv6AddressCount
Constructors
-
NetworkInterfaceIpv6AddressCount(TfArg<
num> ipv6AddressCount) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ipv6AddressCount
→ TfArg<
num> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited