NetworkfirewallFirewallPolicyStatefulRuleGroupReference class final
Typed helper for the firewall_policy.stateful_rule_group_reference block of
aws_networkfirewall_firewall_policy (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkfirewallFirewallPolicyStatefulRuleGroupReference({TfArg<
String> ? deepThreatInspection, TfArg<num> ? priority, required TfArg<String> resourceArn, NetworkfirewallFirewallPolicyOverride? override}) -
const
Properties
-
deepThreatInspection
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- override → NetworkfirewallFirewallPolicyOverride?
-
final
-
priority
→ TfArg<
num> ? -
final
-
resourceArn
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited