NetworkfirewallLoggingConfigurationLogDestinationConfig class final
Typed helper for the logging_configuration.log_destination_config block of
aws_networkfirewall_logging_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkfirewallLoggingConfigurationLogDestinationConfig({required TfArg<
Map< logDestination, required NetworkfirewallLoggingConfigurationLogDestinationType logDestinationType, required NetworkfirewallLoggingConfigurationLogType logType})String, String> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logDestination
→ TfArg<
Map< String, String> > -
final
- logDestinationType → NetworkfirewallLoggingConfigurationLogDestinationType
-
final
- logType → NetworkfirewallLoggingConfigurationLogType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited