NetworkfirewallRuleGroupStatelessRulesAndCustomActions class final
Typed helper for the rule_group.rules_source.stateless_rules_and_custom_actions block of
aws_networkfirewall_rule_group (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
NetworkfirewallRuleGroupStatelessRulesAndCustomActions({List<
NetworkfirewallRuleGroupCustomAction> ? customAction, required List<NetworkfirewallRuleGroupStatelessRule> statelessRule}) -
const
Properties
-
customAction
→ List<
NetworkfirewallRuleGroupCustomAction> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statelessRule
→ List<
NetworkfirewallRuleGroupStatelessRule> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited