QuicksightAnalysisCustomValues class final
Typed helper for the definition.sheets.visuals.bar_chart_visual.actions.action_operations.set_parameters_operation.parameter_value_configurations.value.custom_values_configuration.custom_values block of
aws_quicksight_analysis (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
Properties
-
dateTimeValues
→ TfArg<
List< ?String> > -
final
-
decimalValues
→ TfArg<
List< ?num> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
integerValues
→ TfArg<
List< ?num> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stringValues
→ TfArg<
List< ?String> > -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited