QuicksightAnalysisDataPath class final
Typed helper for the definition.sheets.visuals.pivot_table_visual.chart_configuration.sort_configuration.field_sort_options.sort_by.data_path block of
aws_quicksight_analysis (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
QuicksightAnalysisDataPath({required TfArg<
String> direction, required List<QuicksightAnalysisElement> sortPaths}) -
const
Properties
-
direction
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sortPaths
→ List<
QuicksightAnalysisElement> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited