QuicksightAnalysisDecimalParameterDeclarationDefaultValues class final
Typed helper for the definition.parameter_declarations.decimal_parameter_declaration.default_values block of
aws_quicksight_analysis (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
QuicksightAnalysisDecimalParameterDeclarationDefaultValues({TfArg<
List< ? staticValues, QuicksightAnalysisDynamicValue? dynamicValue})num> > -
const
Properties
- dynamicValue → QuicksightAnalysisDynamicValue?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
staticValues
→ TfArg<
List< ?num> > -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited