QuicksightAnalysisFilterControlsSlider class final
Typed helper for the definition.sheets.filter_controls.slider block of
aws_quicksight_analysis (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
QuicksightAnalysisFilterControlsSlider({required TfArg<
String> filterControlId, required TfArg<num> maximumValue, required TfArg<num> minimumValue, required TfArg<String> sourceFilterId, required TfArg<num> stepSize, required TfArg<String> title, TfArg<String> ? type, QuicksightAnalysisSliderDisplayOptions? displayOptions}) -
const
Properties
- displayOptions → QuicksightAnalysisSliderDisplayOptions?
-
final
-
filterControlId
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
maximumValue
→ TfArg<
num> -
final
-
minimumValue
→ TfArg<
num> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceFilterId
→ TfArg<
String> -
final
-
stepSize
→ TfArg<
num> -
final
-
title
→ TfArg<
String> -
final
-
type
→ TfArg<
String> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited