QuicksightAnalysisFontConfiguration class final
Typed helper for the definition.sheets.filter_controls.date_time_picker.display_options.title_options.font_configuration block of
aws_quicksight_analysis (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
QuicksightAnalysisFontConfiguration({TfArg<
String> ? fontColor, TfArg<String> ? fontDecoration, TfArg<String> ? fontStyle, QuicksightAnalysisFontSize? fontSize, QuicksightAnalysisFontWeight? fontWeight}) -
const
Properties
-
fontColor
→ TfArg<
String> ? -
final
-
fontDecoration
→ TfArg<
String> ? -
final
- fontSize → QuicksightAnalysisFontSize?
-
final
-
fontStyle
→ TfArg<
String> ? -
final
- fontWeight → QuicksightAnalysisFontWeight?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited