QuicksightAnalysisPanelConfiguration class final
Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.small_multiples_options.panel_configuration block of
aws_quicksight_analysis (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
QuicksightAnalysisPanelConfiguration({TfArg<
String> ? backgroundColor, TfArg<String> ? backgroundVisibility, TfArg<String> ? borderColor, TfArg<String> ? borderStyle, TfArg<String> ? borderThickness, TfArg<String> ? borderVisibility, TfArg<String> ? gutterSpacing, TfArg<String> ? gutterVisibility, QuicksightAnalysisTitle? title}) -
const
Properties
-
backgroundColor
→ TfArg<
String> ? -
final
-
backgroundVisibility
→ TfArg<
String> ? -
final
-
borderColor
→ TfArg<
String> ? -
final
-
borderStyle
→ TfArg<
String> ? -
final
-
borderThickness
→ TfArg<
String> ? -
final
-
borderVisibility
→ TfArg<
String> ? -
final
-
gutterSpacing
→ TfArg<
String> ? -
final
-
gutterVisibility
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → QuicksightAnalysisTitle?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited