QuicksightDashboardBoxPlotVisual class final
Typed helper for the definition.sheets.visuals.box_plot_visual block of
aws_quicksight_dashboard (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
QuicksightDashboardBoxPlotVisual({required TfArg<
String> visualId, List<QuicksightDashboardActions> ? actions, QuicksightDashboardBoxPlotVisualChartConfiguration? chartConfiguration, List<QuicksightDashboardColumnHierarchies> ? columnHierarchies, QuicksightDashboardSubtitle? subtitle, QuicksightDashboardSubtitle? title}) -
const
Properties
-
actions
→ List<
QuicksightDashboardActions> ? -
final
- chartConfiguration → QuicksightDashboardBoxPlotVisualChartConfiguration?
-
final
-
columnHierarchies
→ List<
QuicksightDashboardColumnHierarchies> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → QuicksightDashboardSubtitle?
-
final
- title → QuicksightDashboardSubtitle?
-
final
-
visualId
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited