QuicksightTemplateDateTimeFormatConfiguration class final
Typed helper for the definition.column_configurations.format_configuration.date_time_format_configuration block of
aws_quicksight_template (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
QuicksightTemplateDateTimeFormatConfiguration({TfArg<
String> ? dateTimeFormat, QuicksightTemplateNullValueFormatConfiguration? nullValueFormatConfiguration, QuicksightTemplateNumericFormatConfiguration? numericFormatConfiguration}) -
const
Properties
-
dateTimeFormat
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nullValueFormatConfiguration → QuicksightTemplateNullValueFormatConfiguration?
-
final
- numericFormatConfiguration → QuicksightTemplateNumericFormatConfiguration?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited