QuicksightTemplatePivotTableVisualTableOptions class final
Typed helper for the definition.sheets.visuals.pivot_table_visual.chart_configuration.table_options block of
aws_quicksight_template (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
QuicksightTemplatePivotTableVisualTableOptions({TfArg<
String> ? collapsedRowDimensionsVisibility, TfArg<String> ? columnNamesVisibility, TfArg<String> ? metricPlacement, TfArg<String> ? singleMetricVisibility, TfArg<String> ? toggleButtonsVisibility, QuicksightTemplateCellStyle? cellStyle, QuicksightTemplateCellStyle? columnHeaderStyle, QuicksightTemplateRowAlternateColorOptions? rowAlternateColorOptions, QuicksightTemplateCellStyle? rowFieldNamesStyle, QuicksightTemplateCellStyle? rowHeaderStyle}) -
const
Properties
- cellStyle → QuicksightTemplateCellStyle?
-
final
-
collapsedRowDimensionsVisibility
→ TfArg<
String> ? -
final
- columnHeaderStyle → QuicksightTemplateCellStyle?
-
final
-
columnNamesVisibility
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metricPlacement
→ TfArg<
String> ? -
final
- rowAlternateColorOptions → QuicksightTemplateRowAlternateColorOptions?
-
final
- rowFieldNamesStyle → QuicksightTemplateCellStyle?
-
final
- rowHeaderStyle → QuicksightTemplateCellStyle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
singleMetricVisibility
→ TfArg<
String> ? -
final
-
toggleButtonsVisibility
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited