QuicksightTemplateStaticConfiguration class final
Typed helper for the definition.sheets.visuals.bar_chart_visual.chart_configuration.reference_lines.data_configuration.static_configuration block of
aws_quicksight_template (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
QuicksightTemplateStaticConfiguration({required TfArg<
num> value}) -
const
Properties
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited