RdsClusterRestoreToPointInTime class final
Typed helper for the restore_to_point_in_time block of
aws_rds_cluster (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- RdsClusterRestoreToPointInTime({required RdsClusterTarget target, RdsClusterRestoreType? restoreType, required RdsClusterSourceCluster sourceCluster})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- restoreType → RdsClusterRestoreType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceCluster → RdsClusterSourceCluster
-
final
- target → RdsClusterTarget
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited