S3BucketAnalyticsConfigurationDestination class final
Typed helper for the storage_class_analysis.data_export.destination block of
aws_s3_bucket_analytics_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- S3BucketAnalyticsConfigurationDestination({required S3BucketAnalyticsConfigurationS3BucketDestination s3BucketDestination})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s3BucketDestination → S3BucketAnalyticsConfigurationS3BucketDestination
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited