S3BucketAnalyticsConfigurationS3BucketDestination class final
Typed helper for the storage_class_analysis.data_export.destination.s3_bucket_destination block of
aws_s3_bucket_analytics_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
S3BucketAnalyticsConfigurationS3BucketDestination({TfArg<
String> ? bucketAccountId, required RefTo<AwsS3Bucket> bucketArn, TfArg<S3BucketAnalyticsConfigurationFormat> ? format, TfArg<String> ? prefix}) -
const
Properties
-
bucketAccountId
→ TfArg<
String> ? -
final
-
bucketArn
→ RefTo<
AwsS3Bucket> -
final
-
format
→ TfArg<
S3BucketAnalyticsConfigurationFormat> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
prefix
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited