S3BucketLifecycleConfigurationFilter class final
Typed helper for the rule.filter block of
aws_s3_bucket_lifecycle_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
S3BucketLifecycleConfigurationFilter({TfArg<
num> ? objectSizeGreaterThan, TfArg<num> ? objectSizeLessThan, TfArg<String> ? prefix, List<S3BucketLifecycleConfigurationAnd> ? and, List<S3BucketLifecycleConfigurationTag> ? tag}) -
const
Properties
-
and
→ List<
S3BucketLifecycleConfigurationAnd> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
objectSizeGreaterThan
→ TfArg<
num> ? -
final
-
objectSizeLessThan
→ TfArg<
num> ? -
final
-
prefix
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tag
→ List<
S3BucketLifecycleConfigurationTag> ? -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited