S3BucketLifecycleConfigurationNoncurrentVersionTransition class final
Typed helper for the rule.noncurrent_version_transition block of
aws_s3_bucket_lifecycle_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
S3BucketLifecycleConfigurationNoncurrentVersionTransition({TfArg<
num> ? newerNoncurrentVersions, required TfArg<num> noncurrentDays, required S3BucketLifecycleConfigurationStorageClass storageClass}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
newerNoncurrentVersions
→ TfArg<
num> ? -
final
-
noncurrentDays
→ TfArg<
num> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageClass → S3BucketLifecycleConfigurationStorageClass
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited