S3BucketMetadataConfigurationJournalTableConfiguration class final
Typed helper for the metadata_configuration.journal_table_configuration block of
aws_s3_bucket_metadata_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
S3BucketMetadataConfigurationJournalTableConfiguration({List<
S3BucketMetadataConfigurationEncryptionConfiguration> ? encryptionConfiguration, List<S3BucketMetadataConfigurationRecordExpiration> ? recordExpiration}) -
const
Properties
-
encryptionConfiguration
→ List<
S3BucketMetadataConfigurationEncryptionConfiguration> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
recordExpiration
→ List<
S3BucketMetadataConfigurationRecordExpiration> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited