S3BucketNotificationQueue class final
Typed helper for the queue block of
aws_s3_bucket_notification (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
events
→ TfArg<
List< String> > -
final
-
filterPrefix
→ TfArg<
String> ? -
final
-
filterSuffix
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ TfArg<
String> ? -
final
-
queueArn
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited