S3BucketServerSideEncryptionConfigurationRule class final
Typed helper for the rule block of
aws_s3_bucket_server_side_encryption_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
S3BucketServerSideEncryptionConfigurationRule({List<
S3BucketServerSideEncryptionConfigurationBlockedEncryptionTypes> ? blockedEncryptionTypes, TfArg<bool> ? bucketKeyEnabled, S3BucketServerSideEncryptionConfigurationApplyServerSideEncryptionByDefault? applyServerSideEncryptionByDefault}) -
const
Properties
- applyServerSideEncryptionByDefault → S3BucketServerSideEncryptionConfigurationApplyServerSideEncryptionByDefault?
-
final
-
blockedEncryptionTypes
→ List<
S3BucketServerSideEncryptionConfigurationBlockedEncryptionTypes> ? -
final
-
bucketKeyEnabled
→ TfArg<
bool> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited