SagemakerAlgorithmInferenceSpecification class final

Typed helper for the inference_specification block of aws_sagemaker_algorithm (derived from provider schema).

Annotations
  • @immutable

Constructors

SagemakerAlgorithmInferenceSpecification({TfArg<List<String>>? supportedContentTypes, List<TfArg<SagemakerAlgorithmSupportedRealtimeInferenceInstanceTypes>>? supportedRealtimeInferenceInstanceTypes, TfArg<List<String>>? supportedResponseMimeTypes, List<TfArg<SagemakerAlgorithmSupportedTransformInstanceTypes>>? supportedTransformInstanceTypes, List<SagemakerAlgorithmContainers>? containers})
const

Properties

containers → List<SagemakerAlgorithmContainers>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedContentTypes → TfArg<List<String>>?
final
supportedRealtimeInferenceInstanceTypes → List<TfArg<SagemakerAlgorithmSupportedRealtimeInferenceInstanceTypes>>?
final
supportedResponseMimeTypes → TfArg<List<String>>?
final
supportedTransformInstanceTypes → List<TfArg<SagemakerAlgorithmSupportedTransformInstanceTypes>>?
final

Methods

encode() → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited