SagemakerAlgorithmInstanceGroups class final
Typed helper for the validation_specification.validation_profiles.training_job_definition.resource_config.instance_groups block of
aws_sagemaker_algorithm (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SagemakerAlgorithmInstanceGroups({required TfArg<
num> instanceCount, required TfArg<String> instanceGroupName, required TfArg<SagemakerAlgorithmResourceConfigInstanceType> instanceType}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instanceCount
→ TfArg<
num> -
final
-
instanceGroupName
→ TfArg<
String> -
final
-
instanceType
→ TfArg<
SagemakerAlgorithmResourceConfigInstanceType> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited