SagemakerAlgorithmOutputDataConfig class final
Typed helper for the validation_specification.validation_profiles.training_job_definition.output_data_config block of
aws_sagemaker_algorithm (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SagemakerAlgorithmOutputDataConfig({SagemakerAlgorithmOutputDataConfigCompressionType? compressionType, RefTo<
AwsKmsKey> ? kmsKeyId, required TfArg<String> s3OutputPath}) -
const
Properties
- compressionType → SagemakerAlgorithmOutputDataConfigCompressionType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeyId
→ RefTo<
AwsKmsKey> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
s3OutputPath
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited