SagemakerAlgorithmTrainingJobDefinition class final
Typed helper for the validation_specification.validation_profiles.training_job_definition block of
aws_sagemaker_algorithm (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SagemakerAlgorithmTrainingJobDefinition({TfArg<
Map< ? hyperParameters, required SagemakerAlgorithmTrainingInputMode trainingInputMode, List<String, String> >SagemakerAlgorithmInputDataConfig> ? inputDataConfig, List<SagemakerAlgorithmOutputDataConfig> ? outputDataConfig, List<SagemakerAlgorithmResourceConfig> ? resourceConfig, List<SagemakerAlgorithmStoppingCondition> ? stoppingCondition}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hyperParameters
→ TfArg<
Map< ?String, String> > -
final
-
inputDataConfig
→ List<
SagemakerAlgorithmInputDataConfig> ? -
final
-
outputDataConfig
→ List<
SagemakerAlgorithmOutputDataConfig> ? -
final
-
resourceConfig
→ List<
SagemakerAlgorithmResourceConfig> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stoppingCondition
→ List<
SagemakerAlgorithmStoppingCondition> ? -
final
- trainingInputMode → SagemakerAlgorithmTrainingInputMode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited