SagemakerDomainRStudioServerProAppSettings class final
Typed helper for the default_user_settings.r_studio_server_pro_app_settings block of
aws_sagemaker_domain (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- SagemakerDomainRStudioServerProAppSettings({SagemakerDomainAccessStatus? accessStatus, SagemakerDomainUserGroup? userGroup})
-
const
Properties
- accessStatus → SagemakerDomainAccessStatus?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userGroup → SagemakerDomainUserGroup?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited