SagemakerFeatureGroupFeatureDefinition class final
Typed helper for the feature_definition block of
aws_sagemaker_feature_group (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SagemakerFeatureGroupFeatureDefinition({SagemakerFeatureGroupCollectionType? collectionType, TfArg<
String> ? featureName, SagemakerFeatureGroupFeatureType? featureType, SagemakerFeatureGroupCollectionConfig? collectionConfig}) -
const
Properties
- collectionConfig → SagemakerFeatureGroupCollectionConfig?
-
final
- collectionType → SagemakerFeatureGroupCollectionType?
-
final
-
featureName
→ TfArg<
String> ? -
final
- featureType → SagemakerFeatureGroupFeatureType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited