SagemakerHyperParameterTuningJobInputDataConfig class final
Typed helper for the training_job_definition.input_data_config block of
aws_sagemaker_hyper_parameter_tuning_job (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
SagemakerHyperParameterTuningJobInputDataConfig({required TfArg<
String> channelName, SagemakerHyperParameterTuningJobInputDataConfigCompressionType? compressionType, TfArg<String> ? contentType, SagemakerHyperParameterTuningJobInputMode? inputMode, SagemakerHyperParameterTuningJobRecordWrapperType? recordWrapperType, List<SagemakerHyperParameterTuningJobDataSource> ? dataSource, List<SagemakerHyperParameterTuningJobShuffleConfig> ? shuffleConfig}) -
const
Properties
-
channelName
→ TfArg<
String> -
final
- compressionType → SagemakerHyperParameterTuningJobInputDataConfigCompressionType?
-
final
-
contentType
→ TfArg<
String> ? -
final
-
dataSource
→ List<
SagemakerHyperParameterTuningJobDataSource> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputMode → SagemakerHyperParameterTuningJobInputMode?
-
final
- recordWrapperType → SagemakerHyperParameterTuningJobRecordWrapperType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shuffleConfig
→ List<
SagemakerHyperParameterTuningJobShuffleConfig> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited