SagemakerHyperParameterTuningJobModelAccessConfig class final
Typed helper for the training_job_definition.input_data_config.data_source.s3_data_source.model_access_config block of
aws_sagemaker_hyper_parameter_tuning_job (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
SagemakerHyperParameterTuningJobModelAccessConfig({required TfArg<
bool> acceptEula}) -
const
Properties
-
acceptEula
→ TfArg<
bool> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited