SagemakerHyperParameterTuningJobS3DataSource class final
Typed helper for the training_job_definition.input_data_config.data_source.s3_data_source block of
aws_sagemaker_hyper_parameter_tuning_job (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
SagemakerHyperParameterTuningJobS3DataSource({TfArg<
List< ? attributeNames, TfArg<String> >List< ? instanceGroupNames, TfArg<String> >SagemakerHyperParameterTuningJobS3DataDistributionType> ? s3DataDistributionType, required TfArg<SagemakerHyperParameterTuningJobS3DataType> s3DataType, required TfArg<String> s3Uri, List<SagemakerHyperParameterTuningJobHubAccessConfig> ? hubAccessConfig, List<SagemakerHyperParameterTuningJobModelAccessConfig> ? modelAccessConfig}) -
const
Properties
-
attributeNames
→ TfArg<
List< ?String> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hubAccessConfig
→ List<
SagemakerHyperParameterTuningJobHubAccessConfig> ? -
final
-
instanceGroupNames
→ TfArg<
List< ?String> > -
final
-
modelAccessConfig
→ List<
SagemakerHyperParameterTuningJobModelAccessConfig> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
s3DataDistributionType
→ TfArg<
SagemakerHyperParameterTuningJobS3DataDistributionType> ? -
final
-
s3DataType
→ TfArg<
SagemakerHyperParameterTuningJobS3DataType> -
final
-
s3Uri
→ TfArg<
String> -
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited