SagemakerMonitoringScheduleMonitoringOutputConfig class final
Typed helper for the monitoring_schedule_config.monitoring_job_definition.monitoring_output_config block of
aws_sagemaker_monitoring_schedule (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SagemakerMonitoringScheduleMonitoringOutputConfig({RefTo<
AwsKmsKey> ? kmsKeyId, required SagemakerMonitoringScheduleMonitoringOutputs monitoringOutputs}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kmsKeyId
→ RefTo<
AwsKmsKey> ? -
final
- monitoringOutputs → SagemakerMonitoringScheduleMonitoringOutputs
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited