SagemakerTrainingJobDebugHookConfig class final
Typed helper for the debug_hook_config block of
aws_sagemaker_training_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
collectionConfigurations
→ List<
SagemakerTrainingJobCollectionConfigurations> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hookParameters
→ TfArg<
Map< ?String, String> > -
final
-
localPath
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
s3OutputPath
→ TfArg<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited