SagemakerTrainingJobDebugRuleConfigurationsInstanceType extension type
instance_type — derived from the provider schema description.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTfJson(
) → Object? -
Value emitted into Terraform JSON.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- mlC4p2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC4p4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC4p8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC4Xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC5p2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC5p4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC5p9xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC5p18xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC5Xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC6i2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC6i4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC6i8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC6i12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC6i16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC6i24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC6i32xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC6iXlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC7i2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC7i4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC7i8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC7i12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC7i16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC7i24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC7i48xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC7iLarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlC7iXlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG4dn2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG4dn4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG4dn8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG4dn12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG4dn16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG4dnXlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG5p2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG5p4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG5p8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG5p12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG5p16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG5p24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG5p48xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG5Xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6e2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6e4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6e8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6e12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6e16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6e24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6e48xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6eXlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6p2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6p4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6p8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6p12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6p16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6p24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6p48xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG6Xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7e2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7e4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7e8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7e12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7e24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7e48xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7p2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7p4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7p8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7p12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7p24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlG7p48xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM4p2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM4p4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM4p10xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM4p16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM4Xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM5Large → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM5p2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM5p4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM5p12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM5p24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM5Xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM6i2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM6i4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM6i8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM6i12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM6i16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM6i24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM6i32xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM6iLarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM6iXlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM7i2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM7i4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM7i8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM7i12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM7i16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM7i24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM7i48xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM7iLarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlM7iXlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlP2p8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlP2p16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlP2Xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlP3p2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlP3p8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlP3p16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlP5p4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5d2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5d4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5d8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5d12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5d16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5d24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5dLarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5dXlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5Large → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5p2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5p4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5p8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5p12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5p16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5p24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR5Xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR7i2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR7i4xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR7i8xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR7i12xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR7i16xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR7i24xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR7i48xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR7iLarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlR7iXlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlT3Large → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlT3Medium → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlT3p2xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
- mlT3Xlarge → const SagemakerTrainingJobDebugRuleConfigurationsInstanceType
-
values
→ const List<
SagemakerTrainingJobDebugRuleConfigurationsInstanceType>