SagemakerTrainingJobServerlessJobConfig class final
Typed helper for the serverless_job_config block of
aws_sagemaker_training_job (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SagemakerTrainingJobServerlessJobConfig({TfArg<
bool> ? acceptEula, required TfArg<String> baseModelArn, SagemakerTrainingJobCustomizationTechnique? customizationTechnique, SagemakerTrainingJobEvaluationType? evaluationType, TfArg<String> ? evaluatorArn, required SagemakerTrainingJobType jobType, SagemakerTrainingJobPeft? peft}) -
const
Properties
-
acceptEula
→ TfArg<
bool> ? -
final
-
baseModelArn
→ TfArg<
String> -
final
- customizationTechnique → SagemakerTrainingJobCustomizationTechnique?
-
final
- evaluationType → SagemakerTrainingJobEvaluationType?
-
final
-
evaluatorArn
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- jobType → SagemakerTrainingJobType
-
final
- peft → SagemakerTrainingJobPeft?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited