SecurityhubAutomationRuleV2ExternalIntegrationConfiguration class final
Typed helper for the action.external_integration_configuration block of
aws_securityhub_automation_rule_v2 (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SecurityhubAutomationRuleV2ExternalIntegrationConfiguration({required TfArg<
String> connectorArn}) -
const
Properties
-
connectorArn
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited