ServicecatalogProvisionedProductStackSetProvisioningPreferences class final
Typed helper for the stack_set_provisioning_preferences block of
aws_servicecatalog_provisioned_product (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
ServicecatalogProvisionedProductStackSetProvisioningPreferences({TfArg<
List< ? accounts, required ServicecatalogProvisionedProductFailureTolerance failureTolerance, required ServicecatalogProvisionedProductMaxConcurrency maxConcurrency, TfArg<String> >List< ? regions})String> > -
const
Properties
-
accounts
→ TfArg<
List< ?String> > -
final
- failureTolerance → ServicecatalogProvisionedProductFailureTolerance
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrency → ServicecatalogProvisionedProductMaxConcurrency
-
final
-
regions
→ TfArg<
List< ?String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited