Sesv2ConfigurationSetEventDestinationPinpointDestination class final
Typed helper for the event_destination.pinpoint_destination block of
aws_sesv2_configuration_set_event_destination (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Sesv2ConfigurationSetEventDestinationPinpointDestination({required TfArg<
String> applicationArn}) -
const
Properties
-
applicationArn
→ TfArg<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited