SsmMaintenanceWindowTaskInvocationParameters class final
Typed helper for the task_invocation_parameters block of
aws_ssm_maintenance_window_task (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- SsmMaintenanceWindowTaskInvocationParameters({SsmMaintenanceWindowTaskAutomationParameters? automationParameters, SsmMaintenanceWindowTaskLambdaParameters? lambdaParameters, SsmMaintenanceWindowTaskRunCommandParameters? runCommandParameters, SsmMaintenanceWindowTaskStepFunctionsParameters? stepFunctionsParameters})
-
const
Properties
- automationParameters → SsmMaintenanceWindowTaskAutomationParameters?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lambdaParameters → SsmMaintenanceWindowTaskLambdaParameters?
-
final
- runCommandParameters → SsmMaintenanceWindowTaskRunCommandParameters?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stepFunctionsParameters → SsmMaintenanceWindowTaskStepFunctionsParameters?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited