SsoadminInstanceAccessControlAttributesAttribute class final
Typed helper for the attribute block of
aws_ssoadmin_instance_access_control_attributes (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
SsoadminInstanceAccessControlAttributesAttribute({required TfArg<
String> key, required List<SsoadminInstanceAccessControlAttributesValue> value}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
key
→ TfArg<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ List<
SsoadminInstanceAccessControlAttributesValue> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited