TimestreamqueryScheduledQueryMultiMeasureAttributeMapping class final
Typed helper for the target_configuration.timestream_configuration.mixed_measure_mapping.multi_measure_attribute_mapping block of
aws_timestreamquery_scheduled_query (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
-
TimestreamqueryScheduledQueryMultiMeasureAttributeMapping({required TimestreamqueryScheduledQueryMultiMeasureAttributeMappingMeasureValueType measureValueType, required TfArg<
String> sourceColumn, TfArg<String> ? targetMultiMeasureAttributeName}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- measureValueType → TimestreamqueryScheduledQueryMultiMeasureAttributeMappingMeasureValueType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceColumn
→ TfArg<
String> -
final
-
targetMultiMeasureAttributeName
→ TfArg<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited