TransferWorkflowDestinationFileLocation class final
Typed helper for the on_exception_steps.copy_step_details.destination_file_location block of
aws_transfer_workflow (derived from provider schema).
Shared by every block of this shape in the resource.
- Annotations
-
- @immutable
Constructors
- TransferWorkflowDestinationFileLocation({TransferWorkflowEfsFileLocation? efsFileLocation, TransferWorkflowS3FileLocation? s3FileLocation})
-
const
Properties
- efsFileLocation → TransferWorkflowEfsFileLocation?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s3FileLocation → TransferWorkflowS3FileLocation?
-
final
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited