VerifiedaccessInstanceLoggingConfigurationS3 class final
Typed helper for the access_logs.s3 block of
aws_verifiedaccess_instance_logging_configuration (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
VerifiedaccessInstanceLoggingConfigurationS3({RefTo<
AwsS3Bucket> ? bucketName, TfArg<String> ? bucketOwner, required TfArg<bool> enabled, TfArg<String> ? prefix}) -
const
Properties
-
bucketName
→ RefTo<
AwsS3Bucket> ? -
final
-
bucketOwner
→ TfArg<
String> ? -
final
-
enabled
→ TfArg<
bool> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
prefix
→ TfArg<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Map< String, Object?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited