Wafv2RuleGroupRateBasedStatement class final
Typed helper for the rule.statement.rate_based_statement block of
aws_wafv2_rule_group (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
Wafv2RuleGroupRateBasedStatement({Wafv2RuleGroupAggregateKeyType? aggregateKeyType, TfArg<
num> ? evaluationWindowSec, required TfArg<num> limit, List<Wafv2RuleGroupCustomKey> ? customKey, Wafv2RuleGroupForwardedIpConfig? forwardedIpConfig, Wafv2RuleGroupAndStatementStatement? scopeDownStatement}) -
const
Properties
- aggregateKeyType → Wafv2RuleGroupAggregateKeyType?
-
final
-
customKey
→ List<
Wafv2RuleGroupCustomKey> ? -
final
-
evaluationWindowSec
→ TfArg<
num> ? -
final
- forwardedIpConfig → Wafv2RuleGroupForwardedIpConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
limit
→ TfArg<
num> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeDownStatement → Wafv2RuleGroupAndStatementStatement?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited