timestreamquery library
AWS Timestream scheduled queries.
Classes
- AwsTimestreamqueryScheduledQuery
-
Factory wrapper for
aws_timestreamquery_scheduled_query. - TimestreamqueryScheduledQueryDimensionMapping
-
Typed helper for the
target_configuration.timestream_configuration.dimension_mappingblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQueryErrorReportConfiguration
-
Typed helper for the
error_report_configurationblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQueryErrorReportLocation
-
Typed helper for the
last_run_summary.error_report_locationblock ofaws_timestreamquery_scheduled_query(derived from provider schema). Shared by every block of this shape in the resource. - TimestreamqueryScheduledQueryExecutionStats
-
Typed helper for the
last_run_summary.execution_statsblock ofaws_timestreamquery_scheduled_query(derived from provider schema). Shared by every block of this shape in the resource. - TimestreamqueryScheduledQueryInsightsResponse
-
Typed helper for the
last_run_summary.query_insights_responseblock ofaws_timestreamquery_scheduled_query(derived from provider schema). Shared by every block of this shape in the resource. - TimestreamqueryScheduledQueryLastRunSummary
-
Typed helper for the
last_run_summaryblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQueryMax
-
Typed helper for the
last_run_summary.query_insights_response.query_spatial_coverage.maxblock ofaws_timestreamquery_scheduled_query(derived from provider schema). Shared by every block of this shape in the resource. - TimestreamqueryScheduledQueryMixedMeasureMapping
-
Typed helper for the
target_configuration.timestream_configuration.mixed_measure_mappingblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQueryMultiMeasureAttributeMapping
-
Typed helper for the
target_configuration.timestream_configuration.mixed_measure_mapping.multi_measure_attribute_mappingblock ofaws_timestreamquery_scheduled_query(derived from provider schema). Shared by every block of this shape in the resource. - TimestreamqueryScheduledQueryMultiMeasureMappings
-
Typed helper for the
target_configuration.timestream_configuration.multi_measure_mappingsblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQueryNotificationConfiguration
-
Typed helper for the
notification_configurationblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQueryRecentlyFailedRuns
-
Typed helper for the
recently_failed_runsblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQueryS3Configuration
-
Typed helper for the
error_report_configuration.s3_configurationblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQueryS3ReportLocation
-
Typed helper for the
last_run_summary.error_report_location.s3_report_locationblock ofaws_timestreamquery_scheduled_query(derived from provider schema). Shared by every block of this shape in the resource. - TimestreamqueryScheduledQueryScheduleConfiguration
-
Typed helper for the
schedule_configurationblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQuerySnsConfiguration
-
Typed helper for the
notification_configuration.sns_configurationblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQuerySpatialCoverage
-
Typed helper for the
last_run_summary.query_insights_response.query_spatial_coverageblock ofaws_timestreamquery_scheduled_query(derived from provider schema). Shared by every block of this shape in the resource. - TimestreamqueryScheduledQueryTargetConfiguration
-
Typed helper for the
target_configurationblock ofaws_timestreamquery_scheduled_query(derived from provider schema). - TimestreamqueryScheduledQueryTemporalRange
-
Typed helper for the
last_run_summary.query_insights_response.query_temporal_rangeblock ofaws_timestreamquery_scheduled_query(derived from provider schema). Shared by every block of this shape in the resource. - TimestreamqueryScheduledQueryTimestreamConfiguration
-
Typed helper for the
target_configuration.timestream_configurationblock ofaws_timestreamquery_scheduled_query(derived from provider schema).
Enums
- TimestreamqueryScheduledQueryDimensionValueType
-
dimension_value_type— derived from the provider schema description. - TimestreamqueryScheduledQueryEncryptionOption
-
encryption_option— derived from the provider schema description. - TimestreamqueryScheduledQueryMeasureValueType
-
measure_value_type— derived from the provider schema description. - TimestreamqueryScheduledQueryMultiMeasureAttributeMappingMeasureValueType
-
measure_value_type— derived from the provider schema description.