transcribe library
AWS Transcribe.
Classes
- AwsTranscribeLanguageModel
-
Factory wrapper for
aws_transcribe_language_model. - AwsTranscribeMedicalVocabulary
-
Factory wrapper for
aws_transcribe_medical_vocabulary. - AwsTranscribeVocabulary
-
Factory wrapper for
aws_transcribe_vocabulary. - AwsTranscribeVocabularyFilter
-
Factory wrapper for
aws_transcribe_vocabulary_filter. - TranscribeLanguageModelInputDataConfig
-
Typed helper for the
input_data_configblock ofaws_transcribe_language_model(derived from provider schema). - TranscribeVocabularyFilterTerms
-
Exactly one of
vocabulary_filter_file_uri,wordsonaws_transcribe_vocabulary_filter: the provider rejects none and more than one, so each variant sets one of them. - TranscribeVocabularyFilterTermsVocabularyFilterFileUri
-
The TranscribeVocabularyFilterTerms.vocabularyFilterFileUri choice: sets
vocabulary_filter_file_uri. - TranscribeVocabularyFilterTermsWords
-
The TranscribeVocabularyFilterTerms.words choice: sets
words. - TranscribeVocabularyTerms
-
Exactly one of
phrases,vocabulary_file_urionaws_transcribe_vocabulary: the provider rejects none and more than one, so each variant sets one of them. - TranscribeVocabularyTermsPhrases
-
The TranscribeVocabularyTerms.phrases choice: sets
phrases. - TranscribeVocabularyTermsVocabularyFileUri
-
The TranscribeVocabularyTerms.vocabularyFileUri choice: sets
vocabulary_file_uri.
Enums
- TranscribeLanguageModelBaseModelName
-
Transcribe Language Model Base Model enum for
base_model_name. - TranscribeLanguageModelLanguageCode
-
Transcribe Language Model Language enum for
language_code. - TranscribeMedicalVocabularyLanguageCode
-
Transcribe Medical Vocabulary Language enum for
language_code.