vpclattice library
AWS VPC Lattice.
Classes
- AwsVpclatticeAccessLogSubscription
-
Factory wrapper for
aws_vpclattice_access_log_subscription. - AwsVpclatticeAuthPolicy
-
Factory wrapper for
aws_vpclattice_auth_policy. - AwsVpclatticeDomainVerification
-
Factory wrapper for
aws_vpclattice_domain_verification. - AwsVpclatticeListener
-
Factory wrapper for
aws_vpclattice_listener. - AwsVpclatticeListenerRule
-
Factory wrapper for
aws_vpclattice_listener_rule. - AwsVpclatticeResourceConfiguration
-
Factory wrapper for
aws_vpclattice_resource_configuration. - AwsVpclatticeResourceGateway
-
Factory wrapper for
aws_vpclattice_resource_gateway. - AwsVpclatticeResourcePolicy
-
Factory wrapper for
aws_vpclattice_resource_policy. - AwsVpclatticeService
-
Factory wrapper for
aws_vpclattice_service. - AwsVpclatticeServiceNetwork
-
Factory wrapper for
aws_vpclattice_service_network. - AwsVpclatticeServiceNetworkResourceAssociation
-
Factory wrapper for
aws_vpclattice_service_network_resource_association. - AwsVpclatticeServiceNetworkServiceAssociation
-
Factory wrapper for
aws_vpclattice_service_network_service_association. - AwsVpclatticeServiceNetworkVpcAssociation
-
Factory wrapper for
aws_vpclattice_service_network_vpc_association. - AwsVpclatticeTargetGroup
-
Factory wrapper for
aws_vpclattice_target_group. - AwsVpclatticeTargetGroupAttachment
-
Factory wrapper for
aws_vpclattice_target_group_attachment. - VpclatticeListenerDefaultAction
-
Typed helper for the
default_actionblock ofaws_vpclattice_listener(derived from provider schema). - VpclatticeListenerFixedResponse
-
Typed helper for the
default_action.fixed_responseblock ofaws_vpclattice_listener(derived from provider schema). - VpclatticeListenerForward
-
Typed helper for the
default_action.forwardblock ofaws_vpclattice_listener(derived from provider schema). - VpclatticeListenerRuleAction
-
Exactly one of
fixed_response,forwardon theactionblock ofaws_vpclattice_listener_rule: the provider rejects none and more than one, so each variant sets one of them. - VpclatticeListenerRuleActionFixedResponse
-
The VpclatticeListenerRuleAction.fixedResponse choice: sets
fixed_response. - VpclatticeListenerRuleActionForward
-
The VpclatticeListenerRuleAction.forward choice: sets
forward. - VpclatticeListenerRuleFixedResponse
-
Typed helper for the
action.fixed_responseblock ofaws_vpclattice_listener_rule(derived from provider schema). - VpclatticeListenerRuleForward
-
Typed helper for the
action.forwardblock ofaws_vpclattice_listener_rule(derived from provider schema). - VpclatticeListenerRuleHeaderMatches
-
Typed helper for the
match.http_match.header_matchesblock ofaws_vpclattice_listener_rule(derived from provider schema). - VpclatticeListenerRuleHeaderMatchesMatch
-
Typed helper for the
match.http_match.header_matches.matchblock ofaws_vpclattice_listener_rule(derived from provider schema). - VpclatticeListenerRuleHttpMatch
-
Typed helper for the
match.http_matchblock ofaws_vpclattice_listener_rule(derived from provider schema). - VpclatticeListenerRuleMatch
-
Typed helper for the
matchblock ofaws_vpclattice_listener_rule(derived from provider schema). - VpclatticeListenerRulePathMatch
-
Typed helper for the
match.http_match.path_matchblock ofaws_vpclattice_listener_rule(derived from provider schema). - VpclatticeListenerRulePathMatchMatch
-
Typed helper for the
match.http_match.path_match.matchblock ofaws_vpclattice_listener_rule(derived from provider schema). - VpclatticeListenerRuleTargetGroups
-
Typed helper for the
action.forward.target_groupsblock ofaws_vpclattice_listener_rule(derived from provider schema). - VpclatticeListenerTargetGroups
-
Typed helper for the
default_action.forward.target_groupsblock ofaws_vpclattice_listener(derived from provider schema). - VpclatticeResourceConfigurationArnResource
-
Typed helper for the
resource_configuration_definition.arn_resourceblock ofaws_vpclattice_resource_configuration(derived from provider schema). - VpclatticeResourceConfigurationDefinition
-
Exactly one of
arn_resource,dns_resource,ip_resourceon theresource_configuration_definitionblock ofaws_vpclattice_resource_configuration: the provider rejects none and more than one, so each variant sets one of them. - VpclatticeResourceConfigurationDefinitionArnResource
-
The VpclatticeResourceConfigurationDefinition.arnResource choice: sets
arn_resource. - VpclatticeResourceConfigurationDefinitionDnsResource
-
The VpclatticeResourceConfigurationDefinition.dnsResource choice: sets
dns_resource. - VpclatticeResourceConfigurationDefinitionIpResource
-
The VpclatticeResourceConfigurationDefinition.ipResource choice: sets
ip_resource. - VpclatticeResourceConfigurationDnsResource
-
Typed helper for the
resource_configuration_definition.dns_resourceblock ofaws_vpclattice_resource_configuration(derived from provider schema). - VpclatticeResourceConfigurationIpResource
-
Typed helper for the
resource_configuration_definition.ip_resourceblock ofaws_vpclattice_resource_configuration(derived from provider schema). - VpclatticeResourceConfigurationParent
-
Exactly one of
resource_configuration_group_id,resource_gateway_identifieronaws_vpclattice_resource_configuration: the provider rejects none and more than one, so each variant sets one of them. - VpclatticeResourceConfigurationParentResourceConfigurationGroupId
-
The VpclatticeResourceConfigurationParent.resourceConfigurationGroupId choice: sets
resource_configuration_group_id. - VpclatticeResourceConfigurationParentResourceGatewayIdentifier
-
The VpclatticeResourceConfigurationParent.resourceGatewayIdentifier choice: sets
resource_gateway_identifier. - VpclatticeServiceNetworkVpcAssociationDnsOptions
-
Typed helper for the
dns_optionsblock ofaws_vpclattice_service_network_vpc_association(derived from provider schema). - VpclatticeTargetGroupAttachmentTarget
-
Typed helper for the
targetblock ofaws_vpclattice_target_group_attachment(derived from provider schema). - VpclatticeTargetGroupConfig
-
Typed helper for the
configblock ofaws_vpclattice_target_group(derived from provider schema). - VpclatticeTargetGroupHealthCheck
-
Typed helper for the
config.health_checkblock ofaws_vpclattice_target_group(derived from provider schema). - VpclatticeTargetGroupMatcher
-
Typed helper for the
config.health_check.matcherblock ofaws_vpclattice_target_group(derived from provider schema).
Enums
- VpclatticeAccessLogSubscriptionServiceNetworkLogType
-
Vpclattice Access Log Subscription Service Network Log enum for
service_network_log_type. - VpclatticeListenerProtocol
-
Vpclattice Listener enum for
protocol. - VpclatticeResourceConfigurationIpAddressType
-
ip_address_type— derived from the provider schema description. - VpclatticeResourceConfigurationProtocol
-
Vpclattice Resource Configuration enum for
protocol. - VpclatticeResourceGatewayIpAddressType
-
Vpclattice Resource Gateway Ip Address enum for
ip_address_type. - VpclatticeResourceGatewayResourceConfigDnsResolution
-
Vpclattice Resource Gateway Resource Config Dns enum for
resource_config_dns_resolution. - VpclatticeServiceAuthType
-
Vpclattice Service Auth enum for
auth_type. - VpclatticeServiceNetworkAuthType
-
Vpclattice Service Network Auth enum for
auth_type. - VpclatticeServiceNetworkVpcAssociationPrivateDnsPreference
-
private_dns_preference— derived from the provider schema description. - VpclatticeTargetGroupHealthCheckProtocolVersion
-
protocol_version— derived from the provider schema description. - VpclatticeTargetGroupIpAddressType
-
ip_address_type— derived from the provider schema description. - VpclatticeTargetGroupLambdaEventStructureVersion
-
lambda_event_structure_version— derived from the provider schema description. - VpclatticeTargetGroupProtocol
-
protocol— derived from the provider schema description. - VpclatticeTargetGroupProtocolVersion
-
protocol_version— derived from the provider schema description. - VpclatticeTargetGroupType
-
Vpclattice Target Group enum for
type.