wafv2 library
AWS WAF.
Classes
- AwsWafv2ApiKey
-
Factory wrapper for
aws_wafv2_api_key. - AwsWafv2IpSet
-
Factory wrapper for
aws_wafv2_ip_set. - AwsWafv2RegexPatternSet
-
Factory wrapper for
aws_wafv2_regex_pattern_set. - AwsWafv2RuleGroup
-
Factory wrapper for
aws_wafv2_rule_group. - AwsWafv2WebAcl
-
Factory wrapper for
aws_wafv2_web_acl. - AwsWafv2WebAclAssociation
-
Factory wrapper for
aws_wafv2_web_acl_association. - AwsWafv2WebAclLoggingConfiguration
-
Factory wrapper for
aws_wafv2_web_acl_logging_configuration. - AwsWafv2WebAclRule
-
Factory wrapper for
aws_wafv2_web_acl_rule. - AwsWafv2WebAclRuleGroupAssociation
-
Factory wrapper for
aws_wafv2_web_acl_rule_group_association. - Wafv2IpSetName
-
At most one of
name,name_prefixonaws_wafv2_ip_set: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - Wafv2IpSetNameChoice
-
The Wafv2IpSetName.name choice: sets
name. - Wafv2IpSetNamePrefix
-
The Wafv2IpSetName.namePrefix choice: sets
name_prefix. - Wafv2RegexPatternSetName
-
At most one of
name,name_prefixonaws_wafv2_regex_pattern_set: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - Wafv2RegexPatternSetNameChoice
-
The Wafv2RegexPatternSetName.name choice: sets
name. - Wafv2RegexPatternSetNamePrefix
-
The Wafv2RegexPatternSetName.namePrefix choice: sets
name_prefix. - Wafv2RegexPatternSetRegularExpression
-
Typed helper for the
regular_expressionblock ofaws_wafv2_regex_pattern_set(derived from provider schema). - Wafv2RuleGroupAction
-
Typed helper for the
rule.actionblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupAllow
-
Typed helper for the
rule.action.allowblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupAllQueryArguments
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.all_query_argumentsblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupAndStatement
-
Typed helper for the
rule.statement.and_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupAndStatementAndStatement
-
Typed helper for the
rule.statement.and_statement.statement.and_statement.statement.and_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupAndStatementStatement
-
Typed helper for the
rule.statement.and_statement.statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupAsnMatchStatement
-
Typed helper for the
rule.statement.asn_match_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupBlock
-
Typed helper for the
rule.action.blockblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupBody
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.bodyblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupByteMatchStatement
-
Typed helper for the
rule.statement.byte_match_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupCaptchaConfig
-
Typed helper for the
rule.captcha_configblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupCookie
-
Typed helper for the
rule.statement.rate_based_statement.custom_key.cookieblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupCookies
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.cookiesblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupCookiesMatchPattern
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.cookies.match_patternblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupCustomKey
-
Typed helper for the
rule.statement.rate_based_statement.custom_keyblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupCustomRequestHandling
-
Typed helper for the
rule.action.allow.custom_request_handlingblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupCustomResponse
-
Typed helper for the
rule.action.block.custom_responseblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupCustomResponseBody
-
Typed helper for the
custom_response_bodyblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupFieldToMatch
-
Typed helper for the
rule.statement.byte_match_statement.field_to_matchblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupForwardedIpConfig
-
Typed helper for the
rule.statement.asn_match_statement.forwarded_ip_configblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupGeoMatchStatement
-
Typed helper for the
rule.statement.geo_match_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupHeaderOrder
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.header_orderblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupHeaders
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.headersblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupHeadersMatchPattern
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.headers.match_patternblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupImmunityTimeProperty
-
Typed helper for the
rule.captcha_config.immunity_time_propertyblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupInsertHeader
-
Typed helper for the
rule.action.allow.custom_request_handling.insert_headerblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupIpSetForwardedIpConfig
-
Typed helper for the
rule.statement.ip_set_reference_statement.ip_set_forwarded_ip_configblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupIpSetReferenceStatement
-
Typed helper for the
rule.statement.ip_set_reference_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupJa3Fingerprint
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.ja3_fingerprintblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupJsonBody
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.json_bodyblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupJsonBodyMatchPattern
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.json_body.match_patternblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupLabelMatchStatement
-
Typed helper for the
rule.statement.label_match_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupLabelNamespace
-
Typed helper for the
rule.statement.rate_based_statement.custom_key.label_namespaceblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupName
-
At most one of
name,name_prefixonaws_wafv2_rule_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - Wafv2RuleGroupNameChoice
-
The Wafv2RuleGroupName.name choice: sets
name. - Wafv2RuleGroupNamePrefix
-
The Wafv2RuleGroupName.namePrefix choice: sets
name_prefix. - Wafv2RuleGroupPreParseTextTransformation
-
Typed helper for the
rule.statement.byte_match_statement.pre_parse_text_transformationblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupQueryString
-
Typed helper for the
rule.statement.rate_based_statement.custom_key.query_stringblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupRateBasedStatement
-
Typed helper for the
rule.statement.rate_based_statementblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupRegexMatchStatement
-
Typed helper for the
rule.statement.regex_match_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupRegexPatternSetReferenceStatement
-
Typed helper for the
rule.statement.regex_pattern_set_reference_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupRule
-
Typed helper for the
ruleblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupRuleLabel
-
Typed helper for the
rule.rule_labelblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupRules
-
At most one of
rule,rules_jsononaws_wafv2_rule_group: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - Wafv2RuleGroupRulesJson
-
The Wafv2RuleGroupRules.rulesJson choice: sets
rules_json. - Wafv2RuleGroupRulesRule
-
The Wafv2RuleGroupRules.rule choice: sets
rule. - Wafv2RuleGroupRuleStatement
-
Typed helper for the
rule.statement.and_statement.statement.and_statement.statement.and_statement.statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupSizeConstraintStatement
-
Typed helper for the
rule.statement.size_constraint_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupSqliMatchStatement
-
Typed helper for the
rule.statement.sqli_match_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupStatement
-
Typed helper for the
rule.statementblock ofaws_wafv2_rule_group(derived from provider schema). - Wafv2RuleGroupStatementAndStatement
-
Typed helper for the
rule.statement.and_statement.statement.and_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupStatementStatement
-
Typed helper for the
rule.statement.and_statement.statement.and_statement.statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupUriFragment
-
Typed helper for the
rule.statement.byte_match_statement.field_to_match.uri_fragmentblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupVisibilityConfig
-
Typed helper for the
visibility_configblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2RuleGroupXssMatchStatement
-
Typed helper for the
rule.statement.xss_match_statementblock ofaws_wafv2_rule_group(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclAllow
-
Typed helper for the
default_action.allowblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclApiGateway
-
Typed helper for the
association_config.request_body.api_gatewayblock ofaws_wafv2_web_acl(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclAssociationConfig
-
Typed helper for the
association_configblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclBlock
-
Typed helper for the
default_action.blockblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclCaptchaConfig
-
Typed helper for the
captcha_configblock ofaws_wafv2_web_acl(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclCustomRequestHandling
-
Typed helper for the
default_action.allow.custom_request_handlingblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclCustomResponse
-
Typed helper for the
default_action.block.custom_responseblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclCustomResponseBody
-
Typed helper for the
custom_response_bodyblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclDataProtection
-
Typed helper for the
data_protection_config.data_protectionblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclDataProtectionConfig
-
Typed helper for the
data_protection_configblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclDefaultAction
-
Typed helper for the
default_actionblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclField
-
Typed helper for the
data_protection_config.data_protection.fieldblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclImmunityTimeProperty
-
Typed helper for the
captcha_config.immunity_time_propertyblock ofaws_wafv2_web_acl(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclInsertHeader
-
Typed helper for the
default_action.allow.custom_request_handling.insert_headerblock ofaws_wafv2_web_acl(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclLoggingConfigurationActionCondition
-
Typed helper for the
logging_filter.filter.condition.action_conditionblock ofaws_wafv2_web_acl_logging_configuration(derived from provider schema). - Wafv2WebAclLoggingConfigurationCondition
-
Typed helper for the
logging_filter.filter.conditionblock ofaws_wafv2_web_acl_logging_configuration(derived from provider schema). - Wafv2WebAclLoggingConfigurationFilter
-
Typed helper for the
logging_filter.filterblock ofaws_wafv2_web_acl_logging_configuration(derived from provider schema). - Wafv2WebAclLoggingConfigurationLabelNameCondition
-
Typed helper for the
logging_filter.filter.condition.label_name_conditionblock ofaws_wafv2_web_acl_logging_configuration(derived from provider schema). - Wafv2WebAclLoggingConfigurationLoggingFilter
-
Typed helper for the
logging_filterblock ofaws_wafv2_web_acl_logging_configuration(derived from provider schema). - Wafv2WebAclLoggingConfigurationMethod
-
Typed helper for the
redacted_fields.methodblock ofaws_wafv2_web_acl_logging_configuration(derived from provider schema). - Wafv2WebAclLoggingConfigurationQueryString
-
Typed helper for the
redacted_fields.query_stringblock ofaws_wafv2_web_acl_logging_configuration(derived from provider schema). - Wafv2WebAclLoggingConfigurationRedactedFields
-
Typed helper for the
redacted_fieldsblock ofaws_wafv2_web_acl_logging_configuration(derived from provider schema). - Wafv2WebAclLoggingConfigurationSingleHeader
-
Typed helper for the
redacted_fields.single_headerblock ofaws_wafv2_web_acl_logging_configuration(derived from provider schema). - Wafv2WebAclLoggingConfigurationUriPath
-
Typed helper for the
redacted_fields.uri_pathblock ofaws_wafv2_web_acl_logging_configuration(derived from provider schema). - Wafv2WebAclName
-
At most one of
name,name_prefixonaws_wafv2_web_acl: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - Wafv2WebAclNameChoice
-
The Wafv2WebAclName.name choice: sets
name. - Wafv2WebAclNamePrefix
-
The Wafv2WebAclName.namePrefix choice: sets
name_prefix. - Wafv2WebAclRequestBody
-
Typed helper for the
association_config.request_bodyblock ofaws_wafv2_web_acl(derived from provider schema). - Wafv2WebAclRuleAction
-
Typed helper for the
actionblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAddressFields
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.request_inspection.address_fieldsblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAllow
-
Typed helper for the
action.allowblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAndStatement
-
Typed helper for the
statement.and_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAndStatementAndStatement
-
Typed helper for the
statement.and_statement.statement.and_statement.statement.and_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAndStatementStatement
-
Typed helper for the
statement.and_statement.statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAsnMatchStatement
-
Typed helper for the
statement.asn_match_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAwsManagedRulesAcfpRuleSet
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_acfp_rule_setblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAwsManagedRulesAcfpRuleSetRequestInspection
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.request_inspectionblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAwsManagedRulesAntiDdosRuleSet
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_anti_ddos_rule_setblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAwsManagedRulesAtpRuleSet
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_atp_rule_setblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAwsManagedRulesAtpRuleSetRequestInspection
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_atp_rule_set.request_inspectionblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleAwsManagedRulesBotControlRuleSet
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_bot_control_rule_setblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleBehavior
-
At most one of
action,override_actiononaws_wafv2_web_acl_rule: the provider rejects more than one, so each variant sets one of them and a null choice sets none. - Wafv2WebAclRuleBehaviorAction
-
The Wafv2WebAclRuleBehavior.action choice: sets
action. - Wafv2WebAclRuleBehaviorOverrideAction
-
The Wafv2WebAclRuleBehavior.overrideAction choice: sets
override_action. - Wafv2WebAclRuleBlock
-
Typed helper for the
action.blockblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleBody
-
Typed helper for the
statement.byte_match_statement.field_to_match.bodyblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleBodyContains
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.response_inspection.body_containsblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleByteMatchStatement
-
Typed helper for the
statement.byte_match_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleCaptchaConfig
-
Typed helper for the
captcha_configblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleChallenge
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_anti_ddos_rule_set.client_side_action_config.challengeblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleClientSideActionConfig
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_anti_ddos_rule_set.client_side_action_configblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleCookie
-
Typed helper for the
statement.rate_based_statement.custom_keys.cookieblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleCookies
-
Typed helper for the
statement.byte_match_statement.field_to_match.cookiesblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleCookiesMatchPattern
-
Typed helper for the
statement.byte_match_statement.field_to_match.cookies.match_patternblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleCount
-
Typed helper for the
override_action.countblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleCustomKeys
-
Typed helper for the
statement.rate_based_statement.custom_keysblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleCustomRequestHandling
-
Typed helper for the
action.allow.custom_request_handlingblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleCustomResponse
-
Typed helper for the
action.block.custom_responseblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleExemptUriRegularExpression
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_anti_ddos_rule_set.client_side_action_config.challenge.exempt_uri_regular_expressionblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleFieldToMatch
-
Typed helper for the
statement.byte_match_statement.field_to_matchblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleForwardedIpConfig
-
Typed helper for the
statement.asn_match_statement.forwarded_ip_configblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGeoMatchStatement
-
Typed helper for the
statement.geo_match_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationActionToUse
-
Typed helper for the
managed_rule_group.rule_action_override.action_to_useblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationAddressFields
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.request_inspection.address_fieldsblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationAllow
-
Typed helper for the
managed_rule_group.rule_action_override.action_to_use.allowblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationAwsManagedRulesAcfpRuleSet
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_setblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationAwsManagedRulesAcfpRuleSetRequestInspection
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.request_inspectionblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationAwsManagedRulesAntiDdosRuleSet
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_anti_ddos_rule_setblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationAwsManagedRulesAtpRuleSet
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_atp_rule_setblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationAwsManagedRulesAtpRuleSetRequestInspection
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_atp_rule_set.request_inspectionblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationAwsManagedRulesBotControlRuleSet
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_bot_control_rule_setblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationBlock
-
Typed helper for the
managed_rule_group.rule_action_override.action_to_use.blockblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationBodyContains
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.response_inspection.body_containsblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationCaptcha
-
Typed helper for the
managed_rule_group.rule_action_override.action_to_use.captchablock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationChallenge
-
Typed helper for the
managed_rule_group.rule_action_override.action_to_use.challengeblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationClientSideActionConfig
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_anti_ddos_rule_set.client_side_action_configblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationClientSideActionConfigChallenge
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_anti_ddos_rule_set.client_side_action_config.challengeblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationCount
-
Typed helper for the
managed_rule_group.rule_action_override.action_to_use.countblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationCustomRequestHandling
-
Typed helper for the
managed_rule_group.rule_action_override.action_to_use.allow.custom_request_handlingblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationCustomResponse
-
Typed helper for the
managed_rule_group.rule_action_override.action_to_use.block.custom_responseblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationEmailField
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.request_inspection.email_fieldblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationExemptUriRegularExpression
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_anti_ddos_rule_set.client_side_action_config.challenge.exempt_uri_regular_expressionblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationHeader
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.response_inspection.headerblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationInsertHeader
-
Typed helper for the
managed_rule_group.rule_action_override.action_to_use.allow.custom_request_handling.insert_headerblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationJson
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.response_inspection.jsonblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationManagedRuleGroup
-
Typed helper for the
managed_rule_groupblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationManagedRuleGroupConfigs
-
Typed helper for the
managed_rule_group.managed_rule_group_configsblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationPasswordField
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.request_inspection.password_fieldblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationPhoneNumberFields
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.request_inspection.phone_number_fieldsblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationResponseHeader
-
Typed helper for the
managed_rule_group.rule_action_override.action_to_use.block.custom_response.response_headerblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationResponseInspection
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.response_inspectionblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationRuleActionOverride
-
Typed helper for the
managed_rule_group.rule_action_overrideblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationRuleGroupReference
-
Typed helper for the
rule_group_referenceblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleGroupAssociationSource
-
Exactly one of
managed_rule_group,rule_group_referenceonaws_wafv2_web_acl_rule_group_association: the provider rejects none and more than one, so each variant sets one of them. - Wafv2WebAclRuleGroupAssociationSourceManagedRuleGroup
-
The Wafv2WebAclRuleGroupAssociationSource.managedRuleGroup choice: sets
managed_rule_group. - Wafv2WebAclRuleGroupAssociationSourceRuleGroupReference
-
The Wafv2WebAclRuleGroupAssociationSource.ruleGroupReference choice: sets
rule_group_reference. - Wafv2WebAclRuleGroupAssociationStatusCode
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.response_inspection.status_codeblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationUsernameField
-
Typed helper for the
managed_rule_group.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.request_inspection.username_fieldblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleGroupAssociationVisibilityConfig
-
Typed helper for the
visibility_configblock ofaws_wafv2_web_acl_rule_group_association(derived from provider schema). - Wafv2WebAclRuleHeader
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.response_inspection.headerblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleHeaderOrder
-
Typed helper for the
statement.byte_match_statement.field_to_match.header_orderblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleHeaders
-
Typed helper for the
statement.byte_match_statement.field_to_match.headersblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleHeadersMatchPattern
-
Typed helper for the
statement.byte_match_statement.field_to_match.headers.match_patternblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleImmunityTimeProperty
-
Typed helper for the
captcha_config.immunity_time_propertyblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleInsertHeader
-
Typed helper for the
action.allow.custom_request_handling.insert_headerblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleIpSetForwardedIpConfig
-
Typed helper for the
statement.ip_set_reference_statement.ip_set_forwarded_ip_configblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleIpSetReferenceStatement
-
Typed helper for the
statement.ip_set_reference_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleJa3Fingerprint
-
Typed helper for the
statement.byte_match_statement.field_to_match.ja3_fingerprintblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleJson
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.response_inspection.jsonblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleJsonBody
-
Typed helper for the
statement.byte_match_statement.field_to_match.json_bodyblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleJsonBodyMatchPattern
-
Typed helper for the
statement.byte_match_statement.field_to_match.json_body.match_patternblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleLabelMatchStatement
-
Typed helper for the
statement.label_match_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleLabelNamespace
-
Typed helper for the
statement.rate_based_statement.custom_keys.label_namespaceblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleManagedRuleGroupConfigs
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configsblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleManagedRuleGroupStatement
-
Typed helper for the
statement.managed_rule_group_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleManagedRuleGroupStatementRuleActionOverride
-
Typed helper for the
statement.managed_rule_group_statement.rule_action_overrideblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleOverrideAction
-
Typed helper for the
override_actionblock ofaws_wafv2_web_acl_rule(derived from provider schema). - Wafv2WebAclRulePasswordField
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.password_fieldblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleQueryString
-
Typed helper for the
statement.rate_based_statement.custom_keys.query_stringblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleRateBasedStatement
-
Typed helper for the
statement.rate_based_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleRegexMatchStatement
-
Typed helper for the
statement.regex_match_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleRegexPatternSetReferenceStatement
-
Typed helper for the
statement.regex_pattern_set_reference_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleResponseInspection
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.response_inspectionblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleRuleLabel
-
Typed helper for the
rule_labelblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleScopeDownStatement
-
Typed helper for the
statement.managed_rule_group_statement.scope_down_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleSizeConstraintStatement
-
Typed helper for the
statement.size_constraint_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleSqliMatchStatement
-
Typed helper for the
statement.sqli_match_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleStatement
-
Typed helper for the
statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). - Wafv2WebAclRuleStatementAndStatement
-
Typed helper for the
statement.and_statement.statement.and_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleStatementAndStatementStatement
-
Typed helper for the
statement.and_statement.statement.and_statement.statement.and_statement.statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleStatementRuleGroupReferenceStatement
-
Typed helper for the
statement.rule_group_reference_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleStatementStatement
-
Typed helper for the
statement.and_statement.statement.and_statement.statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleStatusCode
-
Typed helper for the
statement.managed_rule_group_statement.managed_rule_group_configs.aws_managed_rules_acfp_rule_set.response_inspection.status_codeblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleTextTransformation
-
Typed helper for the
statement.byte_match_statement.text_transformationblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleUriFragment
-
Typed helper for the
statement.byte_match_statement.field_to_match.uri_fragmentblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclRuleVisibilityConfig
-
Typed helper for the
visibility_configblock ofaws_wafv2_web_acl_rule(derived from provider schema). - Wafv2WebAclRuleXssMatchStatement
-
Typed helper for the
statement.xss_match_statementblock ofaws_wafv2_web_acl_rule(derived from provider schema). Shared by every block of this shape in the resource. - Wafv2WebAclVisibilityConfig
-
Typed helper for the
visibility_configblock ofaws_wafv2_web_acl(derived from provider schema).
Enums
- Wafv2ApiKeyScope
-
Wafv2 Api Key enum for
scope. - Wafv2IpSetIpAddressVersion
-
Wafv2 Ip Set Ip Address enum for
ip_address_version. - Wafv2IpSetScope
-
Wafv2 Ip Set enum for
scope. - Wafv2RegexPatternSetScope
-
Wafv2 Regex Pattern Set enum for
scope. - Wafv2RuleGroupAggregateKeyType
-
aggregate_key_type— derived from the provider schema description. - Wafv2RuleGroupScope
-
Wafv2 Rule Group enum for
scope. - Wafv2WebAclAction
-
action— derived from the provider schema description. - Wafv2WebAclFieldType
-
field_type— derived from the provider schema description. - Wafv2WebAclLoggingConfigurationAction
-
action— derived from the provider schema description. - Wafv2WebAclLoggingConfigurationBehavior
-
behavior— derived from the provider schema description. - Wafv2WebAclLoggingConfigurationDefaultBehavior
-
default_behavior— derived from the provider schema description. - Wafv2WebAclLoggingConfigurationRequirement
-
requirement— derived from the provider schema description. - Wafv2WebAclRuleGroupAssociationOverrideAction
-
Wafv2 Web Acl Rule Group Association Override enum for
override_action. - Wafv2WebAclScope
-
Wafv2 Web Acl enum for
scope.